r'''
# `datadog_powerpack`

Refer to the Terraform Registry for docs: [`datadog_powerpack`](https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack).
'''
from pkgutil import extend_path
__path__ = extend_path(__path__, __name__)

import abc
import builtins
import datetime
import enum
import typing

import jsii
import publication
import typing_extensions

import typeguard
from importlib.metadata import version as _metadata_package_version
TYPEGUARD_MAJOR_VERSION = int(_metadata_package_version('typeguard').split('.')[0])

def check_type(argname: str, value: object, expected_type: typing.Any) -> typing.Any:
    if TYPEGUARD_MAJOR_VERSION <= 2:
        return typeguard.check_type(argname=argname, value=value, expected_type=expected_type) # type:ignore
    else:
        if isinstance(value, jsii._reference_map.InterfaceDynamicProxy): # pyright: ignore [reportAttributeAccessIssue]
           pass
        else:
            if TYPEGUARD_MAJOR_VERSION == 3:
                typeguard.config.collection_check_strategy = typeguard.CollectionCheckStrategy.ALL_ITEMS # type:ignore
                typeguard.check_type(value=value, expected_type=expected_type) # type:ignore
            else:
                typeguard.check_type(value=value, expected_type=expected_type, collection_check_strategy=typeguard.CollectionCheckStrategy.ALL_ITEMS) # type:ignore

from .._jsii import *

import cdktf as _cdktf_9a9027ec
import constructs as _constructs_77d1e7e8


class Powerpack(
    _cdktf_9a9027ec.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.Powerpack",
):
    '''Represents a {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack datadog_powerpack}.'''

    def __init__(
        self,
        scope: _constructs_77d1e7e8.Construct,
        id_: builtins.str,
        *,
        description: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        layout: typing.Optional[typing.Union["PowerpackLayout", typing.Dict[builtins.str, typing.Any]]] = None,
        live_span: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
        show_title: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        tags: typing.Optional[typing.Sequence[builtins.str]] = None,
        template_variables: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackTemplateVariables", typing.Dict[builtins.str, typing.Any]]]]] = None,
        widget: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidget", typing.Dict[builtins.str, typing.Any]]]]] = None,
        connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
        count: typing.Optional[typing.Union[jsii.Number, _cdktf_9a9027ec.TerraformCount]] = None,
        depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
        for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
        lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
    ) -> None:
        '''Create a new {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack datadog_powerpack} Resource.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param description: The description of the powerpack. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#description Powerpack#description}
        :param id: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#id Powerpack#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param layout: layout block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#layout Powerpack#layout}
        :param live_span: The timeframe to use when displaying the widget. Valid values are ``1m``, ``5m``, ``10m``, ``15m``, ``30m``, ``1h``, ``4h``, ``1d``, ``2d``, ``1w``, ``1mo``, ``3mo``, ``6mo``, ``week_to_date``, ``month_to_date``, ``1y``, ``alert``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#live_span Powerpack#live_span}
        :param name: The name for the powerpack. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param show_title: Whether or not title should be displayed in the powerpack. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#show_title Powerpack#show_title}
        :param tags: List of tags to identify this powerpack. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#tags Powerpack#tags}
        :param template_variables: template_variables block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#template_variables Powerpack#template_variables}
        :param widget: widget block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#widget Powerpack#widget}
        :param connection: 
        :param count: 
        :param depends_on: 
        :param for_each: 
        :param lifecycle: 
        :param provider: 
        :param provisioners: 
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__682e86bb24811a148a4f3d2258896bcb6b6b65244baeeb92ad850ec956824c12)
            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
            check_type(argname="argument id_", value=id_, expected_type=type_hints["id_"])
        config = PowerpackConfig(
            description=description,
            id=id,
            layout=layout,
            live_span=live_span,
            name=name,
            show_title=show_title,
            tags=tags,
            template_variables=template_variables,
            widget=widget,
            connection=connection,
            count=count,
            depends_on=depends_on,
            for_each=for_each,
            lifecycle=lifecycle,
            provider=provider,
            provisioners=provisioners,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="generateConfigForImport")
    @builtins.classmethod
    def generate_config_for_import(
        cls,
        scope: _constructs_77d1e7e8.Construct,
        import_to_id: builtins.str,
        import_from_id: builtins.str,
        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
    ) -> _cdktf_9a9027ec.ImportableResource:
        '''Generates CDKTF code for importing a Powerpack resource upon running "cdktf plan ".

        :param scope: The scope in which to define this construct.
        :param import_to_id: The construct id used in the generated config for the Powerpack to import.
        :param import_from_id: The id of the existing Powerpack that should be imported. Refer to the {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#import import section} in the documentation of this resource for the id to use
        :param provider: ? Optional instance of the provider where the Powerpack to import is found.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__769f6e4b5b2e096f135c1862b0c8aa8519be9edd36cc36703c1430b06dc9c7e7)
            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
            check_type(argname="argument import_to_id", value=import_to_id, expected_type=type_hints["import_to_id"])
            check_type(argname="argument import_from_id", value=import_from_id, expected_type=type_hints["import_from_id"])
            check_type(argname="argument provider", value=provider, expected_type=type_hints["provider"])
        return typing.cast(_cdktf_9a9027ec.ImportableResource, jsii.sinvoke(cls, "generateConfigForImport", [scope, import_to_id, import_from_id, provider]))

    @jsii.member(jsii_name="putLayout")
    def put_layout(
        self,
        *,
        height: typing.Optional[jsii.Number] = None,
        width: typing.Optional[jsii.Number] = None,
        x: typing.Optional[jsii.Number] = None,
        y: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param height: The height of the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#height Powerpack#height}
        :param width: The width of the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#width Powerpack#width}
        :param x: The position of the widget on the x (horizontal) axis. Should be greater than or equal to 0. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#x Powerpack#x}
        :param y: The position of the widget on the y (vertical) axis. Should be greater than or equal to 0. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#y Powerpack#y}
        '''
        value = PowerpackLayout(height=height, width=width, x=x, y=y)

        return typing.cast(None, jsii.invoke(self, "putLayout", [value]))

    @jsii.member(jsii_name="putTemplateVariables")
    def put_template_variables(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackTemplateVariables", typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__33bf8aaca41d90e63e9f653ec0be43a79662a8f3784fb655ed349e97b7e9ae57)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putTemplateVariables", [value]))

    @jsii.member(jsii_name="putWidget")
    def put_widget(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidget", typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__586eba0121f83088a3bff0bf9b1691ab26904ec68a88857d9a09146ced02cec4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putWidget", [value]))

    @jsii.member(jsii_name="resetDescription")
    def reset_description(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDescription", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetLayout")
    def reset_layout(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLayout", []))

    @jsii.member(jsii_name="resetLiveSpan")
    def reset_live_span(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLiveSpan", []))

    @jsii.member(jsii_name="resetName")
    def reset_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetName", []))

    @jsii.member(jsii_name="resetShowTitle")
    def reset_show_title(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetShowTitle", []))

    @jsii.member(jsii_name="resetTags")
    def reset_tags(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTags", []))

    @jsii.member(jsii_name="resetTemplateVariables")
    def reset_template_variables(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTemplateVariables", []))

    @jsii.member(jsii_name="resetWidget")
    def reset_widget(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetWidget", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.member(jsii_name="synthesizeHclAttributes")
    def _synthesize_hcl_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeHclAttributes", []))

    @jsii.python.classproperty
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property
    @jsii.member(jsii_name="layout")
    def layout(self) -> "PowerpackLayoutOutputReference":
        return typing.cast("PowerpackLayoutOutputReference", jsii.get(self, "layout"))

    @builtins.property
    @jsii.member(jsii_name="templateVariables")
    def template_variables(self) -> "PowerpackTemplateVariablesList":
        return typing.cast("PowerpackTemplateVariablesList", jsii.get(self, "templateVariables"))

    @builtins.property
    @jsii.member(jsii_name="widget")
    def widget(self) -> "PowerpackWidgetList":
        return typing.cast("PowerpackWidgetList", jsii.get(self, "widget"))

    @builtins.property
    @jsii.member(jsii_name="descriptionInput")
    def description_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "descriptionInput"))

    @builtins.property
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property
    @jsii.member(jsii_name="layoutInput")
    def layout_input(self) -> typing.Optional["PowerpackLayout"]:
        return typing.cast(typing.Optional["PowerpackLayout"], jsii.get(self, "layoutInput"))

    @builtins.property
    @jsii.member(jsii_name="liveSpanInput")
    def live_span_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "liveSpanInput"))

    @builtins.property
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property
    @jsii.member(jsii_name="showTitleInput")
    def show_title_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "showTitleInput"))

    @builtins.property
    @jsii.member(jsii_name="tagsInput")
    def tags_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "tagsInput"))

    @builtins.property
    @jsii.member(jsii_name="templateVariablesInput")
    def template_variables_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackTemplateVariables"]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackTemplateVariables"]]], jsii.get(self, "templateVariablesInput"))

    @builtins.property
    @jsii.member(jsii_name="widgetInput")
    def widget_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidget"]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidget"]]], jsii.get(self, "widgetInput"))

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @description.setter
    def description(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b18eedd7d3ea102263036e3effb020b05e5e170d7f6c11fa86d74effb469d3b2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "description", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d742c88ede505c5f7af19f871f9da0fee0a8f7766a8a40a1cc7870842da740fb)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "id", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="liveSpan")
    def live_span(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "liveSpan"))

    @live_span.setter
    def live_span(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c05f13c680dd58c84ed44f09347cc999b8d3d66441b2416cc28a941adb741f42)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "liveSpan", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e2727b37dd96b0c1e3f665a43aaeaa191dcb0eb370c486ceec26c4e0e780704a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "name", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="showTitle")
    def show_title(self) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "showTitle"))

    @show_title.setter
    def show_title(
        self,
        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d7c1e59b50f775f0125266056c7acf2b11485a0527a8caabae814ca68c813a2d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "showTitle", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "tags"))

    @tags.setter
    def tags(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5c2b3b25ee374a5ac2ab60dc1ce5b5eca5a9b6843f451c5298855b1540c4779a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "tags", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackConfig",
    jsii_struct_bases=[_cdktf_9a9027ec.TerraformMetaArguments],
    name_mapping={
        "connection": "connection",
        "count": "count",
        "depends_on": "dependsOn",
        "for_each": "forEach",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "provisioners": "provisioners",
        "description": "description",
        "id": "id",
        "layout": "layout",
        "live_span": "liveSpan",
        "name": "name",
        "show_title": "showTitle",
        "tags": "tags",
        "template_variables": "templateVariables",
        "widget": "widget",
    },
)
class PowerpackConfig(_cdktf_9a9027ec.TerraformMetaArguments):
    def __init__(
        self,
        *,
        connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
        count: typing.Optional[typing.Union[jsii.Number, _cdktf_9a9027ec.TerraformCount]] = None,
        depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
        for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
        lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
        description: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        layout: typing.Optional[typing.Union["PowerpackLayout", typing.Dict[builtins.str, typing.Any]]] = None,
        live_span: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
        show_title: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        tags: typing.Optional[typing.Sequence[builtins.str]] = None,
        template_variables: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackTemplateVariables", typing.Dict[builtins.str, typing.Any]]]]] = None,
        widget: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidget", typing.Dict[builtins.str, typing.Any]]]]] = None,
    ) -> None:
        '''
        :param connection: 
        :param count: 
        :param depends_on: 
        :param for_each: 
        :param lifecycle: 
        :param provider: 
        :param provisioners: 
        :param description: The description of the powerpack. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#description Powerpack#description}
        :param id: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#id Powerpack#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param layout: layout block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#layout Powerpack#layout}
        :param live_span: The timeframe to use when displaying the widget. Valid values are ``1m``, ``5m``, ``10m``, ``15m``, ``30m``, ``1h``, ``4h``, ``1d``, ``2d``, ``1w``, ``1mo``, ``3mo``, ``6mo``, ``week_to_date``, ``month_to_date``, ``1y``, ``alert``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#live_span Powerpack#live_span}
        :param name: The name for the powerpack. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param show_title: Whether or not title should be displayed in the powerpack. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#show_title Powerpack#show_title}
        :param tags: List of tags to identify this powerpack. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#tags Powerpack#tags}
        :param template_variables: template_variables block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#template_variables Powerpack#template_variables}
        :param widget: widget block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#widget Powerpack#widget}
        '''
        if isinstance(lifecycle, dict):
            lifecycle = _cdktf_9a9027ec.TerraformResourceLifecycle(**lifecycle)
        if isinstance(layout, dict):
            layout = PowerpackLayout(**layout)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__02799c950872d76d53d9e8b056f17223ca02fca5411e5f4e108a412d13a6c7a1)
            check_type(argname="argument connection", value=connection, expected_type=type_hints["connection"])
            check_type(argname="argument count", value=count, expected_type=type_hints["count"])
            check_type(argname="argument depends_on", value=depends_on, expected_type=type_hints["depends_on"])
            check_type(argname="argument for_each", value=for_each, expected_type=type_hints["for_each"])
            check_type(argname="argument lifecycle", value=lifecycle, expected_type=type_hints["lifecycle"])
            check_type(argname="argument provider", value=provider, expected_type=type_hints["provider"])
            check_type(argname="argument provisioners", value=provisioners, expected_type=type_hints["provisioners"])
            check_type(argname="argument description", value=description, expected_type=type_hints["description"])
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
            check_type(argname="argument layout", value=layout, expected_type=type_hints["layout"])
            check_type(argname="argument live_span", value=live_span, expected_type=type_hints["live_span"])
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument show_title", value=show_title, expected_type=type_hints["show_title"])
            check_type(argname="argument tags", value=tags, expected_type=type_hints["tags"])
            check_type(argname="argument template_variables", value=template_variables, expected_type=type_hints["template_variables"])
            check_type(argname="argument widget", value=widget, expected_type=type_hints["widget"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if connection is not None:
            self._values["connection"] = connection
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if for_each is not None:
            self._values["for_each"] = for_each
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if provisioners is not None:
            self._values["provisioners"] = provisioners
        if description is not None:
            self._values["description"] = description
        if id is not None:
            self._values["id"] = id
        if layout is not None:
            self._values["layout"] = layout
        if live_span is not None:
            self._values["live_span"] = live_span
        if name is not None:
            self._values["name"] = name
        if show_title is not None:
            self._values["show_title"] = show_title
        if tags is not None:
            self._values["tags"] = tags
        if template_variables is not None:
            self._values["template_variables"] = template_variables
        if widget is not None:
            self._values["widget"] = widget

    @builtins.property
    def connection(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, _cdktf_9a9027ec.WinrmProvisionerConnection]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("connection")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, _cdktf_9a9027ec.WinrmProvisionerConnection]], result)

    @builtins.property
    def count(
        self,
    ) -> typing.Optional[typing.Union[jsii.Number, _cdktf_9a9027ec.TerraformCount]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[typing.Union[jsii.Number, _cdktf_9a9027ec.TerraformCount]], result)

    @builtins.property
    def depends_on(
        self,
    ) -> typing.Optional[typing.List[_cdktf_9a9027ec.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[_cdktf_9a9027ec.ITerraformDependable]], result)

    @builtins.property
    def for_each(self) -> typing.Optional[_cdktf_9a9027ec.ITerraformIterator]:
        '''
        :stability: experimental
        '''
        result = self._values.get("for_each")
        return typing.cast(typing.Optional[_cdktf_9a9027ec.ITerraformIterator], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[_cdktf_9a9027ec.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[_cdktf_9a9027ec.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[_cdktf_9a9027ec.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[_cdktf_9a9027ec.TerraformProvider], result)

    @builtins.property
    def provisioners(
        self,
    ) -> typing.Optional[typing.List[typing.Union[_cdktf_9a9027ec.FileProvisioner, _cdktf_9a9027ec.LocalExecProvisioner, _cdktf_9a9027ec.RemoteExecProvisioner]]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provisioners")
        return typing.cast(typing.Optional[typing.List[typing.Union[_cdktf_9a9027ec.FileProvisioner, _cdktf_9a9027ec.LocalExecProvisioner, _cdktf_9a9027ec.RemoteExecProvisioner]]], result)

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        '''The description of the powerpack.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#description Powerpack#description}
        '''
        result = self._values.get("description")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#id Powerpack#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def layout(self) -> typing.Optional["PowerpackLayout"]:
        '''layout block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#layout Powerpack#layout}
        '''
        result = self._values.get("layout")
        return typing.cast(typing.Optional["PowerpackLayout"], result)

    @builtins.property
    def live_span(self) -> typing.Optional[builtins.str]:
        '''The timeframe to use when displaying the widget.

        Valid values are ``1m``, ``5m``, ``10m``, ``15m``, ``30m``, ``1h``, ``4h``, ``1d``, ``2d``, ``1w``, ``1mo``, ``3mo``, ``6mo``, ``week_to_date``, ``month_to_date``, ``1y``, ``alert``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#live_span Powerpack#live_span}
        '''
        result = self._values.get("live_span")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''The name for the powerpack.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        '''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def show_title(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        '''Whether or not title should be displayed in the powerpack.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#show_title Powerpack#show_title}
        '''
        result = self._values.get("show_title")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)

    @builtins.property
    def tags(self) -> typing.Optional[typing.List[builtins.str]]:
        '''List of tags to identify this powerpack.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#tags Powerpack#tags}
        '''
        result = self._values.get("tags")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def template_variables(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackTemplateVariables"]]]:
        '''template_variables block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#template_variables Powerpack#template_variables}
        '''
        result = self._values.get("template_variables")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackTemplateVariables"]]], result)

    @builtins.property
    def widget(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidget"]]]:
        '''widget block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#widget Powerpack#widget}
        '''
        result = self._values.get("widget")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidget"]]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackLayout",
    jsii_struct_bases=[],
    name_mapping={"height": "height", "width": "width", "x": "x", "y": "y"},
)
class PowerpackLayout:
    def __init__(
        self,
        *,
        height: typing.Optional[jsii.Number] = None,
        width: typing.Optional[jsii.Number] = None,
        x: typing.Optional[jsii.Number] = None,
        y: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param height: The height of the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#height Powerpack#height}
        :param width: The width of the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#width Powerpack#width}
        :param x: The position of the widget on the x (horizontal) axis. Should be greater than or equal to 0. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#x Powerpack#x}
        :param y: The position of the widget on the y (vertical) axis. Should be greater than or equal to 0. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#y Powerpack#y}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__10da6775a4e3e9b1a841407c6d50f21ffb0f12d1706dea3aa4b13250357ac0f6)
            check_type(argname="argument height", value=height, expected_type=type_hints["height"])
            check_type(argname="argument width", value=width, expected_type=type_hints["width"])
            check_type(argname="argument x", value=x, expected_type=type_hints["x"])
            check_type(argname="argument y", value=y, expected_type=type_hints["y"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if height is not None:
            self._values["height"] = height
        if width is not None:
            self._values["width"] = width
        if x is not None:
            self._values["x"] = x
        if y is not None:
            self._values["y"] = y

    @builtins.property
    def height(self) -> typing.Optional[jsii.Number]:
        '''The height of the widget.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#height Powerpack#height}
        '''
        result = self._values.get("height")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def width(self) -> typing.Optional[jsii.Number]:
        '''The width of the widget.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#width Powerpack#width}
        '''
        result = self._values.get("width")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def x(self) -> typing.Optional[jsii.Number]:
        '''The position of the widget on the x (horizontal) axis. Should be greater than or equal to 0.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#x Powerpack#x}
        '''
        result = self._values.get("x")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def y(self) -> typing.Optional[jsii.Number]:
        '''The position of the widget on the y (vertical) axis. Should be greater than or equal to 0.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#y Powerpack#y}
        '''
        result = self._values.get("y")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackLayout(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackLayoutOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackLayoutOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__06b9ed18faf691fe8674c9bf3bab45d393894a30d3d141d4702ed7f54ea1a563)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetHeight")
    def reset_height(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHeight", []))

    @jsii.member(jsii_name="resetWidth")
    def reset_width(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetWidth", []))

    @jsii.member(jsii_name="resetX")
    def reset_x(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetX", []))

    @jsii.member(jsii_name="resetY")
    def reset_y(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetY", []))

    @builtins.property
    @jsii.member(jsii_name="heightInput")
    def height_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "heightInput"))

    @builtins.property
    @jsii.member(jsii_name="widthInput")
    def width_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "widthInput"))

    @builtins.property
    @jsii.member(jsii_name="xInput")
    def x_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "xInput"))

    @builtins.property
    @jsii.member(jsii_name="yInput")
    def y_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "yInput"))

    @builtins.property
    @jsii.member(jsii_name="height")
    def height(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "height"))

    @height.setter
    def height(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__51ab0dd873b13757ba2f45664155cd48eebc85fccf6eba2c2d067cc431cd6190)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "height", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="width")
    def width(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "width"))

    @width.setter
    def width(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3c1eef5882a88dcc859b05b920148eb696f68d5667307837bf823bbffd360424)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "width", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="x")
    def x(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "x"))

    @x.setter
    def x(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6134b612b36fd2ce55362392b87db95c455f4aa9b4119f4ffdc3cc2b9a5a6813)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "x", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="y")
    def y(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "y"))

    @y.setter
    def y(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3b6c85e775d78d59b6a6d62ec97416b102c45e6ab11e9c15617f9d312b4f7b4c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "y", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[PowerpackLayout]:
        return typing.cast(typing.Optional[PowerpackLayout], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(self, value: typing.Optional[PowerpackLayout]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__96f8547ba0dae2a6381c1346183eb94e5ab2ef9c354c0d8662ba60e2e277bb61)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackTemplateVariables",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "defaults": "defaults"},
)
class PowerpackTemplateVariables:
    def __init__(
        self,
        *,
        name: builtins.str,
        defaults: typing.Optional[typing.Sequence[builtins.str]] = None,
    ) -> None:
        '''
        :param name: The name of the powerpack template variable. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param defaults: One or many default values for powerpack template variables on load. If more than one default is specified, they will be unioned together with ``OR``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#defaults Powerpack#defaults}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e7601857687ea35f174ca5fab4b1ce23bdd159a676a4f17789b3dc35e371898f)
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument defaults", value=defaults, expected_type=type_hints["defaults"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "name": name,
        }
        if defaults is not None:
            self._values["defaults"] = defaults

    @builtins.property
    def name(self) -> builtins.str:
        '''The name of the powerpack template variable.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        '''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def defaults(self) -> typing.Optional[typing.List[builtins.str]]:
        '''One or many default values for powerpack template variables on load.

        If more than one default is specified, they will be unioned together with ``OR``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#defaults Powerpack#defaults}
        '''
        result = self._values.get("defaults")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackTemplateVariables(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackTemplateVariablesList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackTemplateVariablesList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1663087723d07187d17abe814a5c8c49c54e847572ac2bf3fffc1f60447dc9f7)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(self, index: jsii.Number) -> "PowerpackTemplateVariablesOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fb8162b221b3cc24ed26ebaa4866adcab7c792c7e29a2a3852255c84279da53a)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackTemplateVariablesOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__573bc00a3dc9fd13149ead45ead220c2d825079ea922ffa2c2d372f51d60b516)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ff6200c5abdbdfc8cb4cfea66cd304478f348634886b5b28659eda6a6e5dab63)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__26f9ac5f3e7d0c5083be230d798068391a92ed54b65c1b2c8e3757f58556d3d9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackTemplateVariables]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackTemplateVariables]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackTemplateVariables]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d53297c7cd8e100cada0f1c60809002531c54779032ad45a941a8205da3f1899)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackTemplateVariablesOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackTemplateVariablesOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a8f550005c8af583e1981cc10c0c3da2d09ec2b7c873aaef5ba613c2004d1ae9)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetDefaults")
    def reset_defaults(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDefaults", []))

    @builtins.property
    @jsii.member(jsii_name="defaultsInput")
    def defaults_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "defaultsInput"))

    @builtins.property
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property
    @jsii.member(jsii_name="defaults")
    def defaults(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "defaults"))

    @defaults.setter
    def defaults(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cc5fe0d98510831c3fc7ec6ad32411cc561c779da427be5ef13c5c56e4bc55ff)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "defaults", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e259029a48542cdd63a3f74ca5cd86d25cdb3f27ea4621ecf8cfd725280f201b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "name", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackTemplateVariables]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackTemplateVariables]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackTemplateVariables]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__005e0426567a46d9304ec4d49b3c56ae480b7a64f7048f5f3cae9ce1bb07aaec)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidget",
    jsii_struct_bases=[],
    name_mapping={
        "alert_graph_definition": "alertGraphDefinition",
        "alert_value_definition": "alertValueDefinition",
        "change_definition": "changeDefinition",
        "check_status_definition": "checkStatusDefinition",
        "distribution_definition": "distributionDefinition",
        "event_stream_definition": "eventStreamDefinition",
        "event_timeline_definition": "eventTimelineDefinition",
        "free_text_definition": "freeTextDefinition",
        "geomap_definition": "geomapDefinition",
        "heatmap_definition": "heatmapDefinition",
        "hostmap_definition": "hostmapDefinition",
        "iframe_definition": "iframeDefinition",
        "image_definition": "imageDefinition",
        "list_stream_definition": "listStreamDefinition",
        "log_stream_definition": "logStreamDefinition",
        "manage_status_definition": "manageStatusDefinition",
        "note_definition": "noteDefinition",
        "query_table_definition": "queryTableDefinition",
        "query_value_definition": "queryValueDefinition",
        "run_workflow_definition": "runWorkflowDefinition",
        "scatterplot_definition": "scatterplotDefinition",
        "service_level_objective_definition": "serviceLevelObjectiveDefinition",
        "servicemap_definition": "servicemapDefinition",
        "slo_list_definition": "sloListDefinition",
        "sunburst_definition": "sunburstDefinition",
        "timeseries_definition": "timeseriesDefinition",
        "toplist_definition": "toplistDefinition",
        "topology_map_definition": "topologyMapDefinition",
        "trace_service_definition": "traceServiceDefinition",
        "treemap_definition": "treemapDefinition",
        "widget_layout": "widgetLayout",
    },
)
class PowerpackWidget:
    def __init__(
        self,
        *,
        alert_graph_definition: typing.Optional[typing.Union["PowerpackWidgetAlertGraphDefinition", typing.Dict[builtins.str, typing.Any]]] = None,
        alert_value_definition: typing.Optional[typing.Union["PowerpackWidgetAlertValueDefinition", typing.Dict[builtins.str, typing.Any]]] = None,
        change_definition: typing.Optional[typing.Union["PowerpackWidgetChangeDefinition", typing.Dict[builtins.str, typing.Any]]] = None,
        check_status_definition: typing.Optional[typing.Union["PowerpackWidgetCheckStatusDefinition", typing.Dict[builtins.str, typing.Any]]] = None,
        distribution_definition: typing.Optional[typing.Union["PowerpackWidgetDistributionDefinition", typing.Dict[builtins.str, typing.Any]]] = None,
        event_stream_definition: typing.Optional[typing.Union["PowerpackWidgetEventStreamDefinition", typing.Dict[builtins.str, typing.Any]]] = None,
        event_timeline_definition: typing.Optional[typing.Union["PowerpackWidgetEventTimelineDefinition", typing.Dict[builtins.str, typing.Any]]] = None,
        free_text_definition: typing.Optional[typing.Union["PowerpackWidgetFreeTextDefinition", typing.Dict[builtins.str, typing.Any]]] = None,
        geomap_definition: typing.Optional[typing.Union["PowerpackWidgetGeomapDefinition", typing.Dict[builtins.str, typing.Any]]] = None,
        heatmap_definition: typing.Optional[typing.Union["PowerpackWidgetHeatmapDefinition", typing.Dict[builtins.str, typing.Any]]] = None,
        hostmap_definition: typing.Optional[typing.Union["PowerpackWidgetHostmapDefinition", typing.Dict[builtins.str, typing.Any]]] = None,
        iframe_definition: typing.Optional[typing.Union["PowerpackWidgetIframeDefinition", typing.Dict[builtins.str, typing.Any]]] = None,
        image_definition: typing.Optional[typing.Union["PowerpackWidgetImageDefinition", typing.Dict[builtins.str, typing.Any]]] = None,
        list_stream_definition: typing.Optional[typing.Union["PowerpackWidgetListStreamDefinition", typing.Dict[builtins.str, typing.Any]]] = None,
        log_stream_definition: typing.Optional[typing.Union["PowerpackWidgetLogStreamDefinition", typing.Dict[builtins.str, typing.Any]]] = None,
        manage_status_definition: typing.Optional[typing.Union["PowerpackWidgetManageStatusDefinition", typing.Dict[builtins.str, typing.Any]]] = None,
        note_definition: typing.Optional[typing.Union["PowerpackWidgetNoteDefinition", typing.Dict[builtins.str, typing.Any]]] = None,
        query_table_definition: typing.Optional[typing.Union["PowerpackWidgetQueryTableDefinition", typing.Dict[builtins.str, typing.Any]]] = None,
        query_value_definition: typing.Optional[typing.Union["PowerpackWidgetQueryValueDefinition", typing.Dict[builtins.str, typing.Any]]] = None,
        run_workflow_definition: typing.Optional[typing.Union["PowerpackWidgetRunWorkflowDefinition", typing.Dict[builtins.str, typing.Any]]] = None,
        scatterplot_definition: typing.Optional[typing.Union["PowerpackWidgetScatterplotDefinition", typing.Dict[builtins.str, typing.Any]]] = None,
        service_level_objective_definition: typing.Optional[typing.Union["PowerpackWidgetServiceLevelObjectiveDefinition", typing.Dict[builtins.str, typing.Any]]] = None,
        servicemap_definition: typing.Optional[typing.Union["PowerpackWidgetServicemapDefinition", typing.Dict[builtins.str, typing.Any]]] = None,
        slo_list_definition: typing.Optional[typing.Union["PowerpackWidgetSloListDefinition", typing.Dict[builtins.str, typing.Any]]] = None,
        sunburst_definition: typing.Optional[typing.Union["PowerpackWidgetSunburstDefinition", typing.Dict[builtins.str, typing.Any]]] = None,
        timeseries_definition: typing.Optional[typing.Union["PowerpackWidgetTimeseriesDefinition", typing.Dict[builtins.str, typing.Any]]] = None,
        toplist_definition: typing.Optional[typing.Union["PowerpackWidgetToplistDefinition", typing.Dict[builtins.str, typing.Any]]] = None,
        topology_map_definition: typing.Optional[typing.Union["PowerpackWidgetTopologyMapDefinition", typing.Dict[builtins.str, typing.Any]]] = None,
        trace_service_definition: typing.Optional[typing.Union["PowerpackWidgetTraceServiceDefinition", typing.Dict[builtins.str, typing.Any]]] = None,
        treemap_definition: typing.Optional[typing.Union["PowerpackWidgetTreemapDefinition", typing.Dict[builtins.str, typing.Any]]] = None,
        widget_layout: typing.Optional[typing.Union["PowerpackWidgetWidgetLayout", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param alert_graph_definition: alert_graph_definition block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#alert_graph_definition Powerpack#alert_graph_definition}
        :param alert_value_definition: alert_value_definition block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#alert_value_definition Powerpack#alert_value_definition}
        :param change_definition: change_definition block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#change_definition Powerpack#change_definition}
        :param check_status_definition: check_status_definition block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#check_status_definition Powerpack#check_status_definition}
        :param distribution_definition: distribution_definition block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#distribution_definition Powerpack#distribution_definition}
        :param event_stream_definition: event_stream_definition block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#event_stream_definition Powerpack#event_stream_definition}
        :param event_timeline_definition: event_timeline_definition block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#event_timeline_definition Powerpack#event_timeline_definition}
        :param free_text_definition: free_text_definition block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#free_text_definition Powerpack#free_text_definition}
        :param geomap_definition: geomap_definition block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#geomap_definition Powerpack#geomap_definition}
        :param heatmap_definition: heatmap_definition block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#heatmap_definition Powerpack#heatmap_definition}
        :param hostmap_definition: hostmap_definition block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#hostmap_definition Powerpack#hostmap_definition}
        :param iframe_definition: iframe_definition block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#iframe_definition Powerpack#iframe_definition}
        :param image_definition: image_definition block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#image_definition Powerpack#image_definition}
        :param list_stream_definition: list_stream_definition block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#list_stream_definition Powerpack#list_stream_definition}
        :param log_stream_definition: log_stream_definition block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#log_stream_definition Powerpack#log_stream_definition}
        :param manage_status_definition: manage_status_definition block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#manage_status_definition Powerpack#manage_status_definition}
        :param note_definition: note_definition block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#note_definition Powerpack#note_definition}
        :param query_table_definition: query_table_definition block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query_table_definition Powerpack#query_table_definition}
        :param query_value_definition: query_value_definition block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query_value_definition Powerpack#query_value_definition}
        :param run_workflow_definition: run_workflow_definition block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#run_workflow_definition Powerpack#run_workflow_definition}
        :param scatterplot_definition: scatterplot_definition block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#scatterplot_definition Powerpack#scatterplot_definition}
        :param service_level_objective_definition: service_level_objective_definition block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#service_level_objective_definition Powerpack#service_level_objective_definition}
        :param servicemap_definition: servicemap_definition block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#servicemap_definition Powerpack#servicemap_definition}
        :param slo_list_definition: slo_list_definition block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#slo_list_definition Powerpack#slo_list_definition}
        :param sunburst_definition: sunburst_definition block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sunburst_definition Powerpack#sunburst_definition}
        :param timeseries_definition: timeseries_definition block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#timeseries_definition Powerpack#timeseries_definition}
        :param toplist_definition: toplist_definition block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#toplist_definition Powerpack#toplist_definition}
        :param topology_map_definition: topology_map_definition block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#topology_map_definition Powerpack#topology_map_definition}
        :param trace_service_definition: trace_service_definition block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#trace_service_definition Powerpack#trace_service_definition}
        :param treemap_definition: treemap_definition block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#treemap_definition Powerpack#treemap_definition}
        :param widget_layout: widget_layout block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#widget_layout Powerpack#widget_layout}
        '''
        if isinstance(alert_graph_definition, dict):
            alert_graph_definition = PowerpackWidgetAlertGraphDefinition(**alert_graph_definition)
        if isinstance(alert_value_definition, dict):
            alert_value_definition = PowerpackWidgetAlertValueDefinition(**alert_value_definition)
        if isinstance(change_definition, dict):
            change_definition = PowerpackWidgetChangeDefinition(**change_definition)
        if isinstance(check_status_definition, dict):
            check_status_definition = PowerpackWidgetCheckStatusDefinition(**check_status_definition)
        if isinstance(distribution_definition, dict):
            distribution_definition = PowerpackWidgetDistributionDefinition(**distribution_definition)
        if isinstance(event_stream_definition, dict):
            event_stream_definition = PowerpackWidgetEventStreamDefinition(**event_stream_definition)
        if isinstance(event_timeline_definition, dict):
            event_timeline_definition = PowerpackWidgetEventTimelineDefinition(**event_timeline_definition)
        if isinstance(free_text_definition, dict):
            free_text_definition = PowerpackWidgetFreeTextDefinition(**free_text_definition)
        if isinstance(geomap_definition, dict):
            geomap_definition = PowerpackWidgetGeomapDefinition(**geomap_definition)
        if isinstance(heatmap_definition, dict):
            heatmap_definition = PowerpackWidgetHeatmapDefinition(**heatmap_definition)
        if isinstance(hostmap_definition, dict):
            hostmap_definition = PowerpackWidgetHostmapDefinition(**hostmap_definition)
        if isinstance(iframe_definition, dict):
            iframe_definition = PowerpackWidgetIframeDefinition(**iframe_definition)
        if isinstance(image_definition, dict):
            image_definition = PowerpackWidgetImageDefinition(**image_definition)
        if isinstance(list_stream_definition, dict):
            list_stream_definition = PowerpackWidgetListStreamDefinition(**list_stream_definition)
        if isinstance(log_stream_definition, dict):
            log_stream_definition = PowerpackWidgetLogStreamDefinition(**log_stream_definition)
        if isinstance(manage_status_definition, dict):
            manage_status_definition = PowerpackWidgetManageStatusDefinition(**manage_status_definition)
        if isinstance(note_definition, dict):
            note_definition = PowerpackWidgetNoteDefinition(**note_definition)
        if isinstance(query_table_definition, dict):
            query_table_definition = PowerpackWidgetQueryTableDefinition(**query_table_definition)
        if isinstance(query_value_definition, dict):
            query_value_definition = PowerpackWidgetQueryValueDefinition(**query_value_definition)
        if isinstance(run_workflow_definition, dict):
            run_workflow_definition = PowerpackWidgetRunWorkflowDefinition(**run_workflow_definition)
        if isinstance(scatterplot_definition, dict):
            scatterplot_definition = PowerpackWidgetScatterplotDefinition(**scatterplot_definition)
        if isinstance(service_level_objective_definition, dict):
            service_level_objective_definition = PowerpackWidgetServiceLevelObjectiveDefinition(**service_level_objective_definition)
        if isinstance(servicemap_definition, dict):
            servicemap_definition = PowerpackWidgetServicemapDefinition(**servicemap_definition)
        if isinstance(slo_list_definition, dict):
            slo_list_definition = PowerpackWidgetSloListDefinition(**slo_list_definition)
        if isinstance(sunburst_definition, dict):
            sunburst_definition = PowerpackWidgetSunburstDefinition(**sunburst_definition)
        if isinstance(timeseries_definition, dict):
            timeseries_definition = PowerpackWidgetTimeseriesDefinition(**timeseries_definition)
        if isinstance(toplist_definition, dict):
            toplist_definition = PowerpackWidgetToplistDefinition(**toplist_definition)
        if isinstance(topology_map_definition, dict):
            topology_map_definition = PowerpackWidgetTopologyMapDefinition(**topology_map_definition)
        if isinstance(trace_service_definition, dict):
            trace_service_definition = PowerpackWidgetTraceServiceDefinition(**trace_service_definition)
        if isinstance(treemap_definition, dict):
            treemap_definition = PowerpackWidgetTreemapDefinition(**treemap_definition)
        if isinstance(widget_layout, dict):
            widget_layout = PowerpackWidgetWidgetLayout(**widget_layout)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e3a85f435536b9b174f7093c6eb1e94738a36cc6203eba45901a3cab0e88a745)
            check_type(argname="argument alert_graph_definition", value=alert_graph_definition, expected_type=type_hints["alert_graph_definition"])
            check_type(argname="argument alert_value_definition", value=alert_value_definition, expected_type=type_hints["alert_value_definition"])
            check_type(argname="argument change_definition", value=change_definition, expected_type=type_hints["change_definition"])
            check_type(argname="argument check_status_definition", value=check_status_definition, expected_type=type_hints["check_status_definition"])
            check_type(argname="argument distribution_definition", value=distribution_definition, expected_type=type_hints["distribution_definition"])
            check_type(argname="argument event_stream_definition", value=event_stream_definition, expected_type=type_hints["event_stream_definition"])
            check_type(argname="argument event_timeline_definition", value=event_timeline_definition, expected_type=type_hints["event_timeline_definition"])
            check_type(argname="argument free_text_definition", value=free_text_definition, expected_type=type_hints["free_text_definition"])
            check_type(argname="argument geomap_definition", value=geomap_definition, expected_type=type_hints["geomap_definition"])
            check_type(argname="argument heatmap_definition", value=heatmap_definition, expected_type=type_hints["heatmap_definition"])
            check_type(argname="argument hostmap_definition", value=hostmap_definition, expected_type=type_hints["hostmap_definition"])
            check_type(argname="argument iframe_definition", value=iframe_definition, expected_type=type_hints["iframe_definition"])
            check_type(argname="argument image_definition", value=image_definition, expected_type=type_hints["image_definition"])
            check_type(argname="argument list_stream_definition", value=list_stream_definition, expected_type=type_hints["list_stream_definition"])
            check_type(argname="argument log_stream_definition", value=log_stream_definition, expected_type=type_hints["log_stream_definition"])
            check_type(argname="argument manage_status_definition", value=manage_status_definition, expected_type=type_hints["manage_status_definition"])
            check_type(argname="argument note_definition", value=note_definition, expected_type=type_hints["note_definition"])
            check_type(argname="argument query_table_definition", value=query_table_definition, expected_type=type_hints["query_table_definition"])
            check_type(argname="argument query_value_definition", value=query_value_definition, expected_type=type_hints["query_value_definition"])
            check_type(argname="argument run_workflow_definition", value=run_workflow_definition, expected_type=type_hints["run_workflow_definition"])
            check_type(argname="argument scatterplot_definition", value=scatterplot_definition, expected_type=type_hints["scatterplot_definition"])
            check_type(argname="argument service_level_objective_definition", value=service_level_objective_definition, expected_type=type_hints["service_level_objective_definition"])
            check_type(argname="argument servicemap_definition", value=servicemap_definition, expected_type=type_hints["servicemap_definition"])
            check_type(argname="argument slo_list_definition", value=slo_list_definition, expected_type=type_hints["slo_list_definition"])
            check_type(argname="argument sunburst_definition", value=sunburst_definition, expected_type=type_hints["sunburst_definition"])
            check_type(argname="argument timeseries_definition", value=timeseries_definition, expected_type=type_hints["timeseries_definition"])
            check_type(argname="argument toplist_definition", value=toplist_definition, expected_type=type_hints["toplist_definition"])
            check_type(argname="argument topology_map_definition", value=topology_map_definition, expected_type=type_hints["topology_map_definition"])
            check_type(argname="argument trace_service_definition", value=trace_service_definition, expected_type=type_hints["trace_service_definition"])
            check_type(argname="argument treemap_definition", value=treemap_definition, expected_type=type_hints["treemap_definition"])
            check_type(argname="argument widget_layout", value=widget_layout, expected_type=type_hints["widget_layout"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if alert_graph_definition is not None:
            self._values["alert_graph_definition"] = alert_graph_definition
        if alert_value_definition is not None:
            self._values["alert_value_definition"] = alert_value_definition
        if change_definition is not None:
            self._values["change_definition"] = change_definition
        if check_status_definition is not None:
            self._values["check_status_definition"] = check_status_definition
        if distribution_definition is not None:
            self._values["distribution_definition"] = distribution_definition
        if event_stream_definition is not None:
            self._values["event_stream_definition"] = event_stream_definition
        if event_timeline_definition is not None:
            self._values["event_timeline_definition"] = event_timeline_definition
        if free_text_definition is not None:
            self._values["free_text_definition"] = free_text_definition
        if geomap_definition is not None:
            self._values["geomap_definition"] = geomap_definition
        if heatmap_definition is not None:
            self._values["heatmap_definition"] = heatmap_definition
        if hostmap_definition is not None:
            self._values["hostmap_definition"] = hostmap_definition
        if iframe_definition is not None:
            self._values["iframe_definition"] = iframe_definition
        if image_definition is not None:
            self._values["image_definition"] = image_definition
        if list_stream_definition is not None:
            self._values["list_stream_definition"] = list_stream_definition
        if log_stream_definition is not None:
            self._values["log_stream_definition"] = log_stream_definition
        if manage_status_definition is not None:
            self._values["manage_status_definition"] = manage_status_definition
        if note_definition is not None:
            self._values["note_definition"] = note_definition
        if query_table_definition is not None:
            self._values["query_table_definition"] = query_table_definition
        if query_value_definition is not None:
            self._values["query_value_definition"] = query_value_definition
        if run_workflow_definition is not None:
            self._values["run_workflow_definition"] = run_workflow_definition
        if scatterplot_definition is not None:
            self._values["scatterplot_definition"] = scatterplot_definition
        if service_level_objective_definition is not None:
            self._values["service_level_objective_definition"] = service_level_objective_definition
        if servicemap_definition is not None:
            self._values["servicemap_definition"] = servicemap_definition
        if slo_list_definition is not None:
            self._values["slo_list_definition"] = slo_list_definition
        if sunburst_definition is not None:
            self._values["sunburst_definition"] = sunburst_definition
        if timeseries_definition is not None:
            self._values["timeseries_definition"] = timeseries_definition
        if toplist_definition is not None:
            self._values["toplist_definition"] = toplist_definition
        if topology_map_definition is not None:
            self._values["topology_map_definition"] = topology_map_definition
        if trace_service_definition is not None:
            self._values["trace_service_definition"] = trace_service_definition
        if treemap_definition is not None:
            self._values["treemap_definition"] = treemap_definition
        if widget_layout is not None:
            self._values["widget_layout"] = widget_layout

    @builtins.property
    def alert_graph_definition(
        self,
    ) -> typing.Optional["PowerpackWidgetAlertGraphDefinition"]:
        '''alert_graph_definition block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#alert_graph_definition Powerpack#alert_graph_definition}
        '''
        result = self._values.get("alert_graph_definition")
        return typing.cast(typing.Optional["PowerpackWidgetAlertGraphDefinition"], result)

    @builtins.property
    def alert_value_definition(
        self,
    ) -> typing.Optional["PowerpackWidgetAlertValueDefinition"]:
        '''alert_value_definition block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#alert_value_definition Powerpack#alert_value_definition}
        '''
        result = self._values.get("alert_value_definition")
        return typing.cast(typing.Optional["PowerpackWidgetAlertValueDefinition"], result)

    @builtins.property
    def change_definition(self) -> typing.Optional["PowerpackWidgetChangeDefinition"]:
        '''change_definition block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#change_definition Powerpack#change_definition}
        '''
        result = self._values.get("change_definition")
        return typing.cast(typing.Optional["PowerpackWidgetChangeDefinition"], result)

    @builtins.property
    def check_status_definition(
        self,
    ) -> typing.Optional["PowerpackWidgetCheckStatusDefinition"]:
        '''check_status_definition block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#check_status_definition Powerpack#check_status_definition}
        '''
        result = self._values.get("check_status_definition")
        return typing.cast(typing.Optional["PowerpackWidgetCheckStatusDefinition"], result)

    @builtins.property
    def distribution_definition(
        self,
    ) -> typing.Optional["PowerpackWidgetDistributionDefinition"]:
        '''distribution_definition block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#distribution_definition Powerpack#distribution_definition}
        '''
        result = self._values.get("distribution_definition")
        return typing.cast(typing.Optional["PowerpackWidgetDistributionDefinition"], result)

    @builtins.property
    def event_stream_definition(
        self,
    ) -> typing.Optional["PowerpackWidgetEventStreamDefinition"]:
        '''event_stream_definition block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#event_stream_definition Powerpack#event_stream_definition}
        '''
        result = self._values.get("event_stream_definition")
        return typing.cast(typing.Optional["PowerpackWidgetEventStreamDefinition"], result)

    @builtins.property
    def event_timeline_definition(
        self,
    ) -> typing.Optional["PowerpackWidgetEventTimelineDefinition"]:
        '''event_timeline_definition block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#event_timeline_definition Powerpack#event_timeline_definition}
        '''
        result = self._values.get("event_timeline_definition")
        return typing.cast(typing.Optional["PowerpackWidgetEventTimelineDefinition"], result)

    @builtins.property
    def free_text_definition(
        self,
    ) -> typing.Optional["PowerpackWidgetFreeTextDefinition"]:
        '''free_text_definition block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#free_text_definition Powerpack#free_text_definition}
        '''
        result = self._values.get("free_text_definition")
        return typing.cast(typing.Optional["PowerpackWidgetFreeTextDefinition"], result)

    @builtins.property
    def geomap_definition(self) -> typing.Optional["PowerpackWidgetGeomapDefinition"]:
        '''geomap_definition block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#geomap_definition Powerpack#geomap_definition}
        '''
        result = self._values.get("geomap_definition")
        return typing.cast(typing.Optional["PowerpackWidgetGeomapDefinition"], result)

    @builtins.property
    def heatmap_definition(self) -> typing.Optional["PowerpackWidgetHeatmapDefinition"]:
        '''heatmap_definition block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#heatmap_definition Powerpack#heatmap_definition}
        '''
        result = self._values.get("heatmap_definition")
        return typing.cast(typing.Optional["PowerpackWidgetHeatmapDefinition"], result)

    @builtins.property
    def hostmap_definition(self) -> typing.Optional["PowerpackWidgetHostmapDefinition"]:
        '''hostmap_definition block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#hostmap_definition Powerpack#hostmap_definition}
        '''
        result = self._values.get("hostmap_definition")
        return typing.cast(typing.Optional["PowerpackWidgetHostmapDefinition"], result)

    @builtins.property
    def iframe_definition(self) -> typing.Optional["PowerpackWidgetIframeDefinition"]:
        '''iframe_definition block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#iframe_definition Powerpack#iframe_definition}
        '''
        result = self._values.get("iframe_definition")
        return typing.cast(typing.Optional["PowerpackWidgetIframeDefinition"], result)

    @builtins.property
    def image_definition(self) -> typing.Optional["PowerpackWidgetImageDefinition"]:
        '''image_definition block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#image_definition Powerpack#image_definition}
        '''
        result = self._values.get("image_definition")
        return typing.cast(typing.Optional["PowerpackWidgetImageDefinition"], result)

    @builtins.property
    def list_stream_definition(
        self,
    ) -> typing.Optional["PowerpackWidgetListStreamDefinition"]:
        '''list_stream_definition block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#list_stream_definition Powerpack#list_stream_definition}
        '''
        result = self._values.get("list_stream_definition")
        return typing.cast(typing.Optional["PowerpackWidgetListStreamDefinition"], result)

    @builtins.property
    def log_stream_definition(
        self,
    ) -> typing.Optional["PowerpackWidgetLogStreamDefinition"]:
        '''log_stream_definition block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#log_stream_definition Powerpack#log_stream_definition}
        '''
        result = self._values.get("log_stream_definition")
        return typing.cast(typing.Optional["PowerpackWidgetLogStreamDefinition"], result)

    @builtins.property
    def manage_status_definition(
        self,
    ) -> typing.Optional["PowerpackWidgetManageStatusDefinition"]:
        '''manage_status_definition block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#manage_status_definition Powerpack#manage_status_definition}
        '''
        result = self._values.get("manage_status_definition")
        return typing.cast(typing.Optional["PowerpackWidgetManageStatusDefinition"], result)

    @builtins.property
    def note_definition(self) -> typing.Optional["PowerpackWidgetNoteDefinition"]:
        '''note_definition block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#note_definition Powerpack#note_definition}
        '''
        result = self._values.get("note_definition")
        return typing.cast(typing.Optional["PowerpackWidgetNoteDefinition"], result)

    @builtins.property
    def query_table_definition(
        self,
    ) -> typing.Optional["PowerpackWidgetQueryTableDefinition"]:
        '''query_table_definition block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query_table_definition Powerpack#query_table_definition}
        '''
        result = self._values.get("query_table_definition")
        return typing.cast(typing.Optional["PowerpackWidgetQueryTableDefinition"], result)

    @builtins.property
    def query_value_definition(
        self,
    ) -> typing.Optional["PowerpackWidgetQueryValueDefinition"]:
        '''query_value_definition block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query_value_definition Powerpack#query_value_definition}
        '''
        result = self._values.get("query_value_definition")
        return typing.cast(typing.Optional["PowerpackWidgetQueryValueDefinition"], result)

    @builtins.property
    def run_workflow_definition(
        self,
    ) -> typing.Optional["PowerpackWidgetRunWorkflowDefinition"]:
        '''run_workflow_definition block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#run_workflow_definition Powerpack#run_workflow_definition}
        '''
        result = self._values.get("run_workflow_definition")
        return typing.cast(typing.Optional["PowerpackWidgetRunWorkflowDefinition"], result)

    @builtins.property
    def scatterplot_definition(
        self,
    ) -> typing.Optional["PowerpackWidgetScatterplotDefinition"]:
        '''scatterplot_definition block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#scatterplot_definition Powerpack#scatterplot_definition}
        '''
        result = self._values.get("scatterplot_definition")
        return typing.cast(typing.Optional["PowerpackWidgetScatterplotDefinition"], result)

    @builtins.property
    def service_level_objective_definition(
        self,
    ) -> typing.Optional["PowerpackWidgetServiceLevelObjectiveDefinition"]:
        '''service_level_objective_definition block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#service_level_objective_definition Powerpack#service_level_objective_definition}
        '''
        result = self._values.get("service_level_objective_definition")
        return typing.cast(typing.Optional["PowerpackWidgetServiceLevelObjectiveDefinition"], result)

    @builtins.property
    def servicemap_definition(
        self,
    ) -> typing.Optional["PowerpackWidgetServicemapDefinition"]:
        '''servicemap_definition block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#servicemap_definition Powerpack#servicemap_definition}
        '''
        result = self._values.get("servicemap_definition")
        return typing.cast(typing.Optional["PowerpackWidgetServicemapDefinition"], result)

    @builtins.property
    def slo_list_definition(
        self,
    ) -> typing.Optional["PowerpackWidgetSloListDefinition"]:
        '''slo_list_definition block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#slo_list_definition Powerpack#slo_list_definition}
        '''
        result = self._values.get("slo_list_definition")
        return typing.cast(typing.Optional["PowerpackWidgetSloListDefinition"], result)

    @builtins.property
    def sunburst_definition(
        self,
    ) -> typing.Optional["PowerpackWidgetSunburstDefinition"]:
        '''sunburst_definition block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sunburst_definition Powerpack#sunburst_definition}
        '''
        result = self._values.get("sunburst_definition")
        return typing.cast(typing.Optional["PowerpackWidgetSunburstDefinition"], result)

    @builtins.property
    def timeseries_definition(
        self,
    ) -> typing.Optional["PowerpackWidgetTimeseriesDefinition"]:
        '''timeseries_definition block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#timeseries_definition Powerpack#timeseries_definition}
        '''
        result = self._values.get("timeseries_definition")
        return typing.cast(typing.Optional["PowerpackWidgetTimeseriesDefinition"], result)

    @builtins.property
    def toplist_definition(self) -> typing.Optional["PowerpackWidgetToplistDefinition"]:
        '''toplist_definition block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#toplist_definition Powerpack#toplist_definition}
        '''
        result = self._values.get("toplist_definition")
        return typing.cast(typing.Optional["PowerpackWidgetToplistDefinition"], result)

    @builtins.property
    def topology_map_definition(
        self,
    ) -> typing.Optional["PowerpackWidgetTopologyMapDefinition"]:
        '''topology_map_definition block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#topology_map_definition Powerpack#topology_map_definition}
        '''
        result = self._values.get("topology_map_definition")
        return typing.cast(typing.Optional["PowerpackWidgetTopologyMapDefinition"], result)

    @builtins.property
    def trace_service_definition(
        self,
    ) -> typing.Optional["PowerpackWidgetTraceServiceDefinition"]:
        '''trace_service_definition block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#trace_service_definition Powerpack#trace_service_definition}
        '''
        result = self._values.get("trace_service_definition")
        return typing.cast(typing.Optional["PowerpackWidgetTraceServiceDefinition"], result)

    @builtins.property
    def treemap_definition(self) -> typing.Optional["PowerpackWidgetTreemapDefinition"]:
        '''treemap_definition block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#treemap_definition Powerpack#treemap_definition}
        '''
        result = self._values.get("treemap_definition")
        return typing.cast(typing.Optional["PowerpackWidgetTreemapDefinition"], result)

    @builtins.property
    def widget_layout(self) -> typing.Optional["PowerpackWidgetWidgetLayout"]:
        '''widget_layout block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#widget_layout Powerpack#widget_layout}
        '''
        result = self._values.get("widget_layout")
        return typing.cast(typing.Optional["PowerpackWidgetWidgetLayout"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidget(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetAlertGraphDefinition",
    jsii_struct_bases=[],
    name_mapping={
        "alert_id": "alertId",
        "viz_type": "vizType",
        "live_span": "liveSpan",
        "title": "title",
        "title_align": "titleAlign",
        "title_size": "titleSize",
    },
)
class PowerpackWidgetAlertGraphDefinition:
    def __init__(
        self,
        *,
        alert_id: builtins.str,
        viz_type: builtins.str,
        live_span: typing.Optional[builtins.str] = None,
        title: typing.Optional[builtins.str] = None,
        title_align: typing.Optional[builtins.str] = None,
        title_size: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param alert_id: The ID of the monitor used by the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#alert_id Powerpack#alert_id}
        :param viz_type: Type of visualization to use when displaying the widget. Valid values are ``timeseries``, ``toplist``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#viz_type Powerpack#viz_type}
        :param live_span: The timeframe to use when displaying the widget. Valid values are ``1m``, ``5m``, ``10m``, ``15m``, ``30m``, ``1h``, ``4h``, ``1d``, ``2d``, ``1w``, ``1mo``, ``3mo``, ``6mo``, ``week_to_date``, ``month_to_date``, ``1y``, ``alert``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#live_span Powerpack#live_span}
        :param title: The title of the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title Powerpack#title}
        :param title_align: The alignment of the widget's title. Valid values are ``center``, ``left``, ``right``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_align Powerpack#title_align}
        :param title_size: The size of the widget's title (defaults to 16). Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_size Powerpack#title_size}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8af3159e18bfd0e3fb61adebeb31f485b95461f3763907a7cc5e1d4f88b26887)
            check_type(argname="argument alert_id", value=alert_id, expected_type=type_hints["alert_id"])
            check_type(argname="argument viz_type", value=viz_type, expected_type=type_hints["viz_type"])
            check_type(argname="argument live_span", value=live_span, expected_type=type_hints["live_span"])
            check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            check_type(argname="argument title_align", value=title_align, expected_type=type_hints["title_align"])
            check_type(argname="argument title_size", value=title_size, expected_type=type_hints["title_size"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "alert_id": alert_id,
            "viz_type": viz_type,
        }
        if live_span is not None:
            self._values["live_span"] = live_span
        if title is not None:
            self._values["title"] = title
        if title_align is not None:
            self._values["title_align"] = title_align
        if title_size is not None:
            self._values["title_size"] = title_size

    @builtins.property
    def alert_id(self) -> builtins.str:
        '''The ID of the monitor used by the widget.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#alert_id Powerpack#alert_id}
        '''
        result = self._values.get("alert_id")
        assert result is not None, "Required property 'alert_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def viz_type(self) -> builtins.str:
        '''Type of visualization to use when displaying the widget. Valid values are ``timeseries``, ``toplist``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#viz_type Powerpack#viz_type}
        '''
        result = self._values.get("viz_type")
        assert result is not None, "Required property 'viz_type' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def live_span(self) -> typing.Optional[builtins.str]:
        '''The timeframe to use when displaying the widget.

        Valid values are ``1m``, ``5m``, ``10m``, ``15m``, ``30m``, ``1h``, ``4h``, ``1d``, ``2d``, ``1w``, ``1mo``, ``3mo``, ``6mo``, ``week_to_date``, ``month_to_date``, ``1y``, ``alert``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#live_span Powerpack#live_span}
        '''
        result = self._values.get("live_span")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def title(self) -> typing.Optional[builtins.str]:
        '''The title of the widget.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title Powerpack#title}
        '''
        result = self._values.get("title")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def title_align(self) -> typing.Optional[builtins.str]:
        '''The alignment of the widget's title. Valid values are ``center``, ``left``, ``right``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_align Powerpack#title_align}
        '''
        result = self._values.get("title_align")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def title_size(self) -> typing.Optional[builtins.str]:
        '''The size of the widget's title (defaults to 16).

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_size Powerpack#title_size}
        '''
        result = self._values.get("title_size")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetAlertGraphDefinition(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetAlertGraphDefinitionOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetAlertGraphDefinitionOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__beacb426e1e51a6b9c6e5bc0513c3abf9535a3066c84a506c1b74c0c2d58b87d)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetLiveSpan")
    def reset_live_span(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLiveSpan", []))

    @jsii.member(jsii_name="resetTitle")
    def reset_title(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTitle", []))

    @jsii.member(jsii_name="resetTitleAlign")
    def reset_title_align(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTitleAlign", []))

    @jsii.member(jsii_name="resetTitleSize")
    def reset_title_size(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTitleSize", []))

    @builtins.property
    @jsii.member(jsii_name="alertIdInput")
    def alert_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "alertIdInput"))

    @builtins.property
    @jsii.member(jsii_name="liveSpanInput")
    def live_span_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "liveSpanInput"))

    @builtins.property
    @jsii.member(jsii_name="titleAlignInput")
    def title_align_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "titleAlignInput"))

    @builtins.property
    @jsii.member(jsii_name="titleInput")
    def title_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "titleInput"))

    @builtins.property
    @jsii.member(jsii_name="titleSizeInput")
    def title_size_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "titleSizeInput"))

    @builtins.property
    @jsii.member(jsii_name="vizTypeInput")
    def viz_type_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "vizTypeInput"))

    @builtins.property
    @jsii.member(jsii_name="alertId")
    def alert_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "alertId"))

    @alert_id.setter
    def alert_id(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__93df006b3fe7fa3f706b8bbf2f9baef873a5e39f6e53c8600cdb514cac9bb1e4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "alertId", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="liveSpan")
    def live_span(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "liveSpan"))

    @live_span.setter
    def live_span(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ad1992321ab1c7a664e3b2d4e6269fe687b18e99ee8af4ddd98284e25ecb2523)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "liveSpan", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="title")
    def title(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "title"))

    @title.setter
    def title(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0c5f79f6df16714cc5972c1a30412948ec79a66eb43c5f34b2f766e6e273e585)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "title", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="titleAlign")
    def title_align(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "titleAlign"))

    @title_align.setter
    def title_align(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3e59049b1184dc18e042cbd2e2c63f21a77c0fdf034d22e0e228742cd9ff0429)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "titleAlign", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="titleSize")
    def title_size(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "titleSize"))

    @title_size.setter
    def title_size(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5a090fff08200787337ba4814ca665a31685e238f2a49b2bc77e6cfa0366e959)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "titleSize", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="vizType")
    def viz_type(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "vizType"))

    @viz_type.setter
    def viz_type(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bb0a98e7955f9b526fcf495920c9c757b09a2329ad4d7777ed8ea266ce857985)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "vizType", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[PowerpackWidgetAlertGraphDefinition]:
        return typing.cast(typing.Optional[PowerpackWidgetAlertGraphDefinition], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetAlertGraphDefinition],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a25e08f1755b3b12b48f602bb2aa74c2021626ff4b111c93632a0dc54b39b21c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetAlertValueDefinition",
    jsii_struct_bases=[],
    name_mapping={
        "alert_id": "alertId",
        "precision": "precision",
        "text_align": "textAlign",
        "title": "title",
        "title_align": "titleAlign",
        "title_size": "titleSize",
        "unit": "unit",
    },
)
class PowerpackWidgetAlertValueDefinition:
    def __init__(
        self,
        *,
        alert_id: builtins.str,
        precision: typing.Optional[jsii.Number] = None,
        text_align: typing.Optional[builtins.str] = None,
        title: typing.Optional[builtins.str] = None,
        title_align: typing.Optional[builtins.str] = None,
        title_size: typing.Optional[builtins.str] = None,
        unit: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param alert_id: The ID of the monitor used by the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#alert_id Powerpack#alert_id}
        :param precision: The precision to use when displaying the value. Use ``*`` for maximum precision. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#precision Powerpack#precision}
        :param text_align: The alignment of the text in the widget. Valid values are ``center``, ``left``, ``right``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#text_align Powerpack#text_align}
        :param title: The title of the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title Powerpack#title}
        :param title_align: The alignment of the widget's title. Valid values are ``center``, ``left``, ``right``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_align Powerpack#title_align}
        :param title_size: The size of the widget's title (defaults to 16). Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_size Powerpack#title_size}
        :param unit: The unit for the value displayed in the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit Powerpack#unit}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c02b99e55fc9ec4d7e393ecd943350fba30fa0d7ddf8bd133c7a7cbdf6d2f131)
            check_type(argname="argument alert_id", value=alert_id, expected_type=type_hints["alert_id"])
            check_type(argname="argument precision", value=precision, expected_type=type_hints["precision"])
            check_type(argname="argument text_align", value=text_align, expected_type=type_hints["text_align"])
            check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            check_type(argname="argument title_align", value=title_align, expected_type=type_hints["title_align"])
            check_type(argname="argument title_size", value=title_size, expected_type=type_hints["title_size"])
            check_type(argname="argument unit", value=unit, expected_type=type_hints["unit"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "alert_id": alert_id,
        }
        if precision is not None:
            self._values["precision"] = precision
        if text_align is not None:
            self._values["text_align"] = text_align
        if title is not None:
            self._values["title"] = title
        if title_align is not None:
            self._values["title_align"] = title_align
        if title_size is not None:
            self._values["title_size"] = title_size
        if unit is not None:
            self._values["unit"] = unit

    @builtins.property
    def alert_id(self) -> builtins.str:
        '''The ID of the monitor used by the widget.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#alert_id Powerpack#alert_id}
        '''
        result = self._values.get("alert_id")
        assert result is not None, "Required property 'alert_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def precision(self) -> typing.Optional[jsii.Number]:
        '''The precision to use when displaying the value. Use ``*`` for maximum precision.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#precision Powerpack#precision}
        '''
        result = self._values.get("precision")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def text_align(self) -> typing.Optional[builtins.str]:
        '''The alignment of the text in the widget. Valid values are ``center``, ``left``, ``right``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#text_align Powerpack#text_align}
        '''
        result = self._values.get("text_align")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def title(self) -> typing.Optional[builtins.str]:
        '''The title of the widget.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title Powerpack#title}
        '''
        result = self._values.get("title")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def title_align(self) -> typing.Optional[builtins.str]:
        '''The alignment of the widget's title. Valid values are ``center``, ``left``, ``right``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_align Powerpack#title_align}
        '''
        result = self._values.get("title_align")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def title_size(self) -> typing.Optional[builtins.str]:
        '''The size of the widget's title (defaults to 16).

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_size Powerpack#title_size}
        '''
        result = self._values.get("title_size")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def unit(self) -> typing.Optional[builtins.str]:
        '''The unit for the value displayed in the widget.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit Powerpack#unit}
        '''
        result = self._values.get("unit")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetAlertValueDefinition(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetAlertValueDefinitionOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetAlertValueDefinitionOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__27b1ccbccc89714e5641c207b00dde2ce1faeb49f14cb472a1b6926dea75fb4c)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetPrecision")
    def reset_precision(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPrecision", []))

    @jsii.member(jsii_name="resetTextAlign")
    def reset_text_align(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTextAlign", []))

    @jsii.member(jsii_name="resetTitle")
    def reset_title(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTitle", []))

    @jsii.member(jsii_name="resetTitleAlign")
    def reset_title_align(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTitleAlign", []))

    @jsii.member(jsii_name="resetTitleSize")
    def reset_title_size(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTitleSize", []))

    @jsii.member(jsii_name="resetUnit")
    def reset_unit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetUnit", []))

    @builtins.property
    @jsii.member(jsii_name="alertIdInput")
    def alert_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "alertIdInput"))

    @builtins.property
    @jsii.member(jsii_name="precisionInput")
    def precision_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "precisionInput"))

    @builtins.property
    @jsii.member(jsii_name="textAlignInput")
    def text_align_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "textAlignInput"))

    @builtins.property
    @jsii.member(jsii_name="titleAlignInput")
    def title_align_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "titleAlignInput"))

    @builtins.property
    @jsii.member(jsii_name="titleInput")
    def title_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "titleInput"))

    @builtins.property
    @jsii.member(jsii_name="titleSizeInput")
    def title_size_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "titleSizeInput"))

    @builtins.property
    @jsii.member(jsii_name="unitInput")
    def unit_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "unitInput"))

    @builtins.property
    @jsii.member(jsii_name="alertId")
    def alert_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "alertId"))

    @alert_id.setter
    def alert_id(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__168678d56a385a8191a2eae185b1b181ecb940c88ad4feb346159a484ed4e00e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "alertId", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="precision")
    def precision(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "precision"))

    @precision.setter
    def precision(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__184c3fbbe79b9a87308107d8e1125e4cbccb88fca70e33e1a286d29bb15934e4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "precision", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="textAlign")
    def text_align(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "textAlign"))

    @text_align.setter
    def text_align(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4b96f8d879f1acf21c783bfee994be8ee86910b2002a738e03ad384a28a678b6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "textAlign", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="title")
    def title(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "title"))

    @title.setter
    def title(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__74b1141c20a1b6a71638246ce5a9fae4dc453ac007717503f1a1912d930caf44)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "title", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="titleAlign")
    def title_align(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "titleAlign"))

    @title_align.setter
    def title_align(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6bd89a59116b792e6c14082993b5d5ddf7da0fadc14ce05ac53f8f0048ccdcd2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "titleAlign", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="titleSize")
    def title_size(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "titleSize"))

    @title_size.setter
    def title_size(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a11f257cd3748c5cf1e87b37955c6120b56ec5a6d279ceca0f5db12a18ee4321)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "titleSize", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="unit")
    def unit(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "unit"))

    @unit.setter
    def unit(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e0d7855f2526cc9cbcbd439e51d8541c846d6b6c495dd2288c49fb3f41c608db)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "unit", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[PowerpackWidgetAlertValueDefinition]:
        return typing.cast(typing.Optional[PowerpackWidgetAlertValueDefinition], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetAlertValueDefinition],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9f5707fe7ea9d6e9761e7b2908493e3a5b3d92d4105ba9e3c351c0aa25af448c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinition",
    jsii_struct_bases=[],
    name_mapping={
        "custom_link": "customLink",
        "live_span": "liveSpan",
        "request": "request",
        "title": "title",
        "title_align": "titleAlign",
        "title_size": "titleSize",
    },
)
class PowerpackWidgetChangeDefinition:
    def __init__(
        self,
        *,
        custom_link: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetChangeDefinitionCustomLink", typing.Dict[builtins.str, typing.Any]]]]] = None,
        live_span: typing.Optional[builtins.str] = None,
        request: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetChangeDefinitionRequest", typing.Dict[builtins.str, typing.Any]]]]] = None,
        title: typing.Optional[builtins.str] = None,
        title_align: typing.Optional[builtins.str] = None,
        title_size: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param custom_link: custom_link block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom_link Powerpack#custom_link}
        :param live_span: The timeframe to use when displaying the widget. Valid values are ``1m``, ``5m``, ``10m``, ``15m``, ``30m``, ``1h``, ``4h``, ``1d``, ``2d``, ``1w``, ``1mo``, ``3mo``, ``6mo``, ``week_to_date``, ``month_to_date``, ``1y``, ``alert``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#live_span Powerpack#live_span}
        :param request: request block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#request Powerpack#request}
        :param title: The title of the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title Powerpack#title}
        :param title_align: The alignment of the widget's title. Valid values are ``center``, ``left``, ``right``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_align Powerpack#title_align}
        :param title_size: The size of the widget's title (defaults to 16). Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_size Powerpack#title_size}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__33cc5d0526ac0dbc9bff49a60a9b441e62d37e785cfe520082b53120bfdeb65b)
            check_type(argname="argument custom_link", value=custom_link, expected_type=type_hints["custom_link"])
            check_type(argname="argument live_span", value=live_span, expected_type=type_hints["live_span"])
            check_type(argname="argument request", value=request, expected_type=type_hints["request"])
            check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            check_type(argname="argument title_align", value=title_align, expected_type=type_hints["title_align"])
            check_type(argname="argument title_size", value=title_size, expected_type=type_hints["title_size"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if custom_link is not None:
            self._values["custom_link"] = custom_link
        if live_span is not None:
            self._values["live_span"] = live_span
        if request is not None:
            self._values["request"] = request
        if title is not None:
            self._values["title"] = title
        if title_align is not None:
            self._values["title_align"] = title_align
        if title_size is not None:
            self._values["title_size"] = title_size

    @builtins.property
    def custom_link(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetChangeDefinitionCustomLink"]]]:
        '''custom_link block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom_link Powerpack#custom_link}
        '''
        result = self._values.get("custom_link")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetChangeDefinitionCustomLink"]]], result)

    @builtins.property
    def live_span(self) -> typing.Optional[builtins.str]:
        '''The timeframe to use when displaying the widget.

        Valid values are ``1m``, ``5m``, ``10m``, ``15m``, ``30m``, ``1h``, ``4h``, ``1d``, ``2d``, ``1w``, ``1mo``, ``3mo``, ``6mo``, ``week_to_date``, ``month_to_date``, ``1y``, ``alert``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#live_span Powerpack#live_span}
        '''
        result = self._values.get("live_span")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def request(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetChangeDefinitionRequest"]]]:
        '''request block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#request Powerpack#request}
        '''
        result = self._values.get("request")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetChangeDefinitionRequest"]]], result)

    @builtins.property
    def title(self) -> typing.Optional[builtins.str]:
        '''The title of the widget.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title Powerpack#title}
        '''
        result = self._values.get("title")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def title_align(self) -> typing.Optional[builtins.str]:
        '''The alignment of the widget's title. Valid values are ``center``, ``left``, ``right``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_align Powerpack#title_align}
        '''
        result = self._values.get("title_align")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def title_size(self) -> typing.Optional[builtins.str]:
        '''The size of the widget's title (defaults to 16).

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_size Powerpack#title_size}
        '''
        result = self._values.get("title_size")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetChangeDefinition(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionCustomLink",
    jsii_struct_bases=[],
    name_mapping={
        "is_hidden": "isHidden",
        "label": "label",
        "link": "link",
        "override_label": "overrideLabel",
    },
)
class PowerpackWidgetChangeDefinitionCustomLink:
    def __init__(
        self,
        *,
        is_hidden: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        label: typing.Optional[builtins.str] = None,
        link: typing.Optional[builtins.str] = None,
        override_label: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param is_hidden: The flag for toggling context menu link visibility. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#is_hidden Powerpack#is_hidden}
        :param label: The label for the custom link URL. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#label Powerpack#label}
        :param link: The URL of the custom link. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#link Powerpack#link}
        :param override_label: The label ID that refers to a context menu link item. When ``override_label`` is provided, the client request omits the label field. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#override_label Powerpack#override_label}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4ca7282347527785edc14b71c148155967c4380b78aae06bb70bc154051e21a9)
            check_type(argname="argument is_hidden", value=is_hidden, expected_type=type_hints["is_hidden"])
            check_type(argname="argument label", value=label, expected_type=type_hints["label"])
            check_type(argname="argument link", value=link, expected_type=type_hints["link"])
            check_type(argname="argument override_label", value=override_label, expected_type=type_hints["override_label"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if is_hidden is not None:
            self._values["is_hidden"] = is_hidden
        if label is not None:
            self._values["label"] = label
        if link is not None:
            self._values["link"] = link
        if override_label is not None:
            self._values["override_label"] = override_label

    @builtins.property
    def is_hidden(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        '''The flag for toggling context menu link visibility.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#is_hidden Powerpack#is_hidden}
        '''
        result = self._values.get("is_hidden")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)

    @builtins.property
    def label(self) -> typing.Optional[builtins.str]:
        '''The label for the custom link URL.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#label Powerpack#label}
        '''
        result = self._values.get("label")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def link(self) -> typing.Optional[builtins.str]:
        '''The URL of the custom link.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#link Powerpack#link}
        '''
        result = self._values.get("link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def override_label(self) -> typing.Optional[builtins.str]:
        '''The label ID that refers to a context menu link item.

        When ``override_label`` is provided, the client request omits the label field.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#override_label Powerpack#override_label}
        '''
        result = self._values.get("override_label")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetChangeDefinitionCustomLink(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetChangeDefinitionCustomLinkList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionCustomLinkList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a720d81d593313da8393528a7cba4cb7daf8cefb005cf68e7b188f4a7ce8b24e)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetChangeDefinitionCustomLinkOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ace3e17a2e8511b031ab54e669572352766ba3250953ee8371f9a86643d0a742)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetChangeDefinitionCustomLinkOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__422589d98fc105d5936075b7791a9c7dd9a69434f2d33c2f51eb784fffa3a3f6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9475ad922600e3f38cd63a6cf02847c72e0131235e844071e32352107e321697)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4cb4c7f297ffd115284f58f58f87fba472b84197890bf15a99bc3e56f7d24b13)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetChangeDefinitionCustomLink]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetChangeDefinitionCustomLink]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetChangeDefinitionCustomLink]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8386fa850baabbdad560ba7bbe7a8c3e5abf6dd44c90e927b4d42f5f9dac04b2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetChangeDefinitionCustomLinkOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionCustomLinkOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__58c2b8a2c9739ca85df3d854f9af2aaed899cd05a4dc955451328be9133ad674)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetIsHidden")
    def reset_is_hidden(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetIsHidden", []))

    @jsii.member(jsii_name="resetLabel")
    def reset_label(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLabel", []))

    @jsii.member(jsii_name="resetLink")
    def reset_link(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLink", []))

    @jsii.member(jsii_name="resetOverrideLabel")
    def reset_override_label(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetOverrideLabel", []))

    @builtins.property
    @jsii.member(jsii_name="isHiddenInput")
    def is_hidden_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "isHiddenInput"))

    @builtins.property
    @jsii.member(jsii_name="labelInput")
    def label_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "labelInput"))

    @builtins.property
    @jsii.member(jsii_name="linkInput")
    def link_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "linkInput"))

    @builtins.property
    @jsii.member(jsii_name="overrideLabelInput")
    def override_label_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "overrideLabelInput"))

    @builtins.property
    @jsii.member(jsii_name="isHidden")
    def is_hidden(self) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "isHidden"))

    @is_hidden.setter
    def is_hidden(
        self,
        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__785e3bb6ef3c4e4953e35c5c5113e56d7fdc3bd406fd756ae1d4301af25944fb)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "isHidden", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="label")
    def label(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "label"))

    @label.setter
    def label(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fbacd7aa8af68d9b5b8efe674ff43aa4d80d61813c10b2f4424666d73d1019b8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "label", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="link")
    def link(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "link"))

    @link.setter
    def link(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e743ae67777a94aaaf94262b32255f36efec2c743852e16ef2b436ee3229af8c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "link", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="overrideLabel")
    def override_label(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "overrideLabel"))

    @override_label.setter
    def override_label(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c552895daae99ba2014b43bca1b7e6ccb69775bd9a537213e220b146b253b37b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "overrideLabel", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetChangeDefinitionCustomLink]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetChangeDefinitionCustomLink]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetChangeDefinitionCustomLink]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6c25d41e83bec396a5f7620078d08c7302a50ed97dd93c4a56b3097a3b6ae8d3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetChangeDefinitionOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fa9519d289f670469e0b188c2cd9b4e6b15fe32b74b324f23bb625641dec4714)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putCustomLink")
    def put_custom_link(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetChangeDefinitionCustomLink, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__72a4ff013ed5ec5fae37d1636daf9d9ed5ef87bb3cdf7e941a0943a378013872)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putCustomLink", [value]))

    @jsii.member(jsii_name="putRequest")
    def put_request(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetChangeDefinitionRequest", typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c0275aa72ac3740d7ed6fcfae16577bc2eda7cfbf4f9ca7e6a95f433112497af)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putRequest", [value]))

    @jsii.member(jsii_name="resetCustomLink")
    def reset_custom_link(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCustomLink", []))

    @jsii.member(jsii_name="resetLiveSpan")
    def reset_live_span(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLiveSpan", []))

    @jsii.member(jsii_name="resetRequest")
    def reset_request(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetRequest", []))

    @jsii.member(jsii_name="resetTitle")
    def reset_title(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTitle", []))

    @jsii.member(jsii_name="resetTitleAlign")
    def reset_title_align(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTitleAlign", []))

    @jsii.member(jsii_name="resetTitleSize")
    def reset_title_size(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTitleSize", []))

    @builtins.property
    @jsii.member(jsii_name="customLink")
    def custom_link(self) -> PowerpackWidgetChangeDefinitionCustomLinkList:
        return typing.cast(PowerpackWidgetChangeDefinitionCustomLinkList, jsii.get(self, "customLink"))

    @builtins.property
    @jsii.member(jsii_name="request")
    def request(self) -> "PowerpackWidgetChangeDefinitionRequestList":
        return typing.cast("PowerpackWidgetChangeDefinitionRequestList", jsii.get(self, "request"))

    @builtins.property
    @jsii.member(jsii_name="customLinkInput")
    def custom_link_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetChangeDefinitionCustomLink]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetChangeDefinitionCustomLink]]], jsii.get(self, "customLinkInput"))

    @builtins.property
    @jsii.member(jsii_name="liveSpanInput")
    def live_span_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "liveSpanInput"))

    @builtins.property
    @jsii.member(jsii_name="requestInput")
    def request_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetChangeDefinitionRequest"]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetChangeDefinitionRequest"]]], jsii.get(self, "requestInput"))

    @builtins.property
    @jsii.member(jsii_name="titleAlignInput")
    def title_align_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "titleAlignInput"))

    @builtins.property
    @jsii.member(jsii_name="titleInput")
    def title_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "titleInput"))

    @builtins.property
    @jsii.member(jsii_name="titleSizeInput")
    def title_size_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "titleSizeInput"))

    @builtins.property
    @jsii.member(jsii_name="liveSpan")
    def live_span(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "liveSpan"))

    @live_span.setter
    def live_span(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__09800b0f9b8fb20698a0c39866c4e3ffd19ba61941dc738f286ddda6fed5a00d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "liveSpan", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="title")
    def title(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "title"))

    @title.setter
    def title(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5d77f754183366abef992c12eda7e5843c6834bfc182ceb754946ec4cdfca1d2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "title", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="titleAlign")
    def title_align(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "titleAlign"))

    @title_align.setter
    def title_align(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__653074cb93d130414662e636cd9eee815255a8992b2c9fc7a2c16e7c9390dd7a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "titleAlign", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="titleSize")
    def title_size(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "titleSize"))

    @title_size.setter
    def title_size(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a873c4b274a226e2aa3e0a3eaa494834098793594cda9301b28e97a07e198569)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "titleSize", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[PowerpackWidgetChangeDefinition]:
        return typing.cast(typing.Optional[PowerpackWidgetChangeDefinition], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetChangeDefinition],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8b4b756e1c2d3397e147cef492f7b084f153509fd26ce2b68b3b8632b2782c19)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionRequest",
    jsii_struct_bases=[],
    name_mapping={
        "apm_query": "apmQuery",
        "change_type": "changeType",
        "compare_to": "compareTo",
        "formula": "formula",
        "increase_good": "increaseGood",
        "log_query": "logQuery",
        "order_by": "orderBy",
        "order_dir": "orderDir",
        "process_query": "processQuery",
        "q": "q",
        "query": "query",
        "rum_query": "rumQuery",
        "security_query": "securityQuery",
        "show_present": "showPresent",
    },
)
class PowerpackWidgetChangeDefinitionRequest:
    def __init__(
        self,
        *,
        apm_query: typing.Optional[typing.Union["PowerpackWidgetChangeDefinitionRequestApmQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        change_type: typing.Optional[builtins.str] = None,
        compare_to: typing.Optional[builtins.str] = None,
        formula: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetChangeDefinitionRequestFormula", typing.Dict[builtins.str, typing.Any]]]]] = None,
        increase_good: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        log_query: typing.Optional[typing.Union["PowerpackWidgetChangeDefinitionRequestLogQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        order_by: typing.Optional[builtins.str] = None,
        order_dir: typing.Optional[builtins.str] = None,
        process_query: typing.Optional[typing.Union["PowerpackWidgetChangeDefinitionRequestProcessQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        q: typing.Optional[builtins.str] = None,
        query: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetChangeDefinitionRequestQuery", typing.Dict[builtins.str, typing.Any]]]]] = None,
        rum_query: typing.Optional[typing.Union["PowerpackWidgetChangeDefinitionRequestRumQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        security_query: typing.Optional[typing.Union["PowerpackWidgetChangeDefinitionRequestSecurityQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        show_present: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
    ) -> None:
        '''
        :param apm_query: apm_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#apm_query Powerpack#apm_query}
        :param change_type: Whether to show absolute or relative change. Valid values are ``absolute``, ``relative``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#change_type Powerpack#change_type}
        :param compare_to: Choose from when to compare current data to. Valid values are ``hour_before``, ``day_before``, ``week_before``, ``month_before``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compare_to Powerpack#compare_to}
        :param formula: formula block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#formula Powerpack#formula}
        :param increase_good: A Boolean indicating whether an increase in the value is good (displayed in green) or not (displayed in red). Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#increase_good Powerpack#increase_good}
        :param log_query: log_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#log_query Powerpack#log_query}
        :param order_by: What to order by. Valid values are ``change``, ``name``, ``present``, ``past``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order_by Powerpack#order_by}
        :param order_dir: Widget sorting method. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order_dir Powerpack#order_dir}
        :param process_query: process_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#process_query Powerpack#process_query}
        :param q: The metric query to use for this widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#q Powerpack#q}
        :param query: query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        :param rum_query: rum_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#rum_query Powerpack#rum_query}
        :param security_query: security_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#security_query Powerpack#security_query}
        :param show_present: If set to ``true``, displays the current value. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#show_present Powerpack#show_present}
        '''
        if isinstance(apm_query, dict):
            apm_query = PowerpackWidgetChangeDefinitionRequestApmQuery(**apm_query)
        if isinstance(log_query, dict):
            log_query = PowerpackWidgetChangeDefinitionRequestLogQuery(**log_query)
        if isinstance(process_query, dict):
            process_query = PowerpackWidgetChangeDefinitionRequestProcessQuery(**process_query)
        if isinstance(rum_query, dict):
            rum_query = PowerpackWidgetChangeDefinitionRequestRumQuery(**rum_query)
        if isinstance(security_query, dict):
            security_query = PowerpackWidgetChangeDefinitionRequestSecurityQuery(**security_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6dac301bbb30035de357bbd4014c66166ccf78694c74280a6d1164aacb40f9d5)
            check_type(argname="argument apm_query", value=apm_query, expected_type=type_hints["apm_query"])
            check_type(argname="argument change_type", value=change_type, expected_type=type_hints["change_type"])
            check_type(argname="argument compare_to", value=compare_to, expected_type=type_hints["compare_to"])
            check_type(argname="argument formula", value=formula, expected_type=type_hints["formula"])
            check_type(argname="argument increase_good", value=increase_good, expected_type=type_hints["increase_good"])
            check_type(argname="argument log_query", value=log_query, expected_type=type_hints["log_query"])
            check_type(argname="argument order_by", value=order_by, expected_type=type_hints["order_by"])
            check_type(argname="argument order_dir", value=order_dir, expected_type=type_hints["order_dir"])
            check_type(argname="argument process_query", value=process_query, expected_type=type_hints["process_query"])
            check_type(argname="argument q", value=q, expected_type=type_hints["q"])
            check_type(argname="argument query", value=query, expected_type=type_hints["query"])
            check_type(argname="argument rum_query", value=rum_query, expected_type=type_hints["rum_query"])
            check_type(argname="argument security_query", value=security_query, expected_type=type_hints["security_query"])
            check_type(argname="argument show_present", value=show_present, expected_type=type_hints["show_present"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if apm_query is not None:
            self._values["apm_query"] = apm_query
        if change_type is not None:
            self._values["change_type"] = change_type
        if compare_to is not None:
            self._values["compare_to"] = compare_to
        if formula is not None:
            self._values["formula"] = formula
        if increase_good is not None:
            self._values["increase_good"] = increase_good
        if log_query is not None:
            self._values["log_query"] = log_query
        if order_by is not None:
            self._values["order_by"] = order_by
        if order_dir is not None:
            self._values["order_dir"] = order_dir
        if process_query is not None:
            self._values["process_query"] = process_query
        if q is not None:
            self._values["q"] = q
        if query is not None:
            self._values["query"] = query
        if rum_query is not None:
            self._values["rum_query"] = rum_query
        if security_query is not None:
            self._values["security_query"] = security_query
        if show_present is not None:
            self._values["show_present"] = show_present

    @builtins.property
    def apm_query(
        self,
    ) -> typing.Optional["PowerpackWidgetChangeDefinitionRequestApmQuery"]:
        '''apm_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#apm_query Powerpack#apm_query}
        '''
        result = self._values.get("apm_query")
        return typing.cast(typing.Optional["PowerpackWidgetChangeDefinitionRequestApmQuery"], result)

    @builtins.property
    def change_type(self) -> typing.Optional[builtins.str]:
        '''Whether to show absolute or relative change. Valid values are ``absolute``, ``relative``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#change_type Powerpack#change_type}
        '''
        result = self._values.get("change_type")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def compare_to(self) -> typing.Optional[builtins.str]:
        '''Choose from when to compare current data to. Valid values are ``hour_before``, ``day_before``, ``week_before``, ``month_before``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compare_to Powerpack#compare_to}
        '''
        result = self._values.get("compare_to")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def formula(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetChangeDefinitionRequestFormula"]]]:
        '''formula block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#formula Powerpack#formula}
        '''
        result = self._values.get("formula")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetChangeDefinitionRequestFormula"]]], result)

    @builtins.property
    def increase_good(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        '''A Boolean indicating whether an increase in the value is good (displayed in green) or not (displayed in red).

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#increase_good Powerpack#increase_good}
        '''
        result = self._values.get("increase_good")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)

    @builtins.property
    def log_query(
        self,
    ) -> typing.Optional["PowerpackWidgetChangeDefinitionRequestLogQuery"]:
        '''log_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#log_query Powerpack#log_query}
        '''
        result = self._values.get("log_query")
        return typing.cast(typing.Optional["PowerpackWidgetChangeDefinitionRequestLogQuery"], result)

    @builtins.property
    def order_by(self) -> typing.Optional[builtins.str]:
        '''What to order by. Valid values are ``change``, ``name``, ``present``, ``past``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order_by Powerpack#order_by}
        '''
        result = self._values.get("order_by")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def order_dir(self) -> typing.Optional[builtins.str]:
        '''Widget sorting method. Valid values are ``asc``, ``desc``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order_dir Powerpack#order_dir}
        '''
        result = self._values.get("order_dir")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def process_query(
        self,
    ) -> typing.Optional["PowerpackWidgetChangeDefinitionRequestProcessQuery"]:
        '''process_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#process_query Powerpack#process_query}
        '''
        result = self._values.get("process_query")
        return typing.cast(typing.Optional["PowerpackWidgetChangeDefinitionRequestProcessQuery"], result)

    @builtins.property
    def q(self) -> typing.Optional[builtins.str]:
        '''The metric query to use for this widget.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#q Powerpack#q}
        '''
        result = self._values.get("q")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def query(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetChangeDefinitionRequestQuery"]]]:
        '''query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        '''
        result = self._values.get("query")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetChangeDefinitionRequestQuery"]]], result)

    @builtins.property
    def rum_query(
        self,
    ) -> typing.Optional["PowerpackWidgetChangeDefinitionRequestRumQuery"]:
        '''rum_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#rum_query Powerpack#rum_query}
        '''
        result = self._values.get("rum_query")
        return typing.cast(typing.Optional["PowerpackWidgetChangeDefinitionRequestRumQuery"], result)

    @builtins.property
    def security_query(
        self,
    ) -> typing.Optional["PowerpackWidgetChangeDefinitionRequestSecurityQuery"]:
        '''security_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#security_query Powerpack#security_query}
        '''
        result = self._values.get("security_query")
        return typing.cast(typing.Optional["PowerpackWidgetChangeDefinitionRequestSecurityQuery"], result)

    @builtins.property
    def show_present(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        '''If set to ``true``, displays the current value.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#show_present Powerpack#show_present}
        '''
        result = self._values.get("show_present")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetChangeDefinitionRequest(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionRequestApmQuery",
    jsii_struct_bases=[],
    name_mapping={
        "index": "index",
        "compute_query": "computeQuery",
        "group_by": "groupBy",
        "multi_compute": "multiCompute",
        "search_query": "searchQuery",
    },
)
class PowerpackWidgetChangeDefinitionRequestApmQuery:
    def __init__(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union["PowerpackWidgetChangeDefinitionRequestApmQueryComputeQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetChangeDefinitionRequestApmQueryGroupBy", typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetChangeDefinitionRequestApmQueryMultiCompute", typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        if isinstance(compute_query, dict):
            compute_query = PowerpackWidgetChangeDefinitionRequestApmQueryComputeQuery(**compute_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0116fb2ac09206dca599e38f3e0e561841e61e7c5e84d8371717cc75210f4a38)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
            check_type(argname="argument compute_query", value=compute_query, expected_type=type_hints["compute_query"])
            check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
            check_type(argname="argument multi_compute", value=multi_compute, expected_type=type_hints["multi_compute"])
            check_type(argname="argument search_query", value=search_query, expected_type=type_hints["search_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "index": index,
        }
        if compute_query is not None:
            self._values["compute_query"] = compute_query
        if group_by is not None:
            self._values["group_by"] = group_by
        if multi_compute is not None:
            self._values["multi_compute"] = multi_compute
        if search_query is not None:
            self._values["search_query"] = search_query

    @builtins.property
    def index(self) -> builtins.str:
        '''The name of the index to query.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        '''
        result = self._values.get("index")
        assert result is not None, "Required property 'index' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def compute_query(
        self,
    ) -> typing.Optional["PowerpackWidgetChangeDefinitionRequestApmQueryComputeQuery"]:
        '''compute_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        '''
        result = self._values.get("compute_query")
        return typing.cast(typing.Optional["PowerpackWidgetChangeDefinitionRequestApmQueryComputeQuery"], result)

    @builtins.property
    def group_by(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetChangeDefinitionRequestApmQueryGroupBy"]]]:
        '''group_by block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        '''
        result = self._values.get("group_by")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetChangeDefinitionRequestApmQueryGroupBy"]]], result)

    @builtins.property
    def multi_compute(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetChangeDefinitionRequestApmQueryMultiCompute"]]]:
        '''multi_compute block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        '''
        result = self._values.get("multi_compute")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetChangeDefinitionRequestApmQueryMultiCompute"]]], result)

    @builtins.property
    def search_query(self) -> typing.Optional[builtins.str]:
        '''The search query to use.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        result = self._values.get("search_query")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetChangeDefinitionRequestApmQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionRequestApmQueryComputeQuery",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetChangeDefinitionRequestApmQueryComputeQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2345095dd7afd121906918ed7f1abe01cfedba9ebdcb8799aff98a65392e0d9a)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetChangeDefinitionRequestApmQueryComputeQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetChangeDefinitionRequestApmQueryComputeQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionRequestApmQueryComputeQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__43d7775a21a2c0ec1b90bf20131f1a7555722b039faada06687ea1d184f0ef33)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4a1ae72b6614770febea52f1402b73bf8b88dd44b3a9a2f754e8b56db1ff188f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a3851bf0d691513ab7f4259c29d8988a19e6e28801602e299daf3295c4cab0d4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__107b95079e3a2a968a34cbae859e53c7771350326b39500f96ffc71fb617b546)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetChangeDefinitionRequestApmQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetChangeDefinitionRequestApmQueryComputeQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetChangeDefinitionRequestApmQueryComputeQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__506d2b559aa3cce60d6fa51c84e833d2655d3a021be8219156111dc6e15b6229)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionRequestApmQueryGroupBy",
    jsii_struct_bases=[],
    name_mapping={"facet": "facet", "limit": "limit", "sort_query": "sortQuery"},
)
class PowerpackWidgetChangeDefinitionRequestApmQueryGroupBy:
    def __init__(
        self,
        *,
        facet: typing.Optional[builtins.str] = None,
        limit: typing.Optional[jsii.Number] = None,
        sort_query: typing.Optional[typing.Union["PowerpackWidgetChangeDefinitionRequestApmQueryGroupBySortQuery", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param limit: The maximum number of items in the group. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param sort_query: sort_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        if isinstance(sort_query, dict):
            sort_query = PowerpackWidgetChangeDefinitionRequestApmQueryGroupBySortQuery(**sort_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__84a2e7ec2710a7352f360859eaae412791e6f3417d1d924759ac463dc0d76d04)
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
            check_type(argname="argument sort_query", value=sort_query, expected_type=type_hints["sort_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if facet is not None:
            self._values["facet"] = facet
        if limit is not None:
            self._values["limit"] = limit
        if sort_query is not None:
            self._values["sort_query"] = sort_query

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def limit(self) -> typing.Optional[jsii.Number]:
        '''The maximum number of items in the group.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        '''
        result = self._values.get("limit")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def sort_query(
        self,
    ) -> typing.Optional["PowerpackWidgetChangeDefinitionRequestApmQueryGroupBySortQuery"]:
        '''sort_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        result = self._values.get("sort_query")
        return typing.cast(typing.Optional["PowerpackWidgetChangeDefinitionRequestApmQueryGroupBySortQuery"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetChangeDefinitionRequestApmQueryGroupBy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetChangeDefinitionRequestApmQueryGroupByList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionRequestApmQueryGroupByList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b107829ce7c18ab19a5e29882cae6c3432d3ef6242d498e432f76ba3032c7492)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetChangeDefinitionRequestApmQueryGroupByOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e08752e431002c8de01706f4754b992eaa8e2fd75e44f86da36f51fc49dbb530)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetChangeDefinitionRequestApmQueryGroupByOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__89bd9bc97c05c42965a72b3a04f97a109c18f59da44d733c1de8457bd7981338)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__70e59f1ad1f1d256e21d3505dccf6531e47116f93da27f477c0ba4df7f63db69)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__beadb7c662b921cf154652d5230f9808d41f2e7731a75bc497f0d464f468e67e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetChangeDefinitionRequestApmQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetChangeDefinitionRequestApmQueryGroupBy]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetChangeDefinitionRequestApmQueryGroupBy]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__99a736826c7c6705ba597d59fac216c0aa1978a43b59426718cd47b542ae2dfa)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetChangeDefinitionRequestApmQueryGroupByOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionRequestApmQueryGroupByOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__57d79e5bfd38a938b8593cebac04b7332b5eb9ae8d0054870a5e6ab76d15b850)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putSortQuery")
    def put_sort_query(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        value = PowerpackWidgetChangeDefinitionRequestApmQueryGroupBySortQuery(
            aggregation=aggregation, order=order, facet=facet
        )

        return typing.cast(None, jsii.invoke(self, "putSortQuery", [value]))

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetLimit")
    def reset_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLimit", []))

    @jsii.member(jsii_name="resetSortQuery")
    def reset_sort_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSortQuery", []))

    @builtins.property
    @jsii.member(jsii_name="sortQuery")
    def sort_query(
        self,
    ) -> "PowerpackWidgetChangeDefinitionRequestApmQueryGroupBySortQueryOutputReference":
        return typing.cast("PowerpackWidgetChangeDefinitionRequestApmQueryGroupBySortQueryOutputReference", jsii.get(self, "sortQuery"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="limitInput")
    def limit_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "limitInput"))

    @builtins.property
    @jsii.member(jsii_name="sortQueryInput")
    def sort_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetChangeDefinitionRequestApmQueryGroupBySortQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetChangeDefinitionRequestApmQueryGroupBySortQuery"], jsii.get(self, "sortQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__39462667ce3f6e6bb1fa65a47a5bb051835122e7d3388733b8498774c43b7ea0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="limit")
    def limit(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "limit"))

    @limit.setter
    def limit(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1957bd861a3fb06b8dfc3ef7b07908b8f008f4b7533523f7284c01531e90b4c0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "limit", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetChangeDefinitionRequestApmQueryGroupBy]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetChangeDefinitionRequestApmQueryGroupBy]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetChangeDefinitionRequestApmQueryGroupBy]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e2f96b1867ba2bca7b056755be489c7992a183c3ce06a70ee4bbba1b31be34c3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionRequestApmQueryGroupBySortQuery",
    jsii_struct_bases=[],
    name_mapping={"aggregation": "aggregation", "order": "order", "facet": "facet"},
)
class PowerpackWidgetChangeDefinitionRequestApmQueryGroupBySortQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__61c9285722ae637810956a21de071465cfdb5deec464658835d2fc48c9fbde22)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument order", value=order, expected_type=type_hints["order"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
            "order": order,
        }
        if facet is not None:
            self._values["facet"] = facet

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def order(self) -> builtins.str:
        '''Widget sorting methods. Valid values are ``asc``, ``desc``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        result = self._values.get("order")
        assert result is not None, "Required property 'order' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetChangeDefinitionRequestApmQueryGroupBySortQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetChangeDefinitionRequestApmQueryGroupBySortQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionRequestApmQueryGroupBySortQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__87e2c35959eff448b834cb5749ccf684cd5932ceec89b2969dcc1b44c3bf5c5f)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="orderInput")
    def order_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "orderInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6854742cf175ea9a235cbd3aa54a655cd45fdbd026c323c0e0f0a7de0d6018ff)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e9e3a2e176879d6f149c1ab951726d6011543651d05673384ef68e3e739576fc)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="order")
    def order(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "order"))

    @order.setter
    def order(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7f35b99ef5c9009ecfd9ce9c9f781cc71b464577ccdcb07d941df696fa4574c0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "order", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetChangeDefinitionRequestApmQueryGroupBySortQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetChangeDefinitionRequestApmQueryGroupBySortQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetChangeDefinitionRequestApmQueryGroupBySortQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ac67a31cfa9f9af4c2178d9ab30f6c3e35c72900560a5bb62b3b1a87687d761d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionRequestApmQueryMultiCompute",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetChangeDefinitionRequestApmQueryMultiCompute:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ab94ba0c01f48e72b814240076ada2f6ebc81fad758544dc15b3c9a966923ddd)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetChangeDefinitionRequestApmQueryMultiCompute(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetChangeDefinitionRequestApmQueryMultiComputeList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionRequestApmQueryMultiComputeList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bc8130868670c72fc2885be07431fe7a0fceede63c213a05c6b7723a7d06c0f0)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetChangeDefinitionRequestApmQueryMultiComputeOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b5b8d53a242b6b528cad81b9401eed5eb68da426490bc5fec61dd4edeca742c2)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetChangeDefinitionRequestApmQueryMultiComputeOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__be5a2fd65da5b6a51a11f7045dd967bbb60ce17066b403d7095120dab6abd3e9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ecd8c0211ebc5128533a7af383b824cdbcfa631bd08ff6ac29d1f7673194b872)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dd4ae4ee6f1e707bb40f448575ca640f832fd7ac9f9b770b1c9ec4798125e660)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetChangeDefinitionRequestApmQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetChangeDefinitionRequestApmQueryMultiCompute]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetChangeDefinitionRequestApmQueryMultiCompute]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__79ac547cfe5a0d7edd165bd3ef8c69da9c316e40adc3aaaa0dabdc6485793c6d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetChangeDefinitionRequestApmQueryMultiComputeOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionRequestApmQueryMultiComputeOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9429c5f792861bb7567fceefe2df019a068aeb3bcd01d75fecb883077ab73a10)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fbce79f6994e9a59d1fac8f38ae0c511d37a923b0f98146fb5adcde01bb4ea50)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c53de71f4ac1b51e99feb926759a77110f611fcf10460209a44bcbda18e6b799)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__eecf0794f2bcb0c4a5c4979b0ac4bba20ca49a23efda48d0721edd66a10ff901)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetChangeDefinitionRequestApmQueryMultiCompute]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetChangeDefinitionRequestApmQueryMultiCompute]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetChangeDefinitionRequestApmQueryMultiCompute]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c08844a9f0c1ea2dc62781a70cee2d205822bd3ba602c4c0dc50a896a47c96fc)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetChangeDefinitionRequestApmQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionRequestApmQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__317c13ecbe9918608385248b0ada4666ca92c09e03ee3521cc68babf96aed0bb)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putComputeQuery")
    def put_compute_query(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        value = PowerpackWidgetChangeDefinitionRequestApmQueryComputeQuery(
            aggregation=aggregation, facet=facet, interval=interval
        )

        return typing.cast(None, jsii.invoke(self, "putComputeQuery", [value]))

    @jsii.member(jsii_name="putGroupBy")
    def put_group_by(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetChangeDefinitionRequestApmQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2c4fce86ed4894d2341fa26ee57e4ffe3bb7585db70201dd68118d20e5ce8ef0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putGroupBy", [value]))

    @jsii.member(jsii_name="putMultiCompute")
    def put_multi_compute(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetChangeDefinitionRequestApmQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__31df7f8a793a74e403b03e6b4f4d7f5100a2b7821074845e8fc736b65a03ceb5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putMultiCompute", [value]))

    @jsii.member(jsii_name="resetComputeQuery")
    def reset_compute_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetComputeQuery", []))

    @jsii.member(jsii_name="resetGroupBy")
    def reset_group_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGroupBy", []))

    @jsii.member(jsii_name="resetMultiCompute")
    def reset_multi_compute(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMultiCompute", []))

    @jsii.member(jsii_name="resetSearchQuery")
    def reset_search_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSearchQuery", []))

    @builtins.property
    @jsii.member(jsii_name="computeQuery")
    def compute_query(
        self,
    ) -> PowerpackWidgetChangeDefinitionRequestApmQueryComputeQueryOutputReference:
        return typing.cast(PowerpackWidgetChangeDefinitionRequestApmQueryComputeQueryOutputReference, jsii.get(self, "computeQuery"))

    @builtins.property
    @jsii.member(jsii_name="groupBy")
    def group_by(self) -> PowerpackWidgetChangeDefinitionRequestApmQueryGroupByList:
        return typing.cast(PowerpackWidgetChangeDefinitionRequestApmQueryGroupByList, jsii.get(self, "groupBy"))

    @builtins.property
    @jsii.member(jsii_name="multiCompute")
    def multi_compute(
        self,
    ) -> PowerpackWidgetChangeDefinitionRequestApmQueryMultiComputeList:
        return typing.cast(PowerpackWidgetChangeDefinitionRequestApmQueryMultiComputeList, jsii.get(self, "multiCompute"))

    @builtins.property
    @jsii.member(jsii_name="computeQueryInput")
    def compute_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetChangeDefinitionRequestApmQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetChangeDefinitionRequestApmQueryComputeQuery], jsii.get(self, "computeQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="groupByInput")
    def group_by_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetChangeDefinitionRequestApmQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetChangeDefinitionRequestApmQueryGroupBy]]], jsii.get(self, "groupByInput"))

    @builtins.property
    @jsii.member(jsii_name="indexInput")
    def index_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "indexInput"))

    @builtins.property
    @jsii.member(jsii_name="multiComputeInput")
    def multi_compute_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetChangeDefinitionRequestApmQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetChangeDefinitionRequestApmQueryMultiCompute]]], jsii.get(self, "multiComputeInput"))

    @builtins.property
    @jsii.member(jsii_name="searchQueryInput")
    def search_query_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "searchQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="index")
    def index(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "index"))

    @index.setter
    def index(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bb4ec459c886bcb3db1e986658b703c9293891a172c159cff96c5a97a1cd5530)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "index", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="searchQuery")
    def search_query(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "searchQuery"))

    @search_query.setter
    def search_query(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fef196a23ddd73c91765defa08fe86bb1e96a4eeb6c0c11afc6c11ac2a1572e0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "searchQuery", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetChangeDefinitionRequestApmQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetChangeDefinitionRequestApmQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetChangeDefinitionRequestApmQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__92b13d22f78aea485015e4a31b33af8b209d281ef4db9662ca517d82617b129c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionRequestFormula",
    jsii_struct_bases=[],
    name_mapping={
        "formula_expression": "formulaExpression",
        "alias": "alias",
        "cell_display_mode": "cellDisplayMode",
        "conditional_formats": "conditionalFormats",
        "limit": "limit",
        "number_format": "numberFormat",
        "style": "style",
    },
)
class PowerpackWidgetChangeDefinitionRequestFormula:
    def __init__(
        self,
        *,
        formula_expression: builtins.str,
        alias: typing.Optional[builtins.str] = None,
        cell_display_mode: typing.Optional[builtins.str] = None,
        conditional_formats: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetChangeDefinitionRequestFormulaConditionalFormats", typing.Dict[builtins.str, typing.Any]]]]] = None,
        limit: typing.Optional[typing.Union["PowerpackWidgetChangeDefinitionRequestFormulaLimit", typing.Dict[builtins.str, typing.Any]]] = None,
        number_format: typing.Optional[typing.Union["PowerpackWidgetChangeDefinitionRequestFormulaNumberFormat", typing.Dict[builtins.str, typing.Any]]] = None,
        style: typing.Optional[typing.Union["PowerpackWidgetChangeDefinitionRequestFormulaStyle", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param formula_expression: A string expression built from queries, formulas, and functions. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#formula_expression Powerpack#formula_expression}
        :param alias: An expression alias. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#alias Powerpack#alias}
        :param cell_display_mode: A list of display modes for each table cell. Valid values are ``number``, ``bar``, ``trend``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cell_display_mode Powerpack#cell_display_mode}
        :param conditional_formats: conditional_formats block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#conditional_formats Powerpack#conditional_formats}
        :param limit: limit block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param number_format: number_format block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#number_format Powerpack#number_format}
        :param style: style block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#style Powerpack#style}
        '''
        if isinstance(limit, dict):
            limit = PowerpackWidgetChangeDefinitionRequestFormulaLimit(**limit)
        if isinstance(number_format, dict):
            number_format = PowerpackWidgetChangeDefinitionRequestFormulaNumberFormat(**number_format)
        if isinstance(style, dict):
            style = PowerpackWidgetChangeDefinitionRequestFormulaStyle(**style)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__55fd50d36bf2c6bc6882b61ef6b55837cd040181363212943091365d5ba44878)
            check_type(argname="argument formula_expression", value=formula_expression, expected_type=type_hints["formula_expression"])
            check_type(argname="argument alias", value=alias, expected_type=type_hints["alias"])
            check_type(argname="argument cell_display_mode", value=cell_display_mode, expected_type=type_hints["cell_display_mode"])
            check_type(argname="argument conditional_formats", value=conditional_formats, expected_type=type_hints["conditional_formats"])
            check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
            check_type(argname="argument number_format", value=number_format, expected_type=type_hints["number_format"])
            check_type(argname="argument style", value=style, expected_type=type_hints["style"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "formula_expression": formula_expression,
        }
        if alias is not None:
            self._values["alias"] = alias
        if cell_display_mode is not None:
            self._values["cell_display_mode"] = cell_display_mode
        if conditional_formats is not None:
            self._values["conditional_formats"] = conditional_formats
        if limit is not None:
            self._values["limit"] = limit
        if number_format is not None:
            self._values["number_format"] = number_format
        if style is not None:
            self._values["style"] = style

    @builtins.property
    def formula_expression(self) -> builtins.str:
        '''A string expression built from queries, formulas, and functions.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#formula_expression Powerpack#formula_expression}
        '''
        result = self._values.get("formula_expression")
        assert result is not None, "Required property 'formula_expression' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def alias(self) -> typing.Optional[builtins.str]:
        '''An expression alias.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#alias Powerpack#alias}
        '''
        result = self._values.get("alias")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def cell_display_mode(self) -> typing.Optional[builtins.str]:
        '''A list of display modes for each table cell. Valid values are ``number``, ``bar``, ``trend``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cell_display_mode Powerpack#cell_display_mode}
        '''
        result = self._values.get("cell_display_mode")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def conditional_formats(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetChangeDefinitionRequestFormulaConditionalFormats"]]]:
        '''conditional_formats block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#conditional_formats Powerpack#conditional_formats}
        '''
        result = self._values.get("conditional_formats")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetChangeDefinitionRequestFormulaConditionalFormats"]]], result)

    @builtins.property
    def limit(
        self,
    ) -> typing.Optional["PowerpackWidgetChangeDefinitionRequestFormulaLimit"]:
        '''limit block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        '''
        result = self._values.get("limit")
        return typing.cast(typing.Optional["PowerpackWidgetChangeDefinitionRequestFormulaLimit"], result)

    @builtins.property
    def number_format(
        self,
    ) -> typing.Optional["PowerpackWidgetChangeDefinitionRequestFormulaNumberFormat"]:
        '''number_format block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#number_format Powerpack#number_format}
        '''
        result = self._values.get("number_format")
        return typing.cast(typing.Optional["PowerpackWidgetChangeDefinitionRequestFormulaNumberFormat"], result)

    @builtins.property
    def style(
        self,
    ) -> typing.Optional["PowerpackWidgetChangeDefinitionRequestFormulaStyle"]:
        '''style block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#style Powerpack#style}
        '''
        result = self._values.get("style")
        return typing.cast(typing.Optional["PowerpackWidgetChangeDefinitionRequestFormulaStyle"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetChangeDefinitionRequestFormula(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionRequestFormulaConditionalFormats",
    jsii_struct_bases=[],
    name_mapping={
        "comparator": "comparator",
        "palette": "palette",
        "value": "value",
        "custom_bg_color": "customBgColor",
        "custom_fg_color": "customFgColor",
        "hide_value": "hideValue",
        "image_url": "imageUrl",
        "metric": "metric",
        "timeframe": "timeframe",
    },
)
class PowerpackWidgetChangeDefinitionRequestFormulaConditionalFormats:
    def __init__(
        self,
        *,
        comparator: builtins.str,
        palette: builtins.str,
        value: jsii.Number,
        custom_bg_color: typing.Optional[builtins.str] = None,
        custom_fg_color: typing.Optional[builtins.str] = None,
        hide_value: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        image_url: typing.Optional[builtins.str] = None,
        metric: typing.Optional[builtins.str] = None,
        timeframe: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param comparator: The comparator to use. Valid values are ``=``, ``>``, ``>=``, ``<``, ``<=``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#comparator Powerpack#comparator}
        :param palette: The color palette to apply. Valid values are ``blue``, ``custom_bg``, ``custom_image``, ``custom_text``, ``gray_on_white``, ``grey``, ``green``, ``orange``, ``red``, ``red_on_white``, ``white_on_gray``, ``white_on_green``, ``green_on_white``, ``white_on_red``, ``white_on_yellow``, ``yellow_on_white``, ``black_on_light_yellow``, ``black_on_light_green``, ``black_on_light_red``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette Powerpack#palette}
        :param value: A value for the comparator. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#value Powerpack#value}
        :param custom_bg_color: The color palette to apply to the background, same values available as palette. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom_bg_color Powerpack#custom_bg_color}
        :param custom_fg_color: The color palette to apply to the foreground, same values available as palette. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom_fg_color Powerpack#custom_fg_color}
        :param hide_value: Setting this to True hides values. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#hide_value Powerpack#hide_value}
        :param image_url: Displays an image as the background. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#image_url Powerpack#image_url}
        :param metric: The metric from the request to correlate with this conditional format. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        :param timeframe: Defines the displayed timeframe. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#timeframe Powerpack#timeframe}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__42bf7075d76e3208206b941c3bc8eed0550647b4d52038ed577f889d8d16ff44)
            check_type(argname="argument comparator", value=comparator, expected_type=type_hints["comparator"])
            check_type(argname="argument palette", value=palette, expected_type=type_hints["palette"])
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument custom_bg_color", value=custom_bg_color, expected_type=type_hints["custom_bg_color"])
            check_type(argname="argument custom_fg_color", value=custom_fg_color, expected_type=type_hints["custom_fg_color"])
            check_type(argname="argument hide_value", value=hide_value, expected_type=type_hints["hide_value"])
            check_type(argname="argument image_url", value=image_url, expected_type=type_hints["image_url"])
            check_type(argname="argument metric", value=metric, expected_type=type_hints["metric"])
            check_type(argname="argument timeframe", value=timeframe, expected_type=type_hints["timeframe"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "comparator": comparator,
            "palette": palette,
            "value": value,
        }
        if custom_bg_color is not None:
            self._values["custom_bg_color"] = custom_bg_color
        if custom_fg_color is not None:
            self._values["custom_fg_color"] = custom_fg_color
        if hide_value is not None:
            self._values["hide_value"] = hide_value
        if image_url is not None:
            self._values["image_url"] = image_url
        if metric is not None:
            self._values["metric"] = metric
        if timeframe is not None:
            self._values["timeframe"] = timeframe

    @builtins.property
    def comparator(self) -> builtins.str:
        '''The comparator to use. Valid values are ``=``, ``>``, ``>=``, ``<``, ``<=``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#comparator Powerpack#comparator}
        '''
        result = self._values.get("comparator")
        assert result is not None, "Required property 'comparator' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def palette(self) -> builtins.str:
        '''The color palette to apply.

        Valid values are ``blue``, ``custom_bg``, ``custom_image``, ``custom_text``, ``gray_on_white``, ``grey``, ``green``, ``orange``, ``red``, ``red_on_white``, ``white_on_gray``, ``white_on_green``, ``green_on_white``, ``white_on_red``, ``white_on_yellow``, ``yellow_on_white``, ``black_on_light_yellow``, ``black_on_light_green``, ``black_on_light_red``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette Powerpack#palette}
        '''
        result = self._values.get("palette")
        assert result is not None, "Required property 'palette' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def value(self) -> jsii.Number:
        '''A value for the comparator.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#value Powerpack#value}
        '''
        result = self._values.get("value")
        assert result is not None, "Required property 'value' is missing"
        return typing.cast(jsii.Number, result)

    @builtins.property
    def custom_bg_color(self) -> typing.Optional[builtins.str]:
        '''The color palette to apply to the background, same values available as palette.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom_bg_color Powerpack#custom_bg_color}
        '''
        result = self._values.get("custom_bg_color")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def custom_fg_color(self) -> typing.Optional[builtins.str]:
        '''The color palette to apply to the foreground, same values available as palette.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom_fg_color Powerpack#custom_fg_color}
        '''
        result = self._values.get("custom_fg_color")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def hide_value(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        '''Setting this to True hides values.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#hide_value Powerpack#hide_value}
        '''
        result = self._values.get("hide_value")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)

    @builtins.property
    def image_url(self) -> typing.Optional[builtins.str]:
        '''Displays an image as the background.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#image_url Powerpack#image_url}
        '''
        result = self._values.get("image_url")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def metric(self) -> typing.Optional[builtins.str]:
        '''The metric from the request to correlate with this conditional format.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        '''
        result = self._values.get("metric")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def timeframe(self) -> typing.Optional[builtins.str]:
        '''Defines the displayed timeframe.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#timeframe Powerpack#timeframe}
        '''
        result = self._values.get("timeframe")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetChangeDefinitionRequestFormulaConditionalFormats(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetChangeDefinitionRequestFormulaConditionalFormatsList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionRequestFormulaConditionalFormatsList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0a7a4b2384cc9622b6eab5d2a88969af587cd879323d70017bc5f1c4e8eb2358)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetChangeDefinitionRequestFormulaConditionalFormatsOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c7622d79009b53c74ef1bf45dde54c9a420a167b4fd3133f5ef93f1ddc60d15e)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetChangeDefinitionRequestFormulaConditionalFormatsOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5c1cddbb48220b22bfd4a9de0d0653126badb71ef924e157357e58a3668d602c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a1e57e936155f2abdfda139c1ff6efa5894ec1fe9c5547019ffa08eb5b2f9c3a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1e39b04e0da84c8d5a4a9a5f82b3afdf94e0d2af3d5e75e2ac6bdb256787e15f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetChangeDefinitionRequestFormulaConditionalFormats]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetChangeDefinitionRequestFormulaConditionalFormats]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetChangeDefinitionRequestFormulaConditionalFormats]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6fea580b879bb4e38b9db11ec6ad11ea23ce2609fa5eb8efe079528e18be84f2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetChangeDefinitionRequestFormulaConditionalFormatsOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionRequestFormulaConditionalFormatsOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e6f9a1b464647d2679f92ed52c52596ccd76b45713716a3074ff887ff18bcc17)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetCustomBgColor")
    def reset_custom_bg_color(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCustomBgColor", []))

    @jsii.member(jsii_name="resetCustomFgColor")
    def reset_custom_fg_color(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCustomFgColor", []))

    @jsii.member(jsii_name="resetHideValue")
    def reset_hide_value(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHideValue", []))

    @jsii.member(jsii_name="resetImageUrl")
    def reset_image_url(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetImageUrl", []))

    @jsii.member(jsii_name="resetMetric")
    def reset_metric(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMetric", []))

    @jsii.member(jsii_name="resetTimeframe")
    def reset_timeframe(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTimeframe", []))

    @builtins.property
    @jsii.member(jsii_name="comparatorInput")
    def comparator_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "comparatorInput"))

    @builtins.property
    @jsii.member(jsii_name="customBgColorInput")
    def custom_bg_color_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "customBgColorInput"))

    @builtins.property
    @jsii.member(jsii_name="customFgColorInput")
    def custom_fg_color_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "customFgColorInput"))

    @builtins.property
    @jsii.member(jsii_name="hideValueInput")
    def hide_value_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "hideValueInput"))

    @builtins.property
    @jsii.member(jsii_name="imageUrlInput")
    def image_url_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "imageUrlInput"))

    @builtins.property
    @jsii.member(jsii_name="metricInput")
    def metric_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "metricInput"))

    @builtins.property
    @jsii.member(jsii_name="paletteInput")
    def palette_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "paletteInput"))

    @builtins.property
    @jsii.member(jsii_name="timeframeInput")
    def timeframe_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "timeframeInput"))

    @builtins.property
    @jsii.member(jsii_name="valueInput")
    def value_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "valueInput"))

    @builtins.property
    @jsii.member(jsii_name="comparator")
    def comparator(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "comparator"))

    @comparator.setter
    def comparator(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bc4e2338aa40e7ec965438009b0742c07fe56bad5f1d9a867af868a4397d51a9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "comparator", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="customBgColor")
    def custom_bg_color(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "customBgColor"))

    @custom_bg_color.setter
    def custom_bg_color(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__38376e6f00e4ce446f509ee827bdaf532db472754a1571541499f0d031479b98)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "customBgColor", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="customFgColor")
    def custom_fg_color(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "customFgColor"))

    @custom_fg_color.setter
    def custom_fg_color(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9f7bc35644bbb0e2497b0fb27fb581119009687cedd9b33e4a5ece3024b3ad2e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "customFgColor", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="hideValue")
    def hide_value(self) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "hideValue"))

    @hide_value.setter
    def hide_value(
        self,
        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__665e51df0f4855e51a6b87473811305c321e69d5e45311ccf9e4f5bec4760f39)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "hideValue", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="imageUrl")
    def image_url(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "imageUrl"))

    @image_url.setter
    def image_url(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__68668d2067b1d2ab477fd815d05daff45fcee02f927670494ef6f82b01de462f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "imageUrl", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="metric")
    def metric(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "metric"))

    @metric.setter
    def metric(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d9ab29dc7228c100404f1f63cf695a260b1bc1d64376c706649d9dbae970faad)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "metric", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="palette")
    def palette(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "palette"))

    @palette.setter
    def palette(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fc8729779ee63a5285b012daa0b2f8ec26f759367507ce91d471131e26940e31)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "palette", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="timeframe")
    def timeframe(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "timeframe"))

    @timeframe.setter
    def timeframe(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a30f464fa7636ee1c7ddfbfa040335b83e6f40fb00f65a5bb96c685018d8f71f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "timeframe", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="value")
    def value(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "value"))

    @value.setter
    def value(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a26de78ce78e3c05c53df044ce0db5fda967bc57f99ba4a368d86203fd54dfd9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "value", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetChangeDefinitionRequestFormulaConditionalFormats]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetChangeDefinitionRequestFormulaConditionalFormats]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetChangeDefinitionRequestFormulaConditionalFormats]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9239bca76c2ad41a1c53b44cce03c71620893cc2df88f66bfbdd425950a521d1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionRequestFormulaLimit",
    jsii_struct_bases=[],
    name_mapping={"count": "count", "order": "order"},
)
class PowerpackWidgetChangeDefinitionRequestFormulaLimit:
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        order: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param count: The number of results to return. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#count Powerpack#count}
        :param order: The direction of the sort. Valid values are ``asc``, ``desc``. Defaults to ``"desc"``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c86078caf28d24166b82959b50976accdcd5794220a76f70d78b6cd769561685)
            check_type(argname="argument count", value=count, expected_type=type_hints["count"])
            check_type(argname="argument order", value=order, expected_type=type_hints["order"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if count is not None:
            self._values["count"] = count
        if order is not None:
            self._values["order"] = order

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''The number of results to return.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#count Powerpack#count}
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def order(self) -> typing.Optional[builtins.str]:
        '''The direction of the sort. Valid values are ``asc``, ``desc``. Defaults to ``"desc"``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        result = self._values.get("order")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetChangeDefinitionRequestFormulaLimit(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetChangeDefinitionRequestFormulaLimitOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionRequestFormulaLimitOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c24d7df37ab1ba8b5ec103788d02b5b32793eacf585fe41bd466e075dffb9795)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetCount")
    def reset_count(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCount", []))

    @jsii.member(jsii_name="resetOrder")
    def reset_order(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetOrder", []))

    @builtins.property
    @jsii.member(jsii_name="countInput")
    def count_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "countInput"))

    @builtins.property
    @jsii.member(jsii_name="orderInput")
    def order_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "orderInput"))

    @builtins.property
    @jsii.member(jsii_name="count")
    def count(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "count"))

    @count.setter
    def count(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b42c6e8fcd3d739ae86f1142faaf61d25ad301bc3a0ffea8f3e5834f7a43fef4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "count", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="order")
    def order(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "order"))

    @order.setter
    def order(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fd1aa6135f593606968e96afa60a6369dcac7567439aac36724c0adefa088644)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "order", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetChangeDefinitionRequestFormulaLimit]:
        return typing.cast(typing.Optional[PowerpackWidgetChangeDefinitionRequestFormulaLimit], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetChangeDefinitionRequestFormulaLimit],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__38748684681f8de76f8b5ad9dc7fbb62af81b7f5d71289c62d06b24fccf3368d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetChangeDefinitionRequestFormulaList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionRequestFormulaList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c0aa6b05eed679271d862343945167ed8f45f4827ddc56e2902e8051b6a9c882)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetChangeDefinitionRequestFormulaOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__806b6feca0ce458753b028a223fe2488e2d040014751cf0f881812a38451cec5)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetChangeDefinitionRequestFormulaOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c79f737a83b0620699f5e0dcdc1dc4699c6a7ac6adf9f9ccfbf2fac54acc1fb5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8f1656254c022439c8412574222cff596314e1cd19cd427e3e68fc584678b697)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__69d3c11cf7393a19ee59f41accc029e090428e373860616294abae9f8e85f5db)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetChangeDefinitionRequestFormula]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetChangeDefinitionRequestFormula]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetChangeDefinitionRequestFormula]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d909a257d0677275341f70b980b7b436806508d4fefe307404875e0c6042ef19)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionRequestFormulaNumberFormat",
    jsii_struct_bases=[],
    name_mapping={"unit": "unit", "unit_scale": "unitScale"},
)
class PowerpackWidgetChangeDefinitionRequestFormulaNumberFormat:
    def __init__(
        self,
        *,
        unit: typing.Union["PowerpackWidgetChangeDefinitionRequestFormulaNumberFormatUnit", typing.Dict[builtins.str, typing.Any]],
        unit_scale: typing.Optional[typing.Union["PowerpackWidgetChangeDefinitionRequestFormulaNumberFormatUnitScale", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param unit: unit block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit Powerpack#unit}
        :param unit_scale: unit_scale block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit_scale Powerpack#unit_scale}
        '''
        if isinstance(unit, dict):
            unit = PowerpackWidgetChangeDefinitionRequestFormulaNumberFormatUnit(**unit)
        if isinstance(unit_scale, dict):
            unit_scale = PowerpackWidgetChangeDefinitionRequestFormulaNumberFormatUnitScale(**unit_scale)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1bce563587ffcd51a82079327ff4be4faf9fb573661ad86b012bbfb69e932e24)
            check_type(argname="argument unit", value=unit, expected_type=type_hints["unit"])
            check_type(argname="argument unit_scale", value=unit_scale, expected_type=type_hints["unit_scale"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "unit": unit,
        }
        if unit_scale is not None:
            self._values["unit_scale"] = unit_scale

    @builtins.property
    def unit(self) -> "PowerpackWidgetChangeDefinitionRequestFormulaNumberFormatUnit":
        '''unit block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit Powerpack#unit}
        '''
        result = self._values.get("unit")
        assert result is not None, "Required property 'unit' is missing"
        return typing.cast("PowerpackWidgetChangeDefinitionRequestFormulaNumberFormatUnit", result)

    @builtins.property
    def unit_scale(
        self,
    ) -> typing.Optional["PowerpackWidgetChangeDefinitionRequestFormulaNumberFormatUnitScale"]:
        '''unit_scale block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit_scale Powerpack#unit_scale}
        '''
        result = self._values.get("unit_scale")
        return typing.cast(typing.Optional["PowerpackWidgetChangeDefinitionRequestFormulaNumberFormatUnitScale"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetChangeDefinitionRequestFormulaNumberFormat(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetChangeDefinitionRequestFormulaNumberFormatOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionRequestFormulaNumberFormatOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5a71bf9fc90e9c4720f86b4fd2a8b8bc9833a370ef1e3ec24fdc817667bcc4da)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putUnit")
    def put_unit(
        self,
        *,
        canonical: typing.Optional[typing.Union["PowerpackWidgetChangeDefinitionRequestFormulaNumberFormatUnitCanonical", typing.Dict[builtins.str, typing.Any]]] = None,
        custom: typing.Optional[typing.Union["PowerpackWidgetChangeDefinitionRequestFormulaNumberFormatUnitCustom", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param canonical: canonical block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#canonical Powerpack#canonical}
        :param custom: custom block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom Powerpack#custom}
        '''
        value = PowerpackWidgetChangeDefinitionRequestFormulaNumberFormatUnit(
            canonical=canonical, custom=custom
        )

        return typing.cast(None, jsii.invoke(self, "putUnit", [value]))

    @jsii.member(jsii_name="putUnitScale")
    def put_unit_scale(self, *, unit_name: builtins.str) -> None:
        '''
        :param unit_name: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit_name Powerpack#unit_name}.
        '''
        value = PowerpackWidgetChangeDefinitionRequestFormulaNumberFormatUnitScale(
            unit_name=unit_name
        )

        return typing.cast(None, jsii.invoke(self, "putUnitScale", [value]))

    @jsii.member(jsii_name="resetUnitScale")
    def reset_unit_scale(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetUnitScale", []))

    @builtins.property
    @jsii.member(jsii_name="unit")
    def unit(
        self,
    ) -> "PowerpackWidgetChangeDefinitionRequestFormulaNumberFormatUnitOutputReference":
        return typing.cast("PowerpackWidgetChangeDefinitionRequestFormulaNumberFormatUnitOutputReference", jsii.get(self, "unit"))

    @builtins.property
    @jsii.member(jsii_name="unitScale")
    def unit_scale(
        self,
    ) -> "PowerpackWidgetChangeDefinitionRequestFormulaNumberFormatUnitScaleOutputReference":
        return typing.cast("PowerpackWidgetChangeDefinitionRequestFormulaNumberFormatUnitScaleOutputReference", jsii.get(self, "unitScale"))

    @builtins.property
    @jsii.member(jsii_name="unitInput")
    def unit_input(
        self,
    ) -> typing.Optional["PowerpackWidgetChangeDefinitionRequestFormulaNumberFormatUnit"]:
        return typing.cast(typing.Optional["PowerpackWidgetChangeDefinitionRequestFormulaNumberFormatUnit"], jsii.get(self, "unitInput"))

    @builtins.property
    @jsii.member(jsii_name="unitScaleInput")
    def unit_scale_input(
        self,
    ) -> typing.Optional["PowerpackWidgetChangeDefinitionRequestFormulaNumberFormatUnitScale"]:
        return typing.cast(typing.Optional["PowerpackWidgetChangeDefinitionRequestFormulaNumberFormatUnitScale"], jsii.get(self, "unitScaleInput"))

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetChangeDefinitionRequestFormulaNumberFormat]:
        return typing.cast(typing.Optional[PowerpackWidgetChangeDefinitionRequestFormulaNumberFormat], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetChangeDefinitionRequestFormulaNumberFormat],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__04db5296ebf85d23fd74482f8a5fb5feb6dfadaf4a90e4381572984b69d4aa33)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionRequestFormulaNumberFormatUnit",
    jsii_struct_bases=[],
    name_mapping={"canonical": "canonical", "custom": "custom"},
)
class PowerpackWidgetChangeDefinitionRequestFormulaNumberFormatUnit:
    def __init__(
        self,
        *,
        canonical: typing.Optional[typing.Union["PowerpackWidgetChangeDefinitionRequestFormulaNumberFormatUnitCanonical", typing.Dict[builtins.str, typing.Any]]] = None,
        custom: typing.Optional[typing.Union["PowerpackWidgetChangeDefinitionRequestFormulaNumberFormatUnitCustom", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param canonical: canonical block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#canonical Powerpack#canonical}
        :param custom: custom block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom Powerpack#custom}
        '''
        if isinstance(canonical, dict):
            canonical = PowerpackWidgetChangeDefinitionRequestFormulaNumberFormatUnitCanonical(**canonical)
        if isinstance(custom, dict):
            custom = PowerpackWidgetChangeDefinitionRequestFormulaNumberFormatUnitCustom(**custom)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0f7af4f967f70f23388486779b40b29de78d900e6e9ce65d5682edc903276cd6)
            check_type(argname="argument canonical", value=canonical, expected_type=type_hints["canonical"])
            check_type(argname="argument custom", value=custom, expected_type=type_hints["custom"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if canonical is not None:
            self._values["canonical"] = canonical
        if custom is not None:
            self._values["custom"] = custom

    @builtins.property
    def canonical(
        self,
    ) -> typing.Optional["PowerpackWidgetChangeDefinitionRequestFormulaNumberFormatUnitCanonical"]:
        '''canonical block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#canonical Powerpack#canonical}
        '''
        result = self._values.get("canonical")
        return typing.cast(typing.Optional["PowerpackWidgetChangeDefinitionRequestFormulaNumberFormatUnitCanonical"], result)

    @builtins.property
    def custom(
        self,
    ) -> typing.Optional["PowerpackWidgetChangeDefinitionRequestFormulaNumberFormatUnitCustom"]:
        '''custom block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom Powerpack#custom}
        '''
        result = self._values.get("custom")
        return typing.cast(typing.Optional["PowerpackWidgetChangeDefinitionRequestFormulaNumberFormatUnitCustom"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetChangeDefinitionRequestFormulaNumberFormatUnit(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionRequestFormulaNumberFormatUnitCanonical",
    jsii_struct_bases=[],
    name_mapping={"unit_name": "unitName", "per_unit_name": "perUnitName"},
)
class PowerpackWidgetChangeDefinitionRequestFormulaNumberFormatUnitCanonical:
    def __init__(
        self,
        *,
        unit_name: builtins.str,
        per_unit_name: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param unit_name: Unit name. It should be in singular form ('megabyte' and not 'megabytes'). Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit_name Powerpack#unit_name}
        :param per_unit_name: per unit name. If you want to represent megabytes/s, you set 'unit_name' = 'megabyte' and 'per_unit_name = 'second'. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#per_unit_name Powerpack#per_unit_name}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d9e552149db8cdec0c74155e689c2bb4234baf2ea74c7cf5902e0a9ceb901f28)
            check_type(argname="argument unit_name", value=unit_name, expected_type=type_hints["unit_name"])
            check_type(argname="argument per_unit_name", value=per_unit_name, expected_type=type_hints["per_unit_name"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "unit_name": unit_name,
        }
        if per_unit_name is not None:
            self._values["per_unit_name"] = per_unit_name

    @builtins.property
    def unit_name(self) -> builtins.str:
        '''Unit name. It should be in singular form ('megabyte' and not 'megabytes').

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit_name Powerpack#unit_name}
        '''
        result = self._values.get("unit_name")
        assert result is not None, "Required property 'unit_name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def per_unit_name(self) -> typing.Optional[builtins.str]:
        '''per unit name. If you want to represent megabytes/s, you set 'unit_name' = 'megabyte' and 'per_unit_name = 'second'.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#per_unit_name Powerpack#per_unit_name}
        '''
        result = self._values.get("per_unit_name")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetChangeDefinitionRequestFormulaNumberFormatUnitCanonical(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetChangeDefinitionRequestFormulaNumberFormatUnitCanonicalOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionRequestFormulaNumberFormatUnitCanonicalOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5c5c52aee196135f607b609122a3d11d225303a48b779ae66f3d31357572f731)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetPerUnitName")
    def reset_per_unit_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPerUnitName", []))

    @builtins.property
    @jsii.member(jsii_name="perUnitNameInput")
    def per_unit_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "perUnitNameInput"))

    @builtins.property
    @jsii.member(jsii_name="unitNameInput")
    def unit_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "unitNameInput"))

    @builtins.property
    @jsii.member(jsii_name="perUnitName")
    def per_unit_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "perUnitName"))

    @per_unit_name.setter
    def per_unit_name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f78f8b66ee8d2e39f91e4033eb3af9a67b003da28e73d92d1db46d2d37f7eeb0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "perUnitName", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="unitName")
    def unit_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "unitName"))

    @unit_name.setter
    def unit_name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__16ad90490e80498d8c817831fc16cceddb2229bdcd490e234198a0e7693fdfa8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "unitName", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetChangeDefinitionRequestFormulaNumberFormatUnitCanonical]:
        return typing.cast(typing.Optional[PowerpackWidgetChangeDefinitionRequestFormulaNumberFormatUnitCanonical], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetChangeDefinitionRequestFormulaNumberFormatUnitCanonical],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__897c10dcbdd9b6f1d89acf7b147d91f2145e9e4ce3e7ac175216224832cd21fe)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionRequestFormulaNumberFormatUnitCustom",
    jsii_struct_bases=[],
    name_mapping={"label": "label"},
)
class PowerpackWidgetChangeDefinitionRequestFormulaNumberFormatUnitCustom:
    def __init__(self, *, label: builtins.str) -> None:
        '''
        :param label: Unit label. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#label Powerpack#label}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5da005aa0dbf1b01070beb77d37e6e0aefe7e59a2637f0c1b616c3e1069c4779)
            check_type(argname="argument label", value=label, expected_type=type_hints["label"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "label": label,
        }

    @builtins.property
    def label(self) -> builtins.str:
        '''Unit label.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#label Powerpack#label}
        '''
        result = self._values.get("label")
        assert result is not None, "Required property 'label' is missing"
        return typing.cast(builtins.str, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetChangeDefinitionRequestFormulaNumberFormatUnitCustom(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetChangeDefinitionRequestFormulaNumberFormatUnitCustomOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionRequestFormulaNumberFormatUnitCustomOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e4daffccdd0df6dc28d559db5397f8bb46927395259d87c4268ee99acdc66e50)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @builtins.property
    @jsii.member(jsii_name="labelInput")
    def label_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "labelInput"))

    @builtins.property
    @jsii.member(jsii_name="label")
    def label(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "label"))

    @label.setter
    def label(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__93d6cf85c50be8bec13a9987c344777215dbecc062aaf0f223a046da6f939a89)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "label", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetChangeDefinitionRequestFormulaNumberFormatUnitCustom]:
        return typing.cast(typing.Optional[PowerpackWidgetChangeDefinitionRequestFormulaNumberFormatUnitCustom], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetChangeDefinitionRequestFormulaNumberFormatUnitCustom],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__86ea73db316ec95018b768621998a4dc0a3569b0040d5ff0f7f63bc8b9189e43)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetChangeDefinitionRequestFormulaNumberFormatUnitOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionRequestFormulaNumberFormatUnitOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__efe4f0ba4f5f003c03d118194857ea68d93ff1be171e1509b333c787891dc202)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putCanonical")
    def put_canonical(
        self,
        *,
        unit_name: builtins.str,
        per_unit_name: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param unit_name: Unit name. It should be in singular form ('megabyte' and not 'megabytes'). Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit_name Powerpack#unit_name}
        :param per_unit_name: per unit name. If you want to represent megabytes/s, you set 'unit_name' = 'megabyte' and 'per_unit_name = 'second'. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#per_unit_name Powerpack#per_unit_name}
        '''
        value = PowerpackWidgetChangeDefinitionRequestFormulaNumberFormatUnitCanonical(
            unit_name=unit_name, per_unit_name=per_unit_name
        )

        return typing.cast(None, jsii.invoke(self, "putCanonical", [value]))

    @jsii.member(jsii_name="putCustom")
    def put_custom(self, *, label: builtins.str) -> None:
        '''
        :param label: Unit label. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#label Powerpack#label}
        '''
        value = PowerpackWidgetChangeDefinitionRequestFormulaNumberFormatUnitCustom(
            label=label
        )

        return typing.cast(None, jsii.invoke(self, "putCustom", [value]))

    @jsii.member(jsii_name="resetCanonical")
    def reset_canonical(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCanonical", []))

    @jsii.member(jsii_name="resetCustom")
    def reset_custom(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCustom", []))

    @builtins.property
    @jsii.member(jsii_name="canonical")
    def canonical(
        self,
    ) -> PowerpackWidgetChangeDefinitionRequestFormulaNumberFormatUnitCanonicalOutputReference:
        return typing.cast(PowerpackWidgetChangeDefinitionRequestFormulaNumberFormatUnitCanonicalOutputReference, jsii.get(self, "canonical"))

    @builtins.property
    @jsii.member(jsii_name="custom")
    def custom(
        self,
    ) -> PowerpackWidgetChangeDefinitionRequestFormulaNumberFormatUnitCustomOutputReference:
        return typing.cast(PowerpackWidgetChangeDefinitionRequestFormulaNumberFormatUnitCustomOutputReference, jsii.get(self, "custom"))

    @builtins.property
    @jsii.member(jsii_name="canonicalInput")
    def canonical_input(
        self,
    ) -> typing.Optional[PowerpackWidgetChangeDefinitionRequestFormulaNumberFormatUnitCanonical]:
        return typing.cast(typing.Optional[PowerpackWidgetChangeDefinitionRequestFormulaNumberFormatUnitCanonical], jsii.get(self, "canonicalInput"))

    @builtins.property
    @jsii.member(jsii_name="customInput")
    def custom_input(
        self,
    ) -> typing.Optional[PowerpackWidgetChangeDefinitionRequestFormulaNumberFormatUnitCustom]:
        return typing.cast(typing.Optional[PowerpackWidgetChangeDefinitionRequestFormulaNumberFormatUnitCustom], jsii.get(self, "customInput"))

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetChangeDefinitionRequestFormulaNumberFormatUnit]:
        return typing.cast(typing.Optional[PowerpackWidgetChangeDefinitionRequestFormulaNumberFormatUnit], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetChangeDefinitionRequestFormulaNumberFormatUnit],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3384af0d8469f49640ac75aad603a6a86c58f45bfc5ef2553a1f9af97d07b6bd)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionRequestFormulaNumberFormatUnitScale",
    jsii_struct_bases=[],
    name_mapping={"unit_name": "unitName"},
)
class PowerpackWidgetChangeDefinitionRequestFormulaNumberFormatUnitScale:
    def __init__(self, *, unit_name: builtins.str) -> None:
        '''
        :param unit_name: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit_name Powerpack#unit_name}.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b42e12feb93625b8d8734a5bfb3a036903be1a33d0cf432eaccf0c2a8b5773f1)
            check_type(argname="argument unit_name", value=unit_name, expected_type=type_hints["unit_name"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "unit_name": unit_name,
        }

    @builtins.property
    def unit_name(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit_name Powerpack#unit_name}.'''
        result = self._values.get("unit_name")
        assert result is not None, "Required property 'unit_name' is missing"
        return typing.cast(builtins.str, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetChangeDefinitionRequestFormulaNumberFormatUnitScale(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetChangeDefinitionRequestFormulaNumberFormatUnitScaleOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionRequestFormulaNumberFormatUnitScaleOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__94175bbe1da434401236f555a9772d436ff169a9a98fdb1d7cd877b2fb3d5909)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @builtins.property
    @jsii.member(jsii_name="unitNameInput")
    def unit_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "unitNameInput"))

    @builtins.property
    @jsii.member(jsii_name="unitName")
    def unit_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "unitName"))

    @unit_name.setter
    def unit_name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9f8c63cac30cb4f828f78f26542847527c036496d72fcecd364be47662bb8e16)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "unitName", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetChangeDefinitionRequestFormulaNumberFormatUnitScale]:
        return typing.cast(typing.Optional[PowerpackWidgetChangeDefinitionRequestFormulaNumberFormatUnitScale], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetChangeDefinitionRequestFormulaNumberFormatUnitScale],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f47e313bf13ec7ee8c64b3f6c5315601354d1d45e40cc8efa4afeb004dc2b8fc)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetChangeDefinitionRequestFormulaOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionRequestFormulaOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__95904cb0cc0e3642f4c9eeb46d034015a708fa98bfc0aa7965ca0aac050ef1c8)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putConditionalFormats")
    def put_conditional_formats(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetChangeDefinitionRequestFormulaConditionalFormats, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__51017f2fcc67191cb8fa9a67c1b25253a4657f153eb32d5f87cc4b8c28ede151)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putConditionalFormats", [value]))

    @jsii.member(jsii_name="putLimit")
    def put_limit(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        order: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param count: The number of results to return. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#count Powerpack#count}
        :param order: The direction of the sort. Valid values are ``asc``, ``desc``. Defaults to ``"desc"``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        value = PowerpackWidgetChangeDefinitionRequestFormulaLimit(
            count=count, order=order
        )

        return typing.cast(None, jsii.invoke(self, "putLimit", [value]))

    @jsii.member(jsii_name="putNumberFormat")
    def put_number_format(
        self,
        *,
        unit: typing.Union[PowerpackWidgetChangeDefinitionRequestFormulaNumberFormatUnit, typing.Dict[builtins.str, typing.Any]],
        unit_scale: typing.Optional[typing.Union[PowerpackWidgetChangeDefinitionRequestFormulaNumberFormatUnitScale, typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param unit: unit block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit Powerpack#unit}
        :param unit_scale: unit_scale block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit_scale Powerpack#unit_scale}
        '''
        value = PowerpackWidgetChangeDefinitionRequestFormulaNumberFormat(
            unit=unit, unit_scale=unit_scale
        )

        return typing.cast(None, jsii.invoke(self, "putNumberFormat", [value]))

    @jsii.member(jsii_name="putStyle")
    def put_style(
        self,
        *,
        palette: typing.Optional[builtins.str] = None,
        palette_index: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param palette: The color palette used to display the formula. A guide to the available color palettes can be found at https://docs.datadoghq.com/dashboards/guide/widget_colors. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette Powerpack#palette}
        :param palette_index: Index specifying which color to use within the palette. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette_index Powerpack#palette_index}
        '''
        value = PowerpackWidgetChangeDefinitionRequestFormulaStyle(
            palette=palette, palette_index=palette_index
        )

        return typing.cast(None, jsii.invoke(self, "putStyle", [value]))

    @jsii.member(jsii_name="resetAlias")
    def reset_alias(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAlias", []))

    @jsii.member(jsii_name="resetCellDisplayMode")
    def reset_cell_display_mode(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCellDisplayMode", []))

    @jsii.member(jsii_name="resetConditionalFormats")
    def reset_conditional_formats(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetConditionalFormats", []))

    @jsii.member(jsii_name="resetLimit")
    def reset_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLimit", []))

    @jsii.member(jsii_name="resetNumberFormat")
    def reset_number_format(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetNumberFormat", []))

    @jsii.member(jsii_name="resetStyle")
    def reset_style(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetStyle", []))

    @builtins.property
    @jsii.member(jsii_name="conditionalFormats")
    def conditional_formats(
        self,
    ) -> PowerpackWidgetChangeDefinitionRequestFormulaConditionalFormatsList:
        return typing.cast(PowerpackWidgetChangeDefinitionRequestFormulaConditionalFormatsList, jsii.get(self, "conditionalFormats"))

    @builtins.property
    @jsii.member(jsii_name="limit")
    def limit(
        self,
    ) -> PowerpackWidgetChangeDefinitionRequestFormulaLimitOutputReference:
        return typing.cast(PowerpackWidgetChangeDefinitionRequestFormulaLimitOutputReference, jsii.get(self, "limit"))

    @builtins.property
    @jsii.member(jsii_name="numberFormat")
    def number_format(
        self,
    ) -> PowerpackWidgetChangeDefinitionRequestFormulaNumberFormatOutputReference:
        return typing.cast(PowerpackWidgetChangeDefinitionRequestFormulaNumberFormatOutputReference, jsii.get(self, "numberFormat"))

    @builtins.property
    @jsii.member(jsii_name="style")
    def style(
        self,
    ) -> "PowerpackWidgetChangeDefinitionRequestFormulaStyleOutputReference":
        return typing.cast("PowerpackWidgetChangeDefinitionRequestFormulaStyleOutputReference", jsii.get(self, "style"))

    @builtins.property
    @jsii.member(jsii_name="aliasInput")
    def alias_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aliasInput"))

    @builtins.property
    @jsii.member(jsii_name="cellDisplayModeInput")
    def cell_display_mode_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "cellDisplayModeInput"))

    @builtins.property
    @jsii.member(jsii_name="conditionalFormatsInput")
    def conditional_formats_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetChangeDefinitionRequestFormulaConditionalFormats]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetChangeDefinitionRequestFormulaConditionalFormats]]], jsii.get(self, "conditionalFormatsInput"))

    @builtins.property
    @jsii.member(jsii_name="formulaExpressionInput")
    def formula_expression_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "formulaExpressionInput"))

    @builtins.property
    @jsii.member(jsii_name="limitInput")
    def limit_input(
        self,
    ) -> typing.Optional[PowerpackWidgetChangeDefinitionRequestFormulaLimit]:
        return typing.cast(typing.Optional[PowerpackWidgetChangeDefinitionRequestFormulaLimit], jsii.get(self, "limitInput"))

    @builtins.property
    @jsii.member(jsii_name="numberFormatInput")
    def number_format_input(
        self,
    ) -> typing.Optional[PowerpackWidgetChangeDefinitionRequestFormulaNumberFormat]:
        return typing.cast(typing.Optional[PowerpackWidgetChangeDefinitionRequestFormulaNumberFormat], jsii.get(self, "numberFormatInput"))

    @builtins.property
    @jsii.member(jsii_name="styleInput")
    def style_input(
        self,
    ) -> typing.Optional["PowerpackWidgetChangeDefinitionRequestFormulaStyle"]:
        return typing.cast(typing.Optional["PowerpackWidgetChangeDefinitionRequestFormulaStyle"], jsii.get(self, "styleInput"))

    @builtins.property
    @jsii.member(jsii_name="alias")
    def alias(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "alias"))

    @alias.setter
    def alias(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d49a8378ce6b0d4707d788ecfe30920526e9727cfe98b61c5bfb4b63db3421c6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "alias", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="cellDisplayMode")
    def cell_display_mode(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "cellDisplayMode"))

    @cell_display_mode.setter
    def cell_display_mode(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__499325ff84cdabc941d5870aff16570609cd653dc189f561e25993d0b9fa01cf)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "cellDisplayMode", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="formulaExpression")
    def formula_expression(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "formulaExpression"))

    @formula_expression.setter
    def formula_expression(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ee589b22e1d1ff14e29c12594d96fc76cb963d7dafdd784a04ce256f25b0d9d7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "formulaExpression", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetChangeDefinitionRequestFormula]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetChangeDefinitionRequestFormula]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetChangeDefinitionRequestFormula]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ca68621a20074d4fbe686bbea713229ae864965e276dc11f63966cab43d9e1c6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionRequestFormulaStyle",
    jsii_struct_bases=[],
    name_mapping={"palette": "palette", "palette_index": "paletteIndex"},
)
class PowerpackWidgetChangeDefinitionRequestFormulaStyle:
    def __init__(
        self,
        *,
        palette: typing.Optional[builtins.str] = None,
        palette_index: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param palette: The color palette used to display the formula. A guide to the available color palettes can be found at https://docs.datadoghq.com/dashboards/guide/widget_colors. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette Powerpack#palette}
        :param palette_index: Index specifying which color to use within the palette. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette_index Powerpack#palette_index}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__41a79bc9d8457df59c67a16bd43bbe0b99c33328102e8dc01277507edc514d6b)
            check_type(argname="argument palette", value=palette, expected_type=type_hints["palette"])
            check_type(argname="argument palette_index", value=palette_index, expected_type=type_hints["palette_index"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if palette is not None:
            self._values["palette"] = palette
        if palette_index is not None:
            self._values["palette_index"] = palette_index

    @builtins.property
    def palette(self) -> typing.Optional[builtins.str]:
        '''The color palette used to display the formula.

        A guide to the available color palettes can be found at https://docs.datadoghq.com/dashboards/guide/widget_colors.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette Powerpack#palette}
        '''
        result = self._values.get("palette")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def palette_index(self) -> typing.Optional[jsii.Number]:
        '''Index specifying which color to use within the palette.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette_index Powerpack#palette_index}
        '''
        result = self._values.get("palette_index")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetChangeDefinitionRequestFormulaStyle(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetChangeDefinitionRequestFormulaStyleOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionRequestFormulaStyleOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__876aa9360c665afeb9b56ecc52892dffef20dc8ff5ff845ceabdc8de1fe95f67)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetPalette")
    def reset_palette(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPalette", []))

    @jsii.member(jsii_name="resetPaletteIndex")
    def reset_palette_index(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPaletteIndex", []))

    @builtins.property
    @jsii.member(jsii_name="paletteIndexInput")
    def palette_index_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "paletteIndexInput"))

    @builtins.property
    @jsii.member(jsii_name="paletteInput")
    def palette_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "paletteInput"))

    @builtins.property
    @jsii.member(jsii_name="palette")
    def palette(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "palette"))

    @palette.setter
    def palette(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5160002f394992ecf112629275978a8330da8774c98499432a623932176eb6c3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "palette", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="paletteIndex")
    def palette_index(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "paletteIndex"))

    @palette_index.setter
    def palette_index(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__55f23190f05b2970ec410706a92524597808f020ab4208ea7ef8dd6bd40b0033)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "paletteIndex", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetChangeDefinitionRequestFormulaStyle]:
        return typing.cast(typing.Optional[PowerpackWidgetChangeDefinitionRequestFormulaStyle], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetChangeDefinitionRequestFormulaStyle],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8c88051f0cd0f948a3c946da27412466af63dd9e2a65e672c03a2960f083e258)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetChangeDefinitionRequestList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionRequestList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__55acb206c9f38eca53f8dd37e06ccef3883315a1f5645b8a859aecda50ea2952)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetChangeDefinitionRequestOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__60917aac89b63f289bce87351d5ad4b1e9b0beb57606561b7bc240f9639dfe2e)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetChangeDefinitionRequestOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cc707fbe556e6a53466d14d29958056a7b1abfdd2eed04466792b6e173c355c9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__482fc90c52f61398aa49b9648aeab9df421b9c46e7c08cd00eb8ed3ddc459125)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a3e6813928a3a64da6c7c3271f00a3c78ec56ba5ef972c56a75e287fa03cf93c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetChangeDefinitionRequest]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetChangeDefinitionRequest]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetChangeDefinitionRequest]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5e98b7bef70a496b2c002fb333f6119296e42b409e655f11ff940364a9431b37)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionRequestLogQuery",
    jsii_struct_bases=[],
    name_mapping={
        "index": "index",
        "compute_query": "computeQuery",
        "group_by": "groupBy",
        "multi_compute": "multiCompute",
        "search_query": "searchQuery",
    },
)
class PowerpackWidgetChangeDefinitionRequestLogQuery:
    def __init__(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union["PowerpackWidgetChangeDefinitionRequestLogQueryComputeQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetChangeDefinitionRequestLogQueryGroupBy", typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetChangeDefinitionRequestLogQueryMultiCompute", typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        if isinstance(compute_query, dict):
            compute_query = PowerpackWidgetChangeDefinitionRequestLogQueryComputeQuery(**compute_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ddf02bcb1dbbf9eebb722cb94d4001c3a23664daca9a696580556b65b8437b46)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
            check_type(argname="argument compute_query", value=compute_query, expected_type=type_hints["compute_query"])
            check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
            check_type(argname="argument multi_compute", value=multi_compute, expected_type=type_hints["multi_compute"])
            check_type(argname="argument search_query", value=search_query, expected_type=type_hints["search_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "index": index,
        }
        if compute_query is not None:
            self._values["compute_query"] = compute_query
        if group_by is not None:
            self._values["group_by"] = group_by
        if multi_compute is not None:
            self._values["multi_compute"] = multi_compute
        if search_query is not None:
            self._values["search_query"] = search_query

    @builtins.property
    def index(self) -> builtins.str:
        '''The name of the index to query.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        '''
        result = self._values.get("index")
        assert result is not None, "Required property 'index' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def compute_query(
        self,
    ) -> typing.Optional["PowerpackWidgetChangeDefinitionRequestLogQueryComputeQuery"]:
        '''compute_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        '''
        result = self._values.get("compute_query")
        return typing.cast(typing.Optional["PowerpackWidgetChangeDefinitionRequestLogQueryComputeQuery"], result)

    @builtins.property
    def group_by(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetChangeDefinitionRequestLogQueryGroupBy"]]]:
        '''group_by block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        '''
        result = self._values.get("group_by")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetChangeDefinitionRequestLogQueryGroupBy"]]], result)

    @builtins.property
    def multi_compute(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetChangeDefinitionRequestLogQueryMultiCompute"]]]:
        '''multi_compute block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        '''
        result = self._values.get("multi_compute")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetChangeDefinitionRequestLogQueryMultiCompute"]]], result)

    @builtins.property
    def search_query(self) -> typing.Optional[builtins.str]:
        '''The search query to use.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        result = self._values.get("search_query")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetChangeDefinitionRequestLogQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionRequestLogQueryComputeQuery",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetChangeDefinitionRequestLogQueryComputeQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f1c440c64415471b60efe70dd3be39c4ed8be13438cfe50a2c0aef47e9c2db23)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetChangeDefinitionRequestLogQueryComputeQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetChangeDefinitionRequestLogQueryComputeQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionRequestLogQueryComputeQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__508125d1a6a4d3a19198825acffcd25180027840080e40d3319428e7c645582a)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0d149674dfea276f19a52f9b87b64440b9f804197ec47fa604ec1856b4fb616f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3aacbffc6bfde3c345b0fcaad161d6c0ef0984da7aed42ecf3a7294b9cc4d9f5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0a65374e7d12a99366f3177533db77a7ecaee36a24ed03f7b0e9790f2b7c2c10)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetChangeDefinitionRequestLogQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetChangeDefinitionRequestLogQueryComputeQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetChangeDefinitionRequestLogQueryComputeQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__44f0c0db59d58564644ff5c0b9e5b9dbcd01dba257618aad2bbe604be6b14af5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionRequestLogQueryGroupBy",
    jsii_struct_bases=[],
    name_mapping={"facet": "facet", "limit": "limit", "sort_query": "sortQuery"},
)
class PowerpackWidgetChangeDefinitionRequestLogQueryGroupBy:
    def __init__(
        self,
        *,
        facet: typing.Optional[builtins.str] = None,
        limit: typing.Optional[jsii.Number] = None,
        sort_query: typing.Optional[typing.Union["PowerpackWidgetChangeDefinitionRequestLogQueryGroupBySortQuery", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param limit: The maximum number of items in the group. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param sort_query: sort_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        if isinstance(sort_query, dict):
            sort_query = PowerpackWidgetChangeDefinitionRequestLogQueryGroupBySortQuery(**sort_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6a7a00205962c76019c6a241eda84e822f8bbbb0b4c6f12f67577b8d399f1c0e)
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
            check_type(argname="argument sort_query", value=sort_query, expected_type=type_hints["sort_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if facet is not None:
            self._values["facet"] = facet
        if limit is not None:
            self._values["limit"] = limit
        if sort_query is not None:
            self._values["sort_query"] = sort_query

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def limit(self) -> typing.Optional[jsii.Number]:
        '''The maximum number of items in the group.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        '''
        result = self._values.get("limit")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def sort_query(
        self,
    ) -> typing.Optional["PowerpackWidgetChangeDefinitionRequestLogQueryGroupBySortQuery"]:
        '''sort_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        result = self._values.get("sort_query")
        return typing.cast(typing.Optional["PowerpackWidgetChangeDefinitionRequestLogQueryGroupBySortQuery"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetChangeDefinitionRequestLogQueryGroupBy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetChangeDefinitionRequestLogQueryGroupByList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionRequestLogQueryGroupByList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__36d212496dd9718bff5df404d1d7db8184f723f79e067f0754aacec876d2cbc9)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetChangeDefinitionRequestLogQueryGroupByOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1880dbe8955d584ca2f82601b54b6ae5543c9767a70a08c8af5ab1a6010cc25a)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetChangeDefinitionRequestLogQueryGroupByOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a064be7488ffaa809c4e919c93c3eabfcb3216a65b3eb51a834b003ea6f93afd)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__113cbb7bca1234d7d993bc056b0d5da79159389697389d942c56c85fafe693e6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c7164f3ebc00d8c5b460289267cf63582ca5e1ebf6396c8122aa8ff2db1f715d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetChangeDefinitionRequestLogQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetChangeDefinitionRequestLogQueryGroupBy]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetChangeDefinitionRequestLogQueryGroupBy]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a56d909ef981b399250acb1d73ae76f88fab00a3c9de80d7d8c0f2068b221b48)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetChangeDefinitionRequestLogQueryGroupByOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionRequestLogQueryGroupByOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2ebc755f2c080d383abd575cb5ae3a5106d427106c82574584b599561cf4d697)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putSortQuery")
    def put_sort_query(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        value = PowerpackWidgetChangeDefinitionRequestLogQueryGroupBySortQuery(
            aggregation=aggregation, order=order, facet=facet
        )

        return typing.cast(None, jsii.invoke(self, "putSortQuery", [value]))

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetLimit")
    def reset_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLimit", []))

    @jsii.member(jsii_name="resetSortQuery")
    def reset_sort_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSortQuery", []))

    @builtins.property
    @jsii.member(jsii_name="sortQuery")
    def sort_query(
        self,
    ) -> "PowerpackWidgetChangeDefinitionRequestLogQueryGroupBySortQueryOutputReference":
        return typing.cast("PowerpackWidgetChangeDefinitionRequestLogQueryGroupBySortQueryOutputReference", jsii.get(self, "sortQuery"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="limitInput")
    def limit_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "limitInput"))

    @builtins.property
    @jsii.member(jsii_name="sortQueryInput")
    def sort_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetChangeDefinitionRequestLogQueryGroupBySortQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetChangeDefinitionRequestLogQueryGroupBySortQuery"], jsii.get(self, "sortQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__951a5474764145488e12940441e407ce387b3a423b1e886b947032660d2d34a1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="limit")
    def limit(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "limit"))

    @limit.setter
    def limit(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__228fb84e3c4764938fa0fe95b55663c7dbf9c15680582117a3018dfd43f0b645)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "limit", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetChangeDefinitionRequestLogQueryGroupBy]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetChangeDefinitionRequestLogQueryGroupBy]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetChangeDefinitionRequestLogQueryGroupBy]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__304f55c6750cdf9ffa240358d5af127c4351e9357033c41c22ba363a0ecff672)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionRequestLogQueryGroupBySortQuery",
    jsii_struct_bases=[],
    name_mapping={"aggregation": "aggregation", "order": "order", "facet": "facet"},
)
class PowerpackWidgetChangeDefinitionRequestLogQueryGroupBySortQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bdab3c006e0574d7a28126176fa027b5beaf9e0a06a4086c3801178403aef2fc)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument order", value=order, expected_type=type_hints["order"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
            "order": order,
        }
        if facet is not None:
            self._values["facet"] = facet

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def order(self) -> builtins.str:
        '''Widget sorting methods. Valid values are ``asc``, ``desc``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        result = self._values.get("order")
        assert result is not None, "Required property 'order' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetChangeDefinitionRequestLogQueryGroupBySortQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetChangeDefinitionRequestLogQueryGroupBySortQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionRequestLogQueryGroupBySortQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__353601b4f7457eda415a713f152e5ae8a35112dc72d4af15c3a86377d431e91d)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="orderInput")
    def order_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "orderInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8e961b993d5e0459f8c2f0393b5bbf0312c62681d6c71230132c7adc67c0ee1e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__03379a9dd3263f03afd1d7413d2b1180b82ee7f28c3f0b2613d1aa7be0275615)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="order")
    def order(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "order"))

    @order.setter
    def order(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a8ed87ef40f40281b5860cb6f05677db59d32cebc1f2ed514970081a5e7a6045)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "order", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetChangeDefinitionRequestLogQueryGroupBySortQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetChangeDefinitionRequestLogQueryGroupBySortQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetChangeDefinitionRequestLogQueryGroupBySortQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a8ad93a39c2fe9b3e4c0283825925c830907741d6cd1abb21f5237eb39952b77)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionRequestLogQueryMultiCompute",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetChangeDefinitionRequestLogQueryMultiCompute:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__27cce1c74ffe90ac6b9f1eda9db0e59afa5e62d523ee76e9ad9b260dae158759)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetChangeDefinitionRequestLogQueryMultiCompute(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetChangeDefinitionRequestLogQueryMultiComputeList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionRequestLogQueryMultiComputeList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8bb9469a38728fb996bbd381e9ea0e3ee1546992274e93ac416263f230bf87db)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetChangeDefinitionRequestLogQueryMultiComputeOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__df868e8b4738f51daf8330c3f2cd91fd91f1f788fd56ff8a0a77bd0263434431)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetChangeDefinitionRequestLogQueryMultiComputeOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__70f1725e818de07062c6ebbdf354683a70d374f5c4fc9779868383176c74e737)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5bae2bfd90b10300f9e9ae1cbdfe9f959a6596b45e71b82fd00354e09163121e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2c9f86ea544affe8c974c65ee9d1230a39a609aaf5e85858a24106e8aa3d80d2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetChangeDefinitionRequestLogQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetChangeDefinitionRequestLogQueryMultiCompute]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetChangeDefinitionRequestLogQueryMultiCompute]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f01222309d3c068098e021739b8b892e312f451874a5d1f109bfb49c09351e11)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetChangeDefinitionRequestLogQueryMultiComputeOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionRequestLogQueryMultiComputeOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f0224b7dd0152b8b7a4bf7f19245b5031d25690dea9c0289798ab1593adb8680)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__08ca982db5dce5b020ae8e46502080dd03ceca6d7b0a5d7fee29c911dd911a88)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__38bdf2df04a0587f1deeb4e03161c8ccc0367ad63b490f4e96a6329c01db80bd)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__66809b444ecacb96e5e283a270d222d07c66ee05e2541177e3ea44eb96ab43a5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetChangeDefinitionRequestLogQueryMultiCompute]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetChangeDefinitionRequestLogQueryMultiCompute]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetChangeDefinitionRequestLogQueryMultiCompute]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d4ec026ae9d5c8bacf1ccc8faa05685dd7c16213d4df26f92533053a542faac1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetChangeDefinitionRequestLogQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionRequestLogQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__630ac6326d862d9758ba62e1f07491f82b9a60accf0b662c2f37e880d6b2e602)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putComputeQuery")
    def put_compute_query(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        value = PowerpackWidgetChangeDefinitionRequestLogQueryComputeQuery(
            aggregation=aggregation, facet=facet, interval=interval
        )

        return typing.cast(None, jsii.invoke(self, "putComputeQuery", [value]))

    @jsii.member(jsii_name="putGroupBy")
    def put_group_by(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetChangeDefinitionRequestLogQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f220a7ea07171f134ad698bdc8248fed545c4175f8b53a6f900cd9d1a955b005)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putGroupBy", [value]))

    @jsii.member(jsii_name="putMultiCompute")
    def put_multi_compute(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetChangeDefinitionRequestLogQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b92392da1e5223d571230136084f7514ef7f719914aef168355772ed95c67e8c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putMultiCompute", [value]))

    @jsii.member(jsii_name="resetComputeQuery")
    def reset_compute_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetComputeQuery", []))

    @jsii.member(jsii_name="resetGroupBy")
    def reset_group_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGroupBy", []))

    @jsii.member(jsii_name="resetMultiCompute")
    def reset_multi_compute(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMultiCompute", []))

    @jsii.member(jsii_name="resetSearchQuery")
    def reset_search_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSearchQuery", []))

    @builtins.property
    @jsii.member(jsii_name="computeQuery")
    def compute_query(
        self,
    ) -> PowerpackWidgetChangeDefinitionRequestLogQueryComputeQueryOutputReference:
        return typing.cast(PowerpackWidgetChangeDefinitionRequestLogQueryComputeQueryOutputReference, jsii.get(self, "computeQuery"))

    @builtins.property
    @jsii.member(jsii_name="groupBy")
    def group_by(self) -> PowerpackWidgetChangeDefinitionRequestLogQueryGroupByList:
        return typing.cast(PowerpackWidgetChangeDefinitionRequestLogQueryGroupByList, jsii.get(self, "groupBy"))

    @builtins.property
    @jsii.member(jsii_name="multiCompute")
    def multi_compute(
        self,
    ) -> PowerpackWidgetChangeDefinitionRequestLogQueryMultiComputeList:
        return typing.cast(PowerpackWidgetChangeDefinitionRequestLogQueryMultiComputeList, jsii.get(self, "multiCompute"))

    @builtins.property
    @jsii.member(jsii_name="computeQueryInput")
    def compute_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetChangeDefinitionRequestLogQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetChangeDefinitionRequestLogQueryComputeQuery], jsii.get(self, "computeQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="groupByInput")
    def group_by_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetChangeDefinitionRequestLogQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetChangeDefinitionRequestLogQueryGroupBy]]], jsii.get(self, "groupByInput"))

    @builtins.property
    @jsii.member(jsii_name="indexInput")
    def index_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "indexInput"))

    @builtins.property
    @jsii.member(jsii_name="multiComputeInput")
    def multi_compute_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetChangeDefinitionRequestLogQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetChangeDefinitionRequestLogQueryMultiCompute]]], jsii.get(self, "multiComputeInput"))

    @builtins.property
    @jsii.member(jsii_name="searchQueryInput")
    def search_query_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "searchQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="index")
    def index(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "index"))

    @index.setter
    def index(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__82f4c75778ce62d4860d9a2d3c27297b8ad33a04c302a2717a523237fdd5ce1a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "index", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="searchQuery")
    def search_query(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "searchQuery"))

    @search_query.setter
    def search_query(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f8ce28673287f7d91026ef514a009da9d09a0b48863a0682bd4e8e52afcd5fb8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "searchQuery", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetChangeDefinitionRequestLogQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetChangeDefinitionRequestLogQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetChangeDefinitionRequestLogQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e50e49006569bb92bb2f07d549428a96b3f7647c3345d32b1aed1b6bc5df1f02)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetChangeDefinitionRequestOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionRequestOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a7105e686c64b7081f42607fc9da0f3c71b4c04292507317451326b68ecb1db4)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putApmQuery")
    def put_apm_query(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union[PowerpackWidgetChangeDefinitionRequestApmQueryComputeQuery, typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetChangeDefinitionRequestApmQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetChangeDefinitionRequestApmQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        value = PowerpackWidgetChangeDefinitionRequestApmQuery(
            index=index,
            compute_query=compute_query,
            group_by=group_by,
            multi_compute=multi_compute,
            search_query=search_query,
        )

        return typing.cast(None, jsii.invoke(self, "putApmQuery", [value]))

    @jsii.member(jsii_name="putFormula")
    def put_formula(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetChangeDefinitionRequestFormula, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9410a7aca2baaba08e29a9d0cd9454a282c98847b911adc551c1d3b36745053b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putFormula", [value]))

    @jsii.member(jsii_name="putLogQuery")
    def put_log_query(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union[PowerpackWidgetChangeDefinitionRequestLogQueryComputeQuery, typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetChangeDefinitionRequestLogQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetChangeDefinitionRequestLogQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        value = PowerpackWidgetChangeDefinitionRequestLogQuery(
            index=index,
            compute_query=compute_query,
            group_by=group_by,
            multi_compute=multi_compute,
            search_query=search_query,
        )

        return typing.cast(None, jsii.invoke(self, "putLogQuery", [value]))

    @jsii.member(jsii_name="putProcessQuery")
    def put_process_query(
        self,
        *,
        metric: builtins.str,
        filter_by: typing.Optional[typing.Sequence[builtins.str]] = None,
        limit: typing.Optional[jsii.Number] = None,
        search_by: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param metric: Your chosen metric. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        :param filter_by: A list of processes. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#filter_by Powerpack#filter_by}
        :param limit: The max number of items in the filter list. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param search_by: Your chosen search term. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_by Powerpack#search_by}
        '''
        value = PowerpackWidgetChangeDefinitionRequestProcessQuery(
            metric=metric, filter_by=filter_by, limit=limit, search_by=search_by
        )

        return typing.cast(None, jsii.invoke(self, "putProcessQuery", [value]))

    @jsii.member(jsii_name="putQuery")
    def put_query(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetChangeDefinitionRequestQuery", typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e0b0c740ee177cf32c01610aef95f9a8516a7525f4dbbf821fc71f8d41f32133)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putQuery", [value]))

    @jsii.member(jsii_name="putRumQuery")
    def put_rum_query(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union["PowerpackWidgetChangeDefinitionRequestRumQueryComputeQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetChangeDefinitionRequestRumQueryGroupBy", typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetChangeDefinitionRequestRumQueryMultiCompute", typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        value = PowerpackWidgetChangeDefinitionRequestRumQuery(
            index=index,
            compute_query=compute_query,
            group_by=group_by,
            multi_compute=multi_compute,
            search_query=search_query,
        )

        return typing.cast(None, jsii.invoke(self, "putRumQuery", [value]))

    @jsii.member(jsii_name="putSecurityQuery")
    def put_security_query(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union["PowerpackWidgetChangeDefinitionRequestSecurityQueryComputeQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetChangeDefinitionRequestSecurityQueryGroupBy", typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetChangeDefinitionRequestSecurityQueryMultiCompute", typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        value = PowerpackWidgetChangeDefinitionRequestSecurityQuery(
            index=index,
            compute_query=compute_query,
            group_by=group_by,
            multi_compute=multi_compute,
            search_query=search_query,
        )

        return typing.cast(None, jsii.invoke(self, "putSecurityQuery", [value]))

    @jsii.member(jsii_name="resetApmQuery")
    def reset_apm_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetApmQuery", []))

    @jsii.member(jsii_name="resetChangeType")
    def reset_change_type(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetChangeType", []))

    @jsii.member(jsii_name="resetCompareTo")
    def reset_compare_to(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCompareTo", []))

    @jsii.member(jsii_name="resetFormula")
    def reset_formula(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFormula", []))

    @jsii.member(jsii_name="resetIncreaseGood")
    def reset_increase_good(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetIncreaseGood", []))

    @jsii.member(jsii_name="resetLogQuery")
    def reset_log_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLogQuery", []))

    @jsii.member(jsii_name="resetOrderBy")
    def reset_order_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetOrderBy", []))

    @jsii.member(jsii_name="resetOrderDir")
    def reset_order_dir(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetOrderDir", []))

    @jsii.member(jsii_name="resetProcessQuery")
    def reset_process_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetProcessQuery", []))

    @jsii.member(jsii_name="resetQ")
    def reset_q(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetQ", []))

    @jsii.member(jsii_name="resetQuery")
    def reset_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetQuery", []))

    @jsii.member(jsii_name="resetRumQuery")
    def reset_rum_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetRumQuery", []))

    @jsii.member(jsii_name="resetSecurityQuery")
    def reset_security_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSecurityQuery", []))

    @jsii.member(jsii_name="resetShowPresent")
    def reset_show_present(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetShowPresent", []))

    @builtins.property
    @jsii.member(jsii_name="apmQuery")
    def apm_query(
        self,
    ) -> PowerpackWidgetChangeDefinitionRequestApmQueryOutputReference:
        return typing.cast(PowerpackWidgetChangeDefinitionRequestApmQueryOutputReference, jsii.get(self, "apmQuery"))

    @builtins.property
    @jsii.member(jsii_name="formula")
    def formula(self) -> PowerpackWidgetChangeDefinitionRequestFormulaList:
        return typing.cast(PowerpackWidgetChangeDefinitionRequestFormulaList, jsii.get(self, "formula"))

    @builtins.property
    @jsii.member(jsii_name="logQuery")
    def log_query(
        self,
    ) -> PowerpackWidgetChangeDefinitionRequestLogQueryOutputReference:
        return typing.cast(PowerpackWidgetChangeDefinitionRequestLogQueryOutputReference, jsii.get(self, "logQuery"))

    @builtins.property
    @jsii.member(jsii_name="processQuery")
    def process_query(
        self,
    ) -> "PowerpackWidgetChangeDefinitionRequestProcessQueryOutputReference":
        return typing.cast("PowerpackWidgetChangeDefinitionRequestProcessQueryOutputReference", jsii.get(self, "processQuery"))

    @builtins.property
    @jsii.member(jsii_name="query")
    def query(self) -> "PowerpackWidgetChangeDefinitionRequestQueryList":
        return typing.cast("PowerpackWidgetChangeDefinitionRequestQueryList", jsii.get(self, "query"))

    @builtins.property
    @jsii.member(jsii_name="rumQuery")
    def rum_query(
        self,
    ) -> "PowerpackWidgetChangeDefinitionRequestRumQueryOutputReference":
        return typing.cast("PowerpackWidgetChangeDefinitionRequestRumQueryOutputReference", jsii.get(self, "rumQuery"))

    @builtins.property
    @jsii.member(jsii_name="securityQuery")
    def security_query(
        self,
    ) -> "PowerpackWidgetChangeDefinitionRequestSecurityQueryOutputReference":
        return typing.cast("PowerpackWidgetChangeDefinitionRequestSecurityQueryOutputReference", jsii.get(self, "securityQuery"))

    @builtins.property
    @jsii.member(jsii_name="apmQueryInput")
    def apm_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetChangeDefinitionRequestApmQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetChangeDefinitionRequestApmQuery], jsii.get(self, "apmQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="changeTypeInput")
    def change_type_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "changeTypeInput"))

    @builtins.property
    @jsii.member(jsii_name="compareToInput")
    def compare_to_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "compareToInput"))

    @builtins.property
    @jsii.member(jsii_name="formulaInput")
    def formula_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetChangeDefinitionRequestFormula]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetChangeDefinitionRequestFormula]]], jsii.get(self, "formulaInput"))

    @builtins.property
    @jsii.member(jsii_name="increaseGoodInput")
    def increase_good_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "increaseGoodInput"))

    @builtins.property
    @jsii.member(jsii_name="logQueryInput")
    def log_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetChangeDefinitionRequestLogQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetChangeDefinitionRequestLogQuery], jsii.get(self, "logQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="orderByInput")
    def order_by_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "orderByInput"))

    @builtins.property
    @jsii.member(jsii_name="orderDirInput")
    def order_dir_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "orderDirInput"))

    @builtins.property
    @jsii.member(jsii_name="processQueryInput")
    def process_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetChangeDefinitionRequestProcessQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetChangeDefinitionRequestProcessQuery"], jsii.get(self, "processQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="qInput")
    def q_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "qInput"))

    @builtins.property
    @jsii.member(jsii_name="queryInput")
    def query_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetChangeDefinitionRequestQuery"]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetChangeDefinitionRequestQuery"]]], jsii.get(self, "queryInput"))

    @builtins.property
    @jsii.member(jsii_name="rumQueryInput")
    def rum_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetChangeDefinitionRequestRumQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetChangeDefinitionRequestRumQuery"], jsii.get(self, "rumQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="securityQueryInput")
    def security_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetChangeDefinitionRequestSecurityQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetChangeDefinitionRequestSecurityQuery"], jsii.get(self, "securityQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="showPresentInput")
    def show_present_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "showPresentInput"))

    @builtins.property
    @jsii.member(jsii_name="changeType")
    def change_type(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "changeType"))

    @change_type.setter
    def change_type(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__90110937299d789483ce7dcff088287a83fa557031c1dccc5693f1d6cefb5eb6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "changeType", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="compareTo")
    def compare_to(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "compareTo"))

    @compare_to.setter
    def compare_to(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a76517701a1360c81e3503effa87544c3830367559833f5e7174403938ea99c0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "compareTo", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="increaseGood")
    def increase_good(self) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "increaseGood"))

    @increase_good.setter
    def increase_good(
        self,
        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bae0e201b41e2f891bde7f0dbbf45ee11c83193ff38ad96d1df72023a9bf8b4b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "increaseGood", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="orderBy")
    def order_by(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "orderBy"))

    @order_by.setter
    def order_by(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3580057c304c17d13da75e42ff941a9d7d748883503536df0c2349cfcfe44c3f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "orderBy", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="orderDir")
    def order_dir(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "orderDir"))

    @order_dir.setter
    def order_dir(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__260427308520845226f9e03cc1b0bd0b23713af4f97600347a9c124bea683616)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "orderDir", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="q")
    def q(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "q"))

    @q.setter
    def q(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1adea2d0cf418c7c45690544b24e5625e05f100d612666d2f508228f89925e64)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "q", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="showPresent")
    def show_present(self) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "showPresent"))

    @show_present.setter
    def show_present(
        self,
        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6ad9caac2c855ee1581b65eb2408b246b6c8bc4e674fc5b59aabd6d1a9e8ae8a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "showPresent", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetChangeDefinitionRequest]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetChangeDefinitionRequest]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetChangeDefinitionRequest]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d6d2d16dd9321ba77a6ca8cc23eb44d418fed41e58da1324b0f9a7d64b3b4b67)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionRequestProcessQuery",
    jsii_struct_bases=[],
    name_mapping={
        "metric": "metric",
        "filter_by": "filterBy",
        "limit": "limit",
        "search_by": "searchBy",
    },
)
class PowerpackWidgetChangeDefinitionRequestProcessQuery:
    def __init__(
        self,
        *,
        metric: builtins.str,
        filter_by: typing.Optional[typing.Sequence[builtins.str]] = None,
        limit: typing.Optional[jsii.Number] = None,
        search_by: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param metric: Your chosen metric. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        :param filter_by: A list of processes. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#filter_by Powerpack#filter_by}
        :param limit: The max number of items in the filter list. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param search_by: Your chosen search term. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_by Powerpack#search_by}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e973f28b56aa6392836731765ca99deb31b520fea843da563a7bfb3792ee21b0)
            check_type(argname="argument metric", value=metric, expected_type=type_hints["metric"])
            check_type(argname="argument filter_by", value=filter_by, expected_type=type_hints["filter_by"])
            check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
            check_type(argname="argument search_by", value=search_by, expected_type=type_hints["search_by"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "metric": metric,
        }
        if filter_by is not None:
            self._values["filter_by"] = filter_by
        if limit is not None:
            self._values["limit"] = limit
        if search_by is not None:
            self._values["search_by"] = search_by

    @builtins.property
    def metric(self) -> builtins.str:
        '''Your chosen metric.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        '''
        result = self._values.get("metric")
        assert result is not None, "Required property 'metric' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def filter_by(self) -> typing.Optional[typing.List[builtins.str]]:
        '''A list of processes.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#filter_by Powerpack#filter_by}
        '''
        result = self._values.get("filter_by")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def limit(self) -> typing.Optional[jsii.Number]:
        '''The max number of items in the filter list.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        '''
        result = self._values.get("limit")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def search_by(self) -> typing.Optional[builtins.str]:
        '''Your chosen search term.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_by Powerpack#search_by}
        '''
        result = self._values.get("search_by")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetChangeDefinitionRequestProcessQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetChangeDefinitionRequestProcessQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionRequestProcessQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e36be187f10b1e6ce9bfc73dc3954ae6fa88de12c64fe05df5ce1a2d5dce604b)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFilterBy")
    def reset_filter_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFilterBy", []))

    @jsii.member(jsii_name="resetLimit")
    def reset_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLimit", []))

    @jsii.member(jsii_name="resetSearchBy")
    def reset_search_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSearchBy", []))

    @builtins.property
    @jsii.member(jsii_name="filterByInput")
    def filter_by_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "filterByInput"))

    @builtins.property
    @jsii.member(jsii_name="limitInput")
    def limit_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "limitInput"))

    @builtins.property
    @jsii.member(jsii_name="metricInput")
    def metric_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "metricInput"))

    @builtins.property
    @jsii.member(jsii_name="searchByInput")
    def search_by_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "searchByInput"))

    @builtins.property
    @jsii.member(jsii_name="filterBy")
    def filter_by(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "filterBy"))

    @filter_by.setter
    def filter_by(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__333a32880f7501e633d3dfb90c82f783be4f933b6ad75a7ec0d8ad6787acd499)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "filterBy", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="limit")
    def limit(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "limit"))

    @limit.setter
    def limit(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__884670edfdc587705c2fb13991e21d7587d8bae5a0ac8c1de3b6e817cc90a3e7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "limit", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="metric")
    def metric(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "metric"))

    @metric.setter
    def metric(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__eccb09f7044fb24866f76f82a7b1592747c78951f49b2aec7f99449e116d297c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "metric", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="searchBy")
    def search_by(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "searchBy"))

    @search_by.setter
    def search_by(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4475163052e63044ba9103bb5e0ac44097be76ae1e8ac943c1042eb4b99c43bd)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "searchBy", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetChangeDefinitionRequestProcessQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetChangeDefinitionRequestProcessQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetChangeDefinitionRequestProcessQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1997f73a6d8a82b6ab730344a86585bf73404b6d8301f130a5476c305b538ced)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionRequestQuery",
    jsii_struct_bases=[],
    name_mapping={
        "apm_dependency_stats_query": "apmDependencyStatsQuery",
        "apm_resource_stats_query": "apmResourceStatsQuery",
        "cloud_cost_query": "cloudCostQuery",
        "event_query": "eventQuery",
        "metric_query": "metricQuery",
        "process_query": "processQuery",
        "slo_query": "sloQuery",
    },
)
class PowerpackWidgetChangeDefinitionRequestQuery:
    def __init__(
        self,
        *,
        apm_dependency_stats_query: typing.Optional[typing.Union["PowerpackWidgetChangeDefinitionRequestQueryApmDependencyStatsQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        apm_resource_stats_query: typing.Optional[typing.Union["PowerpackWidgetChangeDefinitionRequestQueryApmResourceStatsQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        cloud_cost_query: typing.Optional[typing.Union["PowerpackWidgetChangeDefinitionRequestQueryCloudCostQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        event_query: typing.Optional[typing.Union["PowerpackWidgetChangeDefinitionRequestQueryEventQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        metric_query: typing.Optional[typing.Union["PowerpackWidgetChangeDefinitionRequestQueryMetricQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        process_query: typing.Optional[typing.Union["PowerpackWidgetChangeDefinitionRequestQueryProcessQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        slo_query: typing.Optional[typing.Union["PowerpackWidgetChangeDefinitionRequestQuerySloQuery", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param apm_dependency_stats_query: apm_dependency_stats_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#apm_dependency_stats_query Powerpack#apm_dependency_stats_query}
        :param apm_resource_stats_query: apm_resource_stats_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#apm_resource_stats_query Powerpack#apm_resource_stats_query}
        :param cloud_cost_query: cloud_cost_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cloud_cost_query Powerpack#cloud_cost_query}
        :param event_query: event_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#event_query Powerpack#event_query}
        :param metric_query: metric_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric_query Powerpack#metric_query}
        :param process_query: process_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#process_query Powerpack#process_query}
        :param slo_query: slo_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#slo_query Powerpack#slo_query}
        '''
        if isinstance(apm_dependency_stats_query, dict):
            apm_dependency_stats_query = PowerpackWidgetChangeDefinitionRequestQueryApmDependencyStatsQuery(**apm_dependency_stats_query)
        if isinstance(apm_resource_stats_query, dict):
            apm_resource_stats_query = PowerpackWidgetChangeDefinitionRequestQueryApmResourceStatsQuery(**apm_resource_stats_query)
        if isinstance(cloud_cost_query, dict):
            cloud_cost_query = PowerpackWidgetChangeDefinitionRequestQueryCloudCostQuery(**cloud_cost_query)
        if isinstance(event_query, dict):
            event_query = PowerpackWidgetChangeDefinitionRequestQueryEventQuery(**event_query)
        if isinstance(metric_query, dict):
            metric_query = PowerpackWidgetChangeDefinitionRequestQueryMetricQuery(**metric_query)
        if isinstance(process_query, dict):
            process_query = PowerpackWidgetChangeDefinitionRequestQueryProcessQuery(**process_query)
        if isinstance(slo_query, dict):
            slo_query = PowerpackWidgetChangeDefinitionRequestQuerySloQuery(**slo_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c9c03e4b5c273a72bd7fb4689ff14ce199240d0d2bd7298f711c66b804e30bfb)
            check_type(argname="argument apm_dependency_stats_query", value=apm_dependency_stats_query, expected_type=type_hints["apm_dependency_stats_query"])
            check_type(argname="argument apm_resource_stats_query", value=apm_resource_stats_query, expected_type=type_hints["apm_resource_stats_query"])
            check_type(argname="argument cloud_cost_query", value=cloud_cost_query, expected_type=type_hints["cloud_cost_query"])
            check_type(argname="argument event_query", value=event_query, expected_type=type_hints["event_query"])
            check_type(argname="argument metric_query", value=metric_query, expected_type=type_hints["metric_query"])
            check_type(argname="argument process_query", value=process_query, expected_type=type_hints["process_query"])
            check_type(argname="argument slo_query", value=slo_query, expected_type=type_hints["slo_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if apm_dependency_stats_query is not None:
            self._values["apm_dependency_stats_query"] = apm_dependency_stats_query
        if apm_resource_stats_query is not None:
            self._values["apm_resource_stats_query"] = apm_resource_stats_query
        if cloud_cost_query is not None:
            self._values["cloud_cost_query"] = cloud_cost_query
        if event_query is not None:
            self._values["event_query"] = event_query
        if metric_query is not None:
            self._values["metric_query"] = metric_query
        if process_query is not None:
            self._values["process_query"] = process_query
        if slo_query is not None:
            self._values["slo_query"] = slo_query

    @builtins.property
    def apm_dependency_stats_query(
        self,
    ) -> typing.Optional["PowerpackWidgetChangeDefinitionRequestQueryApmDependencyStatsQuery"]:
        '''apm_dependency_stats_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#apm_dependency_stats_query Powerpack#apm_dependency_stats_query}
        '''
        result = self._values.get("apm_dependency_stats_query")
        return typing.cast(typing.Optional["PowerpackWidgetChangeDefinitionRequestQueryApmDependencyStatsQuery"], result)

    @builtins.property
    def apm_resource_stats_query(
        self,
    ) -> typing.Optional["PowerpackWidgetChangeDefinitionRequestQueryApmResourceStatsQuery"]:
        '''apm_resource_stats_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#apm_resource_stats_query Powerpack#apm_resource_stats_query}
        '''
        result = self._values.get("apm_resource_stats_query")
        return typing.cast(typing.Optional["PowerpackWidgetChangeDefinitionRequestQueryApmResourceStatsQuery"], result)

    @builtins.property
    def cloud_cost_query(
        self,
    ) -> typing.Optional["PowerpackWidgetChangeDefinitionRequestQueryCloudCostQuery"]:
        '''cloud_cost_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cloud_cost_query Powerpack#cloud_cost_query}
        '''
        result = self._values.get("cloud_cost_query")
        return typing.cast(typing.Optional["PowerpackWidgetChangeDefinitionRequestQueryCloudCostQuery"], result)

    @builtins.property
    def event_query(
        self,
    ) -> typing.Optional["PowerpackWidgetChangeDefinitionRequestQueryEventQuery"]:
        '''event_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#event_query Powerpack#event_query}
        '''
        result = self._values.get("event_query")
        return typing.cast(typing.Optional["PowerpackWidgetChangeDefinitionRequestQueryEventQuery"], result)

    @builtins.property
    def metric_query(
        self,
    ) -> typing.Optional["PowerpackWidgetChangeDefinitionRequestQueryMetricQuery"]:
        '''metric_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric_query Powerpack#metric_query}
        '''
        result = self._values.get("metric_query")
        return typing.cast(typing.Optional["PowerpackWidgetChangeDefinitionRequestQueryMetricQuery"], result)

    @builtins.property
    def process_query(
        self,
    ) -> typing.Optional["PowerpackWidgetChangeDefinitionRequestQueryProcessQuery"]:
        '''process_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#process_query Powerpack#process_query}
        '''
        result = self._values.get("process_query")
        return typing.cast(typing.Optional["PowerpackWidgetChangeDefinitionRequestQueryProcessQuery"], result)

    @builtins.property
    def slo_query(
        self,
    ) -> typing.Optional["PowerpackWidgetChangeDefinitionRequestQuerySloQuery"]:
        '''slo_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#slo_query Powerpack#slo_query}
        '''
        result = self._values.get("slo_query")
        return typing.cast(typing.Optional["PowerpackWidgetChangeDefinitionRequestQuerySloQuery"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetChangeDefinitionRequestQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionRequestQueryApmDependencyStatsQuery",
    jsii_struct_bases=[],
    name_mapping={
        "data_source": "dataSource",
        "env": "env",
        "name": "name",
        "operation_name": "operationName",
        "resource_name": "resourceName",
        "service": "service",
        "stat": "stat",
        "cross_org_uuids": "crossOrgUuids",
        "is_upstream": "isUpstream",
        "primary_tag_name": "primaryTagName",
        "primary_tag_value": "primaryTagValue",
    },
)
class PowerpackWidgetChangeDefinitionRequestQueryApmDependencyStatsQuery:
    def __init__(
        self,
        *,
        data_source: builtins.str,
        env: builtins.str,
        name: builtins.str,
        operation_name: builtins.str,
        resource_name: builtins.str,
        service: builtins.str,
        stat: builtins.str,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        is_upstream: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        primary_tag_name: typing.Optional[builtins.str] = None,
        primary_tag_value: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param data_source: The data source for APM Dependency Stats queries. Valid values are ``apm_dependency_stats``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param env: APM environment. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#env Powerpack#env}
        :param name: The name of query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param operation_name: Name of operation on service. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#operation_name Powerpack#operation_name}
        :param resource_name: APM resource. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#resource_name Powerpack#resource_name}
        :param service: APM service. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#service Powerpack#service}
        :param stat: APM statistic. Valid values are ``avg_duration``, ``avg_root_duration``, ``avg_spans_per_trace``, ``error_rate``, ``pct_exec_time``, ``pct_of_traces``, ``total_traces_count``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#stat Powerpack#stat}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param is_upstream: Determines whether stats for upstream or downstream dependencies should be queried. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#is_upstream Powerpack#is_upstream}
        :param primary_tag_name: The name of the second primary tag used within APM; required when ``primary_tag_value`` is specified. See https://docs.datadoghq.com/tracing/guide/setting_primary_tags_to_scope/#add-a-second-primary-tag-in-datadog. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_name Powerpack#primary_tag_name}
        :param primary_tag_value: Filter APM data by the second primary tag. ``primary_tag_name`` must also be specified. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_value Powerpack#primary_tag_value}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__933701178b5520217377afae747ecf16667e69280e6c85cb0ea7c0647fad6491)
            check_type(argname="argument data_source", value=data_source, expected_type=type_hints["data_source"])
            check_type(argname="argument env", value=env, expected_type=type_hints["env"])
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument operation_name", value=operation_name, expected_type=type_hints["operation_name"])
            check_type(argname="argument resource_name", value=resource_name, expected_type=type_hints["resource_name"])
            check_type(argname="argument service", value=service, expected_type=type_hints["service"])
            check_type(argname="argument stat", value=stat, expected_type=type_hints["stat"])
            check_type(argname="argument cross_org_uuids", value=cross_org_uuids, expected_type=type_hints["cross_org_uuids"])
            check_type(argname="argument is_upstream", value=is_upstream, expected_type=type_hints["is_upstream"])
            check_type(argname="argument primary_tag_name", value=primary_tag_name, expected_type=type_hints["primary_tag_name"])
            check_type(argname="argument primary_tag_value", value=primary_tag_value, expected_type=type_hints["primary_tag_value"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "data_source": data_source,
            "env": env,
            "name": name,
            "operation_name": operation_name,
            "resource_name": resource_name,
            "service": service,
            "stat": stat,
        }
        if cross_org_uuids is not None:
            self._values["cross_org_uuids"] = cross_org_uuids
        if is_upstream is not None:
            self._values["is_upstream"] = is_upstream
        if primary_tag_name is not None:
            self._values["primary_tag_name"] = primary_tag_name
        if primary_tag_value is not None:
            self._values["primary_tag_value"] = primary_tag_value

    @builtins.property
    def data_source(self) -> builtins.str:
        '''The data source for APM Dependency Stats queries. Valid values are ``apm_dependency_stats``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        '''
        result = self._values.get("data_source")
        assert result is not None, "Required property 'data_source' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def env(self) -> builtins.str:
        '''APM environment.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#env Powerpack#env}
        '''
        result = self._values.get("env")
        assert result is not None, "Required property 'env' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def name(self) -> builtins.str:
        '''The name of query for use in formulas.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        '''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def operation_name(self) -> builtins.str:
        '''Name of operation on service.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#operation_name Powerpack#operation_name}
        '''
        result = self._values.get("operation_name")
        assert result is not None, "Required property 'operation_name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def resource_name(self) -> builtins.str:
        '''APM resource.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#resource_name Powerpack#resource_name}
        '''
        result = self._values.get("resource_name")
        assert result is not None, "Required property 'resource_name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def service(self) -> builtins.str:
        '''APM service.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#service Powerpack#service}
        '''
        result = self._values.get("service")
        assert result is not None, "Required property 'service' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def stat(self) -> builtins.str:
        '''APM statistic. Valid values are ``avg_duration``, ``avg_root_duration``, ``avg_spans_per_trace``, ``error_rate``, ``pct_exec_time``, ``pct_of_traces``, ``total_traces_count``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#stat Powerpack#stat}
        '''
        result = self._values.get("stat")
        assert result is not None, "Required property 'stat' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def cross_org_uuids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''The source organization UUID for cross organization queries. Feature in Private Beta.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        '''
        result = self._values.get("cross_org_uuids")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def is_upstream(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        '''Determines whether stats for upstream or downstream dependencies should be queried.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#is_upstream Powerpack#is_upstream}
        '''
        result = self._values.get("is_upstream")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)

    @builtins.property
    def primary_tag_name(self) -> typing.Optional[builtins.str]:
        '''The name of the second primary tag used within APM; required when ``primary_tag_value`` is specified. See https://docs.datadoghq.com/tracing/guide/setting_primary_tags_to_scope/#add-a-second-primary-tag-in-datadog.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_name Powerpack#primary_tag_name}
        '''
        result = self._values.get("primary_tag_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def primary_tag_value(self) -> typing.Optional[builtins.str]:
        '''Filter APM data by the second primary tag. ``primary_tag_name`` must also be specified.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_value Powerpack#primary_tag_value}
        '''
        result = self._values.get("primary_tag_value")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetChangeDefinitionRequestQueryApmDependencyStatsQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetChangeDefinitionRequestQueryApmDependencyStatsQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionRequestQueryApmDependencyStatsQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b4defaed05090cb8c0eb30503c02996aefd54b929c50eb20a66a9e8dfbad414b)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetCrossOrgUuids")
    def reset_cross_org_uuids(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCrossOrgUuids", []))

    @jsii.member(jsii_name="resetIsUpstream")
    def reset_is_upstream(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetIsUpstream", []))

    @jsii.member(jsii_name="resetPrimaryTagName")
    def reset_primary_tag_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPrimaryTagName", []))

    @jsii.member(jsii_name="resetPrimaryTagValue")
    def reset_primary_tag_value(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPrimaryTagValue", []))

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuidsInput")
    def cross_org_uuids_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "crossOrgUuidsInput"))

    @builtins.property
    @jsii.member(jsii_name="dataSourceInput")
    def data_source_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "dataSourceInput"))

    @builtins.property
    @jsii.member(jsii_name="envInput")
    def env_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "envInput"))

    @builtins.property
    @jsii.member(jsii_name="isUpstreamInput")
    def is_upstream_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "isUpstreamInput"))

    @builtins.property
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property
    @jsii.member(jsii_name="operationNameInput")
    def operation_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "operationNameInput"))

    @builtins.property
    @jsii.member(jsii_name="primaryTagNameInput")
    def primary_tag_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "primaryTagNameInput"))

    @builtins.property
    @jsii.member(jsii_name="primaryTagValueInput")
    def primary_tag_value_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "primaryTagValueInput"))

    @builtins.property
    @jsii.member(jsii_name="resourceNameInput")
    def resource_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "resourceNameInput"))

    @builtins.property
    @jsii.member(jsii_name="serviceInput")
    def service_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "serviceInput"))

    @builtins.property
    @jsii.member(jsii_name="statInput")
    def stat_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "statInput"))

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuids")
    def cross_org_uuids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "crossOrgUuids"))

    @cross_org_uuids.setter
    def cross_org_uuids(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bdfedb3b860b2801047ce369d2e85b0d0af5341be17a3e628b1a3812c4bf4274)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "crossOrgUuids", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="dataSource")
    def data_source(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "dataSource"))

    @data_source.setter
    def data_source(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__47ddbf75deb98b8806b136bdad9fef30bc9ecbbe626e8eddfb8a0fe946e9afaf)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "dataSource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="env")
    def env(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "env"))

    @env.setter
    def env(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a8e0c5b0359fbb37eb8c8dc6f742bda097043ea3b537b31a95ed744649c2200c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "env", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="isUpstream")
    def is_upstream(self) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "isUpstream"))

    @is_upstream.setter
    def is_upstream(
        self,
        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dc272eb95accea866e826fe118212e0cb01b2bd7c444902a3307c90fdaeb8248)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "isUpstream", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__322c7e583eada8c84fed2df65f7abdcd1f1798f0a2c0d31971d5fd453c4788e0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "name", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="operationName")
    def operation_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "operationName"))

    @operation_name.setter
    def operation_name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a94ca97363bb9f9b14a45e648c27c78eb82fcec3ca4379387853faf3456317d6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "operationName", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="primaryTagName")
    def primary_tag_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "primaryTagName"))

    @primary_tag_name.setter
    def primary_tag_name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d7ad6147594ada825e9ab30d66e5dac32845daee08f0e17a0e6b36d498bbe1c1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "primaryTagName", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="primaryTagValue")
    def primary_tag_value(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "primaryTagValue"))

    @primary_tag_value.setter
    def primary_tag_value(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__09cacdea4ef33a2352d35e38aeb728151756bf3f72827d60f46a8a335d66e794)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "primaryTagValue", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="resourceName")
    def resource_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "resourceName"))

    @resource_name.setter
    def resource_name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1e708369b6d241f3fe8ca3936d39c54e05269910c05fe8e0c4828fcd1a24c036)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "resourceName", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="service")
    def service(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "service"))

    @service.setter
    def service(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a79a15f5f007d80bddbb5814f0209c8d2db6cd34e39bf42af14481b99ced07fd)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "service", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="stat")
    def stat(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "stat"))

    @stat.setter
    def stat(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bb0af87a5bda72ec7d88ad527f30cfe13240c502276c449197d1ea15e3a93f01)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "stat", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetChangeDefinitionRequestQueryApmDependencyStatsQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetChangeDefinitionRequestQueryApmDependencyStatsQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetChangeDefinitionRequestQueryApmDependencyStatsQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e7b4496814c0d770afd9a81bb6486e4f9dcacb7b9da880f84dce6f4a131bd5a5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionRequestQueryApmResourceStatsQuery",
    jsii_struct_bases=[],
    name_mapping={
        "data_source": "dataSource",
        "env": "env",
        "name": "name",
        "service": "service",
        "stat": "stat",
        "cross_org_uuids": "crossOrgUuids",
        "group_by": "groupBy",
        "operation_name": "operationName",
        "primary_tag_name": "primaryTagName",
        "primary_tag_value": "primaryTagValue",
        "resource_name": "resourceName",
    },
)
class PowerpackWidgetChangeDefinitionRequestQueryApmResourceStatsQuery:
    def __init__(
        self,
        *,
        data_source: builtins.str,
        env: builtins.str,
        name: builtins.str,
        service: builtins.str,
        stat: builtins.str,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        group_by: typing.Optional[typing.Sequence[builtins.str]] = None,
        operation_name: typing.Optional[builtins.str] = None,
        primary_tag_name: typing.Optional[builtins.str] = None,
        primary_tag_value: typing.Optional[builtins.str] = None,
        resource_name: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param data_source: The data source for APM Resource Stats queries. Valid values are ``apm_resource_stats``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param env: APM environment. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#env Powerpack#env}
        :param name: The name of query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param service: APM service. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#service Powerpack#service}
        :param stat: APM statistic. Valid values are ``errors``, ``error_rate``, ``hits``, ``latency_avg``, ``latency_distribution``, ``latency_max``, ``latency_p50``, ``latency_p75``, ``latency_p90``, ``latency_p95``, ``latency_p99``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#stat Powerpack#stat}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param group_by: Array of fields to group results by. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param operation_name: Name of operation on service. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#operation_name Powerpack#operation_name}
        :param primary_tag_name: The name of the second primary tag used within APM; required when ``primary_tag_value`` is specified. See https://docs.datadoghq.com/tracing/guide/setting_primary_tags_to_scope/#add-a-second-primary-tag-in-datadog. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_name Powerpack#primary_tag_name}
        :param primary_tag_value: Filter APM data by the second primary tag. ``primary_tag_name`` must also be specified. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_value Powerpack#primary_tag_value}
        :param resource_name: APM resource. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#resource_name Powerpack#resource_name}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fe5192ec2c7eeca54e2c4f23d3052ea715bc580878f07d9d90b0354096bb92ef)
            check_type(argname="argument data_source", value=data_source, expected_type=type_hints["data_source"])
            check_type(argname="argument env", value=env, expected_type=type_hints["env"])
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument service", value=service, expected_type=type_hints["service"])
            check_type(argname="argument stat", value=stat, expected_type=type_hints["stat"])
            check_type(argname="argument cross_org_uuids", value=cross_org_uuids, expected_type=type_hints["cross_org_uuids"])
            check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
            check_type(argname="argument operation_name", value=operation_name, expected_type=type_hints["operation_name"])
            check_type(argname="argument primary_tag_name", value=primary_tag_name, expected_type=type_hints["primary_tag_name"])
            check_type(argname="argument primary_tag_value", value=primary_tag_value, expected_type=type_hints["primary_tag_value"])
            check_type(argname="argument resource_name", value=resource_name, expected_type=type_hints["resource_name"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "data_source": data_source,
            "env": env,
            "name": name,
            "service": service,
            "stat": stat,
        }
        if cross_org_uuids is not None:
            self._values["cross_org_uuids"] = cross_org_uuids
        if group_by is not None:
            self._values["group_by"] = group_by
        if operation_name is not None:
            self._values["operation_name"] = operation_name
        if primary_tag_name is not None:
            self._values["primary_tag_name"] = primary_tag_name
        if primary_tag_value is not None:
            self._values["primary_tag_value"] = primary_tag_value
        if resource_name is not None:
            self._values["resource_name"] = resource_name

    @builtins.property
    def data_source(self) -> builtins.str:
        '''The data source for APM Resource Stats queries. Valid values are ``apm_resource_stats``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        '''
        result = self._values.get("data_source")
        assert result is not None, "Required property 'data_source' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def env(self) -> builtins.str:
        '''APM environment.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#env Powerpack#env}
        '''
        result = self._values.get("env")
        assert result is not None, "Required property 'env' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def name(self) -> builtins.str:
        '''The name of query for use in formulas.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        '''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def service(self) -> builtins.str:
        '''APM service.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#service Powerpack#service}
        '''
        result = self._values.get("service")
        assert result is not None, "Required property 'service' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def stat(self) -> builtins.str:
        '''APM statistic. Valid values are ``errors``, ``error_rate``, ``hits``, ``latency_avg``, ``latency_distribution``, ``latency_max``, ``latency_p50``, ``latency_p75``, ``latency_p90``, ``latency_p95``, ``latency_p99``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#stat Powerpack#stat}
        '''
        result = self._values.get("stat")
        assert result is not None, "Required property 'stat' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def cross_org_uuids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''The source organization UUID for cross organization queries. Feature in Private Beta.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        '''
        result = self._values.get("cross_org_uuids")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def group_by(self) -> typing.Optional[typing.List[builtins.str]]:
        '''Array of fields to group results by.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        '''
        result = self._values.get("group_by")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def operation_name(self) -> typing.Optional[builtins.str]:
        '''Name of operation on service.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#operation_name Powerpack#operation_name}
        '''
        result = self._values.get("operation_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def primary_tag_name(self) -> typing.Optional[builtins.str]:
        '''The name of the second primary tag used within APM; required when ``primary_tag_value`` is specified. See https://docs.datadoghq.com/tracing/guide/setting_primary_tags_to_scope/#add-a-second-primary-tag-in-datadog.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_name Powerpack#primary_tag_name}
        '''
        result = self._values.get("primary_tag_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def primary_tag_value(self) -> typing.Optional[builtins.str]:
        '''Filter APM data by the second primary tag. ``primary_tag_name`` must also be specified.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_value Powerpack#primary_tag_value}
        '''
        result = self._values.get("primary_tag_value")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def resource_name(self) -> typing.Optional[builtins.str]:
        '''APM resource.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#resource_name Powerpack#resource_name}
        '''
        result = self._values.get("resource_name")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetChangeDefinitionRequestQueryApmResourceStatsQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetChangeDefinitionRequestQueryApmResourceStatsQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionRequestQueryApmResourceStatsQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ad3ac082900086a2f0b50cf1acb3a43a458a30afe910677ca42dd1b2aeec2931)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetCrossOrgUuids")
    def reset_cross_org_uuids(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCrossOrgUuids", []))

    @jsii.member(jsii_name="resetGroupBy")
    def reset_group_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGroupBy", []))

    @jsii.member(jsii_name="resetOperationName")
    def reset_operation_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetOperationName", []))

    @jsii.member(jsii_name="resetPrimaryTagName")
    def reset_primary_tag_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPrimaryTagName", []))

    @jsii.member(jsii_name="resetPrimaryTagValue")
    def reset_primary_tag_value(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPrimaryTagValue", []))

    @jsii.member(jsii_name="resetResourceName")
    def reset_resource_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetResourceName", []))

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuidsInput")
    def cross_org_uuids_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "crossOrgUuidsInput"))

    @builtins.property
    @jsii.member(jsii_name="dataSourceInput")
    def data_source_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "dataSourceInput"))

    @builtins.property
    @jsii.member(jsii_name="envInput")
    def env_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "envInput"))

    @builtins.property
    @jsii.member(jsii_name="groupByInput")
    def group_by_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "groupByInput"))

    @builtins.property
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property
    @jsii.member(jsii_name="operationNameInput")
    def operation_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "operationNameInput"))

    @builtins.property
    @jsii.member(jsii_name="primaryTagNameInput")
    def primary_tag_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "primaryTagNameInput"))

    @builtins.property
    @jsii.member(jsii_name="primaryTagValueInput")
    def primary_tag_value_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "primaryTagValueInput"))

    @builtins.property
    @jsii.member(jsii_name="resourceNameInput")
    def resource_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "resourceNameInput"))

    @builtins.property
    @jsii.member(jsii_name="serviceInput")
    def service_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "serviceInput"))

    @builtins.property
    @jsii.member(jsii_name="statInput")
    def stat_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "statInput"))

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuids")
    def cross_org_uuids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "crossOrgUuids"))

    @cross_org_uuids.setter
    def cross_org_uuids(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__add5b83840d067a62e7da0225e7647c22f6646acc52983ee65f4b41323c50dd3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "crossOrgUuids", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="dataSource")
    def data_source(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "dataSource"))

    @data_source.setter
    def data_source(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e8c86ecf6865a25ce827529c7f8bb1c1616bc4fc3aa40dce930b46cbfb90f60b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "dataSource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="env")
    def env(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "env"))

    @env.setter
    def env(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4394e2b8d32f5c4eac45842c633671400f7907cadcf56891aeb8d9a2729bdaad)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "env", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="groupBy")
    def group_by(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "groupBy"))

    @group_by.setter
    def group_by(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c51eec9a3641d1c5b8b3a129165a1a21e6e7d855c39541c500c92ff918744e1e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "groupBy", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a6c9041ada171b5604118a515136323a0e64e3e5ae62e7c9484f9990d91d3e7c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "name", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="operationName")
    def operation_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "operationName"))

    @operation_name.setter
    def operation_name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0131a8210197b057f3ae3146733fd004fa763e47f5fdcb33585bc510e7f0f4d9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "operationName", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="primaryTagName")
    def primary_tag_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "primaryTagName"))

    @primary_tag_name.setter
    def primary_tag_name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__981002cd1d368a445f8f343ee29062226c2ac3251eef9c2230b49ea03142c6b1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "primaryTagName", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="primaryTagValue")
    def primary_tag_value(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "primaryTagValue"))

    @primary_tag_value.setter
    def primary_tag_value(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6d05a4e3377256e6a36a38e732ff5d31876ee8dfb0c66d01f45bcb3c1ceb0862)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "primaryTagValue", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="resourceName")
    def resource_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "resourceName"))

    @resource_name.setter
    def resource_name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__60a7af8c119d9ccdb5018774c15661d516666d04f7622bdd6b0891edc7d40720)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "resourceName", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="service")
    def service(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "service"))

    @service.setter
    def service(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__45ab7b9ce6f6d06dfef7afd97eb88b9f8ece0576f420b8318f4755388a1af7c4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "service", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="stat")
    def stat(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "stat"))

    @stat.setter
    def stat(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bc4b0c90bad9caa68aa2572ed43da555af0a01103d0f55381389bbac2cd64cce)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "stat", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetChangeDefinitionRequestQueryApmResourceStatsQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetChangeDefinitionRequestQueryApmResourceStatsQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetChangeDefinitionRequestQueryApmResourceStatsQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d8d012079aece195431cf7d588e62710bc96e4182fe51afbab76459e9860ea8c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionRequestQueryCloudCostQuery",
    jsii_struct_bases=[],
    name_mapping={
        "data_source": "dataSource",
        "name": "name",
        "query": "query",
        "aggregator": "aggregator",
        "cross_org_uuids": "crossOrgUuids",
    },
)
class PowerpackWidgetChangeDefinitionRequestQueryCloudCostQuery:
    def __init__(
        self,
        *,
        data_source: builtins.str,
        name: builtins.str,
        query: builtins.str,
        aggregator: typing.Optional[builtins.str] = None,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
    ) -> None:
        '''
        :param data_source: The data source for cloud cost queries. Valid values are ``cloud_cost``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param name: The name of the query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param query: The cloud cost query definition. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        :param aggregator: The aggregation methods available for cloud cost queries. Valid values are ``avg``, ``last``, ``max``, ``min``, ``sum``, ``percentile``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregator Powerpack#aggregator}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e3a6a8861c3da17998e451d352eb5dab4d69e51d7d10b9d388a90c6e04fa3e98)
            check_type(argname="argument data_source", value=data_source, expected_type=type_hints["data_source"])
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument query", value=query, expected_type=type_hints["query"])
            check_type(argname="argument aggregator", value=aggregator, expected_type=type_hints["aggregator"])
            check_type(argname="argument cross_org_uuids", value=cross_org_uuids, expected_type=type_hints["cross_org_uuids"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "data_source": data_source,
            "name": name,
            "query": query,
        }
        if aggregator is not None:
            self._values["aggregator"] = aggregator
        if cross_org_uuids is not None:
            self._values["cross_org_uuids"] = cross_org_uuids

    @builtins.property
    def data_source(self) -> builtins.str:
        '''The data source for cloud cost queries. Valid values are ``cloud_cost``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        '''
        result = self._values.get("data_source")
        assert result is not None, "Required property 'data_source' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def name(self) -> builtins.str:
        '''The name of the query for use in formulas.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        '''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def query(self) -> builtins.str:
        '''The cloud cost query definition.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        '''
        result = self._values.get("query")
        assert result is not None, "Required property 'query' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def aggregator(self) -> typing.Optional[builtins.str]:
        '''The aggregation methods available for cloud cost queries. Valid values are ``avg``, ``last``, ``max``, ``min``, ``sum``, ``percentile``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregator Powerpack#aggregator}
        '''
        result = self._values.get("aggregator")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def cross_org_uuids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''The source organization UUID for cross organization queries. Feature in Private Beta.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        '''
        result = self._values.get("cross_org_uuids")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetChangeDefinitionRequestQueryCloudCostQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetChangeDefinitionRequestQueryCloudCostQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionRequestQueryCloudCostQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6c785b59b0feacc98fd41c4afe47e807925925cbba3e4283ff4ba0a3fc83fac8)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetAggregator")
    def reset_aggregator(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAggregator", []))

    @jsii.member(jsii_name="resetCrossOrgUuids")
    def reset_cross_org_uuids(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCrossOrgUuids", []))

    @builtins.property
    @jsii.member(jsii_name="aggregatorInput")
    def aggregator_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregatorInput"))

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuidsInput")
    def cross_org_uuids_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "crossOrgUuidsInput"))

    @builtins.property
    @jsii.member(jsii_name="dataSourceInput")
    def data_source_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "dataSourceInput"))

    @builtins.property
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property
    @jsii.member(jsii_name="queryInput")
    def query_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "queryInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregator")
    def aggregator(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregator"))

    @aggregator.setter
    def aggregator(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cf54098f29415ebbceec27c7dc2ddc02b0e6ad74e9813432c58ab2d2c8e5e5d4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregator", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuids")
    def cross_org_uuids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "crossOrgUuids"))

    @cross_org_uuids.setter
    def cross_org_uuids(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d2fe8bade65eddcab59598ad677bf450337926ed8fbc1a31b7487c17f4ac2be9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "crossOrgUuids", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="dataSource")
    def data_source(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "dataSource"))

    @data_source.setter
    def data_source(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__59bd161b6511c7be970ba2e5366ee74d9361263254f812b844681ba16acb4962)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "dataSource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a697a9a3ddff808fdff9a6b1c1261f6d3fda9ef2a80150219eeb96f31854576e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "name", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="query")
    def query(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "query"))

    @query.setter
    def query(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6167b9eb5be22dc373d81302218ea95a616811b359456ec411f8b75bc9d74d83)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "query", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetChangeDefinitionRequestQueryCloudCostQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetChangeDefinitionRequestQueryCloudCostQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetChangeDefinitionRequestQueryCloudCostQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e690970106709009267892566b746362e330b427a895ccc8925ea254e476ff34)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionRequestQueryEventQuery",
    jsii_struct_bases=[],
    name_mapping={
        "compute": "compute",
        "data_source": "dataSource",
        "name": "name",
        "cross_org_uuids": "crossOrgUuids",
        "group_by": "groupBy",
        "indexes": "indexes",
        "search": "search",
        "storage": "storage",
    },
)
class PowerpackWidgetChangeDefinitionRequestQueryEventQuery:
    def __init__(
        self,
        *,
        compute: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetChangeDefinitionRequestQueryEventQueryCompute", typing.Dict[builtins.str, typing.Any]]]],
        data_source: builtins.str,
        name: builtins.str,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetChangeDefinitionRequestQueryEventQueryGroupBy", typing.Dict[builtins.str, typing.Any]]]]] = None,
        indexes: typing.Optional[typing.Sequence[builtins.str]] = None,
        search: typing.Optional[typing.Union["PowerpackWidgetChangeDefinitionRequestQueryEventQuerySearch", typing.Dict[builtins.str, typing.Any]]] = None,
        storage: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param compute: compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute Powerpack#compute}
        :param data_source: The data source for event platform-based queries. Valid values are ``logs``, ``spans``, ``network``, ``rum``, ``security_signals``, ``profiles``, ``audit``, ``events``, ``ci_tests``, ``ci_pipelines``, ``incident_analytics``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param name: The name of query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param indexes: An array of index names to query in the stream. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#indexes Powerpack#indexes}
        :param search: search block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search Powerpack#search}
        :param storage: Storage location (private beta). Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#storage Powerpack#storage}
        '''
        if isinstance(search, dict):
            search = PowerpackWidgetChangeDefinitionRequestQueryEventQuerySearch(**search)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__43363870da01e3277339557f2464ef650b41d0961b5188c55ee181ce75d39ddd)
            check_type(argname="argument compute", value=compute, expected_type=type_hints["compute"])
            check_type(argname="argument data_source", value=data_source, expected_type=type_hints["data_source"])
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument cross_org_uuids", value=cross_org_uuids, expected_type=type_hints["cross_org_uuids"])
            check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
            check_type(argname="argument indexes", value=indexes, expected_type=type_hints["indexes"])
            check_type(argname="argument search", value=search, expected_type=type_hints["search"])
            check_type(argname="argument storage", value=storage, expected_type=type_hints["storage"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "compute": compute,
            "data_source": data_source,
            "name": name,
        }
        if cross_org_uuids is not None:
            self._values["cross_org_uuids"] = cross_org_uuids
        if group_by is not None:
            self._values["group_by"] = group_by
        if indexes is not None:
            self._values["indexes"] = indexes
        if search is not None:
            self._values["search"] = search
        if storage is not None:
            self._values["storage"] = storage

    @builtins.property
    def compute(
        self,
    ) -> typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetChangeDefinitionRequestQueryEventQueryCompute"]]:
        '''compute block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute Powerpack#compute}
        '''
        result = self._values.get("compute")
        assert result is not None, "Required property 'compute' is missing"
        return typing.cast(typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetChangeDefinitionRequestQueryEventQueryCompute"]], result)

    @builtins.property
    def data_source(self) -> builtins.str:
        '''The data source for event platform-based queries.

        Valid values are ``logs``, ``spans``, ``network``, ``rum``, ``security_signals``, ``profiles``, ``audit``, ``events``, ``ci_tests``, ``ci_pipelines``, ``incident_analytics``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        '''
        result = self._values.get("data_source")
        assert result is not None, "Required property 'data_source' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def name(self) -> builtins.str:
        '''The name of query for use in formulas.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        '''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def cross_org_uuids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''The source organization UUID for cross organization queries. Feature in Private Beta.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        '''
        result = self._values.get("cross_org_uuids")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def group_by(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetChangeDefinitionRequestQueryEventQueryGroupBy"]]]:
        '''group_by block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        '''
        result = self._values.get("group_by")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetChangeDefinitionRequestQueryEventQueryGroupBy"]]], result)

    @builtins.property
    def indexes(self) -> typing.Optional[typing.List[builtins.str]]:
        '''An array of index names to query in the stream.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#indexes Powerpack#indexes}
        '''
        result = self._values.get("indexes")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def search(
        self,
    ) -> typing.Optional["PowerpackWidgetChangeDefinitionRequestQueryEventQuerySearch"]:
        '''search block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search Powerpack#search}
        '''
        result = self._values.get("search")
        return typing.cast(typing.Optional["PowerpackWidgetChangeDefinitionRequestQueryEventQuerySearch"], result)

    @builtins.property
    def storage(self) -> typing.Optional[builtins.str]:
        '''Storage location (private beta).

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#storage Powerpack#storage}
        '''
        result = self._values.get("storage")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetChangeDefinitionRequestQueryEventQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionRequestQueryEventQueryCompute",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "interval": "interval",
        "metric": "metric",
    },
)
class PowerpackWidgetChangeDefinitionRequestQueryEventQueryCompute:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        interval: typing.Optional[jsii.Number] = None,
        metric: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation methods for event platform queries. Valid values are ``count``, ``cardinality``, ``median``, ``pc75``, ``pc90``, ``pc95``, ``pc98``, ``pc99``, ``sum``, ``min``, ``max``, ``avg``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param interval: A time interval in milliseconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        :param metric: The measurable attribute to compute. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1d8892377caa9a49c297461f0b7a4d3c6e009664528d502d97a968b9cb31c010)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
            check_type(argname="argument metric", value=metric, expected_type=type_hints["metric"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if interval is not None:
            self._values["interval"] = interval
        if metric is not None:
            self._values["metric"] = metric

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation methods for event platform queries.

        Valid values are ``count``, ``cardinality``, ``median``, ``pc75``, ``pc90``, ``pc95``, ``pc98``, ``pc99``, ``sum``, ``min``, ``max``, ``avg``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''A time interval in milliseconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def metric(self) -> typing.Optional[builtins.str]:
        '''The measurable attribute to compute.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        '''
        result = self._values.get("metric")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetChangeDefinitionRequestQueryEventQueryCompute(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetChangeDefinitionRequestQueryEventQueryComputeList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionRequestQueryEventQueryComputeList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__015f550ed0c555bfd432d4dbc7927e9d2dfe6e8efe4483b8338178f2fdeb5205)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetChangeDefinitionRequestQueryEventQueryComputeOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1508fd470556c094d8d8c4d519dd0c24f31b57f01379c885bf07861456fad31d)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetChangeDefinitionRequestQueryEventQueryComputeOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__91c01c3e8a630fe9832c6462656bafdcf39cf8ae1a2e8cdadaa02fae8b819458)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ec2ae0d3e3a8624823547ea42d29a0fabb919b91216276be4f718971034f7bd6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__26e6e9a559317915263d2be79127c4c4adc4353fd96fc657d4ccd0039b615b46)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetChangeDefinitionRequestQueryEventQueryCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetChangeDefinitionRequestQueryEventQueryCompute]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetChangeDefinitionRequestQueryEventQueryCompute]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d6e064bd77617d31d6da7890dfeb6eeb67081d32c3d69266df77ca33ea65abc7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetChangeDefinitionRequestQueryEventQueryComputeOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionRequestQueryEventQueryComputeOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b57f0fe83bae2a572f4408a9e74c2ad487e136f86fe129218b1fb8cb3f063ce4)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @jsii.member(jsii_name="resetMetric")
    def reset_metric(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMetric", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="metricInput")
    def metric_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "metricInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__37b1d5369d1c6cbdf7cac0a1b1e4f61f5284fc8209f2d63c963408026fa6d5c0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d2b63724955a5eb1d67a28364769cc587c5a2c0672b7a53dd8566e4b2fa7e1ce)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="metric")
    def metric(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "metric"))

    @metric.setter
    def metric(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f64f99719fd763b553971895dc8eb7a5a4f9b4c762117df008d414ec9731f386)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "metric", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetChangeDefinitionRequestQueryEventQueryCompute]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetChangeDefinitionRequestQueryEventQueryCompute]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetChangeDefinitionRequestQueryEventQueryCompute]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__28bf45c8c35bf05122733a9980d8be4d22db46e06ded8e10b92c14aa677d5302)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionRequestQueryEventQueryGroupBy",
    jsii_struct_bases=[],
    name_mapping={"facet": "facet", "limit": "limit", "sort": "sort"},
)
class PowerpackWidgetChangeDefinitionRequestQueryEventQueryGroupBy:
    def __init__(
        self,
        *,
        facet: builtins.str,
        limit: typing.Optional[jsii.Number] = None,
        sort: typing.Optional[typing.Union["PowerpackWidgetChangeDefinitionRequestQueryEventQueryGroupBySort", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param facet: The event facet. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param limit: The number of groups to return. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param sort: sort block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort Powerpack#sort}
        '''
        if isinstance(sort, dict):
            sort = PowerpackWidgetChangeDefinitionRequestQueryEventQueryGroupBySort(**sort)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7c247bdaf3ed1c77bc79872276889dda4d16453ec08c5748900ff5ac7b249700)
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
            check_type(argname="argument sort", value=sort, expected_type=type_hints["sort"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "facet": facet,
        }
        if limit is not None:
            self._values["limit"] = limit
        if sort is not None:
            self._values["sort"] = sort

    @builtins.property
    def facet(self) -> builtins.str:
        '''The event facet.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        assert result is not None, "Required property 'facet' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def limit(self) -> typing.Optional[jsii.Number]:
        '''The number of groups to return.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        '''
        result = self._values.get("limit")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def sort(
        self,
    ) -> typing.Optional["PowerpackWidgetChangeDefinitionRequestQueryEventQueryGroupBySort"]:
        '''sort block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort Powerpack#sort}
        '''
        result = self._values.get("sort")
        return typing.cast(typing.Optional["PowerpackWidgetChangeDefinitionRequestQueryEventQueryGroupBySort"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetChangeDefinitionRequestQueryEventQueryGroupBy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetChangeDefinitionRequestQueryEventQueryGroupByList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionRequestQueryEventQueryGroupByList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__95801470614c1cfaad108eeeaad004ad01f3a165f06645616f12decbeb9a687e)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetChangeDefinitionRequestQueryEventQueryGroupByOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bdbdb7dc702541c191ba31cd0dfeccf45bf4c88f81b38f3c920e7018d21c141f)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetChangeDefinitionRequestQueryEventQueryGroupByOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ad9cf0214da2a24a9371de181227e66cbc0dc7d5695e252eb90661bb6a27ebbc)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c0392a9f03bdaddafc9b58984e80fa5194c786a3cb54a2ceb6e02034eb1f5dd6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0a0d7560cd8e71f40975f1a083f9bcfb0c1fb2760319a44e8d62c9a2d4938489)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetChangeDefinitionRequestQueryEventQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetChangeDefinitionRequestQueryEventQueryGroupBy]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetChangeDefinitionRequestQueryEventQueryGroupBy]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4116bae4651846048a87e88b38da9ee055b20a9333cd51f39ccf00b3a5966899)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetChangeDefinitionRequestQueryEventQueryGroupByOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionRequestQueryEventQueryGroupByOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__024eceb0668a832853aaa8cb3573279ef14b50847ffd58f9489a17893c904045)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putSort")
    def put_sort(
        self,
        *,
        aggregation: builtins.str,
        metric: typing.Optional[builtins.str] = None,
        order: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation methods for the event platform queries. Valid values are ``count``, ``cardinality``, ``median``, ``pc75``, ``pc90``, ``pc95``, ``pc98``, ``pc99``, ``sum``, ``min``, ``max``, ``avg``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param metric: The metric used for sorting group by results. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        :param order: Direction of sort. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        value = PowerpackWidgetChangeDefinitionRequestQueryEventQueryGroupBySort(
            aggregation=aggregation, metric=metric, order=order
        )

        return typing.cast(None, jsii.invoke(self, "putSort", [value]))

    @jsii.member(jsii_name="resetLimit")
    def reset_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLimit", []))

    @jsii.member(jsii_name="resetSort")
    def reset_sort(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSort", []))

    @builtins.property
    @jsii.member(jsii_name="sort")
    def sort(
        self,
    ) -> "PowerpackWidgetChangeDefinitionRequestQueryEventQueryGroupBySortOutputReference":
        return typing.cast("PowerpackWidgetChangeDefinitionRequestQueryEventQueryGroupBySortOutputReference", jsii.get(self, "sort"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="limitInput")
    def limit_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "limitInput"))

    @builtins.property
    @jsii.member(jsii_name="sortInput")
    def sort_input(
        self,
    ) -> typing.Optional["PowerpackWidgetChangeDefinitionRequestQueryEventQueryGroupBySort"]:
        return typing.cast(typing.Optional["PowerpackWidgetChangeDefinitionRequestQueryEventQueryGroupBySort"], jsii.get(self, "sortInput"))

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9dcd26da6ca688b8bbf172e5fb82a5c6caab5d60ab0d2462c7516b49a71b0530)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="limit")
    def limit(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "limit"))

    @limit.setter
    def limit(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4394bd7fed5c627b8b5d2cded235298077e3a7c46e1e3cdddf892f6cd5b6f2dd)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "limit", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetChangeDefinitionRequestQueryEventQueryGroupBy]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetChangeDefinitionRequestQueryEventQueryGroupBy]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetChangeDefinitionRequestQueryEventQueryGroupBy]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4f5f9e32b341c29269a4911af9971d70ad2f49d2ec25b1235f3786f02c2cf85e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionRequestQueryEventQueryGroupBySort",
    jsii_struct_bases=[],
    name_mapping={"aggregation": "aggregation", "metric": "metric", "order": "order"},
)
class PowerpackWidgetChangeDefinitionRequestQueryEventQueryGroupBySort:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        metric: typing.Optional[builtins.str] = None,
        order: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation methods for the event platform queries. Valid values are ``count``, ``cardinality``, ``median``, ``pc75``, ``pc90``, ``pc95``, ``pc98``, ``pc99``, ``sum``, ``min``, ``max``, ``avg``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param metric: The metric used for sorting group by results. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        :param order: Direction of sort. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__597061ca910f1e910b9fdcbd0fa7c68880b6a0d7d93abe92eb9db3ff5e6ed872)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument metric", value=metric, expected_type=type_hints["metric"])
            check_type(argname="argument order", value=order, expected_type=type_hints["order"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if metric is not None:
            self._values["metric"] = metric
        if order is not None:
            self._values["order"] = order

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation methods for the event platform queries.

        Valid values are ``count``, ``cardinality``, ``median``, ``pc75``, ``pc90``, ``pc95``, ``pc98``, ``pc99``, ``sum``, ``min``, ``max``, ``avg``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def metric(self) -> typing.Optional[builtins.str]:
        '''The metric used for sorting group by results.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        '''
        result = self._values.get("metric")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def order(self) -> typing.Optional[builtins.str]:
        '''Direction of sort. Valid values are ``asc``, ``desc``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        result = self._values.get("order")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetChangeDefinitionRequestQueryEventQueryGroupBySort(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetChangeDefinitionRequestQueryEventQueryGroupBySortOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionRequestQueryEventQueryGroupBySortOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__15272ad9abbf5ffeaa53f2c08ec8e6ac4fb852abd24d487543162d505ada21fe)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetMetric")
    def reset_metric(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMetric", []))

    @jsii.member(jsii_name="resetOrder")
    def reset_order(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetOrder", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="metricInput")
    def metric_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "metricInput"))

    @builtins.property
    @jsii.member(jsii_name="orderInput")
    def order_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "orderInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5fbec8f286fe1f2179a0e13f5455df96f288264f9a44bdaf8918836a84a9c5ab)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="metric")
    def metric(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "metric"))

    @metric.setter
    def metric(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__663472ee5031d462131386874416f82fd80bc67cdc66033516fe2afd451cad83)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "metric", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="order")
    def order(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "order"))

    @order.setter
    def order(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d800091786f27d0a005bc82c580621740a2bc7fe058a834ef44ef2305e5e6857)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "order", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetChangeDefinitionRequestQueryEventQueryGroupBySort]:
        return typing.cast(typing.Optional[PowerpackWidgetChangeDefinitionRequestQueryEventQueryGroupBySort], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetChangeDefinitionRequestQueryEventQueryGroupBySort],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dbaccb15bd6c2d58078f1b0faa5af99e3bdc4585af7946d8fe3ca9ae30d55172)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetChangeDefinitionRequestQueryEventQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionRequestQueryEventQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b5ba1bf8c4aa143a27a30e12f838a1bf3bdd06402bf2187908d11e2566dec08d)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putCompute")
    def put_compute(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetChangeDefinitionRequestQueryEventQueryCompute, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8816b777e63f78a9009249580de3e8bd6d2af5196cef40dc5c87400dea82203e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putCompute", [value]))

    @jsii.member(jsii_name="putGroupBy")
    def put_group_by(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetChangeDefinitionRequestQueryEventQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9e3f7a14d86664e4cb5e1609ed46769e0ffbbc334b5731f005cc65798277c924)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putGroupBy", [value]))

    @jsii.member(jsii_name="putSearch")
    def put_search(self, *, query: builtins.str) -> None:
        '''
        :param query: The events search string. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        '''
        value = PowerpackWidgetChangeDefinitionRequestQueryEventQuerySearch(
            query=query
        )

        return typing.cast(None, jsii.invoke(self, "putSearch", [value]))

    @jsii.member(jsii_name="resetCrossOrgUuids")
    def reset_cross_org_uuids(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCrossOrgUuids", []))

    @jsii.member(jsii_name="resetGroupBy")
    def reset_group_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGroupBy", []))

    @jsii.member(jsii_name="resetIndexes")
    def reset_indexes(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetIndexes", []))

    @jsii.member(jsii_name="resetSearch")
    def reset_search(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSearch", []))

    @jsii.member(jsii_name="resetStorage")
    def reset_storage(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetStorage", []))

    @builtins.property
    @jsii.member(jsii_name="compute")
    def compute(
        self,
    ) -> PowerpackWidgetChangeDefinitionRequestQueryEventQueryComputeList:
        return typing.cast(PowerpackWidgetChangeDefinitionRequestQueryEventQueryComputeList, jsii.get(self, "compute"))

    @builtins.property
    @jsii.member(jsii_name="groupBy")
    def group_by(
        self,
    ) -> PowerpackWidgetChangeDefinitionRequestQueryEventQueryGroupByList:
        return typing.cast(PowerpackWidgetChangeDefinitionRequestQueryEventQueryGroupByList, jsii.get(self, "groupBy"))

    @builtins.property
    @jsii.member(jsii_name="search")
    def search(
        self,
    ) -> "PowerpackWidgetChangeDefinitionRequestQueryEventQuerySearchOutputReference":
        return typing.cast("PowerpackWidgetChangeDefinitionRequestQueryEventQuerySearchOutputReference", jsii.get(self, "search"))

    @builtins.property
    @jsii.member(jsii_name="computeInput")
    def compute_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetChangeDefinitionRequestQueryEventQueryCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetChangeDefinitionRequestQueryEventQueryCompute]]], jsii.get(self, "computeInput"))

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuidsInput")
    def cross_org_uuids_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "crossOrgUuidsInput"))

    @builtins.property
    @jsii.member(jsii_name="dataSourceInput")
    def data_source_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "dataSourceInput"))

    @builtins.property
    @jsii.member(jsii_name="groupByInput")
    def group_by_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetChangeDefinitionRequestQueryEventQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetChangeDefinitionRequestQueryEventQueryGroupBy]]], jsii.get(self, "groupByInput"))

    @builtins.property
    @jsii.member(jsii_name="indexesInput")
    def indexes_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "indexesInput"))

    @builtins.property
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property
    @jsii.member(jsii_name="searchInput")
    def search_input(
        self,
    ) -> typing.Optional["PowerpackWidgetChangeDefinitionRequestQueryEventQuerySearch"]:
        return typing.cast(typing.Optional["PowerpackWidgetChangeDefinitionRequestQueryEventQuerySearch"], jsii.get(self, "searchInput"))

    @builtins.property
    @jsii.member(jsii_name="storageInput")
    def storage_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "storageInput"))

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuids")
    def cross_org_uuids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "crossOrgUuids"))

    @cross_org_uuids.setter
    def cross_org_uuids(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__98030ddaa5db99eaa794a8c2130884b4910e63508989629b26f089d8bc47203f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "crossOrgUuids", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="dataSource")
    def data_source(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "dataSource"))

    @data_source.setter
    def data_source(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__13d2d3058f4c4c6a40749dea56e41961d20bb277025d4097d35e08cee8825f74)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "dataSource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="indexes")
    def indexes(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "indexes"))

    @indexes.setter
    def indexes(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__45d3c1029095d09369f6b405130e303e8bcf6ec9557bd644414f004de8442be1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "indexes", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__87818e7206babb11854bb6a206dea1b4ecfe43421215b9f8b2363053254a448c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "name", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="storage")
    def storage(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "storage"))

    @storage.setter
    def storage(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__622efad95a98f0461f209861207f0beeec5ea4eb7549a77beede9bf18a300058)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "storage", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetChangeDefinitionRequestQueryEventQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetChangeDefinitionRequestQueryEventQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetChangeDefinitionRequestQueryEventQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__68bf1db0da66b0dab41eceb1c72ab3e3b01d3071488caffb19885ef7ba32c033)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionRequestQueryEventQuerySearch",
    jsii_struct_bases=[],
    name_mapping={"query": "query"},
)
class PowerpackWidgetChangeDefinitionRequestQueryEventQuerySearch:
    def __init__(self, *, query: builtins.str) -> None:
        '''
        :param query: The events search string. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__06a1495ea7ab82539e408c09a5a1d31f0d8cd94933175dc8de5a550576727b5c)
            check_type(argname="argument query", value=query, expected_type=type_hints["query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "query": query,
        }

    @builtins.property
    def query(self) -> builtins.str:
        '''The events search string.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        '''
        result = self._values.get("query")
        assert result is not None, "Required property 'query' is missing"
        return typing.cast(builtins.str, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetChangeDefinitionRequestQueryEventQuerySearch(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetChangeDefinitionRequestQueryEventQuerySearchOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionRequestQueryEventQuerySearchOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__099ebc532083f6254fc32cb2caa5e24d90b5440c684bd752a35fa54b5a7964b7)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @builtins.property
    @jsii.member(jsii_name="queryInput")
    def query_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "queryInput"))

    @builtins.property
    @jsii.member(jsii_name="query")
    def query(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "query"))

    @query.setter
    def query(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__08b190124f019eb9040b925c63c7c8dc443be319164d6cef59d9eb973ca86ad6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "query", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetChangeDefinitionRequestQueryEventQuerySearch]:
        return typing.cast(typing.Optional[PowerpackWidgetChangeDefinitionRequestQueryEventQuerySearch], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetChangeDefinitionRequestQueryEventQuerySearch],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7034ea8cbcf87580c95cf5047d13cf60b6cdf5a738f438d72b1a9f6e737f500a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetChangeDefinitionRequestQueryList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionRequestQueryList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8b5cef205305ca68a8fbed942a56fa9d21214d2e89080348132a6239590aa7dc)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetChangeDefinitionRequestQueryOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dcf861b6fe6b48152129ce237d07aeea6a0844be51565ed1c43c2569e7e6521c)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetChangeDefinitionRequestQueryOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6cdf4bb87734cda223e7a100349d40a641f358d3e45adbc152f7daf5cc9e4fa2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4206357466142aae19faebd688a6f605b8076798f2f1bafd6e0e30294f77df53)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6e5cff8cc364f7c987402950831e08cc69dade63b1ebffb00b66dabfdd5a3b33)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetChangeDefinitionRequestQuery]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetChangeDefinitionRequestQuery]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetChangeDefinitionRequestQuery]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0f39bb55048d175bea4487ba76aaebccbdf3fa09f7526abb5cf3015dc4c25ce5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionRequestQueryMetricQuery",
    jsii_struct_bases=[],
    name_mapping={
        "name": "name",
        "query": "query",
        "aggregator": "aggregator",
        "cross_org_uuids": "crossOrgUuids",
        "data_source": "dataSource",
    },
)
class PowerpackWidgetChangeDefinitionRequestQueryMetricQuery:
    def __init__(
        self,
        *,
        name: builtins.str,
        query: builtins.str,
        aggregator: typing.Optional[builtins.str] = None,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        data_source: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param name: The name of the query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param query: The metrics query definition. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        :param aggregator: The aggregation methods available for metrics queries. Valid values are ``avg``, ``min``, ``max``, ``sum``, ``last``, ``area``, ``l2norm``, ``percentile``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregator Powerpack#aggregator}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param data_source: The data source for metrics queries. Defaults to ``"metrics"``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3f5d46761405f318608a029f0a2ee3fa3d62d74a7b4b700fab006475f853efd4)
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument query", value=query, expected_type=type_hints["query"])
            check_type(argname="argument aggregator", value=aggregator, expected_type=type_hints["aggregator"])
            check_type(argname="argument cross_org_uuids", value=cross_org_uuids, expected_type=type_hints["cross_org_uuids"])
            check_type(argname="argument data_source", value=data_source, expected_type=type_hints["data_source"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "name": name,
            "query": query,
        }
        if aggregator is not None:
            self._values["aggregator"] = aggregator
        if cross_org_uuids is not None:
            self._values["cross_org_uuids"] = cross_org_uuids
        if data_source is not None:
            self._values["data_source"] = data_source

    @builtins.property
    def name(self) -> builtins.str:
        '''The name of the query for use in formulas.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        '''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def query(self) -> builtins.str:
        '''The metrics query definition.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        '''
        result = self._values.get("query")
        assert result is not None, "Required property 'query' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def aggregator(self) -> typing.Optional[builtins.str]:
        '''The aggregation methods available for metrics queries. Valid values are ``avg``, ``min``, ``max``, ``sum``, ``last``, ``area``, ``l2norm``, ``percentile``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregator Powerpack#aggregator}
        '''
        result = self._values.get("aggregator")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def cross_org_uuids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''The source organization UUID for cross organization queries. Feature in Private Beta.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        '''
        result = self._values.get("cross_org_uuids")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def data_source(self) -> typing.Optional[builtins.str]:
        '''The data source for metrics queries. Defaults to ``"metrics"``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        '''
        result = self._values.get("data_source")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetChangeDefinitionRequestQueryMetricQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetChangeDefinitionRequestQueryMetricQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionRequestQueryMetricQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5c17a9de0fd28a7c24f257acde4d3a19f8fc0531235d72564713b15167223bd4)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetAggregator")
    def reset_aggregator(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAggregator", []))

    @jsii.member(jsii_name="resetCrossOrgUuids")
    def reset_cross_org_uuids(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCrossOrgUuids", []))

    @jsii.member(jsii_name="resetDataSource")
    def reset_data_source(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDataSource", []))

    @builtins.property
    @jsii.member(jsii_name="aggregatorInput")
    def aggregator_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregatorInput"))

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuidsInput")
    def cross_org_uuids_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "crossOrgUuidsInput"))

    @builtins.property
    @jsii.member(jsii_name="dataSourceInput")
    def data_source_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "dataSourceInput"))

    @builtins.property
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property
    @jsii.member(jsii_name="queryInput")
    def query_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "queryInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregator")
    def aggregator(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregator"))

    @aggregator.setter
    def aggregator(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a5030c7ca34a00574b5ae22bc7b29aebf181a664900379f8fd93070d09ad6d81)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregator", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuids")
    def cross_org_uuids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "crossOrgUuids"))

    @cross_org_uuids.setter
    def cross_org_uuids(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2ddba80508c6049eb5937e7380e52ac7831fea85c04c5675df570c5f3c2a14f4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "crossOrgUuids", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="dataSource")
    def data_source(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "dataSource"))

    @data_source.setter
    def data_source(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__85c6e56abe8654a01341fdef9e238c8de00c1cdc25c6933c6c7d35992bc0a8f7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "dataSource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__44b09f43faf76688de6f2c6db0bf19febf2555fa7bf7ea38e7200c4f3c0bea49)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "name", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="query")
    def query(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "query"))

    @query.setter
    def query(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7f900742f9558388e67f0275c6335457ba0d8f7b786d8c01a21ed9cabde28361)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "query", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetChangeDefinitionRequestQueryMetricQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetChangeDefinitionRequestQueryMetricQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetChangeDefinitionRequestQueryMetricQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d9f56e7126fa736d714884cc6dd2ef7f9d94c5c03d358b7f8ee39646240afd5c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetChangeDefinitionRequestQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionRequestQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e3bfcce3be1ed1518f770ed5781799aa149a0b1a1ac16af4ef2101255df08316)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putApmDependencyStatsQuery")
    def put_apm_dependency_stats_query(
        self,
        *,
        data_source: builtins.str,
        env: builtins.str,
        name: builtins.str,
        operation_name: builtins.str,
        resource_name: builtins.str,
        service: builtins.str,
        stat: builtins.str,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        is_upstream: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        primary_tag_name: typing.Optional[builtins.str] = None,
        primary_tag_value: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param data_source: The data source for APM Dependency Stats queries. Valid values are ``apm_dependency_stats``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param env: APM environment. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#env Powerpack#env}
        :param name: The name of query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param operation_name: Name of operation on service. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#operation_name Powerpack#operation_name}
        :param resource_name: APM resource. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#resource_name Powerpack#resource_name}
        :param service: APM service. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#service Powerpack#service}
        :param stat: APM statistic. Valid values are ``avg_duration``, ``avg_root_duration``, ``avg_spans_per_trace``, ``error_rate``, ``pct_exec_time``, ``pct_of_traces``, ``total_traces_count``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#stat Powerpack#stat}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param is_upstream: Determines whether stats for upstream or downstream dependencies should be queried. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#is_upstream Powerpack#is_upstream}
        :param primary_tag_name: The name of the second primary tag used within APM; required when ``primary_tag_value`` is specified. See https://docs.datadoghq.com/tracing/guide/setting_primary_tags_to_scope/#add-a-second-primary-tag-in-datadog. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_name Powerpack#primary_tag_name}
        :param primary_tag_value: Filter APM data by the second primary tag. ``primary_tag_name`` must also be specified. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_value Powerpack#primary_tag_value}
        '''
        value = PowerpackWidgetChangeDefinitionRequestQueryApmDependencyStatsQuery(
            data_source=data_source,
            env=env,
            name=name,
            operation_name=operation_name,
            resource_name=resource_name,
            service=service,
            stat=stat,
            cross_org_uuids=cross_org_uuids,
            is_upstream=is_upstream,
            primary_tag_name=primary_tag_name,
            primary_tag_value=primary_tag_value,
        )

        return typing.cast(None, jsii.invoke(self, "putApmDependencyStatsQuery", [value]))

    @jsii.member(jsii_name="putApmResourceStatsQuery")
    def put_apm_resource_stats_query(
        self,
        *,
        data_source: builtins.str,
        env: builtins.str,
        name: builtins.str,
        service: builtins.str,
        stat: builtins.str,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        group_by: typing.Optional[typing.Sequence[builtins.str]] = None,
        operation_name: typing.Optional[builtins.str] = None,
        primary_tag_name: typing.Optional[builtins.str] = None,
        primary_tag_value: typing.Optional[builtins.str] = None,
        resource_name: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param data_source: The data source for APM Resource Stats queries. Valid values are ``apm_resource_stats``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param env: APM environment. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#env Powerpack#env}
        :param name: The name of query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param service: APM service. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#service Powerpack#service}
        :param stat: APM statistic. Valid values are ``errors``, ``error_rate``, ``hits``, ``latency_avg``, ``latency_distribution``, ``latency_max``, ``latency_p50``, ``latency_p75``, ``latency_p90``, ``latency_p95``, ``latency_p99``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#stat Powerpack#stat}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param group_by: Array of fields to group results by. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param operation_name: Name of operation on service. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#operation_name Powerpack#operation_name}
        :param primary_tag_name: The name of the second primary tag used within APM; required when ``primary_tag_value`` is specified. See https://docs.datadoghq.com/tracing/guide/setting_primary_tags_to_scope/#add-a-second-primary-tag-in-datadog. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_name Powerpack#primary_tag_name}
        :param primary_tag_value: Filter APM data by the second primary tag. ``primary_tag_name`` must also be specified. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_value Powerpack#primary_tag_value}
        :param resource_name: APM resource. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#resource_name Powerpack#resource_name}
        '''
        value = PowerpackWidgetChangeDefinitionRequestQueryApmResourceStatsQuery(
            data_source=data_source,
            env=env,
            name=name,
            service=service,
            stat=stat,
            cross_org_uuids=cross_org_uuids,
            group_by=group_by,
            operation_name=operation_name,
            primary_tag_name=primary_tag_name,
            primary_tag_value=primary_tag_value,
            resource_name=resource_name,
        )

        return typing.cast(None, jsii.invoke(self, "putApmResourceStatsQuery", [value]))

    @jsii.member(jsii_name="putCloudCostQuery")
    def put_cloud_cost_query(
        self,
        *,
        data_source: builtins.str,
        name: builtins.str,
        query: builtins.str,
        aggregator: typing.Optional[builtins.str] = None,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
    ) -> None:
        '''
        :param data_source: The data source for cloud cost queries. Valid values are ``cloud_cost``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param name: The name of the query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param query: The cloud cost query definition. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        :param aggregator: The aggregation methods available for cloud cost queries. Valid values are ``avg``, ``last``, ``max``, ``min``, ``sum``, ``percentile``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregator Powerpack#aggregator}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        '''
        value = PowerpackWidgetChangeDefinitionRequestQueryCloudCostQuery(
            data_source=data_source,
            name=name,
            query=query,
            aggregator=aggregator,
            cross_org_uuids=cross_org_uuids,
        )

        return typing.cast(None, jsii.invoke(self, "putCloudCostQuery", [value]))

    @jsii.member(jsii_name="putEventQuery")
    def put_event_query(
        self,
        *,
        compute: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetChangeDefinitionRequestQueryEventQueryCompute, typing.Dict[builtins.str, typing.Any]]]],
        data_source: builtins.str,
        name: builtins.str,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetChangeDefinitionRequestQueryEventQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
        indexes: typing.Optional[typing.Sequence[builtins.str]] = None,
        search: typing.Optional[typing.Union[PowerpackWidgetChangeDefinitionRequestQueryEventQuerySearch, typing.Dict[builtins.str, typing.Any]]] = None,
        storage: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param compute: compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute Powerpack#compute}
        :param data_source: The data source for event platform-based queries. Valid values are ``logs``, ``spans``, ``network``, ``rum``, ``security_signals``, ``profiles``, ``audit``, ``events``, ``ci_tests``, ``ci_pipelines``, ``incident_analytics``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param name: The name of query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param indexes: An array of index names to query in the stream. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#indexes Powerpack#indexes}
        :param search: search block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search Powerpack#search}
        :param storage: Storage location (private beta). Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#storage Powerpack#storage}
        '''
        value = PowerpackWidgetChangeDefinitionRequestQueryEventQuery(
            compute=compute,
            data_source=data_source,
            name=name,
            cross_org_uuids=cross_org_uuids,
            group_by=group_by,
            indexes=indexes,
            search=search,
            storage=storage,
        )

        return typing.cast(None, jsii.invoke(self, "putEventQuery", [value]))

    @jsii.member(jsii_name="putMetricQuery")
    def put_metric_query(
        self,
        *,
        name: builtins.str,
        query: builtins.str,
        aggregator: typing.Optional[builtins.str] = None,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        data_source: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param name: The name of the query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param query: The metrics query definition. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        :param aggregator: The aggregation methods available for metrics queries. Valid values are ``avg``, ``min``, ``max``, ``sum``, ``last``, ``area``, ``l2norm``, ``percentile``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregator Powerpack#aggregator}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param data_source: The data source for metrics queries. Defaults to ``"metrics"``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        '''
        value = PowerpackWidgetChangeDefinitionRequestQueryMetricQuery(
            name=name,
            query=query,
            aggregator=aggregator,
            cross_org_uuids=cross_org_uuids,
            data_source=data_source,
        )

        return typing.cast(None, jsii.invoke(self, "putMetricQuery", [value]))

    @jsii.member(jsii_name="putProcessQuery")
    def put_process_query(
        self,
        *,
        data_source: builtins.str,
        metric: builtins.str,
        name: builtins.str,
        aggregator: typing.Optional[builtins.str] = None,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        is_normalized_cpu: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        limit: typing.Optional[jsii.Number] = None,
        sort: typing.Optional[builtins.str] = None,
        tag_filters: typing.Optional[typing.Sequence[builtins.str]] = None,
        text_filter: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param data_source: The data source for process queries. Valid values are ``process``, ``container``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param metric: The process metric name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        :param name: The name of query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param aggregator: The aggregation methods available for metrics queries. Valid values are ``avg``, ``min``, ``max``, ``sum``, ``last``, ``area``, ``l2norm``, ``percentile``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregator Powerpack#aggregator}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param is_normalized_cpu: Whether to normalize the CPU percentages. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#is_normalized_cpu Powerpack#is_normalized_cpu}
        :param limit: The number of hits to return. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param sort: The direction of the sort. Valid values are ``asc``, ``desc``. Defaults to ``"desc"``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort Powerpack#sort}
        :param tag_filters: An array of tags to filter by. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#tag_filters Powerpack#tag_filters}
        :param text_filter: The text to use as a filter. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#text_filter Powerpack#text_filter}
        '''
        value = PowerpackWidgetChangeDefinitionRequestQueryProcessQuery(
            data_source=data_source,
            metric=metric,
            name=name,
            aggregator=aggregator,
            cross_org_uuids=cross_org_uuids,
            is_normalized_cpu=is_normalized_cpu,
            limit=limit,
            sort=sort,
            tag_filters=tag_filters,
            text_filter=text_filter,
        )

        return typing.cast(None, jsii.invoke(self, "putProcessQuery", [value]))

    @jsii.member(jsii_name="putSloQuery")
    def put_slo_query(
        self,
        *,
        data_source: builtins.str,
        measure: builtins.str,
        slo_id: builtins.str,
        additional_query_filters: typing.Optional[builtins.str] = None,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        group_mode: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
        slo_query_type: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param data_source: The data source for SLO queries. Valid values are ``slo``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param measure: SLO measures queries. Valid values are ``good_events``, ``bad_events``, ``good_minutes``, ``bad_minutes``, ``slo_status``, ``error_budget_remaining``, ``burn_rate``, ``error_budget_burndown``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#measure Powerpack#measure}
        :param slo_id: ID of an SLO to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#slo_id Powerpack#slo_id}
        :param additional_query_filters: Additional filters applied to the SLO query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#additional_query_filters Powerpack#additional_query_filters}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param group_mode: Group mode to query measures. Valid values are ``overall``, ``components``. Defaults to ``"overall"``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_mode Powerpack#group_mode}
        :param name: The name of query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param slo_query_type: type of the SLO to query. Valid values are ``metric``, ``monitor``, ``time_slice``. Defaults to ``"metric"``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#slo_query_type Powerpack#slo_query_type}
        '''
        value = PowerpackWidgetChangeDefinitionRequestQuerySloQuery(
            data_source=data_source,
            measure=measure,
            slo_id=slo_id,
            additional_query_filters=additional_query_filters,
            cross_org_uuids=cross_org_uuids,
            group_mode=group_mode,
            name=name,
            slo_query_type=slo_query_type,
        )

        return typing.cast(None, jsii.invoke(self, "putSloQuery", [value]))

    @jsii.member(jsii_name="resetApmDependencyStatsQuery")
    def reset_apm_dependency_stats_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetApmDependencyStatsQuery", []))

    @jsii.member(jsii_name="resetApmResourceStatsQuery")
    def reset_apm_resource_stats_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetApmResourceStatsQuery", []))

    @jsii.member(jsii_name="resetCloudCostQuery")
    def reset_cloud_cost_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCloudCostQuery", []))

    @jsii.member(jsii_name="resetEventQuery")
    def reset_event_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetEventQuery", []))

    @jsii.member(jsii_name="resetMetricQuery")
    def reset_metric_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMetricQuery", []))

    @jsii.member(jsii_name="resetProcessQuery")
    def reset_process_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetProcessQuery", []))

    @jsii.member(jsii_name="resetSloQuery")
    def reset_slo_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSloQuery", []))

    @builtins.property
    @jsii.member(jsii_name="apmDependencyStatsQuery")
    def apm_dependency_stats_query(
        self,
    ) -> PowerpackWidgetChangeDefinitionRequestQueryApmDependencyStatsQueryOutputReference:
        return typing.cast(PowerpackWidgetChangeDefinitionRequestQueryApmDependencyStatsQueryOutputReference, jsii.get(self, "apmDependencyStatsQuery"))

    @builtins.property
    @jsii.member(jsii_name="apmResourceStatsQuery")
    def apm_resource_stats_query(
        self,
    ) -> PowerpackWidgetChangeDefinitionRequestQueryApmResourceStatsQueryOutputReference:
        return typing.cast(PowerpackWidgetChangeDefinitionRequestQueryApmResourceStatsQueryOutputReference, jsii.get(self, "apmResourceStatsQuery"))

    @builtins.property
    @jsii.member(jsii_name="cloudCostQuery")
    def cloud_cost_query(
        self,
    ) -> PowerpackWidgetChangeDefinitionRequestQueryCloudCostQueryOutputReference:
        return typing.cast(PowerpackWidgetChangeDefinitionRequestQueryCloudCostQueryOutputReference, jsii.get(self, "cloudCostQuery"))

    @builtins.property
    @jsii.member(jsii_name="eventQuery")
    def event_query(
        self,
    ) -> PowerpackWidgetChangeDefinitionRequestQueryEventQueryOutputReference:
        return typing.cast(PowerpackWidgetChangeDefinitionRequestQueryEventQueryOutputReference, jsii.get(self, "eventQuery"))

    @builtins.property
    @jsii.member(jsii_name="metricQuery")
    def metric_query(
        self,
    ) -> PowerpackWidgetChangeDefinitionRequestQueryMetricQueryOutputReference:
        return typing.cast(PowerpackWidgetChangeDefinitionRequestQueryMetricQueryOutputReference, jsii.get(self, "metricQuery"))

    @builtins.property
    @jsii.member(jsii_name="processQuery")
    def process_query(
        self,
    ) -> "PowerpackWidgetChangeDefinitionRequestQueryProcessQueryOutputReference":
        return typing.cast("PowerpackWidgetChangeDefinitionRequestQueryProcessQueryOutputReference", jsii.get(self, "processQuery"))

    @builtins.property
    @jsii.member(jsii_name="sloQuery")
    def slo_query(
        self,
    ) -> "PowerpackWidgetChangeDefinitionRequestQuerySloQueryOutputReference":
        return typing.cast("PowerpackWidgetChangeDefinitionRequestQuerySloQueryOutputReference", jsii.get(self, "sloQuery"))

    @builtins.property
    @jsii.member(jsii_name="apmDependencyStatsQueryInput")
    def apm_dependency_stats_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetChangeDefinitionRequestQueryApmDependencyStatsQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetChangeDefinitionRequestQueryApmDependencyStatsQuery], jsii.get(self, "apmDependencyStatsQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="apmResourceStatsQueryInput")
    def apm_resource_stats_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetChangeDefinitionRequestQueryApmResourceStatsQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetChangeDefinitionRequestQueryApmResourceStatsQuery], jsii.get(self, "apmResourceStatsQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="cloudCostQueryInput")
    def cloud_cost_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetChangeDefinitionRequestQueryCloudCostQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetChangeDefinitionRequestQueryCloudCostQuery], jsii.get(self, "cloudCostQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="eventQueryInput")
    def event_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetChangeDefinitionRequestQueryEventQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetChangeDefinitionRequestQueryEventQuery], jsii.get(self, "eventQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="metricQueryInput")
    def metric_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetChangeDefinitionRequestQueryMetricQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetChangeDefinitionRequestQueryMetricQuery], jsii.get(self, "metricQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="processQueryInput")
    def process_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetChangeDefinitionRequestQueryProcessQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetChangeDefinitionRequestQueryProcessQuery"], jsii.get(self, "processQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="sloQueryInput")
    def slo_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetChangeDefinitionRequestQuerySloQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetChangeDefinitionRequestQuerySloQuery"], jsii.get(self, "sloQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetChangeDefinitionRequestQuery]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetChangeDefinitionRequestQuery]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetChangeDefinitionRequestQuery]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c41c3eeb97d5440b041799c6d7f5c230a7e7ec09297e26127b061eaaadf2602c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionRequestQueryProcessQuery",
    jsii_struct_bases=[],
    name_mapping={
        "data_source": "dataSource",
        "metric": "metric",
        "name": "name",
        "aggregator": "aggregator",
        "cross_org_uuids": "crossOrgUuids",
        "is_normalized_cpu": "isNormalizedCpu",
        "limit": "limit",
        "sort": "sort",
        "tag_filters": "tagFilters",
        "text_filter": "textFilter",
    },
)
class PowerpackWidgetChangeDefinitionRequestQueryProcessQuery:
    def __init__(
        self,
        *,
        data_source: builtins.str,
        metric: builtins.str,
        name: builtins.str,
        aggregator: typing.Optional[builtins.str] = None,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        is_normalized_cpu: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        limit: typing.Optional[jsii.Number] = None,
        sort: typing.Optional[builtins.str] = None,
        tag_filters: typing.Optional[typing.Sequence[builtins.str]] = None,
        text_filter: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param data_source: The data source for process queries. Valid values are ``process``, ``container``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param metric: The process metric name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        :param name: The name of query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param aggregator: The aggregation methods available for metrics queries. Valid values are ``avg``, ``min``, ``max``, ``sum``, ``last``, ``area``, ``l2norm``, ``percentile``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregator Powerpack#aggregator}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param is_normalized_cpu: Whether to normalize the CPU percentages. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#is_normalized_cpu Powerpack#is_normalized_cpu}
        :param limit: The number of hits to return. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param sort: The direction of the sort. Valid values are ``asc``, ``desc``. Defaults to ``"desc"``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort Powerpack#sort}
        :param tag_filters: An array of tags to filter by. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#tag_filters Powerpack#tag_filters}
        :param text_filter: The text to use as a filter. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#text_filter Powerpack#text_filter}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cf17447499cf44934efa039e62ff890ef14242f6f8a7f59f37e8d58ba9829326)
            check_type(argname="argument data_source", value=data_source, expected_type=type_hints["data_source"])
            check_type(argname="argument metric", value=metric, expected_type=type_hints["metric"])
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument aggregator", value=aggregator, expected_type=type_hints["aggregator"])
            check_type(argname="argument cross_org_uuids", value=cross_org_uuids, expected_type=type_hints["cross_org_uuids"])
            check_type(argname="argument is_normalized_cpu", value=is_normalized_cpu, expected_type=type_hints["is_normalized_cpu"])
            check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
            check_type(argname="argument sort", value=sort, expected_type=type_hints["sort"])
            check_type(argname="argument tag_filters", value=tag_filters, expected_type=type_hints["tag_filters"])
            check_type(argname="argument text_filter", value=text_filter, expected_type=type_hints["text_filter"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "data_source": data_source,
            "metric": metric,
            "name": name,
        }
        if aggregator is not None:
            self._values["aggregator"] = aggregator
        if cross_org_uuids is not None:
            self._values["cross_org_uuids"] = cross_org_uuids
        if is_normalized_cpu is not None:
            self._values["is_normalized_cpu"] = is_normalized_cpu
        if limit is not None:
            self._values["limit"] = limit
        if sort is not None:
            self._values["sort"] = sort
        if tag_filters is not None:
            self._values["tag_filters"] = tag_filters
        if text_filter is not None:
            self._values["text_filter"] = text_filter

    @builtins.property
    def data_source(self) -> builtins.str:
        '''The data source for process queries. Valid values are ``process``, ``container``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        '''
        result = self._values.get("data_source")
        assert result is not None, "Required property 'data_source' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def metric(self) -> builtins.str:
        '''The process metric name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        '''
        result = self._values.get("metric")
        assert result is not None, "Required property 'metric' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def name(self) -> builtins.str:
        '''The name of query for use in formulas.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        '''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def aggregator(self) -> typing.Optional[builtins.str]:
        '''The aggregation methods available for metrics queries. Valid values are ``avg``, ``min``, ``max``, ``sum``, ``last``, ``area``, ``l2norm``, ``percentile``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregator Powerpack#aggregator}
        '''
        result = self._values.get("aggregator")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def cross_org_uuids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''The source organization UUID for cross organization queries. Feature in Private Beta.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        '''
        result = self._values.get("cross_org_uuids")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def is_normalized_cpu(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        '''Whether to normalize the CPU percentages.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#is_normalized_cpu Powerpack#is_normalized_cpu}
        '''
        result = self._values.get("is_normalized_cpu")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)

    @builtins.property
    def limit(self) -> typing.Optional[jsii.Number]:
        '''The number of hits to return.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        '''
        result = self._values.get("limit")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def sort(self) -> typing.Optional[builtins.str]:
        '''The direction of the sort. Valid values are ``asc``, ``desc``. Defaults to ``"desc"``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort Powerpack#sort}
        '''
        result = self._values.get("sort")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def tag_filters(self) -> typing.Optional[typing.List[builtins.str]]:
        '''An array of tags to filter by.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#tag_filters Powerpack#tag_filters}
        '''
        result = self._values.get("tag_filters")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def text_filter(self) -> typing.Optional[builtins.str]:
        '''The text to use as a filter.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#text_filter Powerpack#text_filter}
        '''
        result = self._values.get("text_filter")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetChangeDefinitionRequestQueryProcessQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetChangeDefinitionRequestQueryProcessQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionRequestQueryProcessQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8118f33dc51172d14712889e6562c06a38be6864c31268179f27aa63287dc184)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetAggregator")
    def reset_aggregator(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAggregator", []))

    @jsii.member(jsii_name="resetCrossOrgUuids")
    def reset_cross_org_uuids(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCrossOrgUuids", []))

    @jsii.member(jsii_name="resetIsNormalizedCpu")
    def reset_is_normalized_cpu(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetIsNormalizedCpu", []))

    @jsii.member(jsii_name="resetLimit")
    def reset_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLimit", []))

    @jsii.member(jsii_name="resetSort")
    def reset_sort(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSort", []))

    @jsii.member(jsii_name="resetTagFilters")
    def reset_tag_filters(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTagFilters", []))

    @jsii.member(jsii_name="resetTextFilter")
    def reset_text_filter(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTextFilter", []))

    @builtins.property
    @jsii.member(jsii_name="aggregatorInput")
    def aggregator_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregatorInput"))

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuidsInput")
    def cross_org_uuids_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "crossOrgUuidsInput"))

    @builtins.property
    @jsii.member(jsii_name="dataSourceInput")
    def data_source_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "dataSourceInput"))

    @builtins.property
    @jsii.member(jsii_name="isNormalizedCpuInput")
    def is_normalized_cpu_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "isNormalizedCpuInput"))

    @builtins.property
    @jsii.member(jsii_name="limitInput")
    def limit_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "limitInput"))

    @builtins.property
    @jsii.member(jsii_name="metricInput")
    def metric_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "metricInput"))

    @builtins.property
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property
    @jsii.member(jsii_name="sortInput")
    def sort_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "sortInput"))

    @builtins.property
    @jsii.member(jsii_name="tagFiltersInput")
    def tag_filters_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "tagFiltersInput"))

    @builtins.property
    @jsii.member(jsii_name="textFilterInput")
    def text_filter_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "textFilterInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregator")
    def aggregator(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregator"))

    @aggregator.setter
    def aggregator(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__858d607cb6ec8080cc7e42b4b765aa33f223138cfadaeff6352e5353d2df1ef5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregator", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuids")
    def cross_org_uuids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "crossOrgUuids"))

    @cross_org_uuids.setter
    def cross_org_uuids(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4e9ce5d0e159db6cdf735646b3cff785d454fea8e2e7adac484861fa6dfbbf5a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "crossOrgUuids", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="dataSource")
    def data_source(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "dataSource"))

    @data_source.setter
    def data_source(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d5bed7bbb99cbd744204701cf4522abcdd551a33bc9f28c5b2e25d0e18c80bac)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "dataSource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="isNormalizedCpu")
    def is_normalized_cpu(
        self,
    ) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "isNormalizedCpu"))

    @is_normalized_cpu.setter
    def is_normalized_cpu(
        self,
        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b0d3af3738d19dfd52ab0a9f2defd52df94c7867dc0b18d22e6b7bb083c11b3d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "isNormalizedCpu", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="limit")
    def limit(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "limit"))

    @limit.setter
    def limit(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5b37bb5365e262bb49f327184c835bbaf84d43f5d075893ab161982749fbc211)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "limit", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="metric")
    def metric(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "metric"))

    @metric.setter
    def metric(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__31bdea53e268829e8e879c9443d26c3e1cf7dfbc5af6cdcc6bb9baf351be0df8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "metric", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__246a0f1e0b2fdff008574c7c2c833902a2f28f78eca9a69202047557f9762eae)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "name", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="sort")
    def sort(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "sort"))

    @sort.setter
    def sort(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b5f216b57f35809d74e65c52e7a13cc49502e510e23b7e6996b0e97871585d21)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "sort", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="tagFilters")
    def tag_filters(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "tagFilters"))

    @tag_filters.setter
    def tag_filters(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c5c578a524071d21c57b750a6688d25bd918d53953d865415f65667089c89b98)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "tagFilters", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="textFilter")
    def text_filter(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "textFilter"))

    @text_filter.setter
    def text_filter(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__39d24200a417dbc8c11b7f01b9515ed0d71c716e721bbd1b94dee16ecf6f52a7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "textFilter", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetChangeDefinitionRequestQueryProcessQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetChangeDefinitionRequestQueryProcessQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetChangeDefinitionRequestQueryProcessQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f504246856e6a8d8192706ddb8fd90ed39be8a851e824d9261dfef59f73c2963)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionRequestQuerySloQuery",
    jsii_struct_bases=[],
    name_mapping={
        "data_source": "dataSource",
        "measure": "measure",
        "slo_id": "sloId",
        "additional_query_filters": "additionalQueryFilters",
        "cross_org_uuids": "crossOrgUuids",
        "group_mode": "groupMode",
        "name": "name",
        "slo_query_type": "sloQueryType",
    },
)
class PowerpackWidgetChangeDefinitionRequestQuerySloQuery:
    def __init__(
        self,
        *,
        data_source: builtins.str,
        measure: builtins.str,
        slo_id: builtins.str,
        additional_query_filters: typing.Optional[builtins.str] = None,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        group_mode: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
        slo_query_type: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param data_source: The data source for SLO queries. Valid values are ``slo``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param measure: SLO measures queries. Valid values are ``good_events``, ``bad_events``, ``good_minutes``, ``bad_minutes``, ``slo_status``, ``error_budget_remaining``, ``burn_rate``, ``error_budget_burndown``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#measure Powerpack#measure}
        :param slo_id: ID of an SLO to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#slo_id Powerpack#slo_id}
        :param additional_query_filters: Additional filters applied to the SLO query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#additional_query_filters Powerpack#additional_query_filters}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param group_mode: Group mode to query measures. Valid values are ``overall``, ``components``. Defaults to ``"overall"``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_mode Powerpack#group_mode}
        :param name: The name of query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param slo_query_type: type of the SLO to query. Valid values are ``metric``, ``monitor``, ``time_slice``. Defaults to ``"metric"``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#slo_query_type Powerpack#slo_query_type}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cb8bb35a6d2779aa59f82cb8360ec0080da8329b0208d88c7f94acd3dbb3391c)
            check_type(argname="argument data_source", value=data_source, expected_type=type_hints["data_source"])
            check_type(argname="argument measure", value=measure, expected_type=type_hints["measure"])
            check_type(argname="argument slo_id", value=slo_id, expected_type=type_hints["slo_id"])
            check_type(argname="argument additional_query_filters", value=additional_query_filters, expected_type=type_hints["additional_query_filters"])
            check_type(argname="argument cross_org_uuids", value=cross_org_uuids, expected_type=type_hints["cross_org_uuids"])
            check_type(argname="argument group_mode", value=group_mode, expected_type=type_hints["group_mode"])
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument slo_query_type", value=slo_query_type, expected_type=type_hints["slo_query_type"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "data_source": data_source,
            "measure": measure,
            "slo_id": slo_id,
        }
        if additional_query_filters is not None:
            self._values["additional_query_filters"] = additional_query_filters
        if cross_org_uuids is not None:
            self._values["cross_org_uuids"] = cross_org_uuids
        if group_mode is not None:
            self._values["group_mode"] = group_mode
        if name is not None:
            self._values["name"] = name
        if slo_query_type is not None:
            self._values["slo_query_type"] = slo_query_type

    @builtins.property
    def data_source(self) -> builtins.str:
        '''The data source for SLO queries. Valid values are ``slo``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        '''
        result = self._values.get("data_source")
        assert result is not None, "Required property 'data_source' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def measure(self) -> builtins.str:
        '''SLO measures queries. Valid values are ``good_events``, ``bad_events``, ``good_minutes``, ``bad_minutes``, ``slo_status``, ``error_budget_remaining``, ``burn_rate``, ``error_budget_burndown``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#measure Powerpack#measure}
        '''
        result = self._values.get("measure")
        assert result is not None, "Required property 'measure' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def slo_id(self) -> builtins.str:
        '''ID of an SLO to query.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#slo_id Powerpack#slo_id}
        '''
        result = self._values.get("slo_id")
        assert result is not None, "Required property 'slo_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def additional_query_filters(self) -> typing.Optional[builtins.str]:
        '''Additional filters applied to the SLO query.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#additional_query_filters Powerpack#additional_query_filters}
        '''
        result = self._values.get("additional_query_filters")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def cross_org_uuids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''The source organization UUID for cross organization queries. Feature in Private Beta.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        '''
        result = self._values.get("cross_org_uuids")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def group_mode(self) -> typing.Optional[builtins.str]:
        '''Group mode to query measures. Valid values are ``overall``, ``components``. Defaults to ``"overall"``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_mode Powerpack#group_mode}
        '''
        result = self._values.get("group_mode")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''The name of query for use in formulas.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        '''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def slo_query_type(self) -> typing.Optional[builtins.str]:
        '''type of the SLO to query. Valid values are ``metric``, ``monitor``, ``time_slice``. Defaults to ``"metric"``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#slo_query_type Powerpack#slo_query_type}
        '''
        result = self._values.get("slo_query_type")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetChangeDefinitionRequestQuerySloQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetChangeDefinitionRequestQuerySloQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionRequestQuerySloQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c04d9be88cdb3f912cb1d9d7e06c6436886283c8455f9f09e64c93ab7c93020e)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetAdditionalQueryFilters")
    def reset_additional_query_filters(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAdditionalQueryFilters", []))

    @jsii.member(jsii_name="resetCrossOrgUuids")
    def reset_cross_org_uuids(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCrossOrgUuids", []))

    @jsii.member(jsii_name="resetGroupMode")
    def reset_group_mode(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGroupMode", []))

    @jsii.member(jsii_name="resetName")
    def reset_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetName", []))

    @jsii.member(jsii_name="resetSloQueryType")
    def reset_slo_query_type(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSloQueryType", []))

    @builtins.property
    @jsii.member(jsii_name="additionalQueryFiltersInput")
    def additional_query_filters_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "additionalQueryFiltersInput"))

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuidsInput")
    def cross_org_uuids_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "crossOrgUuidsInput"))

    @builtins.property
    @jsii.member(jsii_name="dataSourceInput")
    def data_source_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "dataSourceInput"))

    @builtins.property
    @jsii.member(jsii_name="groupModeInput")
    def group_mode_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "groupModeInput"))

    @builtins.property
    @jsii.member(jsii_name="measureInput")
    def measure_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "measureInput"))

    @builtins.property
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property
    @jsii.member(jsii_name="sloIdInput")
    def slo_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "sloIdInput"))

    @builtins.property
    @jsii.member(jsii_name="sloQueryTypeInput")
    def slo_query_type_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "sloQueryTypeInput"))

    @builtins.property
    @jsii.member(jsii_name="additionalQueryFilters")
    def additional_query_filters(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "additionalQueryFilters"))

    @additional_query_filters.setter
    def additional_query_filters(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__800f9cb369caefd0b2a0625239e0b46375ebce83f332782a4f730676be8a9d73)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "additionalQueryFilters", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuids")
    def cross_org_uuids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "crossOrgUuids"))

    @cross_org_uuids.setter
    def cross_org_uuids(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ac4810ef7901c3290949411944deb3db65b0bca4a8826fcf03aa20ed822111fd)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "crossOrgUuids", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="dataSource")
    def data_source(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "dataSource"))

    @data_source.setter
    def data_source(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f0c0006cffc45c136ddb9746014db171e7e7b9996e48cf1653a1557bd7a71cb3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "dataSource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="groupMode")
    def group_mode(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "groupMode"))

    @group_mode.setter
    def group_mode(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__eca4ac20cc58fd337895a28d7cddbc535267f7e428635614667832792232e6c1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "groupMode", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="measure")
    def measure(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "measure"))

    @measure.setter
    def measure(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__021dc8782eec0443772b6f52ee20dabecfa47389df02b79deb5d5152a9fa39ad)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "measure", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__28c0d3793692df6501ab3312f15c47102b3a02206ae4f61437ca227445d1e2be)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "name", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="sloId")
    def slo_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "sloId"))

    @slo_id.setter
    def slo_id(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__60a2599df9d7d3115e38f150fbd773959bd4744517dc26ff4e5dd81f34ed5ef9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "sloId", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="sloQueryType")
    def slo_query_type(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "sloQueryType"))

    @slo_query_type.setter
    def slo_query_type(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__22f2248d7ce8c3b7e9c48d8cf8633966b7a7240e7d539a20b2d8ad81d43b6a88)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "sloQueryType", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetChangeDefinitionRequestQuerySloQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetChangeDefinitionRequestQuerySloQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetChangeDefinitionRequestQuerySloQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a3b4cf06ceb8729cc3df0f5270cad8d60ce085df41f95c54a83bdb75193c966e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionRequestRumQuery",
    jsii_struct_bases=[],
    name_mapping={
        "index": "index",
        "compute_query": "computeQuery",
        "group_by": "groupBy",
        "multi_compute": "multiCompute",
        "search_query": "searchQuery",
    },
)
class PowerpackWidgetChangeDefinitionRequestRumQuery:
    def __init__(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union["PowerpackWidgetChangeDefinitionRequestRumQueryComputeQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetChangeDefinitionRequestRumQueryGroupBy", typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetChangeDefinitionRequestRumQueryMultiCompute", typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        if isinstance(compute_query, dict):
            compute_query = PowerpackWidgetChangeDefinitionRequestRumQueryComputeQuery(**compute_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8ddf477cff25d6311e3b37939e2097707a6130120fb230528c252b2ced5425f0)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
            check_type(argname="argument compute_query", value=compute_query, expected_type=type_hints["compute_query"])
            check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
            check_type(argname="argument multi_compute", value=multi_compute, expected_type=type_hints["multi_compute"])
            check_type(argname="argument search_query", value=search_query, expected_type=type_hints["search_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "index": index,
        }
        if compute_query is not None:
            self._values["compute_query"] = compute_query
        if group_by is not None:
            self._values["group_by"] = group_by
        if multi_compute is not None:
            self._values["multi_compute"] = multi_compute
        if search_query is not None:
            self._values["search_query"] = search_query

    @builtins.property
    def index(self) -> builtins.str:
        '''The name of the index to query.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        '''
        result = self._values.get("index")
        assert result is not None, "Required property 'index' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def compute_query(
        self,
    ) -> typing.Optional["PowerpackWidgetChangeDefinitionRequestRumQueryComputeQuery"]:
        '''compute_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        '''
        result = self._values.get("compute_query")
        return typing.cast(typing.Optional["PowerpackWidgetChangeDefinitionRequestRumQueryComputeQuery"], result)

    @builtins.property
    def group_by(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetChangeDefinitionRequestRumQueryGroupBy"]]]:
        '''group_by block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        '''
        result = self._values.get("group_by")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetChangeDefinitionRequestRumQueryGroupBy"]]], result)

    @builtins.property
    def multi_compute(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetChangeDefinitionRequestRumQueryMultiCompute"]]]:
        '''multi_compute block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        '''
        result = self._values.get("multi_compute")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetChangeDefinitionRequestRumQueryMultiCompute"]]], result)

    @builtins.property
    def search_query(self) -> typing.Optional[builtins.str]:
        '''The search query to use.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        result = self._values.get("search_query")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetChangeDefinitionRequestRumQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionRequestRumQueryComputeQuery",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetChangeDefinitionRequestRumQueryComputeQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9bb15aaa41334c359982e126ab518b350c57ba0a52b039b6eacd6c2dc43cc2ac)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetChangeDefinitionRequestRumQueryComputeQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetChangeDefinitionRequestRumQueryComputeQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionRequestRumQueryComputeQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__106c518ef784eb104aafab486c01bbe37578c39a77768186018a283a9765348a)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a001d5acfa0eaf499a4d4ac3ec3dfe765cf21a27f06af8eadd2b4d3b2f331a0b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bf652af3d89c072993d3b79914a7e0e9f0e8e0866adf765dfa5d45c750a72fb2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d1e0729b91b6d39f5c912eef7afb845e069cae38e09094cf2f787aadb88ff1e5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetChangeDefinitionRequestRumQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetChangeDefinitionRequestRumQueryComputeQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetChangeDefinitionRequestRumQueryComputeQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e66f1888d4da22a8d44edca3c98ac3248546f1af87540ca1df9d62e626868403)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionRequestRumQueryGroupBy",
    jsii_struct_bases=[],
    name_mapping={"facet": "facet", "limit": "limit", "sort_query": "sortQuery"},
)
class PowerpackWidgetChangeDefinitionRequestRumQueryGroupBy:
    def __init__(
        self,
        *,
        facet: typing.Optional[builtins.str] = None,
        limit: typing.Optional[jsii.Number] = None,
        sort_query: typing.Optional[typing.Union["PowerpackWidgetChangeDefinitionRequestRumQueryGroupBySortQuery", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param limit: The maximum number of items in the group. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param sort_query: sort_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        if isinstance(sort_query, dict):
            sort_query = PowerpackWidgetChangeDefinitionRequestRumQueryGroupBySortQuery(**sort_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__463e8e7655181b2971174d6d60afaed3a04212edb804725b24a6d421cdeec722)
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
            check_type(argname="argument sort_query", value=sort_query, expected_type=type_hints["sort_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if facet is not None:
            self._values["facet"] = facet
        if limit is not None:
            self._values["limit"] = limit
        if sort_query is not None:
            self._values["sort_query"] = sort_query

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def limit(self) -> typing.Optional[jsii.Number]:
        '''The maximum number of items in the group.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        '''
        result = self._values.get("limit")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def sort_query(
        self,
    ) -> typing.Optional["PowerpackWidgetChangeDefinitionRequestRumQueryGroupBySortQuery"]:
        '''sort_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        result = self._values.get("sort_query")
        return typing.cast(typing.Optional["PowerpackWidgetChangeDefinitionRequestRumQueryGroupBySortQuery"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetChangeDefinitionRequestRumQueryGroupBy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetChangeDefinitionRequestRumQueryGroupByList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionRequestRumQueryGroupByList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__457afb2bbb73b9780b80342edd50dc23c00671a7fa59e163b8d406c6c5f5420d)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetChangeDefinitionRequestRumQueryGroupByOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2ef14e2fc63fb318ce34e5f8f93d2917e1f02b05bf47e509976a2944dfe04879)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetChangeDefinitionRequestRumQueryGroupByOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f3906c3c5eec1e17ecd416fd42842dc860c2667835d42b90753131f6fcf626c2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dae54872a860256632c16ad55db980fc184a41f555c1af29d15d561524a15c53)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c2b8d8c0b3597f3cf2a0caefad5928ea58b8ac1330ad005f9c9fb82a861b4fb1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetChangeDefinitionRequestRumQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetChangeDefinitionRequestRumQueryGroupBy]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetChangeDefinitionRequestRumQueryGroupBy]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f16b7b9b6f695c306546e3af2447510ad044fc4a3d3554709d14612f92ed2091)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetChangeDefinitionRequestRumQueryGroupByOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionRequestRumQueryGroupByOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7665082b6b41af3bdd13a9c51d55b8d81a3430dc28f417d5b76ce293fd1b1618)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putSortQuery")
    def put_sort_query(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        value = PowerpackWidgetChangeDefinitionRequestRumQueryGroupBySortQuery(
            aggregation=aggregation, order=order, facet=facet
        )

        return typing.cast(None, jsii.invoke(self, "putSortQuery", [value]))

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetLimit")
    def reset_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLimit", []))

    @jsii.member(jsii_name="resetSortQuery")
    def reset_sort_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSortQuery", []))

    @builtins.property
    @jsii.member(jsii_name="sortQuery")
    def sort_query(
        self,
    ) -> "PowerpackWidgetChangeDefinitionRequestRumQueryGroupBySortQueryOutputReference":
        return typing.cast("PowerpackWidgetChangeDefinitionRequestRumQueryGroupBySortQueryOutputReference", jsii.get(self, "sortQuery"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="limitInput")
    def limit_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "limitInput"))

    @builtins.property
    @jsii.member(jsii_name="sortQueryInput")
    def sort_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetChangeDefinitionRequestRumQueryGroupBySortQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetChangeDefinitionRequestRumQueryGroupBySortQuery"], jsii.get(self, "sortQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f9b44ae418f326ea2d8bf08b9591637b98b78f716b547d4bcca0f08bf70657d6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="limit")
    def limit(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "limit"))

    @limit.setter
    def limit(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ea0284dcaeb4604f858414b693ae44ce187792ea703ee331a2de7516f7746afe)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "limit", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetChangeDefinitionRequestRumQueryGroupBy]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetChangeDefinitionRequestRumQueryGroupBy]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetChangeDefinitionRequestRumQueryGroupBy]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2d26f198bd749e9b61578faa82aaa7a444edd493bdb8f6156a58320c3018b962)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionRequestRumQueryGroupBySortQuery",
    jsii_struct_bases=[],
    name_mapping={"aggregation": "aggregation", "order": "order", "facet": "facet"},
)
class PowerpackWidgetChangeDefinitionRequestRumQueryGroupBySortQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__105f74058809aeef995df649e4f486a833633bdc18ecf9fe3379960b86ec96f6)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument order", value=order, expected_type=type_hints["order"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
            "order": order,
        }
        if facet is not None:
            self._values["facet"] = facet

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def order(self) -> builtins.str:
        '''Widget sorting methods. Valid values are ``asc``, ``desc``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        result = self._values.get("order")
        assert result is not None, "Required property 'order' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetChangeDefinitionRequestRumQueryGroupBySortQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetChangeDefinitionRequestRumQueryGroupBySortQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionRequestRumQueryGroupBySortQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__43e80d8091f2c79471532a2a708c73b77cfe49a56638ca979bb7f561b9bd2369)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="orderInput")
    def order_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "orderInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__47587309ce22487d654c848d95dfe059cd6aa602f6c104e58cfc6e25a0adaf39)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__55260b8f951f188fdc1dca8fef6dedfb7265d82b06ae8793971d95db72eec7af)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="order")
    def order(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "order"))

    @order.setter
    def order(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__63b951a1ec7cda1aba6db797e7b2b0f5451498bd0bfd86b5c1dfbed69404b4f3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "order", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetChangeDefinitionRequestRumQueryGroupBySortQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetChangeDefinitionRequestRumQueryGroupBySortQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetChangeDefinitionRequestRumQueryGroupBySortQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7fad92eec20846f5eee50ab7e9a732b2d07932f71c5db8c4e4c94b87fc65a675)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionRequestRumQueryMultiCompute",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetChangeDefinitionRequestRumQueryMultiCompute:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5b16cd45b82d6366d28a264edf37390146c2204335e9438fa9ec3fef0bf279a8)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetChangeDefinitionRequestRumQueryMultiCompute(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetChangeDefinitionRequestRumQueryMultiComputeList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionRequestRumQueryMultiComputeList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bc83a90ee8101061c45e9380f6634356e1515ec4f155e62b503aa96295067aaf)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetChangeDefinitionRequestRumQueryMultiComputeOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bc3586efe98def580bd4995d091dc3e0634e39c64a213986476db68eb0f73285)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetChangeDefinitionRequestRumQueryMultiComputeOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9ada21390c89f6bd083b93778cbc29aa53b560094e5badd115be9dc582de3787)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5dabfabd5b050434639ce0e7041ab9f5393a1982e82e39235778bd10d544b9a2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__79858e687103db0014e3173f35b4e347f823a468a622436799960124c407a4dc)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetChangeDefinitionRequestRumQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetChangeDefinitionRequestRumQueryMultiCompute]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetChangeDefinitionRequestRumQueryMultiCompute]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4af3c8297934d1116865f0dca3634693386c39b6227c5726f463e74a218156df)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetChangeDefinitionRequestRumQueryMultiComputeOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionRequestRumQueryMultiComputeOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__80380a95e8a89896edca96ee6675c4e1f38225b3e02579e37f25d21bf893dbfc)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6da0b5728b9b34829f3c0975d3431b574c1a63c70af317d12ae807c93c574be3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9e35980c9942e41eafeb187af4146a3a6b03fbc7f138f63c85a4867a084d0c56)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c279c295b45dbc71791ed64abea81b6ab15df0475fe6452f20960d7fa4d7c7ef)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetChangeDefinitionRequestRumQueryMultiCompute]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetChangeDefinitionRequestRumQueryMultiCompute]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetChangeDefinitionRequestRumQueryMultiCompute]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__55a0aa50bdbc1b88b962d59f40b845ea65bef4e451c59d2851efdb5fe7837993)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetChangeDefinitionRequestRumQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionRequestRumQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ab2747b1ebc3fc902f5dc7255d977ff1e547476ef7d889e3140d64acb0279866)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putComputeQuery")
    def put_compute_query(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        value = PowerpackWidgetChangeDefinitionRequestRumQueryComputeQuery(
            aggregation=aggregation, facet=facet, interval=interval
        )

        return typing.cast(None, jsii.invoke(self, "putComputeQuery", [value]))

    @jsii.member(jsii_name="putGroupBy")
    def put_group_by(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetChangeDefinitionRequestRumQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f40992a5337aa2cdcf6af346664415d40cd4d923a608d9978e6b2d46137eb464)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putGroupBy", [value]))

    @jsii.member(jsii_name="putMultiCompute")
    def put_multi_compute(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetChangeDefinitionRequestRumQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__aea0f9029c4d36ab1cca4b4e69144dc98183c613d623f08ad44557ab1665344c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putMultiCompute", [value]))

    @jsii.member(jsii_name="resetComputeQuery")
    def reset_compute_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetComputeQuery", []))

    @jsii.member(jsii_name="resetGroupBy")
    def reset_group_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGroupBy", []))

    @jsii.member(jsii_name="resetMultiCompute")
    def reset_multi_compute(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMultiCompute", []))

    @jsii.member(jsii_name="resetSearchQuery")
    def reset_search_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSearchQuery", []))

    @builtins.property
    @jsii.member(jsii_name="computeQuery")
    def compute_query(
        self,
    ) -> PowerpackWidgetChangeDefinitionRequestRumQueryComputeQueryOutputReference:
        return typing.cast(PowerpackWidgetChangeDefinitionRequestRumQueryComputeQueryOutputReference, jsii.get(self, "computeQuery"))

    @builtins.property
    @jsii.member(jsii_name="groupBy")
    def group_by(self) -> PowerpackWidgetChangeDefinitionRequestRumQueryGroupByList:
        return typing.cast(PowerpackWidgetChangeDefinitionRequestRumQueryGroupByList, jsii.get(self, "groupBy"))

    @builtins.property
    @jsii.member(jsii_name="multiCompute")
    def multi_compute(
        self,
    ) -> PowerpackWidgetChangeDefinitionRequestRumQueryMultiComputeList:
        return typing.cast(PowerpackWidgetChangeDefinitionRequestRumQueryMultiComputeList, jsii.get(self, "multiCompute"))

    @builtins.property
    @jsii.member(jsii_name="computeQueryInput")
    def compute_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetChangeDefinitionRequestRumQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetChangeDefinitionRequestRumQueryComputeQuery], jsii.get(self, "computeQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="groupByInput")
    def group_by_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetChangeDefinitionRequestRumQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetChangeDefinitionRequestRumQueryGroupBy]]], jsii.get(self, "groupByInput"))

    @builtins.property
    @jsii.member(jsii_name="indexInput")
    def index_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "indexInput"))

    @builtins.property
    @jsii.member(jsii_name="multiComputeInput")
    def multi_compute_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetChangeDefinitionRequestRumQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetChangeDefinitionRequestRumQueryMultiCompute]]], jsii.get(self, "multiComputeInput"))

    @builtins.property
    @jsii.member(jsii_name="searchQueryInput")
    def search_query_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "searchQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="index")
    def index(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "index"))

    @index.setter
    def index(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9ad74c39e0383cd7e842d25a28b22ec38ba9d0e9c77252c99f9cc13f9750789b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "index", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="searchQuery")
    def search_query(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "searchQuery"))

    @search_query.setter
    def search_query(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__238ae78b0fbb38ffd8e4a7f0e5d444cc54b6484d38a791a07e99be2c01d3c605)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "searchQuery", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetChangeDefinitionRequestRumQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetChangeDefinitionRequestRumQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetChangeDefinitionRequestRumQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__80690955ed6a52285fa7245a419014a8dfbe91a1d2ae94ea1734531caea72903)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionRequestSecurityQuery",
    jsii_struct_bases=[],
    name_mapping={
        "index": "index",
        "compute_query": "computeQuery",
        "group_by": "groupBy",
        "multi_compute": "multiCompute",
        "search_query": "searchQuery",
    },
)
class PowerpackWidgetChangeDefinitionRequestSecurityQuery:
    def __init__(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union["PowerpackWidgetChangeDefinitionRequestSecurityQueryComputeQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetChangeDefinitionRequestSecurityQueryGroupBy", typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetChangeDefinitionRequestSecurityQueryMultiCompute", typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        if isinstance(compute_query, dict):
            compute_query = PowerpackWidgetChangeDefinitionRequestSecurityQueryComputeQuery(**compute_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__61605098fa73ebc9ca540ea2b509f8c4031264543127e09d88f11630995073b9)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
            check_type(argname="argument compute_query", value=compute_query, expected_type=type_hints["compute_query"])
            check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
            check_type(argname="argument multi_compute", value=multi_compute, expected_type=type_hints["multi_compute"])
            check_type(argname="argument search_query", value=search_query, expected_type=type_hints["search_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "index": index,
        }
        if compute_query is not None:
            self._values["compute_query"] = compute_query
        if group_by is not None:
            self._values["group_by"] = group_by
        if multi_compute is not None:
            self._values["multi_compute"] = multi_compute
        if search_query is not None:
            self._values["search_query"] = search_query

    @builtins.property
    def index(self) -> builtins.str:
        '''The name of the index to query.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        '''
        result = self._values.get("index")
        assert result is not None, "Required property 'index' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def compute_query(
        self,
    ) -> typing.Optional["PowerpackWidgetChangeDefinitionRequestSecurityQueryComputeQuery"]:
        '''compute_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        '''
        result = self._values.get("compute_query")
        return typing.cast(typing.Optional["PowerpackWidgetChangeDefinitionRequestSecurityQueryComputeQuery"], result)

    @builtins.property
    def group_by(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetChangeDefinitionRequestSecurityQueryGroupBy"]]]:
        '''group_by block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        '''
        result = self._values.get("group_by")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetChangeDefinitionRequestSecurityQueryGroupBy"]]], result)

    @builtins.property
    def multi_compute(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetChangeDefinitionRequestSecurityQueryMultiCompute"]]]:
        '''multi_compute block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        '''
        result = self._values.get("multi_compute")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetChangeDefinitionRequestSecurityQueryMultiCompute"]]], result)

    @builtins.property
    def search_query(self) -> typing.Optional[builtins.str]:
        '''The search query to use.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        result = self._values.get("search_query")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetChangeDefinitionRequestSecurityQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionRequestSecurityQueryComputeQuery",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetChangeDefinitionRequestSecurityQueryComputeQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__505396dff28fc5949d57837f2255f74c36a82c8018874d3af88db9826c2956d2)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetChangeDefinitionRequestSecurityQueryComputeQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetChangeDefinitionRequestSecurityQueryComputeQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionRequestSecurityQueryComputeQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__097267bc72f4528c90c640b4d2198297ccac2bbd12f64eda3569a801eb139e52)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7846ed5edcc107f275aea24c8d7c67fb15a2cf989cb815456d1f39059c93a914)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__aabfabb459843d661123664e654d99b7d34fb963ae329705b71adf74a5920180)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ad32a1ac61ebf7e9b7b30c72d02e3289df76c0b891b06e97500b5f0b0d5e6c93)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetChangeDefinitionRequestSecurityQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetChangeDefinitionRequestSecurityQueryComputeQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetChangeDefinitionRequestSecurityQueryComputeQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__49d0ce0632acea037a0184ecdcbf7e674f6d46c5566380d0b7e0a803dc4125f5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionRequestSecurityQueryGroupBy",
    jsii_struct_bases=[],
    name_mapping={"facet": "facet", "limit": "limit", "sort_query": "sortQuery"},
)
class PowerpackWidgetChangeDefinitionRequestSecurityQueryGroupBy:
    def __init__(
        self,
        *,
        facet: typing.Optional[builtins.str] = None,
        limit: typing.Optional[jsii.Number] = None,
        sort_query: typing.Optional[typing.Union["PowerpackWidgetChangeDefinitionRequestSecurityQueryGroupBySortQuery", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param limit: The maximum number of items in the group. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param sort_query: sort_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        if isinstance(sort_query, dict):
            sort_query = PowerpackWidgetChangeDefinitionRequestSecurityQueryGroupBySortQuery(**sort_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fe94348965cacf648584d4e4ef6881027110d759b3464bd59da632c66d46a495)
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
            check_type(argname="argument sort_query", value=sort_query, expected_type=type_hints["sort_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if facet is not None:
            self._values["facet"] = facet
        if limit is not None:
            self._values["limit"] = limit
        if sort_query is not None:
            self._values["sort_query"] = sort_query

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def limit(self) -> typing.Optional[jsii.Number]:
        '''The maximum number of items in the group.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        '''
        result = self._values.get("limit")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def sort_query(
        self,
    ) -> typing.Optional["PowerpackWidgetChangeDefinitionRequestSecurityQueryGroupBySortQuery"]:
        '''sort_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        result = self._values.get("sort_query")
        return typing.cast(typing.Optional["PowerpackWidgetChangeDefinitionRequestSecurityQueryGroupBySortQuery"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetChangeDefinitionRequestSecurityQueryGroupBy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetChangeDefinitionRequestSecurityQueryGroupByList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionRequestSecurityQueryGroupByList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dac8663d9fac6f1f1b8e65a49322328ea1eb379c453c8eb0f2c4962ccb02faa5)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetChangeDefinitionRequestSecurityQueryGroupByOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__40f739710e9c3c49745e5c638785da4a4f812c48d9b519ae043171f29b254de7)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetChangeDefinitionRequestSecurityQueryGroupByOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__504260fb504eb77357e5767522958e581ab27bd61b4d5be582271861b4efd7ae)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1af7293747cc134cc6c480d07b1d2888344bebaeb8bfc499c504484c23bd0c1f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3756a49df6bf3a32488efb984e82c4abf961e3ae62897ef9a7902ec45e3cd15f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetChangeDefinitionRequestSecurityQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetChangeDefinitionRequestSecurityQueryGroupBy]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetChangeDefinitionRequestSecurityQueryGroupBy]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3489be53bbe04a93a8d527901edfedcd6fb14d7d60601bcf48994f3bd24d0721)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetChangeDefinitionRequestSecurityQueryGroupByOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionRequestSecurityQueryGroupByOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c2345150a1741bc6c457710f41df032a7b9fa0c38506e49fa7bd514e4224083e)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putSortQuery")
    def put_sort_query(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        value = PowerpackWidgetChangeDefinitionRequestSecurityQueryGroupBySortQuery(
            aggregation=aggregation, order=order, facet=facet
        )

        return typing.cast(None, jsii.invoke(self, "putSortQuery", [value]))

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetLimit")
    def reset_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLimit", []))

    @jsii.member(jsii_name="resetSortQuery")
    def reset_sort_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSortQuery", []))

    @builtins.property
    @jsii.member(jsii_name="sortQuery")
    def sort_query(
        self,
    ) -> "PowerpackWidgetChangeDefinitionRequestSecurityQueryGroupBySortQueryOutputReference":
        return typing.cast("PowerpackWidgetChangeDefinitionRequestSecurityQueryGroupBySortQueryOutputReference", jsii.get(self, "sortQuery"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="limitInput")
    def limit_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "limitInput"))

    @builtins.property
    @jsii.member(jsii_name="sortQueryInput")
    def sort_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetChangeDefinitionRequestSecurityQueryGroupBySortQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetChangeDefinitionRequestSecurityQueryGroupBySortQuery"], jsii.get(self, "sortQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__835061259ab7bc38427104ba887e158ead12b2665d94ce3479ce5146e830b1f4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="limit")
    def limit(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "limit"))

    @limit.setter
    def limit(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__63387e73105ecdcba938e4198fc885a0da25da012d8f9bd33a6a537b0e382e94)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "limit", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetChangeDefinitionRequestSecurityQueryGroupBy]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetChangeDefinitionRequestSecurityQueryGroupBy]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetChangeDefinitionRequestSecurityQueryGroupBy]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2b1c1a69c6fccff79ec6f65fbb5151b652319f3bcb0fce5aa42ab81c62b5ed27)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionRequestSecurityQueryGroupBySortQuery",
    jsii_struct_bases=[],
    name_mapping={"aggregation": "aggregation", "order": "order", "facet": "facet"},
)
class PowerpackWidgetChangeDefinitionRequestSecurityQueryGroupBySortQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__91dcc69537592db09e5ec150d3f465867981fd17847fd35c96344d30977f3ca6)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument order", value=order, expected_type=type_hints["order"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
            "order": order,
        }
        if facet is not None:
            self._values["facet"] = facet

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def order(self) -> builtins.str:
        '''Widget sorting methods. Valid values are ``asc``, ``desc``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        result = self._values.get("order")
        assert result is not None, "Required property 'order' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetChangeDefinitionRequestSecurityQueryGroupBySortQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetChangeDefinitionRequestSecurityQueryGroupBySortQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionRequestSecurityQueryGroupBySortQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4f343bff2f44a0f1187f8e0e3934638996327e645df5cc8adac44e78c779b79e)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="orderInput")
    def order_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "orderInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3ab33252f74f7fce3199b5604829a592afdb885f8b592d4d4c22fd2f0d0ecd57)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d79a58e8560fb812305464d02def890b04f9da1d93bd0f89cbcb442f3992a530)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="order")
    def order(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "order"))

    @order.setter
    def order(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__14f161d246c538adf9d1cf84745ecf5a1b99108836d75b1bb7d638815776ded1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "order", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetChangeDefinitionRequestSecurityQueryGroupBySortQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetChangeDefinitionRequestSecurityQueryGroupBySortQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetChangeDefinitionRequestSecurityQueryGroupBySortQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4ebbde209c11738cf56192fb1c0f172d04061e297acc555a6229bd0f17b1891a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionRequestSecurityQueryMultiCompute",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetChangeDefinitionRequestSecurityQueryMultiCompute:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__799f9c787fce417079d84583f9a8b36064f9c728cb268e5b92d7bcdab75ca496)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetChangeDefinitionRequestSecurityQueryMultiCompute(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetChangeDefinitionRequestSecurityQueryMultiComputeList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionRequestSecurityQueryMultiComputeList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5925c020dd143d09e396eace4bb8932c3cf042f535103e1879eed358befecec3)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetChangeDefinitionRequestSecurityQueryMultiComputeOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c0bf5c59ff79e4d42335f5e72cec3821764855053b23b67052118b1122bfa763)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetChangeDefinitionRequestSecurityQueryMultiComputeOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f3d6894edaaae72cf2785378596666ef12c23a83daf6d98f0502b75ef72ceb0b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f1319957b3c4c4b1f3d0abc406d3f520e8b912ba20f505b8afd19d46c1047325)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__06881403d63c54bab7e72d7e1331b9ceb73daef7edaa4af4553d3c4fb90fe20d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetChangeDefinitionRequestSecurityQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetChangeDefinitionRequestSecurityQueryMultiCompute]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetChangeDefinitionRequestSecurityQueryMultiCompute]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3807abb51b1d9df2bbd03bce218d7152259436a011b8e032df20924860a3f6ba)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetChangeDefinitionRequestSecurityQueryMultiComputeOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionRequestSecurityQueryMultiComputeOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5a10471331626f6aa10b7667fc69c5529184121769b53953c29c8cdb31716500)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bac3bcec4e4cd625303b3c2fe538dbe4d70cccf51536ab54e7dead52b9877501)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ad805537cfcaeefaabc478c02ce32ffd6ed6a3739a1379d1e295bfc84836717b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ba2891eedc6f18925b05c8175cd6d0ab33f25d74e91982157be4a3ea692d6494)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetChangeDefinitionRequestSecurityQueryMultiCompute]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetChangeDefinitionRequestSecurityQueryMultiCompute]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetChangeDefinitionRequestSecurityQueryMultiCompute]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b709f0332e1b7c4bbe65f32cb8495024d538478bac4b78c0989aced0bba26463)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetChangeDefinitionRequestSecurityQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetChangeDefinitionRequestSecurityQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c84e74ac4df542cd6e194052fba24fed61ebf88646fdcd40495d928fec173cd5)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putComputeQuery")
    def put_compute_query(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        value = PowerpackWidgetChangeDefinitionRequestSecurityQueryComputeQuery(
            aggregation=aggregation, facet=facet, interval=interval
        )

        return typing.cast(None, jsii.invoke(self, "putComputeQuery", [value]))

    @jsii.member(jsii_name="putGroupBy")
    def put_group_by(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetChangeDefinitionRequestSecurityQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7f72787e5c7f6d7060a3f432ba34f1988919c8ddccd778149fed55bef48b4fa5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putGroupBy", [value]))

    @jsii.member(jsii_name="putMultiCompute")
    def put_multi_compute(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetChangeDefinitionRequestSecurityQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fd6e31fa35b34e65781479bc6185aca11d91250062dd0484cb4eb1f5a93a151c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putMultiCompute", [value]))

    @jsii.member(jsii_name="resetComputeQuery")
    def reset_compute_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetComputeQuery", []))

    @jsii.member(jsii_name="resetGroupBy")
    def reset_group_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGroupBy", []))

    @jsii.member(jsii_name="resetMultiCompute")
    def reset_multi_compute(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMultiCompute", []))

    @jsii.member(jsii_name="resetSearchQuery")
    def reset_search_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSearchQuery", []))

    @builtins.property
    @jsii.member(jsii_name="computeQuery")
    def compute_query(
        self,
    ) -> PowerpackWidgetChangeDefinitionRequestSecurityQueryComputeQueryOutputReference:
        return typing.cast(PowerpackWidgetChangeDefinitionRequestSecurityQueryComputeQueryOutputReference, jsii.get(self, "computeQuery"))

    @builtins.property
    @jsii.member(jsii_name="groupBy")
    def group_by(
        self,
    ) -> PowerpackWidgetChangeDefinitionRequestSecurityQueryGroupByList:
        return typing.cast(PowerpackWidgetChangeDefinitionRequestSecurityQueryGroupByList, jsii.get(self, "groupBy"))

    @builtins.property
    @jsii.member(jsii_name="multiCompute")
    def multi_compute(
        self,
    ) -> PowerpackWidgetChangeDefinitionRequestSecurityQueryMultiComputeList:
        return typing.cast(PowerpackWidgetChangeDefinitionRequestSecurityQueryMultiComputeList, jsii.get(self, "multiCompute"))

    @builtins.property
    @jsii.member(jsii_name="computeQueryInput")
    def compute_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetChangeDefinitionRequestSecurityQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetChangeDefinitionRequestSecurityQueryComputeQuery], jsii.get(self, "computeQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="groupByInput")
    def group_by_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetChangeDefinitionRequestSecurityQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetChangeDefinitionRequestSecurityQueryGroupBy]]], jsii.get(self, "groupByInput"))

    @builtins.property
    @jsii.member(jsii_name="indexInput")
    def index_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "indexInput"))

    @builtins.property
    @jsii.member(jsii_name="multiComputeInput")
    def multi_compute_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetChangeDefinitionRequestSecurityQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetChangeDefinitionRequestSecurityQueryMultiCompute]]], jsii.get(self, "multiComputeInput"))

    @builtins.property
    @jsii.member(jsii_name="searchQueryInput")
    def search_query_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "searchQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="index")
    def index(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "index"))

    @index.setter
    def index(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b61160a755a35cc706f778de244dc69c79017169316657cfcc0b81cd4c40e853)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "index", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="searchQuery")
    def search_query(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "searchQuery"))

    @search_query.setter
    def search_query(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__faa123158a10d55a70501cf16039d1b29feafeb78c796b3227f7205c0189b6f9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "searchQuery", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetChangeDefinitionRequestSecurityQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetChangeDefinitionRequestSecurityQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetChangeDefinitionRequestSecurityQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__130a0d78374d458a0d5eac0466931d225cd2ea1cb6b76145ad8d7d13cd53f97c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetCheckStatusDefinition",
    jsii_struct_bases=[],
    name_mapping={
        "check": "check",
        "grouping": "grouping",
        "group": "group",
        "group_by": "groupBy",
        "live_span": "liveSpan",
        "tags": "tags",
        "title": "title",
        "title_align": "titleAlign",
        "title_size": "titleSize",
    },
)
class PowerpackWidgetCheckStatusDefinition:
    def __init__(
        self,
        *,
        check: builtins.str,
        grouping: builtins.str,
        group: typing.Optional[builtins.str] = None,
        group_by: typing.Optional[typing.Sequence[builtins.str]] = None,
        live_span: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Sequence[builtins.str]] = None,
        title: typing.Optional[builtins.str] = None,
        title_align: typing.Optional[builtins.str] = None,
        title_size: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param check: The check to use in the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#check Powerpack#check}
        :param grouping: The kind of grouping to use. Valid values are ``check``, ``cluster``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#grouping Powerpack#grouping}
        :param group: The check group to use in the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group Powerpack#group}
        :param group_by: When ``grouping = "cluster"``, indicates a list of tags to use for grouping. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param live_span: The timeframe to use when displaying the widget. Valid values are ``1m``, ``5m``, ``10m``, ``15m``, ``30m``, ``1h``, ``4h``, ``1d``, ``2d``, ``1w``, ``1mo``, ``3mo``, ``6mo``, ``week_to_date``, ``month_to_date``, ``1y``, ``alert``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#live_span Powerpack#live_span}
        :param tags: A list of tags to use in the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#tags Powerpack#tags}
        :param title: The title of the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title Powerpack#title}
        :param title_align: The alignment of the widget's title. Valid values are ``center``, ``left``, ``right``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_align Powerpack#title_align}
        :param title_size: The size of the widget's title (defaults to 16). Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_size Powerpack#title_size}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a528e93f0cc550653ec796bc7526fa478f422c9335cd5345947aa306cf68ed54)
            check_type(argname="argument check", value=check, expected_type=type_hints["check"])
            check_type(argname="argument grouping", value=grouping, expected_type=type_hints["grouping"])
            check_type(argname="argument group", value=group, expected_type=type_hints["group"])
            check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
            check_type(argname="argument live_span", value=live_span, expected_type=type_hints["live_span"])
            check_type(argname="argument tags", value=tags, expected_type=type_hints["tags"])
            check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            check_type(argname="argument title_align", value=title_align, expected_type=type_hints["title_align"])
            check_type(argname="argument title_size", value=title_size, expected_type=type_hints["title_size"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "check": check,
            "grouping": grouping,
        }
        if group is not None:
            self._values["group"] = group
        if group_by is not None:
            self._values["group_by"] = group_by
        if live_span is not None:
            self._values["live_span"] = live_span
        if tags is not None:
            self._values["tags"] = tags
        if title is not None:
            self._values["title"] = title
        if title_align is not None:
            self._values["title_align"] = title_align
        if title_size is not None:
            self._values["title_size"] = title_size

    @builtins.property
    def check(self) -> builtins.str:
        '''The check to use in the widget.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#check Powerpack#check}
        '''
        result = self._values.get("check")
        assert result is not None, "Required property 'check' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def grouping(self) -> builtins.str:
        '''The kind of grouping to use. Valid values are ``check``, ``cluster``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#grouping Powerpack#grouping}
        '''
        result = self._values.get("grouping")
        assert result is not None, "Required property 'grouping' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def group(self) -> typing.Optional[builtins.str]:
        '''The check group to use in the widget.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group Powerpack#group}
        '''
        result = self._values.get("group")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def group_by(self) -> typing.Optional[typing.List[builtins.str]]:
        '''When ``grouping = "cluster"``, indicates a list of tags to use for grouping.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        '''
        result = self._values.get("group_by")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def live_span(self) -> typing.Optional[builtins.str]:
        '''The timeframe to use when displaying the widget.

        Valid values are ``1m``, ``5m``, ``10m``, ``15m``, ``30m``, ``1h``, ``4h``, ``1d``, ``2d``, ``1w``, ``1mo``, ``3mo``, ``6mo``, ``week_to_date``, ``month_to_date``, ``1y``, ``alert``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#live_span Powerpack#live_span}
        '''
        result = self._values.get("live_span")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def tags(self) -> typing.Optional[typing.List[builtins.str]]:
        '''A list of tags to use in the widget.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#tags Powerpack#tags}
        '''
        result = self._values.get("tags")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def title(self) -> typing.Optional[builtins.str]:
        '''The title of the widget.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title Powerpack#title}
        '''
        result = self._values.get("title")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def title_align(self) -> typing.Optional[builtins.str]:
        '''The alignment of the widget's title. Valid values are ``center``, ``left``, ``right``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_align Powerpack#title_align}
        '''
        result = self._values.get("title_align")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def title_size(self) -> typing.Optional[builtins.str]:
        '''The size of the widget's title (defaults to 16).

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_size Powerpack#title_size}
        '''
        result = self._values.get("title_size")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetCheckStatusDefinition(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetCheckStatusDefinitionOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetCheckStatusDefinitionOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__93d43ee793989fa2a8db81c509cb2572e5ef11d7abd8049ea6b780ce67118228)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetGroup")
    def reset_group(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGroup", []))

    @jsii.member(jsii_name="resetGroupBy")
    def reset_group_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGroupBy", []))

    @jsii.member(jsii_name="resetLiveSpan")
    def reset_live_span(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLiveSpan", []))

    @jsii.member(jsii_name="resetTags")
    def reset_tags(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTags", []))

    @jsii.member(jsii_name="resetTitle")
    def reset_title(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTitle", []))

    @jsii.member(jsii_name="resetTitleAlign")
    def reset_title_align(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTitleAlign", []))

    @jsii.member(jsii_name="resetTitleSize")
    def reset_title_size(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTitleSize", []))

    @builtins.property
    @jsii.member(jsii_name="checkInput")
    def check_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "checkInput"))

    @builtins.property
    @jsii.member(jsii_name="groupByInput")
    def group_by_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "groupByInput"))

    @builtins.property
    @jsii.member(jsii_name="groupingInput")
    def grouping_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "groupingInput"))

    @builtins.property
    @jsii.member(jsii_name="groupInput")
    def group_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "groupInput"))

    @builtins.property
    @jsii.member(jsii_name="liveSpanInput")
    def live_span_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "liveSpanInput"))

    @builtins.property
    @jsii.member(jsii_name="tagsInput")
    def tags_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "tagsInput"))

    @builtins.property
    @jsii.member(jsii_name="titleAlignInput")
    def title_align_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "titleAlignInput"))

    @builtins.property
    @jsii.member(jsii_name="titleInput")
    def title_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "titleInput"))

    @builtins.property
    @jsii.member(jsii_name="titleSizeInput")
    def title_size_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "titleSizeInput"))

    @builtins.property
    @jsii.member(jsii_name="check")
    def check(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "check"))

    @check.setter
    def check(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3c4497db654a9991174fa6ceebfd21bf4e7c7d4d844af113d46a4e1bd4bad9ba)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "check", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="group")
    def group(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "group"))

    @group.setter
    def group(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d8277402ec49ddde1df7789cb68c8864f57045c294ca0b9963caaa15d6546d10)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "group", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="groupBy")
    def group_by(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "groupBy"))

    @group_by.setter
    def group_by(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dfa493dca684ece961118e85431d9953642c5a1d0a332c618b106a430f5ef068)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "groupBy", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="grouping")
    def grouping(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "grouping"))

    @grouping.setter
    def grouping(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4deed43ec01517cb7316a9202002596bd6b937de955930ed503d2bc02d42bd07)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "grouping", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="liveSpan")
    def live_span(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "liveSpan"))

    @live_span.setter
    def live_span(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f6db54589e647e38cd1f24477ed2ecfa4350a996244b6cc64615450b342d88a3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "liveSpan", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "tags"))

    @tags.setter
    def tags(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__eaf56d15101646d134ea7f7ba0348f917e58eea325a76c7476777e4511cbb490)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "tags", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="title")
    def title(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "title"))

    @title.setter
    def title(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__19181e8ce498e1ae597c1946e8c32d8c18f6a7d6ab183558e139fa92efe8b731)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "title", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="titleAlign")
    def title_align(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "titleAlign"))

    @title_align.setter
    def title_align(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2f08053c041876a6d9244867d2edb0d6d8cc3f1f86cb1768ed37d3ad0479ddbc)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "titleAlign", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="titleSize")
    def title_size(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "titleSize"))

    @title_size.setter
    def title_size(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6c9c6b521c77af995be3bab711ff7bfd2849664d3f9256021b3205cdb983bc12)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "titleSize", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[PowerpackWidgetCheckStatusDefinition]:
        return typing.cast(typing.Optional[PowerpackWidgetCheckStatusDefinition], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetCheckStatusDefinition],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1679f90d7c2b2f9ff166c5d1bdf2c7442c64df8648aeb36de0e9028961db4179)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetDistributionDefinition",
    jsii_struct_bases=[],
    name_mapping={
        "legend_size": "legendSize",
        "live_span": "liveSpan",
        "request": "request",
        "show_legend": "showLegend",
        "title": "title",
        "title_align": "titleAlign",
        "title_size": "titleSize",
        "xaxis": "xaxis",
        "yaxis": "yaxis",
    },
)
class PowerpackWidgetDistributionDefinition:
    def __init__(
        self,
        *,
        legend_size: typing.Optional[builtins.str] = None,
        live_span: typing.Optional[builtins.str] = None,
        request: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetDistributionDefinitionRequest", typing.Dict[builtins.str, typing.Any]]]]] = None,
        show_legend: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        title: typing.Optional[builtins.str] = None,
        title_align: typing.Optional[builtins.str] = None,
        title_size: typing.Optional[builtins.str] = None,
        xaxis: typing.Optional[typing.Union["PowerpackWidgetDistributionDefinitionXaxis", typing.Dict[builtins.str, typing.Any]]] = None,
        yaxis: typing.Optional[typing.Union["PowerpackWidgetDistributionDefinitionYaxis", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param legend_size: The size of the legend displayed in the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#legend_size Powerpack#legend_size}
        :param live_span: The timeframe to use when displaying the widget. Valid values are ``1m``, ``5m``, ``10m``, ``15m``, ``30m``, ``1h``, ``4h``, ``1d``, ``2d``, ``1w``, ``1mo``, ``3mo``, ``6mo``, ``week_to_date``, ``month_to_date``, ``1y``, ``alert``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#live_span Powerpack#live_span}
        :param request: request block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#request Powerpack#request}
        :param show_legend: Whether or not to show the legend on this widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#show_legend Powerpack#show_legend}
        :param title: The title of the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title Powerpack#title}
        :param title_align: The alignment of the widget's title. Valid values are ``center``, ``left``, ``right``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_align Powerpack#title_align}
        :param title_size: The size of the widget's title (defaults to 16). Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_size Powerpack#title_size}
        :param xaxis: xaxis block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#xaxis Powerpack#xaxis}
        :param yaxis: yaxis block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#yaxis Powerpack#yaxis}
        '''
        if isinstance(xaxis, dict):
            xaxis = PowerpackWidgetDistributionDefinitionXaxis(**xaxis)
        if isinstance(yaxis, dict):
            yaxis = PowerpackWidgetDistributionDefinitionYaxis(**yaxis)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2ae9045fde129508dcf294cf60ea38b65cd817b1bef589093c3a4d80be3b66c9)
            check_type(argname="argument legend_size", value=legend_size, expected_type=type_hints["legend_size"])
            check_type(argname="argument live_span", value=live_span, expected_type=type_hints["live_span"])
            check_type(argname="argument request", value=request, expected_type=type_hints["request"])
            check_type(argname="argument show_legend", value=show_legend, expected_type=type_hints["show_legend"])
            check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            check_type(argname="argument title_align", value=title_align, expected_type=type_hints["title_align"])
            check_type(argname="argument title_size", value=title_size, expected_type=type_hints["title_size"])
            check_type(argname="argument xaxis", value=xaxis, expected_type=type_hints["xaxis"])
            check_type(argname="argument yaxis", value=yaxis, expected_type=type_hints["yaxis"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if legend_size is not None:
            self._values["legend_size"] = legend_size
        if live_span is not None:
            self._values["live_span"] = live_span
        if request is not None:
            self._values["request"] = request
        if show_legend is not None:
            self._values["show_legend"] = show_legend
        if title is not None:
            self._values["title"] = title
        if title_align is not None:
            self._values["title_align"] = title_align
        if title_size is not None:
            self._values["title_size"] = title_size
        if xaxis is not None:
            self._values["xaxis"] = xaxis
        if yaxis is not None:
            self._values["yaxis"] = yaxis

    @builtins.property
    def legend_size(self) -> typing.Optional[builtins.str]:
        '''The size of the legend displayed in the widget.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#legend_size Powerpack#legend_size}
        '''
        result = self._values.get("legend_size")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def live_span(self) -> typing.Optional[builtins.str]:
        '''The timeframe to use when displaying the widget.

        Valid values are ``1m``, ``5m``, ``10m``, ``15m``, ``30m``, ``1h``, ``4h``, ``1d``, ``2d``, ``1w``, ``1mo``, ``3mo``, ``6mo``, ``week_to_date``, ``month_to_date``, ``1y``, ``alert``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#live_span Powerpack#live_span}
        '''
        result = self._values.get("live_span")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def request(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetDistributionDefinitionRequest"]]]:
        '''request block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#request Powerpack#request}
        '''
        result = self._values.get("request")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetDistributionDefinitionRequest"]]], result)

    @builtins.property
    def show_legend(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        '''Whether or not to show the legend on this widget.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#show_legend Powerpack#show_legend}
        '''
        result = self._values.get("show_legend")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)

    @builtins.property
    def title(self) -> typing.Optional[builtins.str]:
        '''The title of the widget.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title Powerpack#title}
        '''
        result = self._values.get("title")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def title_align(self) -> typing.Optional[builtins.str]:
        '''The alignment of the widget's title. Valid values are ``center``, ``left``, ``right``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_align Powerpack#title_align}
        '''
        result = self._values.get("title_align")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def title_size(self) -> typing.Optional[builtins.str]:
        '''The size of the widget's title (defaults to 16).

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_size Powerpack#title_size}
        '''
        result = self._values.get("title_size")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def xaxis(self) -> typing.Optional["PowerpackWidgetDistributionDefinitionXaxis"]:
        '''xaxis block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#xaxis Powerpack#xaxis}
        '''
        result = self._values.get("xaxis")
        return typing.cast(typing.Optional["PowerpackWidgetDistributionDefinitionXaxis"], result)

    @builtins.property
    def yaxis(self) -> typing.Optional["PowerpackWidgetDistributionDefinitionYaxis"]:
        '''yaxis block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#yaxis Powerpack#yaxis}
        '''
        result = self._values.get("yaxis")
        return typing.cast(typing.Optional["PowerpackWidgetDistributionDefinitionYaxis"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetDistributionDefinition(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetDistributionDefinitionOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetDistributionDefinitionOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__159ed33343ccd05f450789381de5630b9cb1d41b235e0c9a1c07261554ad18ba)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putRequest")
    def put_request(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetDistributionDefinitionRequest", typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__64874e1a6a7e4a582af613587a9c2c5ae671935ec7dff9a3f25cf94733c67269)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putRequest", [value]))

    @jsii.member(jsii_name="putXaxis")
    def put_xaxis(
        self,
        *,
        include_zero: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        max: typing.Optional[builtins.str] = None,
        min: typing.Optional[builtins.str] = None,
        scale: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param include_zero: Always include zero or fit the axis to the data range. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#include_zero Powerpack#include_zero}
        :param max: Specify the maximum value to show on the Y-axis. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#max Powerpack#max}
        :param min: Specify the minimum value to show on the Y-axis. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#min Powerpack#min}
        :param scale: Specify the scale type, options: ``linear``, ``log``, ``pow``, ``sqrt``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#scale Powerpack#scale}
        '''
        value = PowerpackWidgetDistributionDefinitionXaxis(
            include_zero=include_zero, max=max, min=min, scale=scale
        )

        return typing.cast(None, jsii.invoke(self, "putXaxis", [value]))

    @jsii.member(jsii_name="putYaxis")
    def put_yaxis(
        self,
        *,
        include_zero: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        label: typing.Optional[builtins.str] = None,
        max: typing.Optional[builtins.str] = None,
        min: typing.Optional[builtins.str] = None,
        scale: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param include_zero: Always include zero or fit the axis to the data range. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#include_zero Powerpack#include_zero}
        :param label: The label of the axis to display on the graph. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#label Powerpack#label}
        :param max: Specify the maximum value to show on the Y-axis. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#max Powerpack#max}
        :param min: Specify the minimum value to show on the Y-axis. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#min Powerpack#min}
        :param scale: Specify the scale type, options: ``linear``, ``log``, ``pow``, ``sqrt``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#scale Powerpack#scale}
        '''
        value = PowerpackWidgetDistributionDefinitionYaxis(
            include_zero=include_zero, label=label, max=max, min=min, scale=scale
        )

        return typing.cast(None, jsii.invoke(self, "putYaxis", [value]))

    @jsii.member(jsii_name="resetLegendSize")
    def reset_legend_size(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLegendSize", []))

    @jsii.member(jsii_name="resetLiveSpan")
    def reset_live_span(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLiveSpan", []))

    @jsii.member(jsii_name="resetRequest")
    def reset_request(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetRequest", []))

    @jsii.member(jsii_name="resetShowLegend")
    def reset_show_legend(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetShowLegend", []))

    @jsii.member(jsii_name="resetTitle")
    def reset_title(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTitle", []))

    @jsii.member(jsii_name="resetTitleAlign")
    def reset_title_align(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTitleAlign", []))

    @jsii.member(jsii_name="resetTitleSize")
    def reset_title_size(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTitleSize", []))

    @jsii.member(jsii_name="resetXaxis")
    def reset_xaxis(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetXaxis", []))

    @jsii.member(jsii_name="resetYaxis")
    def reset_yaxis(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetYaxis", []))

    @builtins.property
    @jsii.member(jsii_name="request")
    def request(self) -> "PowerpackWidgetDistributionDefinitionRequestList":
        return typing.cast("PowerpackWidgetDistributionDefinitionRequestList", jsii.get(self, "request"))

    @builtins.property
    @jsii.member(jsii_name="xaxis")
    def xaxis(self) -> "PowerpackWidgetDistributionDefinitionXaxisOutputReference":
        return typing.cast("PowerpackWidgetDistributionDefinitionXaxisOutputReference", jsii.get(self, "xaxis"))

    @builtins.property
    @jsii.member(jsii_name="yaxis")
    def yaxis(self) -> "PowerpackWidgetDistributionDefinitionYaxisOutputReference":
        return typing.cast("PowerpackWidgetDistributionDefinitionYaxisOutputReference", jsii.get(self, "yaxis"))

    @builtins.property
    @jsii.member(jsii_name="legendSizeInput")
    def legend_size_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "legendSizeInput"))

    @builtins.property
    @jsii.member(jsii_name="liveSpanInput")
    def live_span_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "liveSpanInput"))

    @builtins.property
    @jsii.member(jsii_name="requestInput")
    def request_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetDistributionDefinitionRequest"]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetDistributionDefinitionRequest"]]], jsii.get(self, "requestInput"))

    @builtins.property
    @jsii.member(jsii_name="showLegendInput")
    def show_legend_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "showLegendInput"))

    @builtins.property
    @jsii.member(jsii_name="titleAlignInput")
    def title_align_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "titleAlignInput"))

    @builtins.property
    @jsii.member(jsii_name="titleInput")
    def title_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "titleInput"))

    @builtins.property
    @jsii.member(jsii_name="titleSizeInput")
    def title_size_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "titleSizeInput"))

    @builtins.property
    @jsii.member(jsii_name="xaxisInput")
    def xaxis_input(
        self,
    ) -> typing.Optional["PowerpackWidgetDistributionDefinitionXaxis"]:
        return typing.cast(typing.Optional["PowerpackWidgetDistributionDefinitionXaxis"], jsii.get(self, "xaxisInput"))

    @builtins.property
    @jsii.member(jsii_name="yaxisInput")
    def yaxis_input(
        self,
    ) -> typing.Optional["PowerpackWidgetDistributionDefinitionYaxis"]:
        return typing.cast(typing.Optional["PowerpackWidgetDistributionDefinitionYaxis"], jsii.get(self, "yaxisInput"))

    @builtins.property
    @jsii.member(jsii_name="legendSize")
    def legend_size(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "legendSize"))

    @legend_size.setter
    def legend_size(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e04c0aba1e7d20df55f0aebcdc2809597e67ecd139d4e22439aaf87132c0eb50)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "legendSize", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="liveSpan")
    def live_span(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "liveSpan"))

    @live_span.setter
    def live_span(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a70598be44d069fa1ab554c3afbe8b9d3ced26b4bb73d1daf21f4436d4c3595b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "liveSpan", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="showLegend")
    def show_legend(self) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "showLegend"))

    @show_legend.setter
    def show_legend(
        self,
        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1869623e06e34b06ce8315fc41131eb929b1787c42d259474ad66e6ab87068ee)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "showLegend", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="title")
    def title(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "title"))

    @title.setter
    def title(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__51c401e104999066ed1ad5a2dad82bc41b0741630949ea05932df381d5d84497)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "title", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="titleAlign")
    def title_align(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "titleAlign"))

    @title_align.setter
    def title_align(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d195da01ec723e537c215e901afb90054d1d2c6f668bb7368c27b301946147bc)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "titleAlign", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="titleSize")
    def title_size(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "titleSize"))

    @title_size.setter
    def title_size(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c349fc2c8a51e6b70e24e172da4df2dbc38de63fc6c7420abfa6111a2ff348c5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "titleSize", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[PowerpackWidgetDistributionDefinition]:
        return typing.cast(typing.Optional[PowerpackWidgetDistributionDefinition], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetDistributionDefinition],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__68aeaa1b8b53f63a3c97873c122f4c903701ef80a1100fdf14f46139e767fbc6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetDistributionDefinitionRequest",
    jsii_struct_bases=[],
    name_mapping={
        "apm_query": "apmQuery",
        "apm_stats_query": "apmStatsQuery",
        "log_query": "logQuery",
        "process_query": "processQuery",
        "q": "q",
        "rum_query": "rumQuery",
        "security_query": "securityQuery",
        "style": "style",
    },
)
class PowerpackWidgetDistributionDefinitionRequest:
    def __init__(
        self,
        *,
        apm_query: typing.Optional[typing.Union["PowerpackWidgetDistributionDefinitionRequestApmQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        apm_stats_query: typing.Optional[typing.Union["PowerpackWidgetDistributionDefinitionRequestApmStatsQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        log_query: typing.Optional[typing.Union["PowerpackWidgetDistributionDefinitionRequestLogQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        process_query: typing.Optional[typing.Union["PowerpackWidgetDistributionDefinitionRequestProcessQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        q: typing.Optional[builtins.str] = None,
        rum_query: typing.Optional[typing.Union["PowerpackWidgetDistributionDefinitionRequestRumQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        security_query: typing.Optional[typing.Union["PowerpackWidgetDistributionDefinitionRequestSecurityQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        style: typing.Optional[typing.Union["PowerpackWidgetDistributionDefinitionRequestStyle", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param apm_query: apm_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#apm_query Powerpack#apm_query}
        :param apm_stats_query: apm_stats_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#apm_stats_query Powerpack#apm_stats_query}
        :param log_query: log_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#log_query Powerpack#log_query}
        :param process_query: process_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#process_query Powerpack#process_query}
        :param q: The metric query to use for this widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#q Powerpack#q}
        :param rum_query: rum_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#rum_query Powerpack#rum_query}
        :param security_query: security_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#security_query Powerpack#security_query}
        :param style: style block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#style Powerpack#style}
        '''
        if isinstance(apm_query, dict):
            apm_query = PowerpackWidgetDistributionDefinitionRequestApmQuery(**apm_query)
        if isinstance(apm_stats_query, dict):
            apm_stats_query = PowerpackWidgetDistributionDefinitionRequestApmStatsQuery(**apm_stats_query)
        if isinstance(log_query, dict):
            log_query = PowerpackWidgetDistributionDefinitionRequestLogQuery(**log_query)
        if isinstance(process_query, dict):
            process_query = PowerpackWidgetDistributionDefinitionRequestProcessQuery(**process_query)
        if isinstance(rum_query, dict):
            rum_query = PowerpackWidgetDistributionDefinitionRequestRumQuery(**rum_query)
        if isinstance(security_query, dict):
            security_query = PowerpackWidgetDistributionDefinitionRequestSecurityQuery(**security_query)
        if isinstance(style, dict):
            style = PowerpackWidgetDistributionDefinitionRequestStyle(**style)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8835ac2331f04f4fd4c8d6507b2ebe3ae4519143e28d939b29e6d79f252cd5bb)
            check_type(argname="argument apm_query", value=apm_query, expected_type=type_hints["apm_query"])
            check_type(argname="argument apm_stats_query", value=apm_stats_query, expected_type=type_hints["apm_stats_query"])
            check_type(argname="argument log_query", value=log_query, expected_type=type_hints["log_query"])
            check_type(argname="argument process_query", value=process_query, expected_type=type_hints["process_query"])
            check_type(argname="argument q", value=q, expected_type=type_hints["q"])
            check_type(argname="argument rum_query", value=rum_query, expected_type=type_hints["rum_query"])
            check_type(argname="argument security_query", value=security_query, expected_type=type_hints["security_query"])
            check_type(argname="argument style", value=style, expected_type=type_hints["style"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if apm_query is not None:
            self._values["apm_query"] = apm_query
        if apm_stats_query is not None:
            self._values["apm_stats_query"] = apm_stats_query
        if log_query is not None:
            self._values["log_query"] = log_query
        if process_query is not None:
            self._values["process_query"] = process_query
        if q is not None:
            self._values["q"] = q
        if rum_query is not None:
            self._values["rum_query"] = rum_query
        if security_query is not None:
            self._values["security_query"] = security_query
        if style is not None:
            self._values["style"] = style

    @builtins.property
    def apm_query(
        self,
    ) -> typing.Optional["PowerpackWidgetDistributionDefinitionRequestApmQuery"]:
        '''apm_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#apm_query Powerpack#apm_query}
        '''
        result = self._values.get("apm_query")
        return typing.cast(typing.Optional["PowerpackWidgetDistributionDefinitionRequestApmQuery"], result)

    @builtins.property
    def apm_stats_query(
        self,
    ) -> typing.Optional["PowerpackWidgetDistributionDefinitionRequestApmStatsQuery"]:
        '''apm_stats_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#apm_stats_query Powerpack#apm_stats_query}
        '''
        result = self._values.get("apm_stats_query")
        return typing.cast(typing.Optional["PowerpackWidgetDistributionDefinitionRequestApmStatsQuery"], result)

    @builtins.property
    def log_query(
        self,
    ) -> typing.Optional["PowerpackWidgetDistributionDefinitionRequestLogQuery"]:
        '''log_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#log_query Powerpack#log_query}
        '''
        result = self._values.get("log_query")
        return typing.cast(typing.Optional["PowerpackWidgetDistributionDefinitionRequestLogQuery"], result)

    @builtins.property
    def process_query(
        self,
    ) -> typing.Optional["PowerpackWidgetDistributionDefinitionRequestProcessQuery"]:
        '''process_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#process_query Powerpack#process_query}
        '''
        result = self._values.get("process_query")
        return typing.cast(typing.Optional["PowerpackWidgetDistributionDefinitionRequestProcessQuery"], result)

    @builtins.property
    def q(self) -> typing.Optional[builtins.str]:
        '''The metric query to use for this widget.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#q Powerpack#q}
        '''
        result = self._values.get("q")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def rum_query(
        self,
    ) -> typing.Optional["PowerpackWidgetDistributionDefinitionRequestRumQuery"]:
        '''rum_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#rum_query Powerpack#rum_query}
        '''
        result = self._values.get("rum_query")
        return typing.cast(typing.Optional["PowerpackWidgetDistributionDefinitionRequestRumQuery"], result)

    @builtins.property
    def security_query(
        self,
    ) -> typing.Optional["PowerpackWidgetDistributionDefinitionRequestSecurityQuery"]:
        '''security_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#security_query Powerpack#security_query}
        '''
        result = self._values.get("security_query")
        return typing.cast(typing.Optional["PowerpackWidgetDistributionDefinitionRequestSecurityQuery"], result)

    @builtins.property
    def style(
        self,
    ) -> typing.Optional["PowerpackWidgetDistributionDefinitionRequestStyle"]:
        '''style block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#style Powerpack#style}
        '''
        result = self._values.get("style")
        return typing.cast(typing.Optional["PowerpackWidgetDistributionDefinitionRequestStyle"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetDistributionDefinitionRequest(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetDistributionDefinitionRequestApmQuery",
    jsii_struct_bases=[],
    name_mapping={
        "index": "index",
        "compute_query": "computeQuery",
        "group_by": "groupBy",
        "multi_compute": "multiCompute",
        "search_query": "searchQuery",
    },
)
class PowerpackWidgetDistributionDefinitionRequestApmQuery:
    def __init__(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union["PowerpackWidgetDistributionDefinitionRequestApmQueryComputeQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetDistributionDefinitionRequestApmQueryGroupBy", typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetDistributionDefinitionRequestApmQueryMultiCompute", typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        if isinstance(compute_query, dict):
            compute_query = PowerpackWidgetDistributionDefinitionRequestApmQueryComputeQuery(**compute_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bdbf6f7f57d55857004970de06b5a08abffb17766fa596c79f2888eb98aeda19)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
            check_type(argname="argument compute_query", value=compute_query, expected_type=type_hints["compute_query"])
            check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
            check_type(argname="argument multi_compute", value=multi_compute, expected_type=type_hints["multi_compute"])
            check_type(argname="argument search_query", value=search_query, expected_type=type_hints["search_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "index": index,
        }
        if compute_query is not None:
            self._values["compute_query"] = compute_query
        if group_by is not None:
            self._values["group_by"] = group_by
        if multi_compute is not None:
            self._values["multi_compute"] = multi_compute
        if search_query is not None:
            self._values["search_query"] = search_query

    @builtins.property
    def index(self) -> builtins.str:
        '''The name of the index to query.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        '''
        result = self._values.get("index")
        assert result is not None, "Required property 'index' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def compute_query(
        self,
    ) -> typing.Optional["PowerpackWidgetDistributionDefinitionRequestApmQueryComputeQuery"]:
        '''compute_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        '''
        result = self._values.get("compute_query")
        return typing.cast(typing.Optional["PowerpackWidgetDistributionDefinitionRequestApmQueryComputeQuery"], result)

    @builtins.property
    def group_by(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetDistributionDefinitionRequestApmQueryGroupBy"]]]:
        '''group_by block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        '''
        result = self._values.get("group_by")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetDistributionDefinitionRequestApmQueryGroupBy"]]], result)

    @builtins.property
    def multi_compute(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetDistributionDefinitionRequestApmQueryMultiCompute"]]]:
        '''multi_compute block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        '''
        result = self._values.get("multi_compute")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetDistributionDefinitionRequestApmQueryMultiCompute"]]], result)

    @builtins.property
    def search_query(self) -> typing.Optional[builtins.str]:
        '''The search query to use.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        result = self._values.get("search_query")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetDistributionDefinitionRequestApmQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetDistributionDefinitionRequestApmQueryComputeQuery",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetDistributionDefinitionRequestApmQueryComputeQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1f40844eeadc18b24b71e1681fb1edec59514b198ff18ccc32b5cf4124c0b58a)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetDistributionDefinitionRequestApmQueryComputeQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetDistributionDefinitionRequestApmQueryComputeQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetDistributionDefinitionRequestApmQueryComputeQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8939ac30fccf7e2475e6c465edaf48b440cfc9552478a1e7ed53a59b235720ed)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cce6c5310151eae09d5a90d33dcd513989d4a6468c30c87920a7fb00b50db095)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d8b9d27ca00851d7b12cb3d14c349348e343070192823db3c5e26ca81cc954dd)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__58bf99777a327f912a5e1e315f49725f2e9dd3db9ceaf1145809c313e67fde83)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetDistributionDefinitionRequestApmQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetDistributionDefinitionRequestApmQueryComputeQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetDistributionDefinitionRequestApmQueryComputeQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c14eb257e888188803676538d4da26dffdd6816b8fb32b003c1dd40ee0be034c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetDistributionDefinitionRequestApmQueryGroupBy",
    jsii_struct_bases=[],
    name_mapping={"facet": "facet", "limit": "limit", "sort_query": "sortQuery"},
)
class PowerpackWidgetDistributionDefinitionRequestApmQueryGroupBy:
    def __init__(
        self,
        *,
        facet: typing.Optional[builtins.str] = None,
        limit: typing.Optional[jsii.Number] = None,
        sort_query: typing.Optional[typing.Union["PowerpackWidgetDistributionDefinitionRequestApmQueryGroupBySortQuery", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param limit: The maximum number of items in the group. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param sort_query: sort_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        if isinstance(sort_query, dict):
            sort_query = PowerpackWidgetDistributionDefinitionRequestApmQueryGroupBySortQuery(**sort_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0a3d54ce3b20308f65213a763bec26aae7472a9f88c03e3c8539686f3902d1f2)
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
            check_type(argname="argument sort_query", value=sort_query, expected_type=type_hints["sort_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if facet is not None:
            self._values["facet"] = facet
        if limit is not None:
            self._values["limit"] = limit
        if sort_query is not None:
            self._values["sort_query"] = sort_query

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def limit(self) -> typing.Optional[jsii.Number]:
        '''The maximum number of items in the group.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        '''
        result = self._values.get("limit")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def sort_query(
        self,
    ) -> typing.Optional["PowerpackWidgetDistributionDefinitionRequestApmQueryGroupBySortQuery"]:
        '''sort_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        result = self._values.get("sort_query")
        return typing.cast(typing.Optional["PowerpackWidgetDistributionDefinitionRequestApmQueryGroupBySortQuery"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetDistributionDefinitionRequestApmQueryGroupBy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetDistributionDefinitionRequestApmQueryGroupByList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetDistributionDefinitionRequestApmQueryGroupByList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4c18dc4dee0923bc33a61e9e23b79ea2033b07b9faf2bdff3cd67b4924e30767)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetDistributionDefinitionRequestApmQueryGroupByOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c33515fde65ee50e07abd18b5a05f8ddeef43c26575f539007eccff472710792)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetDistributionDefinitionRequestApmQueryGroupByOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2980e860482df45572b17c91e594575bdb385ad949a7b2120ed77c90366f816e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9c09025afedcde966bd7cbcc6dd2ad8ccbc926a1ad97ea92a94b19095eb78840)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__190f3a15e4759cb97b2eaaf437e83cc4e046d7ede50097b569cabf4dbc2bda48)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetDistributionDefinitionRequestApmQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetDistributionDefinitionRequestApmQueryGroupBy]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetDistributionDefinitionRequestApmQueryGroupBy]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d213c6cebcb62a832489b597f3976f860aa7aa3f489f83de5fa9b5512199adc1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetDistributionDefinitionRequestApmQueryGroupByOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetDistributionDefinitionRequestApmQueryGroupByOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bc928e37162080f1aa6e90965c7e8b7cee3201e9f6edd9a985a6e1ca283e5092)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putSortQuery")
    def put_sort_query(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        value = PowerpackWidgetDistributionDefinitionRequestApmQueryGroupBySortQuery(
            aggregation=aggregation, order=order, facet=facet
        )

        return typing.cast(None, jsii.invoke(self, "putSortQuery", [value]))

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetLimit")
    def reset_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLimit", []))

    @jsii.member(jsii_name="resetSortQuery")
    def reset_sort_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSortQuery", []))

    @builtins.property
    @jsii.member(jsii_name="sortQuery")
    def sort_query(
        self,
    ) -> "PowerpackWidgetDistributionDefinitionRequestApmQueryGroupBySortQueryOutputReference":
        return typing.cast("PowerpackWidgetDistributionDefinitionRequestApmQueryGroupBySortQueryOutputReference", jsii.get(self, "sortQuery"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="limitInput")
    def limit_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "limitInput"))

    @builtins.property
    @jsii.member(jsii_name="sortQueryInput")
    def sort_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetDistributionDefinitionRequestApmQueryGroupBySortQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetDistributionDefinitionRequestApmQueryGroupBySortQuery"], jsii.get(self, "sortQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f982d3480edef8789ad93f2d90456ad15de1e90a8e7c2d9fd88cba20686eec4e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="limit")
    def limit(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "limit"))

    @limit.setter
    def limit(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__938e189e5dc75b9fec85df00858f597cc8ee51cab5b99fa586f625d73fd0fb39)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "limit", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetDistributionDefinitionRequestApmQueryGroupBy]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetDistributionDefinitionRequestApmQueryGroupBy]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetDistributionDefinitionRequestApmQueryGroupBy]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__15df13badd283666e603f64926dcd43c1c3db141d66470ed42fae8b769da5c2c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetDistributionDefinitionRequestApmQueryGroupBySortQuery",
    jsii_struct_bases=[],
    name_mapping={"aggregation": "aggregation", "order": "order", "facet": "facet"},
)
class PowerpackWidgetDistributionDefinitionRequestApmQueryGroupBySortQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__eda925cc00b1182427ccdf4804780f06c0d487443a9144eeb5ebc60fc34dff6b)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument order", value=order, expected_type=type_hints["order"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
            "order": order,
        }
        if facet is not None:
            self._values["facet"] = facet

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def order(self) -> builtins.str:
        '''Widget sorting methods. Valid values are ``asc``, ``desc``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        result = self._values.get("order")
        assert result is not None, "Required property 'order' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetDistributionDefinitionRequestApmQueryGroupBySortQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetDistributionDefinitionRequestApmQueryGroupBySortQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetDistributionDefinitionRequestApmQueryGroupBySortQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__11761c5f5851c043c0fd240e89dbea8efefeeb164c688083ffc1d2e49b92a568)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="orderInput")
    def order_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "orderInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7e76f2fbaed85bd6d187c7af8ca4f3e37aee1bb80464656ed25a1c86b1cc26ff)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b9788e4a1a7e14e83046e26062d48a54886c107421c9e830c73383d377cf0c7c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="order")
    def order(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "order"))

    @order.setter
    def order(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f65f04ec7fe44d47d1139f8dab41d464cec16ae725f757171d85949b0b7167cc)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "order", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetDistributionDefinitionRequestApmQueryGroupBySortQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetDistributionDefinitionRequestApmQueryGroupBySortQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetDistributionDefinitionRequestApmQueryGroupBySortQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f1f855dfd9c38280d7a1e22a9173e6de1131c10efda5b17992abf52e7fbb6022)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetDistributionDefinitionRequestApmQueryMultiCompute",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetDistributionDefinitionRequestApmQueryMultiCompute:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3a5d29a3bb2f34b06707a69f9492cb0f5282bbf428d2bf4d2705479bb169df7f)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetDistributionDefinitionRequestApmQueryMultiCompute(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetDistributionDefinitionRequestApmQueryMultiComputeList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetDistributionDefinitionRequestApmQueryMultiComputeList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3a387d4310592bd2c2e484c531f5a81823dcb20947dd05447d160ee90210fe76)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetDistributionDefinitionRequestApmQueryMultiComputeOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c2055819bb84a31728a37ebc755210a90842e1161a92b32e66f2b7c8a6e6f056)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetDistributionDefinitionRequestApmQueryMultiComputeOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d06f62632bf879a8f5ccf46120af0d5272c88312c7fb036ba2b966652afbf142)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9ab2fe944b860abff7014668da6b3535f8c9957efda8c06ca759959aa5e28672)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d5926acfd838731836df8560caa577e47a0d59437849ee76637359acdee82555)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetDistributionDefinitionRequestApmQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetDistributionDefinitionRequestApmQueryMultiCompute]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetDistributionDefinitionRequestApmQueryMultiCompute]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__aa5b648ce63d073444aa2bb96339c377ea797c8c57801f8d2a5d0c48fbf9dfde)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetDistributionDefinitionRequestApmQueryMultiComputeOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetDistributionDefinitionRequestApmQueryMultiComputeOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__652b14194985fdfaa7e284c3a41497376b618f7b3b2bc82d6eb4a61f15ea8fb6)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1a558475833627a6666a2711b656be231ac5f16a90a8a38cdf3891f0588d0f38)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__905dfc054c3d0b52c7f4a8a76ee93fe80280d6e2d08d221234c5e85e6f286909)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__570abf699e9a0ea62e5548332017ee3df2aae62080ef9e22f49d96fc29e3f0ac)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetDistributionDefinitionRequestApmQueryMultiCompute]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetDistributionDefinitionRequestApmQueryMultiCompute]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetDistributionDefinitionRequestApmQueryMultiCompute]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f2ded3c48f9390512c7999eda50fcafeaf112b702d71b30284a744c1e038da6f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetDistributionDefinitionRequestApmQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetDistributionDefinitionRequestApmQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3b511a603221a8cf310236a69fbadb6f707267d8660795178a5ce7f34d8fd1d5)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putComputeQuery")
    def put_compute_query(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        value = PowerpackWidgetDistributionDefinitionRequestApmQueryComputeQuery(
            aggregation=aggregation, facet=facet, interval=interval
        )

        return typing.cast(None, jsii.invoke(self, "putComputeQuery", [value]))

    @jsii.member(jsii_name="putGroupBy")
    def put_group_by(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetDistributionDefinitionRequestApmQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1540f78868cc006b539b31bf8eeb9da33428baf7b9bf1920d6c4d5111a435c32)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putGroupBy", [value]))

    @jsii.member(jsii_name="putMultiCompute")
    def put_multi_compute(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetDistributionDefinitionRequestApmQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__111dd4a4457bda863e8b250966de75fb01a22981db1460875b507f847f7f4c12)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putMultiCompute", [value]))

    @jsii.member(jsii_name="resetComputeQuery")
    def reset_compute_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetComputeQuery", []))

    @jsii.member(jsii_name="resetGroupBy")
    def reset_group_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGroupBy", []))

    @jsii.member(jsii_name="resetMultiCompute")
    def reset_multi_compute(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMultiCompute", []))

    @jsii.member(jsii_name="resetSearchQuery")
    def reset_search_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSearchQuery", []))

    @builtins.property
    @jsii.member(jsii_name="computeQuery")
    def compute_query(
        self,
    ) -> PowerpackWidgetDistributionDefinitionRequestApmQueryComputeQueryOutputReference:
        return typing.cast(PowerpackWidgetDistributionDefinitionRequestApmQueryComputeQueryOutputReference, jsii.get(self, "computeQuery"))

    @builtins.property
    @jsii.member(jsii_name="groupBy")
    def group_by(
        self,
    ) -> PowerpackWidgetDistributionDefinitionRequestApmQueryGroupByList:
        return typing.cast(PowerpackWidgetDistributionDefinitionRequestApmQueryGroupByList, jsii.get(self, "groupBy"))

    @builtins.property
    @jsii.member(jsii_name="multiCompute")
    def multi_compute(
        self,
    ) -> PowerpackWidgetDistributionDefinitionRequestApmQueryMultiComputeList:
        return typing.cast(PowerpackWidgetDistributionDefinitionRequestApmQueryMultiComputeList, jsii.get(self, "multiCompute"))

    @builtins.property
    @jsii.member(jsii_name="computeQueryInput")
    def compute_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetDistributionDefinitionRequestApmQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetDistributionDefinitionRequestApmQueryComputeQuery], jsii.get(self, "computeQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="groupByInput")
    def group_by_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetDistributionDefinitionRequestApmQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetDistributionDefinitionRequestApmQueryGroupBy]]], jsii.get(self, "groupByInput"))

    @builtins.property
    @jsii.member(jsii_name="indexInput")
    def index_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "indexInput"))

    @builtins.property
    @jsii.member(jsii_name="multiComputeInput")
    def multi_compute_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetDistributionDefinitionRequestApmQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetDistributionDefinitionRequestApmQueryMultiCompute]]], jsii.get(self, "multiComputeInput"))

    @builtins.property
    @jsii.member(jsii_name="searchQueryInput")
    def search_query_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "searchQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="index")
    def index(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "index"))

    @index.setter
    def index(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__059328f2c65ce72994da812c3195b7d3c0af7a25aab6aceace7473cd1e61626e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "index", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="searchQuery")
    def search_query(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "searchQuery"))

    @search_query.setter
    def search_query(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5385313704684693821e1263559f3af6e74abaad5cea953561f07e65f517c107)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "searchQuery", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetDistributionDefinitionRequestApmQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetDistributionDefinitionRequestApmQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetDistributionDefinitionRequestApmQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__677cb576b70cd819229dcd6cd702146bb35e7d6a05c92c64f773962974c89869)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetDistributionDefinitionRequestApmStatsQuery",
    jsii_struct_bases=[],
    name_mapping={
        "env": "env",
        "name": "name",
        "primary_tag": "primaryTag",
        "row_type": "rowType",
        "service": "service",
        "columns": "columns",
        "resource": "resource",
    },
)
class PowerpackWidgetDistributionDefinitionRequestApmStatsQuery:
    def __init__(
        self,
        *,
        env: builtins.str,
        name: builtins.str,
        primary_tag: builtins.str,
        row_type: builtins.str,
        service: builtins.str,
        columns: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetDistributionDefinitionRequestApmStatsQueryColumns", typing.Dict[builtins.str, typing.Any]]]]] = None,
        resource: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param env: The environment name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#env Powerpack#env}
        :param name: The operation name associated with the service. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param primary_tag: The organization's host group name and value. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag Powerpack#primary_tag}
        :param row_type: The level of detail for the request. Valid values are ``service``, ``resource``, ``span``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#row_type Powerpack#row_type}
        :param service: The service name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#service Powerpack#service}
        :param columns: columns block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#columns Powerpack#columns}
        :param resource: The resource name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#resource Powerpack#resource}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b5d3d1fada991647302ad3453691352b9fa6138628677a9027c6ed7c1c2227a4)
            check_type(argname="argument env", value=env, expected_type=type_hints["env"])
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument primary_tag", value=primary_tag, expected_type=type_hints["primary_tag"])
            check_type(argname="argument row_type", value=row_type, expected_type=type_hints["row_type"])
            check_type(argname="argument service", value=service, expected_type=type_hints["service"])
            check_type(argname="argument columns", value=columns, expected_type=type_hints["columns"])
            check_type(argname="argument resource", value=resource, expected_type=type_hints["resource"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "env": env,
            "name": name,
            "primary_tag": primary_tag,
            "row_type": row_type,
            "service": service,
        }
        if columns is not None:
            self._values["columns"] = columns
        if resource is not None:
            self._values["resource"] = resource

    @builtins.property
    def env(self) -> builtins.str:
        '''The environment name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#env Powerpack#env}
        '''
        result = self._values.get("env")
        assert result is not None, "Required property 'env' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def name(self) -> builtins.str:
        '''The operation name associated with the service.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        '''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def primary_tag(self) -> builtins.str:
        '''The organization's host group name and value.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag Powerpack#primary_tag}
        '''
        result = self._values.get("primary_tag")
        assert result is not None, "Required property 'primary_tag' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def row_type(self) -> builtins.str:
        '''The level of detail for the request. Valid values are ``service``, ``resource``, ``span``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#row_type Powerpack#row_type}
        '''
        result = self._values.get("row_type")
        assert result is not None, "Required property 'row_type' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def service(self) -> builtins.str:
        '''The service name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#service Powerpack#service}
        '''
        result = self._values.get("service")
        assert result is not None, "Required property 'service' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def columns(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetDistributionDefinitionRequestApmStatsQueryColumns"]]]:
        '''columns block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#columns Powerpack#columns}
        '''
        result = self._values.get("columns")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetDistributionDefinitionRequestApmStatsQueryColumns"]]], result)

    @builtins.property
    def resource(self) -> typing.Optional[builtins.str]:
        '''The resource name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#resource Powerpack#resource}
        '''
        result = self._values.get("resource")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetDistributionDefinitionRequestApmStatsQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetDistributionDefinitionRequestApmStatsQueryColumns",
    jsii_struct_bases=[],
    name_mapping={
        "name": "name",
        "alias": "alias",
        "cell_display_mode": "cellDisplayMode",
        "order": "order",
    },
)
class PowerpackWidgetDistributionDefinitionRequestApmStatsQueryColumns:
    def __init__(
        self,
        *,
        name: builtins.str,
        alias: typing.Optional[builtins.str] = None,
        cell_display_mode: typing.Optional[builtins.str] = None,
        order: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param name: The column name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param alias: A user-assigned alias for the column. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#alias Powerpack#alias}
        :param cell_display_mode: A list of display modes for each table cell. Valid values are ``number``, ``bar``, ``trend``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cell_display_mode Powerpack#cell_display_mode}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6f40f10bbdc312b639dea6f3fe404c74fda6e95396308097b2ededef2b97b44c)
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument alias", value=alias, expected_type=type_hints["alias"])
            check_type(argname="argument cell_display_mode", value=cell_display_mode, expected_type=type_hints["cell_display_mode"])
            check_type(argname="argument order", value=order, expected_type=type_hints["order"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "name": name,
        }
        if alias is not None:
            self._values["alias"] = alias
        if cell_display_mode is not None:
            self._values["cell_display_mode"] = cell_display_mode
        if order is not None:
            self._values["order"] = order

    @builtins.property
    def name(self) -> builtins.str:
        '''The column name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        '''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def alias(self) -> typing.Optional[builtins.str]:
        '''A user-assigned alias for the column.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#alias Powerpack#alias}
        '''
        result = self._values.get("alias")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def cell_display_mode(self) -> typing.Optional[builtins.str]:
        '''A list of display modes for each table cell. Valid values are ``number``, ``bar``, ``trend``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cell_display_mode Powerpack#cell_display_mode}
        '''
        result = self._values.get("cell_display_mode")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def order(self) -> typing.Optional[builtins.str]:
        '''Widget sorting methods. Valid values are ``asc``, ``desc``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        result = self._values.get("order")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetDistributionDefinitionRequestApmStatsQueryColumns(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetDistributionDefinitionRequestApmStatsQueryColumnsList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetDistributionDefinitionRequestApmStatsQueryColumnsList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__130e7a6f467f086a6778f325de982b38738ec62f9aa01652da383408c84f7946)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetDistributionDefinitionRequestApmStatsQueryColumnsOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9138e89c30cfe05d4bee040d339a90ef0a2e2057327b0ab3597739c6dea4f2c2)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetDistributionDefinitionRequestApmStatsQueryColumnsOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bc905fd71da7b56a4ef4774505e6e375eb2c5da31d3e02b1047e7210b8448df5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cb27d5b93a406de25e0b6912b64b823b357a533958f51b712525f80aa59d7b3d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e4444f4f57389db1c9cb5fc57c10d94cf8cdbcececd1228a7b12115f7b7033f6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetDistributionDefinitionRequestApmStatsQueryColumns]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetDistributionDefinitionRequestApmStatsQueryColumns]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetDistributionDefinitionRequestApmStatsQueryColumns]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__785adb3fd2ed80f28faa1cb979c76142637ec2aecf559ecd2ba07b766a7e3d3c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetDistributionDefinitionRequestApmStatsQueryColumnsOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetDistributionDefinitionRequestApmStatsQueryColumnsOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ebda67f1bcb23129a9f06587637634047c5f76c88d1fa5907db918a00bac727c)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetAlias")
    def reset_alias(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAlias", []))

    @jsii.member(jsii_name="resetCellDisplayMode")
    def reset_cell_display_mode(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCellDisplayMode", []))

    @jsii.member(jsii_name="resetOrder")
    def reset_order(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetOrder", []))

    @builtins.property
    @jsii.member(jsii_name="aliasInput")
    def alias_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aliasInput"))

    @builtins.property
    @jsii.member(jsii_name="cellDisplayModeInput")
    def cell_display_mode_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "cellDisplayModeInput"))

    @builtins.property
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property
    @jsii.member(jsii_name="orderInput")
    def order_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "orderInput"))

    @builtins.property
    @jsii.member(jsii_name="alias")
    def alias(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "alias"))

    @alias.setter
    def alias(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1f41ba022eddf78bb64b63e44335ea99d02ff28e273ff55be4273477b2d392fb)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "alias", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="cellDisplayMode")
    def cell_display_mode(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "cellDisplayMode"))

    @cell_display_mode.setter
    def cell_display_mode(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__68489b48d09b12a945357223ffcc67be99097c4708e2dbd87ef0ef6d789746b8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "cellDisplayMode", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ddeebea026b89e5937e5621bacc38ad8863bb9ef95cf9d643ee709aad3974148)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "name", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="order")
    def order(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "order"))

    @order.setter
    def order(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__35c0c356e446c37d869b07d18ca9c9c5fa6ae2df79ed2b6c00ac3da8fb3b48f6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "order", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetDistributionDefinitionRequestApmStatsQueryColumns]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetDistributionDefinitionRequestApmStatsQueryColumns]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetDistributionDefinitionRequestApmStatsQueryColumns]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2f20586d107d4ce6df0c48f91adefb2f4aba788842c57c216fec20b9e4f83880)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetDistributionDefinitionRequestApmStatsQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetDistributionDefinitionRequestApmStatsQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5ad0b35fca28f1bd6e28879ef06ccc2fb5d4e62de34f8d59aa0cda6b9cdf0c89)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putColumns")
    def put_columns(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetDistributionDefinitionRequestApmStatsQueryColumns, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d90113d197665c5304e6f5013c9417b4aed7925e82c15ce0dec7a44d8edd908c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putColumns", [value]))

    @jsii.member(jsii_name="resetColumns")
    def reset_columns(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetColumns", []))

    @jsii.member(jsii_name="resetResource")
    def reset_resource(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetResource", []))

    @builtins.property
    @jsii.member(jsii_name="columns")
    def columns(
        self,
    ) -> PowerpackWidgetDistributionDefinitionRequestApmStatsQueryColumnsList:
        return typing.cast(PowerpackWidgetDistributionDefinitionRequestApmStatsQueryColumnsList, jsii.get(self, "columns"))

    @builtins.property
    @jsii.member(jsii_name="columnsInput")
    def columns_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetDistributionDefinitionRequestApmStatsQueryColumns]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetDistributionDefinitionRequestApmStatsQueryColumns]]], jsii.get(self, "columnsInput"))

    @builtins.property
    @jsii.member(jsii_name="envInput")
    def env_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "envInput"))

    @builtins.property
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property
    @jsii.member(jsii_name="primaryTagInput")
    def primary_tag_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "primaryTagInput"))

    @builtins.property
    @jsii.member(jsii_name="resourceInput")
    def resource_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "resourceInput"))

    @builtins.property
    @jsii.member(jsii_name="rowTypeInput")
    def row_type_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "rowTypeInput"))

    @builtins.property
    @jsii.member(jsii_name="serviceInput")
    def service_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "serviceInput"))

    @builtins.property
    @jsii.member(jsii_name="env")
    def env(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "env"))

    @env.setter
    def env(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d3f98f5417adda48bb44bcddc05194393e28cb000ca08062825d48bf6a8ffbde)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "env", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4de0aeba6cb40e0bb41172c2fb891c5d900e91aacd13c6f6d7b6d7f1f106ad9d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "name", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="primaryTag")
    def primary_tag(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "primaryTag"))

    @primary_tag.setter
    def primary_tag(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9ed0e2bedc9be93b9fecbddf33b5b1d2032c154ce984cb49e44efa833e5ab681)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "primaryTag", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="resource")
    def resource(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "resource"))

    @resource.setter
    def resource(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c37f99a4425f89051e59ba35ec63e4cc211d4e2e16dc3d34637c27d717755e26)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "resource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="rowType")
    def row_type(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "rowType"))

    @row_type.setter
    def row_type(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__38728057d8a6cb6d421ed5b2e59a609c99a0b9efe392b9c9b2da1a268ab42ea9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "rowType", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="service")
    def service(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "service"))

    @service.setter
    def service(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b50d5732091189b1304d96b87a803cc5b1efc3163e2e2bce29d22cb15a3390ae)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "service", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetDistributionDefinitionRequestApmStatsQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetDistributionDefinitionRequestApmStatsQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetDistributionDefinitionRequestApmStatsQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__430c07847a97d5045669bbc6285e1bb3c0e20c01a1cb92354e5f0537b8e18b36)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetDistributionDefinitionRequestList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetDistributionDefinitionRequestList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2ceaa207079e8cb96ce5f603c6b82a1b173865a929dff588c1ac8e58cad49ca3)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetDistributionDefinitionRequestOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0df61af8700cfe802858e581810b1346ce646bca151dc38d7259636552634722)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetDistributionDefinitionRequestOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__32ad7d15498cbace7a962086a836c95b5aeab359a77e77b589a9bc6871611a6a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a3bf1da642cdd20414af6ce8d97668cb4ac8615ba864afa21022385f830d08ca)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8ac074ba6d711811ddeaeb23d7d7244fe576605da8e4049d8a22e9f35a5480d0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetDistributionDefinitionRequest]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetDistributionDefinitionRequest]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetDistributionDefinitionRequest]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__23b74bfdfebe0200c2e06b8b8a2f2cfa590438217065edb72d119b8dba487329)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetDistributionDefinitionRequestLogQuery",
    jsii_struct_bases=[],
    name_mapping={
        "index": "index",
        "compute_query": "computeQuery",
        "group_by": "groupBy",
        "multi_compute": "multiCompute",
        "search_query": "searchQuery",
    },
)
class PowerpackWidgetDistributionDefinitionRequestLogQuery:
    def __init__(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union["PowerpackWidgetDistributionDefinitionRequestLogQueryComputeQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetDistributionDefinitionRequestLogQueryGroupBy", typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetDistributionDefinitionRequestLogQueryMultiCompute", typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        if isinstance(compute_query, dict):
            compute_query = PowerpackWidgetDistributionDefinitionRequestLogQueryComputeQuery(**compute_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7a7c3e89ba648bd3a4bfca4454029a4f6f6e3e57565f72bfe9d1bc91dfc443cf)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
            check_type(argname="argument compute_query", value=compute_query, expected_type=type_hints["compute_query"])
            check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
            check_type(argname="argument multi_compute", value=multi_compute, expected_type=type_hints["multi_compute"])
            check_type(argname="argument search_query", value=search_query, expected_type=type_hints["search_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "index": index,
        }
        if compute_query is not None:
            self._values["compute_query"] = compute_query
        if group_by is not None:
            self._values["group_by"] = group_by
        if multi_compute is not None:
            self._values["multi_compute"] = multi_compute
        if search_query is not None:
            self._values["search_query"] = search_query

    @builtins.property
    def index(self) -> builtins.str:
        '''The name of the index to query.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        '''
        result = self._values.get("index")
        assert result is not None, "Required property 'index' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def compute_query(
        self,
    ) -> typing.Optional["PowerpackWidgetDistributionDefinitionRequestLogQueryComputeQuery"]:
        '''compute_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        '''
        result = self._values.get("compute_query")
        return typing.cast(typing.Optional["PowerpackWidgetDistributionDefinitionRequestLogQueryComputeQuery"], result)

    @builtins.property
    def group_by(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetDistributionDefinitionRequestLogQueryGroupBy"]]]:
        '''group_by block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        '''
        result = self._values.get("group_by")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetDistributionDefinitionRequestLogQueryGroupBy"]]], result)

    @builtins.property
    def multi_compute(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetDistributionDefinitionRequestLogQueryMultiCompute"]]]:
        '''multi_compute block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        '''
        result = self._values.get("multi_compute")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetDistributionDefinitionRequestLogQueryMultiCompute"]]], result)

    @builtins.property
    def search_query(self) -> typing.Optional[builtins.str]:
        '''The search query to use.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        result = self._values.get("search_query")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetDistributionDefinitionRequestLogQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetDistributionDefinitionRequestLogQueryComputeQuery",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetDistributionDefinitionRequestLogQueryComputeQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9809fde5b5d7fe5ec779f0f67ef3e5d592cb05e5fbd4a3e33844d4ff3811cc48)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetDistributionDefinitionRequestLogQueryComputeQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetDistributionDefinitionRequestLogQueryComputeQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetDistributionDefinitionRequestLogQueryComputeQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__19e3ee3d92fdacd022fd6e196cf48fe425da88f2a610e48df501ae89561a50e8)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bfbee9e742a9bea7b1d09c5b680ae6e84b1026afcf142939c6882fb6270d01d8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5389faf8503d96fbb37a86f653b6856758129295d8c414df6a0630fd7a128e1c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4879559fce48f6b941002f7b7647af03236312bfc7c301a5a184d2941fba5f69)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetDistributionDefinitionRequestLogQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetDistributionDefinitionRequestLogQueryComputeQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetDistributionDefinitionRequestLogQueryComputeQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a59a36d9a0f52ea4621cce5677e0a3c718f92a87011cec4c5f8117498a8e25d4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetDistributionDefinitionRequestLogQueryGroupBy",
    jsii_struct_bases=[],
    name_mapping={"facet": "facet", "limit": "limit", "sort_query": "sortQuery"},
)
class PowerpackWidgetDistributionDefinitionRequestLogQueryGroupBy:
    def __init__(
        self,
        *,
        facet: typing.Optional[builtins.str] = None,
        limit: typing.Optional[jsii.Number] = None,
        sort_query: typing.Optional[typing.Union["PowerpackWidgetDistributionDefinitionRequestLogQueryGroupBySortQuery", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param limit: The maximum number of items in the group. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param sort_query: sort_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        if isinstance(sort_query, dict):
            sort_query = PowerpackWidgetDistributionDefinitionRequestLogQueryGroupBySortQuery(**sort_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a08c98a331e33fddc9a415366f8dbba5820b4f96cfec7f9df71a0e01095bf1cc)
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
            check_type(argname="argument sort_query", value=sort_query, expected_type=type_hints["sort_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if facet is not None:
            self._values["facet"] = facet
        if limit is not None:
            self._values["limit"] = limit
        if sort_query is not None:
            self._values["sort_query"] = sort_query

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def limit(self) -> typing.Optional[jsii.Number]:
        '''The maximum number of items in the group.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        '''
        result = self._values.get("limit")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def sort_query(
        self,
    ) -> typing.Optional["PowerpackWidgetDistributionDefinitionRequestLogQueryGroupBySortQuery"]:
        '''sort_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        result = self._values.get("sort_query")
        return typing.cast(typing.Optional["PowerpackWidgetDistributionDefinitionRequestLogQueryGroupBySortQuery"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetDistributionDefinitionRequestLogQueryGroupBy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetDistributionDefinitionRequestLogQueryGroupByList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetDistributionDefinitionRequestLogQueryGroupByList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__821461e22daa03fb23513c12c09b62f70c06df250175502577b96410767cbcc3)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetDistributionDefinitionRequestLogQueryGroupByOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ec8bb2c5fc4e2376d5903b42acf27265fe7109f6ba850c794df11cf376d615b1)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetDistributionDefinitionRequestLogQueryGroupByOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3dd8dfcf795886b01564bd853738ca9ff08987ad97dc22bc7fd2272c414685af)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__05a7a2f37693f5986b7f46ee7b6f72d1a1796c6e021bd1f11d035c96a03742bf)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a81d809853a03fb4f34f9154c915afada5c34bbcebb8db2135fb18457804cf7d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetDistributionDefinitionRequestLogQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetDistributionDefinitionRequestLogQueryGroupBy]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetDistributionDefinitionRequestLogQueryGroupBy]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__af9a15a5a6e05fda813cfef2d06f93cff7422543ca00527ca7a37e82ca12c0aa)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetDistributionDefinitionRequestLogQueryGroupByOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetDistributionDefinitionRequestLogQueryGroupByOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__12f2eab310ca8338f225ff5139229a599ffcb819b0220e4510afa3902bc2a1db)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putSortQuery")
    def put_sort_query(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        value = PowerpackWidgetDistributionDefinitionRequestLogQueryGroupBySortQuery(
            aggregation=aggregation, order=order, facet=facet
        )

        return typing.cast(None, jsii.invoke(self, "putSortQuery", [value]))

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetLimit")
    def reset_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLimit", []))

    @jsii.member(jsii_name="resetSortQuery")
    def reset_sort_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSortQuery", []))

    @builtins.property
    @jsii.member(jsii_name="sortQuery")
    def sort_query(
        self,
    ) -> "PowerpackWidgetDistributionDefinitionRequestLogQueryGroupBySortQueryOutputReference":
        return typing.cast("PowerpackWidgetDistributionDefinitionRequestLogQueryGroupBySortQueryOutputReference", jsii.get(self, "sortQuery"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="limitInput")
    def limit_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "limitInput"))

    @builtins.property
    @jsii.member(jsii_name="sortQueryInput")
    def sort_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetDistributionDefinitionRequestLogQueryGroupBySortQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetDistributionDefinitionRequestLogQueryGroupBySortQuery"], jsii.get(self, "sortQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__336c3c5cd0d601ec775de32331d01c975ee7312ca10425c442618de2bde24b28)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="limit")
    def limit(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "limit"))

    @limit.setter
    def limit(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__65971abeb53e52a2b8106654cda1123cba3260777073098d671dd5ee5ef320f0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "limit", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetDistributionDefinitionRequestLogQueryGroupBy]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetDistributionDefinitionRequestLogQueryGroupBy]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetDistributionDefinitionRequestLogQueryGroupBy]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cae283f6da9ad5ebbd010e36581c2ea149a3c8763d04cbdd5dd2c13a88c29ef2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetDistributionDefinitionRequestLogQueryGroupBySortQuery",
    jsii_struct_bases=[],
    name_mapping={"aggregation": "aggregation", "order": "order", "facet": "facet"},
)
class PowerpackWidgetDistributionDefinitionRequestLogQueryGroupBySortQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fa805ceb921d4d2508aa38aad1877e1bf1a34b7f02a7e9593584fbd61d88615f)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument order", value=order, expected_type=type_hints["order"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
            "order": order,
        }
        if facet is not None:
            self._values["facet"] = facet

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def order(self) -> builtins.str:
        '''Widget sorting methods. Valid values are ``asc``, ``desc``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        result = self._values.get("order")
        assert result is not None, "Required property 'order' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetDistributionDefinitionRequestLogQueryGroupBySortQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetDistributionDefinitionRequestLogQueryGroupBySortQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetDistributionDefinitionRequestLogQueryGroupBySortQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1aa7c20138943c84ce1c6965f5fe64c5581a3597b1bd4bf494a415903c9f9e60)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="orderInput")
    def order_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "orderInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9a984ea281ec4f7ccf1694e2587353700e4f84700258c2cc805994015485c59d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0015986bc4c07e8f999fe62292fcc25187556b67d7c06644d23ac1ab08d37d08)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="order")
    def order(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "order"))

    @order.setter
    def order(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d6f9d4d860a13af1dc87f94c7c73dac908000ad88764096517f0186076aa18c7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "order", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetDistributionDefinitionRequestLogQueryGroupBySortQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetDistributionDefinitionRequestLogQueryGroupBySortQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetDistributionDefinitionRequestLogQueryGroupBySortQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__38f4667147c13e06f8ea974ffe1507fd7b33479bc9768993f198f745fc620ea1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetDistributionDefinitionRequestLogQueryMultiCompute",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetDistributionDefinitionRequestLogQueryMultiCompute:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__57d5ec03937cb38539cc7cdb5b983a9c8b7bc7d9736d057ef294db5ba691aa45)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetDistributionDefinitionRequestLogQueryMultiCompute(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetDistributionDefinitionRequestLogQueryMultiComputeList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetDistributionDefinitionRequestLogQueryMultiComputeList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__14e8c62f04c9036dbad2854ef1b261f32d3052e9f6c30bbb46fe983739a6d74c)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetDistributionDefinitionRequestLogQueryMultiComputeOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__09402740356318834ff592172e93479f855da4c3f5eb95504acc503ca3a7a656)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetDistributionDefinitionRequestLogQueryMultiComputeOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__68c85e90c79551c47d4bdc2dd76632a154de962389850bc43d155775d55e265a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8f7632e47702d20dcbc67b326af1e88d1e0ebf23f0b5aa21001892c2d0ae4a2a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4dad1f48268da045fee8cc3824262e000081e6487a71b45ddbe09a9e453417fc)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetDistributionDefinitionRequestLogQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetDistributionDefinitionRequestLogQueryMultiCompute]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetDistributionDefinitionRequestLogQueryMultiCompute]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__52ca00e9f78c2e22bcf328250c63ec60b10b10196bd7e55b5b7078ec8c384268)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetDistributionDefinitionRequestLogQueryMultiComputeOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetDistributionDefinitionRequestLogQueryMultiComputeOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c857a164bffb2b86359f50f06b0bc86686eeae6e69f85ab2ef5b1278dfa0a600)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c4fb117cce8b168f66a0db08a22d9f8f62c6080282b5213855de69747f29a695)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3fb9530aa5989e0855b61fea0a4a1c127d050e7885d0a87ed73d536ec4d35d17)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b940341a8b2b9235a743949afc729b55039234acf552e0e64af3c9cfb4204f3a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetDistributionDefinitionRequestLogQueryMultiCompute]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetDistributionDefinitionRequestLogQueryMultiCompute]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetDistributionDefinitionRequestLogQueryMultiCompute]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b45af1f544869fa098252c93c1091e333dd32b959423df002ee6eb9dd4b743ee)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetDistributionDefinitionRequestLogQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetDistributionDefinitionRequestLogQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e0e01dce369d1e57fb083122e4f1b3fb4d7f72dc3dcbf0b49b7e2562875f3ec1)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putComputeQuery")
    def put_compute_query(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        value = PowerpackWidgetDistributionDefinitionRequestLogQueryComputeQuery(
            aggregation=aggregation, facet=facet, interval=interval
        )

        return typing.cast(None, jsii.invoke(self, "putComputeQuery", [value]))

    @jsii.member(jsii_name="putGroupBy")
    def put_group_by(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetDistributionDefinitionRequestLogQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c07aa186d907304e3e808d27a7b49dcde13ac8efe25c3c66bd67c09b5f348f40)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putGroupBy", [value]))

    @jsii.member(jsii_name="putMultiCompute")
    def put_multi_compute(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetDistributionDefinitionRequestLogQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8f80f1fec246ac95eebb2276665a7e720b0bb293b84f924fb192d395fde96778)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putMultiCompute", [value]))

    @jsii.member(jsii_name="resetComputeQuery")
    def reset_compute_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetComputeQuery", []))

    @jsii.member(jsii_name="resetGroupBy")
    def reset_group_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGroupBy", []))

    @jsii.member(jsii_name="resetMultiCompute")
    def reset_multi_compute(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMultiCompute", []))

    @jsii.member(jsii_name="resetSearchQuery")
    def reset_search_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSearchQuery", []))

    @builtins.property
    @jsii.member(jsii_name="computeQuery")
    def compute_query(
        self,
    ) -> PowerpackWidgetDistributionDefinitionRequestLogQueryComputeQueryOutputReference:
        return typing.cast(PowerpackWidgetDistributionDefinitionRequestLogQueryComputeQueryOutputReference, jsii.get(self, "computeQuery"))

    @builtins.property
    @jsii.member(jsii_name="groupBy")
    def group_by(
        self,
    ) -> PowerpackWidgetDistributionDefinitionRequestLogQueryGroupByList:
        return typing.cast(PowerpackWidgetDistributionDefinitionRequestLogQueryGroupByList, jsii.get(self, "groupBy"))

    @builtins.property
    @jsii.member(jsii_name="multiCompute")
    def multi_compute(
        self,
    ) -> PowerpackWidgetDistributionDefinitionRequestLogQueryMultiComputeList:
        return typing.cast(PowerpackWidgetDistributionDefinitionRequestLogQueryMultiComputeList, jsii.get(self, "multiCompute"))

    @builtins.property
    @jsii.member(jsii_name="computeQueryInput")
    def compute_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetDistributionDefinitionRequestLogQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetDistributionDefinitionRequestLogQueryComputeQuery], jsii.get(self, "computeQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="groupByInput")
    def group_by_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetDistributionDefinitionRequestLogQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetDistributionDefinitionRequestLogQueryGroupBy]]], jsii.get(self, "groupByInput"))

    @builtins.property
    @jsii.member(jsii_name="indexInput")
    def index_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "indexInput"))

    @builtins.property
    @jsii.member(jsii_name="multiComputeInput")
    def multi_compute_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetDistributionDefinitionRequestLogQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetDistributionDefinitionRequestLogQueryMultiCompute]]], jsii.get(self, "multiComputeInput"))

    @builtins.property
    @jsii.member(jsii_name="searchQueryInput")
    def search_query_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "searchQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="index")
    def index(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "index"))

    @index.setter
    def index(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__101248d76445d68ba6b7463d4e41a646bfa53e87e8fc9f42a5ffddc88f8c504d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "index", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="searchQuery")
    def search_query(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "searchQuery"))

    @search_query.setter
    def search_query(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9d1af9d92e7a31b378fa623ca8e56a43a5965a3b49eb9e09c81f7cb0a61e9bc6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "searchQuery", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetDistributionDefinitionRequestLogQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetDistributionDefinitionRequestLogQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetDistributionDefinitionRequestLogQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1e8d16e0ce0ddece1794872aa3e569d40fded5c5c74a92911562ca2d5dfe3b8c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetDistributionDefinitionRequestOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetDistributionDefinitionRequestOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d1f0b798e2f798b4f5d0cd74c8933ce2be28a71bbeb57240022fbe6e869a40d8)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putApmQuery")
    def put_apm_query(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union[PowerpackWidgetDistributionDefinitionRequestApmQueryComputeQuery, typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetDistributionDefinitionRequestApmQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetDistributionDefinitionRequestApmQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        value = PowerpackWidgetDistributionDefinitionRequestApmQuery(
            index=index,
            compute_query=compute_query,
            group_by=group_by,
            multi_compute=multi_compute,
            search_query=search_query,
        )

        return typing.cast(None, jsii.invoke(self, "putApmQuery", [value]))

    @jsii.member(jsii_name="putApmStatsQuery")
    def put_apm_stats_query(
        self,
        *,
        env: builtins.str,
        name: builtins.str,
        primary_tag: builtins.str,
        row_type: builtins.str,
        service: builtins.str,
        columns: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetDistributionDefinitionRequestApmStatsQueryColumns, typing.Dict[builtins.str, typing.Any]]]]] = None,
        resource: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param env: The environment name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#env Powerpack#env}
        :param name: The operation name associated with the service. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param primary_tag: The organization's host group name and value. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag Powerpack#primary_tag}
        :param row_type: The level of detail for the request. Valid values are ``service``, ``resource``, ``span``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#row_type Powerpack#row_type}
        :param service: The service name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#service Powerpack#service}
        :param columns: columns block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#columns Powerpack#columns}
        :param resource: The resource name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#resource Powerpack#resource}
        '''
        value = PowerpackWidgetDistributionDefinitionRequestApmStatsQuery(
            env=env,
            name=name,
            primary_tag=primary_tag,
            row_type=row_type,
            service=service,
            columns=columns,
            resource=resource,
        )

        return typing.cast(None, jsii.invoke(self, "putApmStatsQuery", [value]))

    @jsii.member(jsii_name="putLogQuery")
    def put_log_query(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union[PowerpackWidgetDistributionDefinitionRequestLogQueryComputeQuery, typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetDistributionDefinitionRequestLogQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetDistributionDefinitionRequestLogQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        value = PowerpackWidgetDistributionDefinitionRequestLogQuery(
            index=index,
            compute_query=compute_query,
            group_by=group_by,
            multi_compute=multi_compute,
            search_query=search_query,
        )

        return typing.cast(None, jsii.invoke(self, "putLogQuery", [value]))

    @jsii.member(jsii_name="putProcessQuery")
    def put_process_query(
        self,
        *,
        metric: builtins.str,
        filter_by: typing.Optional[typing.Sequence[builtins.str]] = None,
        limit: typing.Optional[jsii.Number] = None,
        search_by: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param metric: Your chosen metric. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        :param filter_by: A list of processes. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#filter_by Powerpack#filter_by}
        :param limit: The max number of items in the filter list. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param search_by: Your chosen search term. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_by Powerpack#search_by}
        '''
        value = PowerpackWidgetDistributionDefinitionRequestProcessQuery(
            metric=metric, filter_by=filter_by, limit=limit, search_by=search_by
        )

        return typing.cast(None, jsii.invoke(self, "putProcessQuery", [value]))

    @jsii.member(jsii_name="putRumQuery")
    def put_rum_query(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union["PowerpackWidgetDistributionDefinitionRequestRumQueryComputeQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetDistributionDefinitionRequestRumQueryGroupBy", typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetDistributionDefinitionRequestRumQueryMultiCompute", typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        value = PowerpackWidgetDistributionDefinitionRequestRumQuery(
            index=index,
            compute_query=compute_query,
            group_by=group_by,
            multi_compute=multi_compute,
            search_query=search_query,
        )

        return typing.cast(None, jsii.invoke(self, "putRumQuery", [value]))

    @jsii.member(jsii_name="putSecurityQuery")
    def put_security_query(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union["PowerpackWidgetDistributionDefinitionRequestSecurityQueryComputeQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetDistributionDefinitionRequestSecurityQueryGroupBy", typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetDistributionDefinitionRequestSecurityQueryMultiCompute", typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        value = PowerpackWidgetDistributionDefinitionRequestSecurityQuery(
            index=index,
            compute_query=compute_query,
            group_by=group_by,
            multi_compute=multi_compute,
            search_query=search_query,
        )

        return typing.cast(None, jsii.invoke(self, "putSecurityQuery", [value]))

    @jsii.member(jsii_name="putStyle")
    def put_style(self, *, palette: typing.Optional[builtins.str] = None) -> None:
        '''
        :param palette: A color palette to apply to the widget. The available options are available at: https://docs.datadoghq.com/dashboards/widgets/timeseries/#appearance. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette Powerpack#palette}
        '''
        value = PowerpackWidgetDistributionDefinitionRequestStyle(palette=palette)

        return typing.cast(None, jsii.invoke(self, "putStyle", [value]))

    @jsii.member(jsii_name="resetApmQuery")
    def reset_apm_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetApmQuery", []))

    @jsii.member(jsii_name="resetApmStatsQuery")
    def reset_apm_stats_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetApmStatsQuery", []))

    @jsii.member(jsii_name="resetLogQuery")
    def reset_log_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLogQuery", []))

    @jsii.member(jsii_name="resetProcessQuery")
    def reset_process_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetProcessQuery", []))

    @jsii.member(jsii_name="resetQ")
    def reset_q(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetQ", []))

    @jsii.member(jsii_name="resetRumQuery")
    def reset_rum_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetRumQuery", []))

    @jsii.member(jsii_name="resetSecurityQuery")
    def reset_security_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSecurityQuery", []))

    @jsii.member(jsii_name="resetStyle")
    def reset_style(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetStyle", []))

    @builtins.property
    @jsii.member(jsii_name="apmQuery")
    def apm_query(
        self,
    ) -> PowerpackWidgetDistributionDefinitionRequestApmQueryOutputReference:
        return typing.cast(PowerpackWidgetDistributionDefinitionRequestApmQueryOutputReference, jsii.get(self, "apmQuery"))

    @builtins.property
    @jsii.member(jsii_name="apmStatsQuery")
    def apm_stats_query(
        self,
    ) -> PowerpackWidgetDistributionDefinitionRequestApmStatsQueryOutputReference:
        return typing.cast(PowerpackWidgetDistributionDefinitionRequestApmStatsQueryOutputReference, jsii.get(self, "apmStatsQuery"))

    @builtins.property
    @jsii.member(jsii_name="logQuery")
    def log_query(
        self,
    ) -> PowerpackWidgetDistributionDefinitionRequestLogQueryOutputReference:
        return typing.cast(PowerpackWidgetDistributionDefinitionRequestLogQueryOutputReference, jsii.get(self, "logQuery"))

    @builtins.property
    @jsii.member(jsii_name="processQuery")
    def process_query(
        self,
    ) -> "PowerpackWidgetDistributionDefinitionRequestProcessQueryOutputReference":
        return typing.cast("PowerpackWidgetDistributionDefinitionRequestProcessQueryOutputReference", jsii.get(self, "processQuery"))

    @builtins.property
    @jsii.member(jsii_name="rumQuery")
    def rum_query(
        self,
    ) -> "PowerpackWidgetDistributionDefinitionRequestRumQueryOutputReference":
        return typing.cast("PowerpackWidgetDistributionDefinitionRequestRumQueryOutputReference", jsii.get(self, "rumQuery"))

    @builtins.property
    @jsii.member(jsii_name="securityQuery")
    def security_query(
        self,
    ) -> "PowerpackWidgetDistributionDefinitionRequestSecurityQueryOutputReference":
        return typing.cast("PowerpackWidgetDistributionDefinitionRequestSecurityQueryOutputReference", jsii.get(self, "securityQuery"))

    @builtins.property
    @jsii.member(jsii_name="style")
    def style(
        self,
    ) -> "PowerpackWidgetDistributionDefinitionRequestStyleOutputReference":
        return typing.cast("PowerpackWidgetDistributionDefinitionRequestStyleOutputReference", jsii.get(self, "style"))

    @builtins.property
    @jsii.member(jsii_name="apmQueryInput")
    def apm_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetDistributionDefinitionRequestApmQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetDistributionDefinitionRequestApmQuery], jsii.get(self, "apmQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="apmStatsQueryInput")
    def apm_stats_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetDistributionDefinitionRequestApmStatsQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetDistributionDefinitionRequestApmStatsQuery], jsii.get(self, "apmStatsQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="logQueryInput")
    def log_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetDistributionDefinitionRequestLogQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetDistributionDefinitionRequestLogQuery], jsii.get(self, "logQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="processQueryInput")
    def process_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetDistributionDefinitionRequestProcessQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetDistributionDefinitionRequestProcessQuery"], jsii.get(self, "processQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="qInput")
    def q_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "qInput"))

    @builtins.property
    @jsii.member(jsii_name="rumQueryInput")
    def rum_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetDistributionDefinitionRequestRumQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetDistributionDefinitionRequestRumQuery"], jsii.get(self, "rumQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="securityQueryInput")
    def security_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetDistributionDefinitionRequestSecurityQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetDistributionDefinitionRequestSecurityQuery"], jsii.get(self, "securityQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="styleInput")
    def style_input(
        self,
    ) -> typing.Optional["PowerpackWidgetDistributionDefinitionRequestStyle"]:
        return typing.cast(typing.Optional["PowerpackWidgetDistributionDefinitionRequestStyle"], jsii.get(self, "styleInput"))

    @builtins.property
    @jsii.member(jsii_name="q")
    def q(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "q"))

    @q.setter
    def q(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ce3fb5a5720818e8b76eef4faefad2bbd334ad5891fc2c474990b0ca1688f259)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "q", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetDistributionDefinitionRequest]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetDistributionDefinitionRequest]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetDistributionDefinitionRequest]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1de13a6ff42be381e58e52fb48531372ba9eb9d84e3b5c184a348191aacb6409)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetDistributionDefinitionRequestProcessQuery",
    jsii_struct_bases=[],
    name_mapping={
        "metric": "metric",
        "filter_by": "filterBy",
        "limit": "limit",
        "search_by": "searchBy",
    },
)
class PowerpackWidgetDistributionDefinitionRequestProcessQuery:
    def __init__(
        self,
        *,
        metric: builtins.str,
        filter_by: typing.Optional[typing.Sequence[builtins.str]] = None,
        limit: typing.Optional[jsii.Number] = None,
        search_by: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param metric: Your chosen metric. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        :param filter_by: A list of processes. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#filter_by Powerpack#filter_by}
        :param limit: The max number of items in the filter list. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param search_by: Your chosen search term. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_by Powerpack#search_by}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__858d568179ee7dcc94a9b4230a002c749201d1e056f18b91e8c0eda39dbc0fce)
            check_type(argname="argument metric", value=metric, expected_type=type_hints["metric"])
            check_type(argname="argument filter_by", value=filter_by, expected_type=type_hints["filter_by"])
            check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
            check_type(argname="argument search_by", value=search_by, expected_type=type_hints["search_by"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "metric": metric,
        }
        if filter_by is not None:
            self._values["filter_by"] = filter_by
        if limit is not None:
            self._values["limit"] = limit
        if search_by is not None:
            self._values["search_by"] = search_by

    @builtins.property
    def metric(self) -> builtins.str:
        '''Your chosen metric.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        '''
        result = self._values.get("metric")
        assert result is not None, "Required property 'metric' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def filter_by(self) -> typing.Optional[typing.List[builtins.str]]:
        '''A list of processes.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#filter_by Powerpack#filter_by}
        '''
        result = self._values.get("filter_by")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def limit(self) -> typing.Optional[jsii.Number]:
        '''The max number of items in the filter list.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        '''
        result = self._values.get("limit")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def search_by(self) -> typing.Optional[builtins.str]:
        '''Your chosen search term.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_by Powerpack#search_by}
        '''
        result = self._values.get("search_by")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetDistributionDefinitionRequestProcessQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetDistributionDefinitionRequestProcessQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetDistributionDefinitionRequestProcessQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9c768d89594296715f30f8234d2189821857d2067375f456d817c04ea4a88738)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFilterBy")
    def reset_filter_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFilterBy", []))

    @jsii.member(jsii_name="resetLimit")
    def reset_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLimit", []))

    @jsii.member(jsii_name="resetSearchBy")
    def reset_search_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSearchBy", []))

    @builtins.property
    @jsii.member(jsii_name="filterByInput")
    def filter_by_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "filterByInput"))

    @builtins.property
    @jsii.member(jsii_name="limitInput")
    def limit_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "limitInput"))

    @builtins.property
    @jsii.member(jsii_name="metricInput")
    def metric_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "metricInput"))

    @builtins.property
    @jsii.member(jsii_name="searchByInput")
    def search_by_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "searchByInput"))

    @builtins.property
    @jsii.member(jsii_name="filterBy")
    def filter_by(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "filterBy"))

    @filter_by.setter
    def filter_by(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2ea1a209eb269207059406d2a1bd6c255b0c7e7af90ba4ed3dda77adb80b3fda)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "filterBy", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="limit")
    def limit(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "limit"))

    @limit.setter
    def limit(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4d1e884077f6106acf004f7d780a4ea743e556ee3d6ab081c71f85e9da5be51f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "limit", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="metric")
    def metric(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "metric"))

    @metric.setter
    def metric(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5bc5548d08952d3dea786084af819906cf82d2b008ae5c59b13b4650d4215e72)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "metric", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="searchBy")
    def search_by(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "searchBy"))

    @search_by.setter
    def search_by(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ba4c7b692accc5c9f8a596dddfde6e3795a051aa4329c1bbd0373442a82afdca)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "searchBy", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetDistributionDefinitionRequestProcessQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetDistributionDefinitionRequestProcessQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetDistributionDefinitionRequestProcessQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8be2fd0a9d9400c13a36bd991588fc810f414736f2648041637c1b09c44eb68e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetDistributionDefinitionRequestRumQuery",
    jsii_struct_bases=[],
    name_mapping={
        "index": "index",
        "compute_query": "computeQuery",
        "group_by": "groupBy",
        "multi_compute": "multiCompute",
        "search_query": "searchQuery",
    },
)
class PowerpackWidgetDistributionDefinitionRequestRumQuery:
    def __init__(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union["PowerpackWidgetDistributionDefinitionRequestRumQueryComputeQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetDistributionDefinitionRequestRumQueryGroupBy", typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetDistributionDefinitionRequestRumQueryMultiCompute", typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        if isinstance(compute_query, dict):
            compute_query = PowerpackWidgetDistributionDefinitionRequestRumQueryComputeQuery(**compute_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__926697fbe4dc4e3a6770e098cc84c811a53e4f1db653834444774c027e7d7d8c)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
            check_type(argname="argument compute_query", value=compute_query, expected_type=type_hints["compute_query"])
            check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
            check_type(argname="argument multi_compute", value=multi_compute, expected_type=type_hints["multi_compute"])
            check_type(argname="argument search_query", value=search_query, expected_type=type_hints["search_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "index": index,
        }
        if compute_query is not None:
            self._values["compute_query"] = compute_query
        if group_by is not None:
            self._values["group_by"] = group_by
        if multi_compute is not None:
            self._values["multi_compute"] = multi_compute
        if search_query is not None:
            self._values["search_query"] = search_query

    @builtins.property
    def index(self) -> builtins.str:
        '''The name of the index to query.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        '''
        result = self._values.get("index")
        assert result is not None, "Required property 'index' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def compute_query(
        self,
    ) -> typing.Optional["PowerpackWidgetDistributionDefinitionRequestRumQueryComputeQuery"]:
        '''compute_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        '''
        result = self._values.get("compute_query")
        return typing.cast(typing.Optional["PowerpackWidgetDistributionDefinitionRequestRumQueryComputeQuery"], result)

    @builtins.property
    def group_by(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetDistributionDefinitionRequestRumQueryGroupBy"]]]:
        '''group_by block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        '''
        result = self._values.get("group_by")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetDistributionDefinitionRequestRumQueryGroupBy"]]], result)

    @builtins.property
    def multi_compute(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetDistributionDefinitionRequestRumQueryMultiCompute"]]]:
        '''multi_compute block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        '''
        result = self._values.get("multi_compute")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetDistributionDefinitionRequestRumQueryMultiCompute"]]], result)

    @builtins.property
    def search_query(self) -> typing.Optional[builtins.str]:
        '''The search query to use.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        result = self._values.get("search_query")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetDistributionDefinitionRequestRumQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetDistributionDefinitionRequestRumQueryComputeQuery",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetDistributionDefinitionRequestRumQueryComputeQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a36466e0da031c01cc143588b8cb61adb94329f770c9aa8c44916177b5329455)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetDistributionDefinitionRequestRumQueryComputeQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetDistributionDefinitionRequestRumQueryComputeQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetDistributionDefinitionRequestRumQueryComputeQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__be48d889da7d4a32af71592139c8cef3db3e49478dab924c18d9c8559dfd5ce4)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2c130f9f6fd7701799c5cdfeb6dc840f72f308cac78b3106e0e6b06a7e461bf3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1ba8a0fd6c1d1005c166105087d77f12721fc2fd16468edf88a16e682fc047cb)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cfeb69259ab7760167a18ac7a79dfc4e0edbf2ad443bda2bf1ff4ce399ad976e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetDistributionDefinitionRequestRumQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetDistributionDefinitionRequestRumQueryComputeQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetDistributionDefinitionRequestRumQueryComputeQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__de5ef4b0ac1d9e75da1444e877e9e09deaa9138e7603173769e224d647a71488)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetDistributionDefinitionRequestRumQueryGroupBy",
    jsii_struct_bases=[],
    name_mapping={"facet": "facet", "limit": "limit", "sort_query": "sortQuery"},
)
class PowerpackWidgetDistributionDefinitionRequestRumQueryGroupBy:
    def __init__(
        self,
        *,
        facet: typing.Optional[builtins.str] = None,
        limit: typing.Optional[jsii.Number] = None,
        sort_query: typing.Optional[typing.Union["PowerpackWidgetDistributionDefinitionRequestRumQueryGroupBySortQuery", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param limit: The maximum number of items in the group. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param sort_query: sort_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        if isinstance(sort_query, dict):
            sort_query = PowerpackWidgetDistributionDefinitionRequestRumQueryGroupBySortQuery(**sort_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4f6e15e080aeed35b87dbd4a61a1a90d42a61a3587106aa04023c769e7796e23)
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
            check_type(argname="argument sort_query", value=sort_query, expected_type=type_hints["sort_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if facet is not None:
            self._values["facet"] = facet
        if limit is not None:
            self._values["limit"] = limit
        if sort_query is not None:
            self._values["sort_query"] = sort_query

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def limit(self) -> typing.Optional[jsii.Number]:
        '''The maximum number of items in the group.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        '''
        result = self._values.get("limit")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def sort_query(
        self,
    ) -> typing.Optional["PowerpackWidgetDistributionDefinitionRequestRumQueryGroupBySortQuery"]:
        '''sort_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        result = self._values.get("sort_query")
        return typing.cast(typing.Optional["PowerpackWidgetDistributionDefinitionRequestRumQueryGroupBySortQuery"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetDistributionDefinitionRequestRumQueryGroupBy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetDistributionDefinitionRequestRumQueryGroupByList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetDistributionDefinitionRequestRumQueryGroupByList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0b20ec9b3e56614a28265f7d4cb919ff660f90b9697767d1b2ebda15c4226d97)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetDistributionDefinitionRequestRumQueryGroupByOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f07d3363a275024c44d3ecfc5dbe8becce6e38f83db34e512a2cff2ff1c0d338)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetDistributionDefinitionRequestRumQueryGroupByOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3701985847313987a55d7dac94c834b8b3f7d6bd077c9442818803e99e8ec91f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__33538825c340f09437f190fe286b4ad9e4f9a036483b16f8a147caae67fd9b81)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fb2d64e1b5368a09f3bc24cffc1762b48bb28f931792912a9fb7283825b11494)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetDistributionDefinitionRequestRumQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetDistributionDefinitionRequestRumQueryGroupBy]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetDistributionDefinitionRequestRumQueryGroupBy]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__abed16f1e61e54fceaed8ffa97d0a59f985a9407cd610a0cc391accd646b6879)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetDistributionDefinitionRequestRumQueryGroupByOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetDistributionDefinitionRequestRumQueryGroupByOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__35825156f53b0f43a787698c77f01b5c9a20fdb65e9cb6bc11e9a4f2dc8de26f)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putSortQuery")
    def put_sort_query(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        value = PowerpackWidgetDistributionDefinitionRequestRumQueryGroupBySortQuery(
            aggregation=aggregation, order=order, facet=facet
        )

        return typing.cast(None, jsii.invoke(self, "putSortQuery", [value]))

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetLimit")
    def reset_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLimit", []))

    @jsii.member(jsii_name="resetSortQuery")
    def reset_sort_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSortQuery", []))

    @builtins.property
    @jsii.member(jsii_name="sortQuery")
    def sort_query(
        self,
    ) -> "PowerpackWidgetDistributionDefinitionRequestRumQueryGroupBySortQueryOutputReference":
        return typing.cast("PowerpackWidgetDistributionDefinitionRequestRumQueryGroupBySortQueryOutputReference", jsii.get(self, "sortQuery"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="limitInput")
    def limit_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "limitInput"))

    @builtins.property
    @jsii.member(jsii_name="sortQueryInput")
    def sort_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetDistributionDefinitionRequestRumQueryGroupBySortQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetDistributionDefinitionRequestRumQueryGroupBySortQuery"], jsii.get(self, "sortQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4bdcd8aa7a3b35c353d954e2fd45b5a6cc1ec16e08f28d4e71e1b8a2501e5b83)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="limit")
    def limit(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "limit"))

    @limit.setter
    def limit(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c6986212af8c8eee49bc224002df81b8aa5ad849542c8272c5b8bf539f039240)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "limit", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetDistributionDefinitionRequestRumQueryGroupBy]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetDistributionDefinitionRequestRumQueryGroupBy]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetDistributionDefinitionRequestRumQueryGroupBy]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0ab8340a2e7b5dc8e0fb848228c7d777f7047be1032d0fa83e13eb695572766a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetDistributionDefinitionRequestRumQueryGroupBySortQuery",
    jsii_struct_bases=[],
    name_mapping={"aggregation": "aggregation", "order": "order", "facet": "facet"},
)
class PowerpackWidgetDistributionDefinitionRequestRumQueryGroupBySortQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c7c88dc5d802609a96418adae6df0702dcb6077474beb74ad19ea14f2ecda04a)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument order", value=order, expected_type=type_hints["order"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
            "order": order,
        }
        if facet is not None:
            self._values["facet"] = facet

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def order(self) -> builtins.str:
        '''Widget sorting methods. Valid values are ``asc``, ``desc``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        result = self._values.get("order")
        assert result is not None, "Required property 'order' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetDistributionDefinitionRequestRumQueryGroupBySortQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetDistributionDefinitionRequestRumQueryGroupBySortQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetDistributionDefinitionRequestRumQueryGroupBySortQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8f27d737108ea2f7a8dfa50e572306f25ea836bc961d3ad394c1dd58c4a18cb1)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="orderInput")
    def order_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "orderInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__20b7e1b823a424991c05e9820be86f0cf4e55822d1014cd73a6e8bf9b0067c02)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__72eb783ff5ecb7bb1a2a95db42718ae17c6a0932dee877e51410cb76afb0e684)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="order")
    def order(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "order"))

    @order.setter
    def order(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__08ee2c92972bdfb6e2cb5d1eef0176f8b73f30426ea37dec88b45cdfcf0714a7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "order", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetDistributionDefinitionRequestRumQueryGroupBySortQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetDistributionDefinitionRequestRumQueryGroupBySortQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetDistributionDefinitionRequestRumQueryGroupBySortQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a1b069d72a1cd2dbf48fff1516328860492ee693472bac7516cd68e42d9d2669)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetDistributionDefinitionRequestRumQueryMultiCompute",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetDistributionDefinitionRequestRumQueryMultiCompute:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0f3d1ed45cd0af843bdaaf05a28b6628ca7129e7484659316b5072387de6ab7b)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetDistributionDefinitionRequestRumQueryMultiCompute(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetDistributionDefinitionRequestRumQueryMultiComputeList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetDistributionDefinitionRequestRumQueryMultiComputeList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fa7e129388cad5afa21443a6b7da53c7c2271ef714ee5997062a6c4648c44dc3)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetDistributionDefinitionRequestRumQueryMultiComputeOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__150870c56ba2fe0553f341c41b5b022817d9ac0748975ba7ab9dec0c4c7edbba)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetDistributionDefinitionRequestRumQueryMultiComputeOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c5e67f675d90ab2ed2c757a39e378c01227db7dea166202cbf367ad5b8e22933)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3a3928f15de49231892106d0fc29ef68b83f1628bb9dcca26b5178ae3f070d68)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__011134f4005a57facd3859bf4c7af460cc32b817b0217849d028116013471584)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetDistributionDefinitionRequestRumQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetDistributionDefinitionRequestRumQueryMultiCompute]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetDistributionDefinitionRequestRumQueryMultiCompute]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0fd780dd369632ec170f797b02bcb57657d4a9a8a8412f8c9db7bf64c24f46de)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetDistributionDefinitionRequestRumQueryMultiComputeOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetDistributionDefinitionRequestRumQueryMultiComputeOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d31eb88f18d3828d71135dcd0b1c8d6988109d5962f12a40ba65c0bc2b47a8c1)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7ea1c0b50da18f74e4cbcd54f9ea13ea9daaa485aa4e35e6e550cea7f8cf509c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dcad637f65d5590c3f9e36aa8d4ff727f9c0b5e1add2009c66d22e69ef218ff8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__93d42df763df64b562fae1c9d1975078f11e39f918bbd2ec42463be23c8a45ac)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetDistributionDefinitionRequestRumQueryMultiCompute]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetDistributionDefinitionRequestRumQueryMultiCompute]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetDistributionDefinitionRequestRumQueryMultiCompute]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5c20babd0ee8c7a93c1ce9d0ae9b8c6f60390ee2292be1c73cbe44867469a009)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetDistributionDefinitionRequestRumQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetDistributionDefinitionRequestRumQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d007d172b30f32802392da8874e6d72003ca6428abed316832a860068a6e5b21)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putComputeQuery")
    def put_compute_query(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        value = PowerpackWidgetDistributionDefinitionRequestRumQueryComputeQuery(
            aggregation=aggregation, facet=facet, interval=interval
        )

        return typing.cast(None, jsii.invoke(self, "putComputeQuery", [value]))

    @jsii.member(jsii_name="putGroupBy")
    def put_group_by(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetDistributionDefinitionRequestRumQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__91f231707c7faf9a7147ce8582e27c23a389dd2c783e345d4855138e38732e3d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putGroupBy", [value]))

    @jsii.member(jsii_name="putMultiCompute")
    def put_multi_compute(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetDistributionDefinitionRequestRumQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__700a744eaca4a44c02036f25bd4d66e0a939f2c9974bcac52db658585ebdd00c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putMultiCompute", [value]))

    @jsii.member(jsii_name="resetComputeQuery")
    def reset_compute_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetComputeQuery", []))

    @jsii.member(jsii_name="resetGroupBy")
    def reset_group_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGroupBy", []))

    @jsii.member(jsii_name="resetMultiCompute")
    def reset_multi_compute(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMultiCompute", []))

    @jsii.member(jsii_name="resetSearchQuery")
    def reset_search_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSearchQuery", []))

    @builtins.property
    @jsii.member(jsii_name="computeQuery")
    def compute_query(
        self,
    ) -> PowerpackWidgetDistributionDefinitionRequestRumQueryComputeQueryOutputReference:
        return typing.cast(PowerpackWidgetDistributionDefinitionRequestRumQueryComputeQueryOutputReference, jsii.get(self, "computeQuery"))

    @builtins.property
    @jsii.member(jsii_name="groupBy")
    def group_by(
        self,
    ) -> PowerpackWidgetDistributionDefinitionRequestRumQueryGroupByList:
        return typing.cast(PowerpackWidgetDistributionDefinitionRequestRumQueryGroupByList, jsii.get(self, "groupBy"))

    @builtins.property
    @jsii.member(jsii_name="multiCompute")
    def multi_compute(
        self,
    ) -> PowerpackWidgetDistributionDefinitionRequestRumQueryMultiComputeList:
        return typing.cast(PowerpackWidgetDistributionDefinitionRequestRumQueryMultiComputeList, jsii.get(self, "multiCompute"))

    @builtins.property
    @jsii.member(jsii_name="computeQueryInput")
    def compute_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetDistributionDefinitionRequestRumQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetDistributionDefinitionRequestRumQueryComputeQuery], jsii.get(self, "computeQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="groupByInput")
    def group_by_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetDistributionDefinitionRequestRumQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetDistributionDefinitionRequestRumQueryGroupBy]]], jsii.get(self, "groupByInput"))

    @builtins.property
    @jsii.member(jsii_name="indexInput")
    def index_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "indexInput"))

    @builtins.property
    @jsii.member(jsii_name="multiComputeInput")
    def multi_compute_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetDistributionDefinitionRequestRumQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetDistributionDefinitionRequestRumQueryMultiCompute]]], jsii.get(self, "multiComputeInput"))

    @builtins.property
    @jsii.member(jsii_name="searchQueryInput")
    def search_query_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "searchQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="index")
    def index(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "index"))

    @index.setter
    def index(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6c53bcb6bb3b3677e2dc95bc1ab24184a0eae226abd7460b701ebfa3636ec24f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "index", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="searchQuery")
    def search_query(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "searchQuery"))

    @search_query.setter
    def search_query(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__13364d0213b1e20bd31d09e9fbeefef9fd000d54ac4aaf0a3895a9e31974683e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "searchQuery", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetDistributionDefinitionRequestRumQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetDistributionDefinitionRequestRumQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetDistributionDefinitionRequestRumQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__81d8cd1dd1f244d93e6d82556c926e5a71f4d780492035b9a71d4aaee25c0b36)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetDistributionDefinitionRequestSecurityQuery",
    jsii_struct_bases=[],
    name_mapping={
        "index": "index",
        "compute_query": "computeQuery",
        "group_by": "groupBy",
        "multi_compute": "multiCompute",
        "search_query": "searchQuery",
    },
)
class PowerpackWidgetDistributionDefinitionRequestSecurityQuery:
    def __init__(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union["PowerpackWidgetDistributionDefinitionRequestSecurityQueryComputeQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetDistributionDefinitionRequestSecurityQueryGroupBy", typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetDistributionDefinitionRequestSecurityQueryMultiCompute", typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        if isinstance(compute_query, dict):
            compute_query = PowerpackWidgetDistributionDefinitionRequestSecurityQueryComputeQuery(**compute_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__18b438204bbb9c67b755e0689bff80d14bd1bca2174c5e8be1ceb657132bb481)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
            check_type(argname="argument compute_query", value=compute_query, expected_type=type_hints["compute_query"])
            check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
            check_type(argname="argument multi_compute", value=multi_compute, expected_type=type_hints["multi_compute"])
            check_type(argname="argument search_query", value=search_query, expected_type=type_hints["search_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "index": index,
        }
        if compute_query is not None:
            self._values["compute_query"] = compute_query
        if group_by is not None:
            self._values["group_by"] = group_by
        if multi_compute is not None:
            self._values["multi_compute"] = multi_compute
        if search_query is not None:
            self._values["search_query"] = search_query

    @builtins.property
    def index(self) -> builtins.str:
        '''The name of the index to query.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        '''
        result = self._values.get("index")
        assert result is not None, "Required property 'index' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def compute_query(
        self,
    ) -> typing.Optional["PowerpackWidgetDistributionDefinitionRequestSecurityQueryComputeQuery"]:
        '''compute_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        '''
        result = self._values.get("compute_query")
        return typing.cast(typing.Optional["PowerpackWidgetDistributionDefinitionRequestSecurityQueryComputeQuery"], result)

    @builtins.property
    def group_by(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetDistributionDefinitionRequestSecurityQueryGroupBy"]]]:
        '''group_by block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        '''
        result = self._values.get("group_by")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetDistributionDefinitionRequestSecurityQueryGroupBy"]]], result)

    @builtins.property
    def multi_compute(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetDistributionDefinitionRequestSecurityQueryMultiCompute"]]]:
        '''multi_compute block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        '''
        result = self._values.get("multi_compute")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetDistributionDefinitionRequestSecurityQueryMultiCompute"]]], result)

    @builtins.property
    def search_query(self) -> typing.Optional[builtins.str]:
        '''The search query to use.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        result = self._values.get("search_query")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetDistributionDefinitionRequestSecurityQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetDistributionDefinitionRequestSecurityQueryComputeQuery",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetDistributionDefinitionRequestSecurityQueryComputeQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a7b2fa65664a7c4246f32ec95247500fdd1baf0e91c0562743f3055ede9b149d)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetDistributionDefinitionRequestSecurityQueryComputeQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetDistributionDefinitionRequestSecurityQueryComputeQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetDistributionDefinitionRequestSecurityQueryComputeQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a3c0ab89a67d86259cc74f4970ebfaa7f839b539a74562e3f35fff157313f81b)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__79f34b5a6af482f30dd7be8134fef71900060e1becf3fcaeb006ef48653b1f57)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1419745fe2f740d074fb0375710cfeb1ce826035cc5c06cd13f958ea4a754ee6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c6f8c8c58ddeb7ebe1379498538db3a9fb644a850745409488bfbe5228daa6be)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetDistributionDefinitionRequestSecurityQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetDistributionDefinitionRequestSecurityQueryComputeQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetDistributionDefinitionRequestSecurityQueryComputeQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__98c5ab67d26dbb42df2bcd9fd1c8be2445ae68d8136290989a85c891da06a15f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetDistributionDefinitionRequestSecurityQueryGroupBy",
    jsii_struct_bases=[],
    name_mapping={"facet": "facet", "limit": "limit", "sort_query": "sortQuery"},
)
class PowerpackWidgetDistributionDefinitionRequestSecurityQueryGroupBy:
    def __init__(
        self,
        *,
        facet: typing.Optional[builtins.str] = None,
        limit: typing.Optional[jsii.Number] = None,
        sort_query: typing.Optional[typing.Union["PowerpackWidgetDistributionDefinitionRequestSecurityQueryGroupBySortQuery", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param limit: The maximum number of items in the group. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param sort_query: sort_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        if isinstance(sort_query, dict):
            sort_query = PowerpackWidgetDistributionDefinitionRequestSecurityQueryGroupBySortQuery(**sort_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6be9e50504eb1ce8bd82e25b81c3ee2ad45ac452eb2d0388a29cec7999af8423)
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
            check_type(argname="argument sort_query", value=sort_query, expected_type=type_hints["sort_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if facet is not None:
            self._values["facet"] = facet
        if limit is not None:
            self._values["limit"] = limit
        if sort_query is not None:
            self._values["sort_query"] = sort_query

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def limit(self) -> typing.Optional[jsii.Number]:
        '''The maximum number of items in the group.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        '''
        result = self._values.get("limit")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def sort_query(
        self,
    ) -> typing.Optional["PowerpackWidgetDistributionDefinitionRequestSecurityQueryGroupBySortQuery"]:
        '''sort_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        result = self._values.get("sort_query")
        return typing.cast(typing.Optional["PowerpackWidgetDistributionDefinitionRequestSecurityQueryGroupBySortQuery"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetDistributionDefinitionRequestSecurityQueryGroupBy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetDistributionDefinitionRequestSecurityQueryGroupByList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetDistributionDefinitionRequestSecurityQueryGroupByList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__349706f736d32eb316da264ae6f3b1d5a511e51c817d9878cd0ac37fb3313b42)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetDistributionDefinitionRequestSecurityQueryGroupByOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0472149051d58ebf143ce44e4ea1cf8f7479831fd7687139782ea9246d21b7cd)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetDistributionDefinitionRequestSecurityQueryGroupByOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c9e360d8cfc867faed4d9861434a1df8a52238f2bdf95cf4f70d802f09afefb8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9173e986922abbed81b263f7ffc9069b405acd7f7dad4a325d04df1d5b687ecc)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ffb671c19625e9f94a0f4855d4e6ad51bc3df03e26204abeebde98f6bf1f7e60)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetDistributionDefinitionRequestSecurityQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetDistributionDefinitionRequestSecurityQueryGroupBy]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetDistributionDefinitionRequestSecurityQueryGroupBy]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2d8fdde895b9381578e8e9ec0d07642f02c35e412f5786cc2a7026ba615f61bd)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetDistributionDefinitionRequestSecurityQueryGroupByOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetDistributionDefinitionRequestSecurityQueryGroupByOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1890092036ae69cdccc26f8425b90c439902168dcb2d871b5d0714318f78b50c)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putSortQuery")
    def put_sort_query(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        value = PowerpackWidgetDistributionDefinitionRequestSecurityQueryGroupBySortQuery(
            aggregation=aggregation, order=order, facet=facet
        )

        return typing.cast(None, jsii.invoke(self, "putSortQuery", [value]))

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetLimit")
    def reset_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLimit", []))

    @jsii.member(jsii_name="resetSortQuery")
    def reset_sort_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSortQuery", []))

    @builtins.property
    @jsii.member(jsii_name="sortQuery")
    def sort_query(
        self,
    ) -> "PowerpackWidgetDistributionDefinitionRequestSecurityQueryGroupBySortQueryOutputReference":
        return typing.cast("PowerpackWidgetDistributionDefinitionRequestSecurityQueryGroupBySortQueryOutputReference", jsii.get(self, "sortQuery"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="limitInput")
    def limit_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "limitInput"))

    @builtins.property
    @jsii.member(jsii_name="sortQueryInput")
    def sort_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetDistributionDefinitionRequestSecurityQueryGroupBySortQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetDistributionDefinitionRequestSecurityQueryGroupBySortQuery"], jsii.get(self, "sortQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__60422f6dbafecc449d1097dd82531d2091d83a986e7cf3cafe7ee329ad3412c3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="limit")
    def limit(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "limit"))

    @limit.setter
    def limit(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cf3f74ceabf136d6404e15dcd1e7362cb700ce9ef1d53e0051438378e05e167d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "limit", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetDistributionDefinitionRequestSecurityQueryGroupBy]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetDistributionDefinitionRequestSecurityQueryGroupBy]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetDistributionDefinitionRequestSecurityQueryGroupBy]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__52d5c17735f6aa3576aaeca668ca9db68c1d5c7f505322163fc60f9a4e3b6f3e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetDistributionDefinitionRequestSecurityQueryGroupBySortQuery",
    jsii_struct_bases=[],
    name_mapping={"aggregation": "aggregation", "order": "order", "facet": "facet"},
)
class PowerpackWidgetDistributionDefinitionRequestSecurityQueryGroupBySortQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__aaa98e948be4433cc68cef9364673d486d24971dd8be50bcc3052971003634ea)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument order", value=order, expected_type=type_hints["order"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
            "order": order,
        }
        if facet is not None:
            self._values["facet"] = facet

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def order(self) -> builtins.str:
        '''Widget sorting methods. Valid values are ``asc``, ``desc``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        result = self._values.get("order")
        assert result is not None, "Required property 'order' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetDistributionDefinitionRequestSecurityQueryGroupBySortQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetDistributionDefinitionRequestSecurityQueryGroupBySortQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetDistributionDefinitionRequestSecurityQueryGroupBySortQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c533f1062730cbb3d82ddc0c6c5f98b44d1f709903860db8620c1f5161b699ee)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="orderInput")
    def order_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "orderInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__69c750c6c50f5c056f7ca4e4d410043a3d2040809b5189e8fd383f1944f63035)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2ec50e5f573c91d63cfcc598b828b014ea5730aa4102d95bcbecc3baaa775694)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="order")
    def order(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "order"))

    @order.setter
    def order(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4e5e201234e1d4c84c4354ded6cde22ab65f8a4ca6f6522386716899f7660b0e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "order", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetDistributionDefinitionRequestSecurityQueryGroupBySortQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetDistributionDefinitionRequestSecurityQueryGroupBySortQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetDistributionDefinitionRequestSecurityQueryGroupBySortQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2c663b04a390ec9258bcc3434db707408d42e0319183ab57eed7fec1614c0b8e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetDistributionDefinitionRequestSecurityQueryMultiCompute",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetDistributionDefinitionRequestSecurityQueryMultiCompute:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4165954ce5db1dce2a9910f13a3811e87c256cd5e74174055de4e3039604ffb1)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetDistributionDefinitionRequestSecurityQueryMultiCompute(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetDistributionDefinitionRequestSecurityQueryMultiComputeList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetDistributionDefinitionRequestSecurityQueryMultiComputeList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__517979109055766ea91e3a2970a829df9223c05d2e7634ecb68bdb5108e4d956)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetDistributionDefinitionRequestSecurityQueryMultiComputeOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3c1009e58a397d117e351242bf74de2da3476e801f59f0d1ff8f9d5927b74c3d)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetDistributionDefinitionRequestSecurityQueryMultiComputeOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6897fa1251de7ec7db20ec2eae2d6914c2368b7cd346cd96114c13813f41878c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d262e1cbb5b48a74e95f2b62bf8c790a81f704281a5878289265d9686cae4b75)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5d940e7781362288d982e06eca2b7c5a5a9fb8cef36c101bd266cffc079819e2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetDistributionDefinitionRequestSecurityQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetDistributionDefinitionRequestSecurityQueryMultiCompute]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetDistributionDefinitionRequestSecurityQueryMultiCompute]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4e584269c40290cb3e74c4420832172c4640cd6e5679640ac79e9162ca5d9453)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetDistributionDefinitionRequestSecurityQueryMultiComputeOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetDistributionDefinitionRequestSecurityQueryMultiComputeOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4a5d5438c028dfa1d3b3b0955b1adbb032a8548464857116cfd0e66da10dc080)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f396cb7f00e04facb03e05f645afe34e1c603b201542dabf2f47a6000da24ee9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b3e1e20577c679152037d873f6b9195a8b2efcad861bd5acf7c131cd303d453e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__90d519a8f40dfda253a4eea44d3c4b8e9887e9a614aa77062f05e26b4758f990)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetDistributionDefinitionRequestSecurityQueryMultiCompute]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetDistributionDefinitionRequestSecurityQueryMultiCompute]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetDistributionDefinitionRequestSecurityQueryMultiCompute]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b7aeab96324b3ff9733a452a9becfa98d4c3eab183744d105830f69a7730df6a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetDistributionDefinitionRequestSecurityQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetDistributionDefinitionRequestSecurityQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__74850e37078b8f54fc287c83ec2d44cc9d40050d83cd800078ea6bf9a0c24820)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putComputeQuery")
    def put_compute_query(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        value = PowerpackWidgetDistributionDefinitionRequestSecurityQueryComputeQuery(
            aggregation=aggregation, facet=facet, interval=interval
        )

        return typing.cast(None, jsii.invoke(self, "putComputeQuery", [value]))

    @jsii.member(jsii_name="putGroupBy")
    def put_group_by(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetDistributionDefinitionRequestSecurityQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__aa84505deac529c73ac7db4a2b58cce5cbe78938e459035aeb67327963484d03)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putGroupBy", [value]))

    @jsii.member(jsii_name="putMultiCompute")
    def put_multi_compute(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetDistributionDefinitionRequestSecurityQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__480649b730d6b212a519c8ed1278a35667da87917feec1a83aa15d9756a3f9ae)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putMultiCompute", [value]))

    @jsii.member(jsii_name="resetComputeQuery")
    def reset_compute_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetComputeQuery", []))

    @jsii.member(jsii_name="resetGroupBy")
    def reset_group_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGroupBy", []))

    @jsii.member(jsii_name="resetMultiCompute")
    def reset_multi_compute(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMultiCompute", []))

    @jsii.member(jsii_name="resetSearchQuery")
    def reset_search_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSearchQuery", []))

    @builtins.property
    @jsii.member(jsii_name="computeQuery")
    def compute_query(
        self,
    ) -> PowerpackWidgetDistributionDefinitionRequestSecurityQueryComputeQueryOutputReference:
        return typing.cast(PowerpackWidgetDistributionDefinitionRequestSecurityQueryComputeQueryOutputReference, jsii.get(self, "computeQuery"))

    @builtins.property
    @jsii.member(jsii_name="groupBy")
    def group_by(
        self,
    ) -> PowerpackWidgetDistributionDefinitionRequestSecurityQueryGroupByList:
        return typing.cast(PowerpackWidgetDistributionDefinitionRequestSecurityQueryGroupByList, jsii.get(self, "groupBy"))

    @builtins.property
    @jsii.member(jsii_name="multiCompute")
    def multi_compute(
        self,
    ) -> PowerpackWidgetDistributionDefinitionRequestSecurityQueryMultiComputeList:
        return typing.cast(PowerpackWidgetDistributionDefinitionRequestSecurityQueryMultiComputeList, jsii.get(self, "multiCompute"))

    @builtins.property
    @jsii.member(jsii_name="computeQueryInput")
    def compute_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetDistributionDefinitionRequestSecurityQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetDistributionDefinitionRequestSecurityQueryComputeQuery], jsii.get(self, "computeQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="groupByInput")
    def group_by_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetDistributionDefinitionRequestSecurityQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetDistributionDefinitionRequestSecurityQueryGroupBy]]], jsii.get(self, "groupByInput"))

    @builtins.property
    @jsii.member(jsii_name="indexInput")
    def index_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "indexInput"))

    @builtins.property
    @jsii.member(jsii_name="multiComputeInput")
    def multi_compute_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetDistributionDefinitionRequestSecurityQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetDistributionDefinitionRequestSecurityQueryMultiCompute]]], jsii.get(self, "multiComputeInput"))

    @builtins.property
    @jsii.member(jsii_name="searchQueryInput")
    def search_query_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "searchQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="index")
    def index(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "index"))

    @index.setter
    def index(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6d87a2c115c76acadad02a257e7327a62ca8617e29c4d980594485f2f5a014cc)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "index", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="searchQuery")
    def search_query(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "searchQuery"))

    @search_query.setter
    def search_query(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0b256754a1ee7086d74ef6eb938e8e6767ce9b29dbf1b3c020963e27a0ea0280)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "searchQuery", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetDistributionDefinitionRequestSecurityQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetDistributionDefinitionRequestSecurityQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetDistributionDefinitionRequestSecurityQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e7e1dd8bafe4d259e2160f3f9c2d89e0e7f33fd68c18301ad0dcd37e25fe2fe8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetDistributionDefinitionRequestStyle",
    jsii_struct_bases=[],
    name_mapping={"palette": "palette"},
)
class PowerpackWidgetDistributionDefinitionRequestStyle:
    def __init__(self, *, palette: typing.Optional[builtins.str] = None) -> None:
        '''
        :param palette: A color palette to apply to the widget. The available options are available at: https://docs.datadoghq.com/dashboards/widgets/timeseries/#appearance. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette Powerpack#palette}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__50ffd422e972c7dde1bc38bddda5cf46a6a6c43805d639c3a6853c529a204ee8)
            check_type(argname="argument palette", value=palette, expected_type=type_hints["palette"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if palette is not None:
            self._values["palette"] = palette

    @builtins.property
    def palette(self) -> typing.Optional[builtins.str]:
        '''A color palette to apply to the widget. The available options are available at: https://docs.datadoghq.com/dashboards/widgets/timeseries/#appearance.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette Powerpack#palette}
        '''
        result = self._values.get("palette")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetDistributionDefinitionRequestStyle(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetDistributionDefinitionRequestStyleOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetDistributionDefinitionRequestStyleOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__84ae2c6f43c67dc37781a9efdcb8810cc31abd1899b19a4a978e89eb7a8688f7)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetPalette")
    def reset_palette(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPalette", []))

    @builtins.property
    @jsii.member(jsii_name="paletteInput")
    def palette_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "paletteInput"))

    @builtins.property
    @jsii.member(jsii_name="palette")
    def palette(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "palette"))

    @palette.setter
    def palette(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__90e74220d9b746f368b759b24f8a3a136f552e042ea7bd1668e14d42c98f3de5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "palette", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetDistributionDefinitionRequestStyle]:
        return typing.cast(typing.Optional[PowerpackWidgetDistributionDefinitionRequestStyle], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetDistributionDefinitionRequestStyle],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5e2cd8a6d23190cbeb9654e49b83e7a4a3ed70819c971a7d886c9cda9077bcc9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetDistributionDefinitionXaxis",
    jsii_struct_bases=[],
    name_mapping={
        "include_zero": "includeZero",
        "max": "max",
        "min": "min",
        "scale": "scale",
    },
)
class PowerpackWidgetDistributionDefinitionXaxis:
    def __init__(
        self,
        *,
        include_zero: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        max: typing.Optional[builtins.str] = None,
        min: typing.Optional[builtins.str] = None,
        scale: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param include_zero: Always include zero or fit the axis to the data range. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#include_zero Powerpack#include_zero}
        :param max: Specify the maximum value to show on the Y-axis. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#max Powerpack#max}
        :param min: Specify the minimum value to show on the Y-axis. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#min Powerpack#min}
        :param scale: Specify the scale type, options: ``linear``, ``log``, ``pow``, ``sqrt``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#scale Powerpack#scale}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e46ae4d309128c0505ed2b343d37a9452b4d7e1fc630170cf8c1cabff6ade60e)
            check_type(argname="argument include_zero", value=include_zero, expected_type=type_hints["include_zero"])
            check_type(argname="argument max", value=max, expected_type=type_hints["max"])
            check_type(argname="argument min", value=min, expected_type=type_hints["min"])
            check_type(argname="argument scale", value=scale, expected_type=type_hints["scale"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if include_zero is not None:
            self._values["include_zero"] = include_zero
        if max is not None:
            self._values["max"] = max
        if min is not None:
            self._values["min"] = min
        if scale is not None:
            self._values["scale"] = scale

    @builtins.property
    def include_zero(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        '''Always include zero or fit the axis to the data range.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#include_zero Powerpack#include_zero}
        '''
        result = self._values.get("include_zero")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)

    @builtins.property
    def max(self) -> typing.Optional[builtins.str]:
        '''Specify the maximum value to show on the Y-axis.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#max Powerpack#max}
        '''
        result = self._values.get("max")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def min(self) -> typing.Optional[builtins.str]:
        '''Specify the minimum value to show on the Y-axis.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#min Powerpack#min}
        '''
        result = self._values.get("min")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def scale(self) -> typing.Optional[builtins.str]:
        '''Specify the scale type, options: ``linear``, ``log``, ``pow``, ``sqrt``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#scale Powerpack#scale}
        '''
        result = self._values.get("scale")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetDistributionDefinitionXaxis(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetDistributionDefinitionXaxisOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetDistributionDefinitionXaxisOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__70b16a842527ba295cac1c08bab705fd9745b5e313403471512a8c94c39a8bc4)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetIncludeZero")
    def reset_include_zero(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetIncludeZero", []))

    @jsii.member(jsii_name="resetMax")
    def reset_max(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMax", []))

    @jsii.member(jsii_name="resetMin")
    def reset_min(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMin", []))

    @jsii.member(jsii_name="resetScale")
    def reset_scale(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetScale", []))

    @builtins.property
    @jsii.member(jsii_name="includeZeroInput")
    def include_zero_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "includeZeroInput"))

    @builtins.property
    @jsii.member(jsii_name="maxInput")
    def max_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "maxInput"))

    @builtins.property
    @jsii.member(jsii_name="minInput")
    def min_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "minInput"))

    @builtins.property
    @jsii.member(jsii_name="scaleInput")
    def scale_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "scaleInput"))

    @builtins.property
    @jsii.member(jsii_name="includeZero")
    def include_zero(self) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "includeZero"))

    @include_zero.setter
    def include_zero(
        self,
        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__503f224bd73cf309edd90716ca6548d49b6ce259c9e350799897b24ecdf8fd73)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "includeZero", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="max")
    def max(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "max"))

    @max.setter
    def max(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0b0b6d5b29d3c6fc5b1ee6f56d1c409344e0f43c4d56c494fc8bd0e42dd205de)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "max", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="min")
    def min(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "min"))

    @min.setter
    def min(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__34787269caa4d458569d051c9197c1651e560373436d94adb693f91cfb8e0087)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "min", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="scale")
    def scale(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "scale"))

    @scale.setter
    def scale(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__37902f5d45bd8561877f6db8976bbb04ef9b5342553c3dd9655934726e7ac843)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "scale", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetDistributionDefinitionXaxis]:
        return typing.cast(typing.Optional[PowerpackWidgetDistributionDefinitionXaxis], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetDistributionDefinitionXaxis],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2d214d91d2c9a0764b662f8a02f3317878bedbeed0cd2babe5667d0f22d49357)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetDistributionDefinitionYaxis",
    jsii_struct_bases=[],
    name_mapping={
        "include_zero": "includeZero",
        "label": "label",
        "max": "max",
        "min": "min",
        "scale": "scale",
    },
)
class PowerpackWidgetDistributionDefinitionYaxis:
    def __init__(
        self,
        *,
        include_zero: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        label: typing.Optional[builtins.str] = None,
        max: typing.Optional[builtins.str] = None,
        min: typing.Optional[builtins.str] = None,
        scale: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param include_zero: Always include zero or fit the axis to the data range. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#include_zero Powerpack#include_zero}
        :param label: The label of the axis to display on the graph. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#label Powerpack#label}
        :param max: Specify the maximum value to show on the Y-axis. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#max Powerpack#max}
        :param min: Specify the minimum value to show on the Y-axis. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#min Powerpack#min}
        :param scale: Specify the scale type, options: ``linear``, ``log``, ``pow``, ``sqrt``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#scale Powerpack#scale}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6b263f29a1e7e9d112f5ab7421eb37a99475069c8e8488bb221b98b6e7866de1)
            check_type(argname="argument include_zero", value=include_zero, expected_type=type_hints["include_zero"])
            check_type(argname="argument label", value=label, expected_type=type_hints["label"])
            check_type(argname="argument max", value=max, expected_type=type_hints["max"])
            check_type(argname="argument min", value=min, expected_type=type_hints["min"])
            check_type(argname="argument scale", value=scale, expected_type=type_hints["scale"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if include_zero is not None:
            self._values["include_zero"] = include_zero
        if label is not None:
            self._values["label"] = label
        if max is not None:
            self._values["max"] = max
        if min is not None:
            self._values["min"] = min
        if scale is not None:
            self._values["scale"] = scale

    @builtins.property
    def include_zero(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        '''Always include zero or fit the axis to the data range.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#include_zero Powerpack#include_zero}
        '''
        result = self._values.get("include_zero")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)

    @builtins.property
    def label(self) -> typing.Optional[builtins.str]:
        '''The label of the axis to display on the graph.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#label Powerpack#label}
        '''
        result = self._values.get("label")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def max(self) -> typing.Optional[builtins.str]:
        '''Specify the maximum value to show on the Y-axis.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#max Powerpack#max}
        '''
        result = self._values.get("max")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def min(self) -> typing.Optional[builtins.str]:
        '''Specify the minimum value to show on the Y-axis.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#min Powerpack#min}
        '''
        result = self._values.get("min")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def scale(self) -> typing.Optional[builtins.str]:
        '''Specify the scale type, options: ``linear``, ``log``, ``pow``, ``sqrt``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#scale Powerpack#scale}
        '''
        result = self._values.get("scale")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetDistributionDefinitionYaxis(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetDistributionDefinitionYaxisOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetDistributionDefinitionYaxisOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0e91015f7eec11d52b27694fdce9dad84d6a97395d694a94376c50ebe45e0125)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetIncludeZero")
    def reset_include_zero(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetIncludeZero", []))

    @jsii.member(jsii_name="resetLabel")
    def reset_label(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLabel", []))

    @jsii.member(jsii_name="resetMax")
    def reset_max(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMax", []))

    @jsii.member(jsii_name="resetMin")
    def reset_min(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMin", []))

    @jsii.member(jsii_name="resetScale")
    def reset_scale(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetScale", []))

    @builtins.property
    @jsii.member(jsii_name="includeZeroInput")
    def include_zero_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "includeZeroInput"))

    @builtins.property
    @jsii.member(jsii_name="labelInput")
    def label_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "labelInput"))

    @builtins.property
    @jsii.member(jsii_name="maxInput")
    def max_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "maxInput"))

    @builtins.property
    @jsii.member(jsii_name="minInput")
    def min_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "minInput"))

    @builtins.property
    @jsii.member(jsii_name="scaleInput")
    def scale_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "scaleInput"))

    @builtins.property
    @jsii.member(jsii_name="includeZero")
    def include_zero(self) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "includeZero"))

    @include_zero.setter
    def include_zero(
        self,
        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e4d877de0340e23e7696f2c46ff671c7e415ef69bfc98bb16be87955320ec57d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "includeZero", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="label")
    def label(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "label"))

    @label.setter
    def label(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__db1e2d15a3a8a3c6b59e30af9a61f90ceac039feee442e6a292318e35b2a8686)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "label", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="max")
    def max(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "max"))

    @max.setter
    def max(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b23f6950d651d228656329863c493c022926df9166ce7687c664bf36b342dcc8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "max", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="min")
    def min(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "min"))

    @min.setter
    def min(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5745822b431561f0e0fa899d9dd196808845bf53a9b937b0c9f30f4a8ad3b389)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "min", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="scale")
    def scale(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "scale"))

    @scale.setter
    def scale(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4039f5bf8b7510ea9d6693ab163a6f425dc126d889a99b4ec6eeac12f08fb49e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "scale", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetDistributionDefinitionYaxis]:
        return typing.cast(typing.Optional[PowerpackWidgetDistributionDefinitionYaxis], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetDistributionDefinitionYaxis],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0d5a5a679cb06e223c1d0f61be59ab17e5f6894d0cb43074f44777ee049bea9d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetEventStreamDefinition",
    jsii_struct_bases=[],
    name_mapping={
        "query": "query",
        "event_size": "eventSize",
        "live_span": "liveSpan",
        "tags_execution": "tagsExecution",
        "title": "title",
        "title_align": "titleAlign",
        "title_size": "titleSize",
    },
)
class PowerpackWidgetEventStreamDefinition:
    def __init__(
        self,
        *,
        query: builtins.str,
        event_size: typing.Optional[builtins.str] = None,
        live_span: typing.Optional[builtins.str] = None,
        tags_execution: typing.Optional[builtins.str] = None,
        title: typing.Optional[builtins.str] = None,
        title_align: typing.Optional[builtins.str] = None,
        title_size: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param query: The query to use in the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        :param event_size: The size to use to display an event. Valid values are ``s``, ``l``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#event_size Powerpack#event_size}
        :param live_span: The timeframe to use when displaying the widget. Valid values are ``1m``, ``5m``, ``10m``, ``15m``, ``30m``, ``1h``, ``4h``, ``1d``, ``2d``, ``1w``, ``1mo``, ``3mo``, ``6mo``, ``week_to_date``, ``month_to_date``, ``1y``, ``alert``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#live_span Powerpack#live_span}
        :param tags_execution: The execution method for multi-value filters, options: ``and`` or ``or``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#tags_execution Powerpack#tags_execution}
        :param title: The title of the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title Powerpack#title}
        :param title_align: The alignment of the widget's title. Valid values are ``center``, ``left``, ``right``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_align Powerpack#title_align}
        :param title_size: The size of the widget's title (defaults to 16). Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_size Powerpack#title_size}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d30e8788e11b9947f7ae095c375033143139482eea4d11942a6a6c2c87c65f11)
            check_type(argname="argument query", value=query, expected_type=type_hints["query"])
            check_type(argname="argument event_size", value=event_size, expected_type=type_hints["event_size"])
            check_type(argname="argument live_span", value=live_span, expected_type=type_hints["live_span"])
            check_type(argname="argument tags_execution", value=tags_execution, expected_type=type_hints["tags_execution"])
            check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            check_type(argname="argument title_align", value=title_align, expected_type=type_hints["title_align"])
            check_type(argname="argument title_size", value=title_size, expected_type=type_hints["title_size"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "query": query,
        }
        if event_size is not None:
            self._values["event_size"] = event_size
        if live_span is not None:
            self._values["live_span"] = live_span
        if tags_execution is not None:
            self._values["tags_execution"] = tags_execution
        if title is not None:
            self._values["title"] = title
        if title_align is not None:
            self._values["title_align"] = title_align
        if title_size is not None:
            self._values["title_size"] = title_size

    @builtins.property
    def query(self) -> builtins.str:
        '''The query to use in the widget.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        '''
        result = self._values.get("query")
        assert result is not None, "Required property 'query' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def event_size(self) -> typing.Optional[builtins.str]:
        '''The size to use to display an event. Valid values are ``s``, ``l``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#event_size Powerpack#event_size}
        '''
        result = self._values.get("event_size")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def live_span(self) -> typing.Optional[builtins.str]:
        '''The timeframe to use when displaying the widget.

        Valid values are ``1m``, ``5m``, ``10m``, ``15m``, ``30m``, ``1h``, ``4h``, ``1d``, ``2d``, ``1w``, ``1mo``, ``3mo``, ``6mo``, ``week_to_date``, ``month_to_date``, ``1y``, ``alert``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#live_span Powerpack#live_span}
        '''
        result = self._values.get("live_span")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def tags_execution(self) -> typing.Optional[builtins.str]:
        '''The execution method for multi-value filters, options: ``and`` or ``or``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#tags_execution Powerpack#tags_execution}
        '''
        result = self._values.get("tags_execution")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def title(self) -> typing.Optional[builtins.str]:
        '''The title of the widget.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title Powerpack#title}
        '''
        result = self._values.get("title")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def title_align(self) -> typing.Optional[builtins.str]:
        '''The alignment of the widget's title. Valid values are ``center``, ``left``, ``right``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_align Powerpack#title_align}
        '''
        result = self._values.get("title_align")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def title_size(self) -> typing.Optional[builtins.str]:
        '''The size of the widget's title (defaults to 16).

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_size Powerpack#title_size}
        '''
        result = self._values.get("title_size")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetEventStreamDefinition(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetEventStreamDefinitionOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetEventStreamDefinitionOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__13ff6fe32c70408d64e651b7d6ec203f8d18118647c57836cedbc9fb6d2125a6)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetEventSize")
    def reset_event_size(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetEventSize", []))

    @jsii.member(jsii_name="resetLiveSpan")
    def reset_live_span(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLiveSpan", []))

    @jsii.member(jsii_name="resetTagsExecution")
    def reset_tags_execution(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTagsExecution", []))

    @jsii.member(jsii_name="resetTitle")
    def reset_title(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTitle", []))

    @jsii.member(jsii_name="resetTitleAlign")
    def reset_title_align(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTitleAlign", []))

    @jsii.member(jsii_name="resetTitleSize")
    def reset_title_size(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTitleSize", []))

    @builtins.property
    @jsii.member(jsii_name="eventSizeInput")
    def event_size_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "eventSizeInput"))

    @builtins.property
    @jsii.member(jsii_name="liveSpanInput")
    def live_span_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "liveSpanInput"))

    @builtins.property
    @jsii.member(jsii_name="queryInput")
    def query_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "queryInput"))

    @builtins.property
    @jsii.member(jsii_name="tagsExecutionInput")
    def tags_execution_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "tagsExecutionInput"))

    @builtins.property
    @jsii.member(jsii_name="titleAlignInput")
    def title_align_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "titleAlignInput"))

    @builtins.property
    @jsii.member(jsii_name="titleInput")
    def title_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "titleInput"))

    @builtins.property
    @jsii.member(jsii_name="titleSizeInput")
    def title_size_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "titleSizeInput"))

    @builtins.property
    @jsii.member(jsii_name="eventSize")
    def event_size(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "eventSize"))

    @event_size.setter
    def event_size(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a55709921d655295d43cbf885bccbda60c8c5c57adf482ddb6a93192ecbbaf82)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "eventSize", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="liveSpan")
    def live_span(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "liveSpan"))

    @live_span.setter
    def live_span(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2af12a3f3e4e0b35eb2e50c67ccf2b817d17c086ea1c82fddbbf530469f54cca)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "liveSpan", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="query")
    def query(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "query"))

    @query.setter
    def query(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b0e417b5aa597e8ed7dd2a1d13eb71fbc292251fc349d4dbc2ad04266134f614)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "query", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="tagsExecution")
    def tags_execution(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "tagsExecution"))

    @tags_execution.setter
    def tags_execution(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b42007a4d196dbba4acf782c36bc55e7e4c17981d0fa649a3beddeec0648152c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "tagsExecution", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="title")
    def title(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "title"))

    @title.setter
    def title(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8195f04cca70a759e568709561dee6a5b58728b8fbd950f280a2bca1d2086b31)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "title", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="titleAlign")
    def title_align(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "titleAlign"))

    @title_align.setter
    def title_align(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__081f1bde62a6fbfdeaa2ad7976be9af21f3eea5eed156a6ccc5cd49c17e9f1fa)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "titleAlign", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="titleSize")
    def title_size(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "titleSize"))

    @title_size.setter
    def title_size(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cc5e2c5249872d03cd48bb39d5618155c41af254d7bc290a13300bcb3ea91e4b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "titleSize", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[PowerpackWidgetEventStreamDefinition]:
        return typing.cast(typing.Optional[PowerpackWidgetEventStreamDefinition], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetEventStreamDefinition],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d9a99d76c66efe9fb661aaf65a3cfef3c45cd719776bcea27b067e8a8ccf48c9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetEventTimelineDefinition",
    jsii_struct_bases=[],
    name_mapping={
        "query": "query",
        "live_span": "liveSpan",
        "tags_execution": "tagsExecution",
        "title": "title",
        "title_align": "titleAlign",
        "title_size": "titleSize",
    },
)
class PowerpackWidgetEventTimelineDefinition:
    def __init__(
        self,
        *,
        query: builtins.str,
        live_span: typing.Optional[builtins.str] = None,
        tags_execution: typing.Optional[builtins.str] = None,
        title: typing.Optional[builtins.str] = None,
        title_align: typing.Optional[builtins.str] = None,
        title_size: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param query: The query to use in the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        :param live_span: The timeframe to use when displaying the widget. Valid values are ``1m``, ``5m``, ``10m``, ``15m``, ``30m``, ``1h``, ``4h``, ``1d``, ``2d``, ``1w``, ``1mo``, ``3mo``, ``6mo``, ``week_to_date``, ``month_to_date``, ``1y``, ``alert``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#live_span Powerpack#live_span}
        :param tags_execution: The execution method for multi-value filters, options: ``and`` or ``or``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#tags_execution Powerpack#tags_execution}
        :param title: The title of the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title Powerpack#title}
        :param title_align: The alignment of the widget's title. Valid values are ``center``, ``left``, ``right``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_align Powerpack#title_align}
        :param title_size: The size of the widget's title (defaults to 16). Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_size Powerpack#title_size}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b33b161f7d0faa2f9265e51b8289fa15571a5bb91f144c8bd46843e422b2ff64)
            check_type(argname="argument query", value=query, expected_type=type_hints["query"])
            check_type(argname="argument live_span", value=live_span, expected_type=type_hints["live_span"])
            check_type(argname="argument tags_execution", value=tags_execution, expected_type=type_hints["tags_execution"])
            check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            check_type(argname="argument title_align", value=title_align, expected_type=type_hints["title_align"])
            check_type(argname="argument title_size", value=title_size, expected_type=type_hints["title_size"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "query": query,
        }
        if live_span is not None:
            self._values["live_span"] = live_span
        if tags_execution is not None:
            self._values["tags_execution"] = tags_execution
        if title is not None:
            self._values["title"] = title
        if title_align is not None:
            self._values["title_align"] = title_align
        if title_size is not None:
            self._values["title_size"] = title_size

    @builtins.property
    def query(self) -> builtins.str:
        '''The query to use in the widget.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        '''
        result = self._values.get("query")
        assert result is not None, "Required property 'query' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def live_span(self) -> typing.Optional[builtins.str]:
        '''The timeframe to use when displaying the widget.

        Valid values are ``1m``, ``5m``, ``10m``, ``15m``, ``30m``, ``1h``, ``4h``, ``1d``, ``2d``, ``1w``, ``1mo``, ``3mo``, ``6mo``, ``week_to_date``, ``month_to_date``, ``1y``, ``alert``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#live_span Powerpack#live_span}
        '''
        result = self._values.get("live_span")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def tags_execution(self) -> typing.Optional[builtins.str]:
        '''The execution method for multi-value filters, options: ``and`` or ``or``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#tags_execution Powerpack#tags_execution}
        '''
        result = self._values.get("tags_execution")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def title(self) -> typing.Optional[builtins.str]:
        '''The title of the widget.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title Powerpack#title}
        '''
        result = self._values.get("title")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def title_align(self) -> typing.Optional[builtins.str]:
        '''The alignment of the widget's title. Valid values are ``center``, ``left``, ``right``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_align Powerpack#title_align}
        '''
        result = self._values.get("title_align")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def title_size(self) -> typing.Optional[builtins.str]:
        '''The size of the widget's title (defaults to 16).

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_size Powerpack#title_size}
        '''
        result = self._values.get("title_size")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetEventTimelineDefinition(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetEventTimelineDefinitionOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetEventTimelineDefinitionOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8a17342913a0ffc25bbc7240d4a472596c42af0abc868cec9cbcd433827a94fe)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetLiveSpan")
    def reset_live_span(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLiveSpan", []))

    @jsii.member(jsii_name="resetTagsExecution")
    def reset_tags_execution(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTagsExecution", []))

    @jsii.member(jsii_name="resetTitle")
    def reset_title(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTitle", []))

    @jsii.member(jsii_name="resetTitleAlign")
    def reset_title_align(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTitleAlign", []))

    @jsii.member(jsii_name="resetTitleSize")
    def reset_title_size(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTitleSize", []))

    @builtins.property
    @jsii.member(jsii_name="liveSpanInput")
    def live_span_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "liveSpanInput"))

    @builtins.property
    @jsii.member(jsii_name="queryInput")
    def query_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "queryInput"))

    @builtins.property
    @jsii.member(jsii_name="tagsExecutionInput")
    def tags_execution_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "tagsExecutionInput"))

    @builtins.property
    @jsii.member(jsii_name="titleAlignInput")
    def title_align_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "titleAlignInput"))

    @builtins.property
    @jsii.member(jsii_name="titleInput")
    def title_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "titleInput"))

    @builtins.property
    @jsii.member(jsii_name="titleSizeInput")
    def title_size_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "titleSizeInput"))

    @builtins.property
    @jsii.member(jsii_name="liveSpan")
    def live_span(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "liveSpan"))

    @live_span.setter
    def live_span(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dac0c2a02653bfc1beee78795d8d2ac18e1e1d19780880b6edd54e896d4101fe)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "liveSpan", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="query")
    def query(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "query"))

    @query.setter
    def query(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e520891e94feb5392839d28c4fae2de47a052a537fa65bb61b79f708d87e8f06)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "query", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="tagsExecution")
    def tags_execution(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "tagsExecution"))

    @tags_execution.setter
    def tags_execution(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3cd9d2d48dd95b4bcfb13a444a24ee4c4437f355d9c98a4a89ba7abd18de4da8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "tagsExecution", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="title")
    def title(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "title"))

    @title.setter
    def title(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c07ea0fafe36eace801cb9934f6740fe995019eff17916b0d81718d85e606207)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "title", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="titleAlign")
    def title_align(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "titleAlign"))

    @title_align.setter
    def title_align(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6e0de2bd51b986937a41f84f7678606fc19dfdc61b6ae86adeb80cc2ba8bd063)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "titleAlign", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="titleSize")
    def title_size(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "titleSize"))

    @title_size.setter
    def title_size(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4449565980bc7d3038aebcdc4e0ec2d64f17c5b51040cc12a62dc52a3a2d58b1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "titleSize", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[PowerpackWidgetEventTimelineDefinition]:
        return typing.cast(typing.Optional[PowerpackWidgetEventTimelineDefinition], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetEventTimelineDefinition],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2b7682cbe9ecac80383c181b00c069b299a0d728188feb20250669cce2fedaa8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetFreeTextDefinition",
    jsii_struct_bases=[],
    name_mapping={
        "text": "text",
        "color": "color",
        "font_size": "fontSize",
        "text_align": "textAlign",
    },
)
class PowerpackWidgetFreeTextDefinition:
    def __init__(
        self,
        *,
        text: builtins.str,
        color: typing.Optional[builtins.str] = None,
        font_size: typing.Optional[builtins.str] = None,
        text_align: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param text: The text to display in the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#text Powerpack#text}
        :param color: The color of the text in the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#color Powerpack#color}
        :param font_size: The size of the text in the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#font_size Powerpack#font_size}
        :param text_align: The alignment of the text in the widget. Valid values are ``center``, ``left``, ``right``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#text_align Powerpack#text_align}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5d310e3edf74d36f114dbfee47b9928a7504b3c04837428aec2ebc00d84138c3)
            check_type(argname="argument text", value=text, expected_type=type_hints["text"])
            check_type(argname="argument color", value=color, expected_type=type_hints["color"])
            check_type(argname="argument font_size", value=font_size, expected_type=type_hints["font_size"])
            check_type(argname="argument text_align", value=text_align, expected_type=type_hints["text_align"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "text": text,
        }
        if color is not None:
            self._values["color"] = color
        if font_size is not None:
            self._values["font_size"] = font_size
        if text_align is not None:
            self._values["text_align"] = text_align

    @builtins.property
    def text(self) -> builtins.str:
        '''The text to display in the widget.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#text Powerpack#text}
        '''
        result = self._values.get("text")
        assert result is not None, "Required property 'text' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def color(self) -> typing.Optional[builtins.str]:
        '''The color of the text in the widget.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#color Powerpack#color}
        '''
        result = self._values.get("color")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def font_size(self) -> typing.Optional[builtins.str]:
        '''The size of the text in the widget.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#font_size Powerpack#font_size}
        '''
        result = self._values.get("font_size")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def text_align(self) -> typing.Optional[builtins.str]:
        '''The alignment of the text in the widget. Valid values are ``center``, ``left``, ``right``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#text_align Powerpack#text_align}
        '''
        result = self._values.get("text_align")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetFreeTextDefinition(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetFreeTextDefinitionOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetFreeTextDefinitionOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__74626fb5baed17ccb620adb404ef583ee6f0ed44bb3a7eb9f9f1acee715a77bc)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetColor")
    def reset_color(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetColor", []))

    @jsii.member(jsii_name="resetFontSize")
    def reset_font_size(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFontSize", []))

    @jsii.member(jsii_name="resetTextAlign")
    def reset_text_align(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTextAlign", []))

    @builtins.property
    @jsii.member(jsii_name="colorInput")
    def color_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "colorInput"))

    @builtins.property
    @jsii.member(jsii_name="fontSizeInput")
    def font_size_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "fontSizeInput"))

    @builtins.property
    @jsii.member(jsii_name="textAlignInput")
    def text_align_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "textAlignInput"))

    @builtins.property
    @jsii.member(jsii_name="textInput")
    def text_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "textInput"))

    @builtins.property
    @jsii.member(jsii_name="color")
    def color(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "color"))

    @color.setter
    def color(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1d37fde3b77326540c1052d09e3d931f7ac41a411c80fe7a3686782e80d1ed0e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "color", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="fontSize")
    def font_size(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "fontSize"))

    @font_size.setter
    def font_size(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c8215a8146245a00b1cc789b983299204b036386527421f30b9f919c4280c1f3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "fontSize", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="text")
    def text(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "text"))

    @text.setter
    def text(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c99692ed53ee22d99eff5fa682c7171550b8b9c61ace539bfcae112288c549c9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "text", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="textAlign")
    def text_align(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "textAlign"))

    @text_align.setter
    def text_align(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__03fe783f18ab0cb44857b1ee11ab9b294fa80e7663626cfa9185131a73cd58a1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "textAlign", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[PowerpackWidgetFreeTextDefinition]:
        return typing.cast(typing.Optional[PowerpackWidgetFreeTextDefinition], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetFreeTextDefinition],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7d7eea9e7760a23c23d31fac426c0165edae0458e0bea9c40961595fec24eb3e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetGeomapDefinition",
    jsii_struct_bases=[],
    name_mapping={
        "view": "view",
        "custom_link": "customLink",
        "live_span": "liveSpan",
        "request": "request",
        "style": "style",
        "title": "title",
        "title_align": "titleAlign",
        "title_size": "titleSize",
    },
)
class PowerpackWidgetGeomapDefinition:
    def __init__(
        self,
        *,
        view: typing.Union["PowerpackWidgetGeomapDefinitionView", typing.Dict[builtins.str, typing.Any]],
        custom_link: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetGeomapDefinitionCustomLink", typing.Dict[builtins.str, typing.Any]]]]] = None,
        live_span: typing.Optional[builtins.str] = None,
        request: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetGeomapDefinitionRequest", typing.Dict[builtins.str, typing.Any]]]]] = None,
        style: typing.Optional[typing.Union["PowerpackWidgetGeomapDefinitionStyle", typing.Dict[builtins.str, typing.Any]]] = None,
        title: typing.Optional[builtins.str] = None,
        title_align: typing.Optional[builtins.str] = None,
        title_size: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param view: view block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#view Powerpack#view}
        :param custom_link: custom_link block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom_link Powerpack#custom_link}
        :param live_span: The timeframe to use when displaying the widget. Valid values are ``1m``, ``5m``, ``10m``, ``15m``, ``30m``, ``1h``, ``4h``, ``1d``, ``2d``, ``1w``, ``1mo``, ``3mo``, ``6mo``, ``week_to_date``, ``month_to_date``, ``1y``, ``alert``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#live_span Powerpack#live_span}
        :param request: request block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#request Powerpack#request}
        :param style: style block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#style Powerpack#style}
        :param title: The title of the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title Powerpack#title}
        :param title_align: The alignment of the widget's title. Valid values are ``center``, ``left``, ``right``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_align Powerpack#title_align}
        :param title_size: The size of the widget's title (defaults to 16). Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_size Powerpack#title_size}
        '''
        if isinstance(view, dict):
            view = PowerpackWidgetGeomapDefinitionView(**view)
        if isinstance(style, dict):
            style = PowerpackWidgetGeomapDefinitionStyle(**style)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__28a78970288e602f92ab6705d1445e0250349741f4290d2d818740c908f31ba1)
            check_type(argname="argument view", value=view, expected_type=type_hints["view"])
            check_type(argname="argument custom_link", value=custom_link, expected_type=type_hints["custom_link"])
            check_type(argname="argument live_span", value=live_span, expected_type=type_hints["live_span"])
            check_type(argname="argument request", value=request, expected_type=type_hints["request"])
            check_type(argname="argument style", value=style, expected_type=type_hints["style"])
            check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            check_type(argname="argument title_align", value=title_align, expected_type=type_hints["title_align"])
            check_type(argname="argument title_size", value=title_size, expected_type=type_hints["title_size"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "view": view,
        }
        if custom_link is not None:
            self._values["custom_link"] = custom_link
        if live_span is not None:
            self._values["live_span"] = live_span
        if request is not None:
            self._values["request"] = request
        if style is not None:
            self._values["style"] = style
        if title is not None:
            self._values["title"] = title
        if title_align is not None:
            self._values["title_align"] = title_align
        if title_size is not None:
            self._values["title_size"] = title_size

    @builtins.property
    def view(self) -> "PowerpackWidgetGeomapDefinitionView":
        '''view block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#view Powerpack#view}
        '''
        result = self._values.get("view")
        assert result is not None, "Required property 'view' is missing"
        return typing.cast("PowerpackWidgetGeomapDefinitionView", result)

    @builtins.property
    def custom_link(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetGeomapDefinitionCustomLink"]]]:
        '''custom_link block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom_link Powerpack#custom_link}
        '''
        result = self._values.get("custom_link")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetGeomapDefinitionCustomLink"]]], result)

    @builtins.property
    def live_span(self) -> typing.Optional[builtins.str]:
        '''The timeframe to use when displaying the widget.

        Valid values are ``1m``, ``5m``, ``10m``, ``15m``, ``30m``, ``1h``, ``4h``, ``1d``, ``2d``, ``1w``, ``1mo``, ``3mo``, ``6mo``, ``week_to_date``, ``month_to_date``, ``1y``, ``alert``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#live_span Powerpack#live_span}
        '''
        result = self._values.get("live_span")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def request(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetGeomapDefinitionRequest"]]]:
        '''request block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#request Powerpack#request}
        '''
        result = self._values.get("request")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetGeomapDefinitionRequest"]]], result)

    @builtins.property
    def style(self) -> typing.Optional["PowerpackWidgetGeomapDefinitionStyle"]:
        '''style block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#style Powerpack#style}
        '''
        result = self._values.get("style")
        return typing.cast(typing.Optional["PowerpackWidgetGeomapDefinitionStyle"], result)

    @builtins.property
    def title(self) -> typing.Optional[builtins.str]:
        '''The title of the widget.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title Powerpack#title}
        '''
        result = self._values.get("title")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def title_align(self) -> typing.Optional[builtins.str]:
        '''The alignment of the widget's title. Valid values are ``center``, ``left``, ``right``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_align Powerpack#title_align}
        '''
        result = self._values.get("title_align")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def title_size(self) -> typing.Optional[builtins.str]:
        '''The size of the widget's title (defaults to 16).

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_size Powerpack#title_size}
        '''
        result = self._values.get("title_size")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetGeomapDefinition(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetGeomapDefinitionCustomLink",
    jsii_struct_bases=[],
    name_mapping={
        "is_hidden": "isHidden",
        "label": "label",
        "link": "link",
        "override_label": "overrideLabel",
    },
)
class PowerpackWidgetGeomapDefinitionCustomLink:
    def __init__(
        self,
        *,
        is_hidden: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        label: typing.Optional[builtins.str] = None,
        link: typing.Optional[builtins.str] = None,
        override_label: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param is_hidden: The flag for toggling context menu link visibility. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#is_hidden Powerpack#is_hidden}
        :param label: The label for the custom link URL. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#label Powerpack#label}
        :param link: The URL of the custom link. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#link Powerpack#link}
        :param override_label: The label ID that refers to a context menu link item. When ``override_label`` is provided, the client request omits the label field. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#override_label Powerpack#override_label}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__baa5bfa283643034662a94f0b616c78d5e8921ab5f2bbc899fec08761f4fff2b)
            check_type(argname="argument is_hidden", value=is_hidden, expected_type=type_hints["is_hidden"])
            check_type(argname="argument label", value=label, expected_type=type_hints["label"])
            check_type(argname="argument link", value=link, expected_type=type_hints["link"])
            check_type(argname="argument override_label", value=override_label, expected_type=type_hints["override_label"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if is_hidden is not None:
            self._values["is_hidden"] = is_hidden
        if label is not None:
            self._values["label"] = label
        if link is not None:
            self._values["link"] = link
        if override_label is not None:
            self._values["override_label"] = override_label

    @builtins.property
    def is_hidden(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        '''The flag for toggling context menu link visibility.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#is_hidden Powerpack#is_hidden}
        '''
        result = self._values.get("is_hidden")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)

    @builtins.property
    def label(self) -> typing.Optional[builtins.str]:
        '''The label for the custom link URL.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#label Powerpack#label}
        '''
        result = self._values.get("label")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def link(self) -> typing.Optional[builtins.str]:
        '''The URL of the custom link.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#link Powerpack#link}
        '''
        result = self._values.get("link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def override_label(self) -> typing.Optional[builtins.str]:
        '''The label ID that refers to a context menu link item.

        When ``override_label`` is provided, the client request omits the label field.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#override_label Powerpack#override_label}
        '''
        result = self._values.get("override_label")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetGeomapDefinitionCustomLink(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetGeomapDefinitionCustomLinkList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetGeomapDefinitionCustomLinkList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4fbd771a7d1380746e219a73f3983e07fd7d7a7f3c8b455fad4a56a97f4cc40b)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetGeomapDefinitionCustomLinkOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__52b43ac895d9ecc3976d7dddacb7156ee25dbfacbc107f337f739b62e98177ee)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetGeomapDefinitionCustomLinkOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2fa097c575a37687f0a147ab0245683934d952d3064227327d677d0b821fbe6b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__437d72f8671ab727a19f86365c4c7bdd48ae73586d3caa3f3e4d3523349ee874)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2a989443b7f6d13e8b60be22a57004506a021df977ed823b6cffa7423611cb21)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetGeomapDefinitionCustomLink]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetGeomapDefinitionCustomLink]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetGeomapDefinitionCustomLink]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__38938566652487b54c7095b12c2a26e7db9be8aefa7839017b29915f0730ba69)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetGeomapDefinitionCustomLinkOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetGeomapDefinitionCustomLinkOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5fb2f3d7b30aebd153b8f7e2505184791e0f14b108d857e2b316961c162b8801)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetIsHidden")
    def reset_is_hidden(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetIsHidden", []))

    @jsii.member(jsii_name="resetLabel")
    def reset_label(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLabel", []))

    @jsii.member(jsii_name="resetLink")
    def reset_link(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLink", []))

    @jsii.member(jsii_name="resetOverrideLabel")
    def reset_override_label(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetOverrideLabel", []))

    @builtins.property
    @jsii.member(jsii_name="isHiddenInput")
    def is_hidden_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "isHiddenInput"))

    @builtins.property
    @jsii.member(jsii_name="labelInput")
    def label_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "labelInput"))

    @builtins.property
    @jsii.member(jsii_name="linkInput")
    def link_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "linkInput"))

    @builtins.property
    @jsii.member(jsii_name="overrideLabelInput")
    def override_label_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "overrideLabelInput"))

    @builtins.property
    @jsii.member(jsii_name="isHidden")
    def is_hidden(self) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "isHidden"))

    @is_hidden.setter
    def is_hidden(
        self,
        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__97940fc8e37a94881a4d92d931551d448e4a9e5b33eae4d41352cf3a0f77b802)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "isHidden", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="label")
    def label(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "label"))

    @label.setter
    def label(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8916a42b891dea06f1858db207b8d2221f80983c8891123353cd7e81a98d817b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "label", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="link")
    def link(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "link"))

    @link.setter
    def link(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__15149b40e8a53d7ea9abe9674a7ca1ddee821905002d401ca371870001757aac)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "link", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="overrideLabel")
    def override_label(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "overrideLabel"))

    @override_label.setter
    def override_label(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7314b64678cdf66a6e96166c15771407053b882776a2a476e0596e9f705e5a40)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "overrideLabel", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetGeomapDefinitionCustomLink]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetGeomapDefinitionCustomLink]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetGeomapDefinitionCustomLink]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f588891238f4375caac58d792e870f39fbbbf7218fc79406c6086aba7f77341d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetGeomapDefinitionOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetGeomapDefinitionOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c73401babbf294282cf6fe6c22691f1522150b3dbf1bffe806586edfb9829ebe)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putCustomLink")
    def put_custom_link(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetGeomapDefinitionCustomLink, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dd872b76fb7f05ca467c39b910b8209593ee1c89878d4cc436b8085ca7d24d78)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putCustomLink", [value]))

    @jsii.member(jsii_name="putRequest")
    def put_request(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetGeomapDefinitionRequest", typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__aa032425c2efd15ac4ffba127b55c8406fb200be8eb36b00d47c932d16ed6f85)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putRequest", [value]))

    @jsii.member(jsii_name="putStyle")
    def put_style(
        self,
        *,
        palette: builtins.str,
        palette_flip: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
    ) -> None:
        '''
        :param palette: The color palette to apply to the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette Powerpack#palette}
        :param palette_flip: A Boolean indicating whether to flip the palette tones. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette_flip Powerpack#palette_flip}
        '''
        value = PowerpackWidgetGeomapDefinitionStyle(
            palette=palette, palette_flip=palette_flip
        )

        return typing.cast(None, jsii.invoke(self, "putStyle", [value]))

    @jsii.member(jsii_name="putView")
    def put_view(self, *, focus: builtins.str) -> None:
        '''
        :param focus: The two-letter ISO code of a country to focus the map on (or ``WORLD``). Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#focus Powerpack#focus}
        '''
        value = PowerpackWidgetGeomapDefinitionView(focus=focus)

        return typing.cast(None, jsii.invoke(self, "putView", [value]))

    @jsii.member(jsii_name="resetCustomLink")
    def reset_custom_link(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCustomLink", []))

    @jsii.member(jsii_name="resetLiveSpan")
    def reset_live_span(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLiveSpan", []))

    @jsii.member(jsii_name="resetRequest")
    def reset_request(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetRequest", []))

    @jsii.member(jsii_name="resetStyle")
    def reset_style(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetStyle", []))

    @jsii.member(jsii_name="resetTitle")
    def reset_title(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTitle", []))

    @jsii.member(jsii_name="resetTitleAlign")
    def reset_title_align(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTitleAlign", []))

    @jsii.member(jsii_name="resetTitleSize")
    def reset_title_size(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTitleSize", []))

    @builtins.property
    @jsii.member(jsii_name="customLink")
    def custom_link(self) -> PowerpackWidgetGeomapDefinitionCustomLinkList:
        return typing.cast(PowerpackWidgetGeomapDefinitionCustomLinkList, jsii.get(self, "customLink"))

    @builtins.property
    @jsii.member(jsii_name="request")
    def request(self) -> "PowerpackWidgetGeomapDefinitionRequestList":
        return typing.cast("PowerpackWidgetGeomapDefinitionRequestList", jsii.get(self, "request"))

    @builtins.property
    @jsii.member(jsii_name="style")
    def style(self) -> "PowerpackWidgetGeomapDefinitionStyleOutputReference":
        return typing.cast("PowerpackWidgetGeomapDefinitionStyleOutputReference", jsii.get(self, "style"))

    @builtins.property
    @jsii.member(jsii_name="view")
    def view(self) -> "PowerpackWidgetGeomapDefinitionViewOutputReference":
        return typing.cast("PowerpackWidgetGeomapDefinitionViewOutputReference", jsii.get(self, "view"))

    @builtins.property
    @jsii.member(jsii_name="customLinkInput")
    def custom_link_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetGeomapDefinitionCustomLink]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetGeomapDefinitionCustomLink]]], jsii.get(self, "customLinkInput"))

    @builtins.property
    @jsii.member(jsii_name="liveSpanInput")
    def live_span_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "liveSpanInput"))

    @builtins.property
    @jsii.member(jsii_name="requestInput")
    def request_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetGeomapDefinitionRequest"]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetGeomapDefinitionRequest"]]], jsii.get(self, "requestInput"))

    @builtins.property
    @jsii.member(jsii_name="styleInput")
    def style_input(self) -> typing.Optional["PowerpackWidgetGeomapDefinitionStyle"]:
        return typing.cast(typing.Optional["PowerpackWidgetGeomapDefinitionStyle"], jsii.get(self, "styleInput"))

    @builtins.property
    @jsii.member(jsii_name="titleAlignInput")
    def title_align_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "titleAlignInput"))

    @builtins.property
    @jsii.member(jsii_name="titleInput")
    def title_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "titleInput"))

    @builtins.property
    @jsii.member(jsii_name="titleSizeInput")
    def title_size_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "titleSizeInput"))

    @builtins.property
    @jsii.member(jsii_name="viewInput")
    def view_input(self) -> typing.Optional["PowerpackWidgetGeomapDefinitionView"]:
        return typing.cast(typing.Optional["PowerpackWidgetGeomapDefinitionView"], jsii.get(self, "viewInput"))

    @builtins.property
    @jsii.member(jsii_name="liveSpan")
    def live_span(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "liveSpan"))

    @live_span.setter
    def live_span(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e9dc219710daf54dedfdb8d0d9bbf4385a3ce234cada3c09fb050d5687b607c8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "liveSpan", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="title")
    def title(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "title"))

    @title.setter
    def title(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d3976940a8b0577a73a71b14485d76f2d64cc84806a1bcf79cb3205a15e5f773)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "title", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="titleAlign")
    def title_align(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "titleAlign"))

    @title_align.setter
    def title_align(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__01256fd7a68322914db7acb84083a87367d35f99b9668a4e4e56beb1208096af)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "titleAlign", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="titleSize")
    def title_size(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "titleSize"))

    @title_size.setter
    def title_size(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__813a6db103751ca7abb2eff3573ae250973b7afa150e2021c399190d176bcf72)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "titleSize", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[PowerpackWidgetGeomapDefinition]:
        return typing.cast(typing.Optional[PowerpackWidgetGeomapDefinition], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetGeomapDefinition],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5c53e125331efb2726a0c7cdf717a15da1284650449f92ef65608e18201a432a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetGeomapDefinitionRequest",
    jsii_struct_bases=[],
    name_mapping={
        "formula": "formula",
        "log_query": "logQuery",
        "q": "q",
        "query": "query",
        "rum_query": "rumQuery",
    },
)
class PowerpackWidgetGeomapDefinitionRequest:
    def __init__(
        self,
        *,
        formula: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetGeomapDefinitionRequestFormula", typing.Dict[builtins.str, typing.Any]]]]] = None,
        log_query: typing.Optional[typing.Union["PowerpackWidgetGeomapDefinitionRequestLogQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        q: typing.Optional[builtins.str] = None,
        query: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetGeomapDefinitionRequestQuery", typing.Dict[builtins.str, typing.Any]]]]] = None,
        rum_query: typing.Optional[typing.Union["PowerpackWidgetGeomapDefinitionRequestRumQuery", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param formula: formula block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#formula Powerpack#formula}
        :param log_query: log_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#log_query Powerpack#log_query}
        :param q: The metric query to use for this widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#q Powerpack#q}
        :param query: query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        :param rum_query: rum_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#rum_query Powerpack#rum_query}
        '''
        if isinstance(log_query, dict):
            log_query = PowerpackWidgetGeomapDefinitionRequestLogQuery(**log_query)
        if isinstance(rum_query, dict):
            rum_query = PowerpackWidgetGeomapDefinitionRequestRumQuery(**rum_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3967da8f61e586d027b178add1ff2f1632f617de6169b51372146422e48daf2a)
            check_type(argname="argument formula", value=formula, expected_type=type_hints["formula"])
            check_type(argname="argument log_query", value=log_query, expected_type=type_hints["log_query"])
            check_type(argname="argument q", value=q, expected_type=type_hints["q"])
            check_type(argname="argument query", value=query, expected_type=type_hints["query"])
            check_type(argname="argument rum_query", value=rum_query, expected_type=type_hints["rum_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if formula is not None:
            self._values["formula"] = formula
        if log_query is not None:
            self._values["log_query"] = log_query
        if q is not None:
            self._values["q"] = q
        if query is not None:
            self._values["query"] = query
        if rum_query is not None:
            self._values["rum_query"] = rum_query

    @builtins.property
    def formula(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetGeomapDefinitionRequestFormula"]]]:
        '''formula block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#formula Powerpack#formula}
        '''
        result = self._values.get("formula")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetGeomapDefinitionRequestFormula"]]], result)

    @builtins.property
    def log_query(
        self,
    ) -> typing.Optional["PowerpackWidgetGeomapDefinitionRequestLogQuery"]:
        '''log_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#log_query Powerpack#log_query}
        '''
        result = self._values.get("log_query")
        return typing.cast(typing.Optional["PowerpackWidgetGeomapDefinitionRequestLogQuery"], result)

    @builtins.property
    def q(self) -> typing.Optional[builtins.str]:
        '''The metric query to use for this widget.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#q Powerpack#q}
        '''
        result = self._values.get("q")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def query(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetGeomapDefinitionRequestQuery"]]]:
        '''query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        '''
        result = self._values.get("query")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetGeomapDefinitionRequestQuery"]]], result)

    @builtins.property
    def rum_query(
        self,
    ) -> typing.Optional["PowerpackWidgetGeomapDefinitionRequestRumQuery"]:
        '''rum_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#rum_query Powerpack#rum_query}
        '''
        result = self._values.get("rum_query")
        return typing.cast(typing.Optional["PowerpackWidgetGeomapDefinitionRequestRumQuery"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetGeomapDefinitionRequest(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetGeomapDefinitionRequestFormula",
    jsii_struct_bases=[],
    name_mapping={
        "formula_expression": "formulaExpression",
        "alias": "alias",
        "cell_display_mode": "cellDisplayMode",
        "conditional_formats": "conditionalFormats",
        "limit": "limit",
        "number_format": "numberFormat",
        "style": "style",
    },
)
class PowerpackWidgetGeomapDefinitionRequestFormula:
    def __init__(
        self,
        *,
        formula_expression: builtins.str,
        alias: typing.Optional[builtins.str] = None,
        cell_display_mode: typing.Optional[builtins.str] = None,
        conditional_formats: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetGeomapDefinitionRequestFormulaConditionalFormats", typing.Dict[builtins.str, typing.Any]]]]] = None,
        limit: typing.Optional[typing.Union["PowerpackWidgetGeomapDefinitionRequestFormulaLimit", typing.Dict[builtins.str, typing.Any]]] = None,
        number_format: typing.Optional[typing.Union["PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormat", typing.Dict[builtins.str, typing.Any]]] = None,
        style: typing.Optional[typing.Union["PowerpackWidgetGeomapDefinitionRequestFormulaStyle", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param formula_expression: A string expression built from queries, formulas, and functions. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#formula_expression Powerpack#formula_expression}
        :param alias: An expression alias. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#alias Powerpack#alias}
        :param cell_display_mode: A list of display modes for each table cell. Valid values are ``number``, ``bar``, ``trend``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cell_display_mode Powerpack#cell_display_mode}
        :param conditional_formats: conditional_formats block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#conditional_formats Powerpack#conditional_formats}
        :param limit: limit block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param number_format: number_format block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#number_format Powerpack#number_format}
        :param style: style block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#style Powerpack#style}
        '''
        if isinstance(limit, dict):
            limit = PowerpackWidgetGeomapDefinitionRequestFormulaLimit(**limit)
        if isinstance(number_format, dict):
            number_format = PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormat(**number_format)
        if isinstance(style, dict):
            style = PowerpackWidgetGeomapDefinitionRequestFormulaStyle(**style)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a2ca853103af5e27c9da6944bead07a50df3162863d24b7ed5b65c855a4e504c)
            check_type(argname="argument formula_expression", value=formula_expression, expected_type=type_hints["formula_expression"])
            check_type(argname="argument alias", value=alias, expected_type=type_hints["alias"])
            check_type(argname="argument cell_display_mode", value=cell_display_mode, expected_type=type_hints["cell_display_mode"])
            check_type(argname="argument conditional_formats", value=conditional_formats, expected_type=type_hints["conditional_formats"])
            check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
            check_type(argname="argument number_format", value=number_format, expected_type=type_hints["number_format"])
            check_type(argname="argument style", value=style, expected_type=type_hints["style"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "formula_expression": formula_expression,
        }
        if alias is not None:
            self._values["alias"] = alias
        if cell_display_mode is not None:
            self._values["cell_display_mode"] = cell_display_mode
        if conditional_formats is not None:
            self._values["conditional_formats"] = conditional_formats
        if limit is not None:
            self._values["limit"] = limit
        if number_format is not None:
            self._values["number_format"] = number_format
        if style is not None:
            self._values["style"] = style

    @builtins.property
    def formula_expression(self) -> builtins.str:
        '''A string expression built from queries, formulas, and functions.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#formula_expression Powerpack#formula_expression}
        '''
        result = self._values.get("formula_expression")
        assert result is not None, "Required property 'formula_expression' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def alias(self) -> typing.Optional[builtins.str]:
        '''An expression alias.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#alias Powerpack#alias}
        '''
        result = self._values.get("alias")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def cell_display_mode(self) -> typing.Optional[builtins.str]:
        '''A list of display modes for each table cell. Valid values are ``number``, ``bar``, ``trend``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cell_display_mode Powerpack#cell_display_mode}
        '''
        result = self._values.get("cell_display_mode")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def conditional_formats(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetGeomapDefinitionRequestFormulaConditionalFormats"]]]:
        '''conditional_formats block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#conditional_formats Powerpack#conditional_formats}
        '''
        result = self._values.get("conditional_formats")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetGeomapDefinitionRequestFormulaConditionalFormats"]]], result)

    @builtins.property
    def limit(
        self,
    ) -> typing.Optional["PowerpackWidgetGeomapDefinitionRequestFormulaLimit"]:
        '''limit block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        '''
        result = self._values.get("limit")
        return typing.cast(typing.Optional["PowerpackWidgetGeomapDefinitionRequestFormulaLimit"], result)

    @builtins.property
    def number_format(
        self,
    ) -> typing.Optional["PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormat"]:
        '''number_format block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#number_format Powerpack#number_format}
        '''
        result = self._values.get("number_format")
        return typing.cast(typing.Optional["PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormat"], result)

    @builtins.property
    def style(
        self,
    ) -> typing.Optional["PowerpackWidgetGeomapDefinitionRequestFormulaStyle"]:
        '''style block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#style Powerpack#style}
        '''
        result = self._values.get("style")
        return typing.cast(typing.Optional["PowerpackWidgetGeomapDefinitionRequestFormulaStyle"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetGeomapDefinitionRequestFormula(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetGeomapDefinitionRequestFormulaConditionalFormats",
    jsii_struct_bases=[],
    name_mapping={
        "comparator": "comparator",
        "palette": "palette",
        "value": "value",
        "custom_bg_color": "customBgColor",
        "custom_fg_color": "customFgColor",
        "hide_value": "hideValue",
        "image_url": "imageUrl",
        "metric": "metric",
        "timeframe": "timeframe",
    },
)
class PowerpackWidgetGeomapDefinitionRequestFormulaConditionalFormats:
    def __init__(
        self,
        *,
        comparator: builtins.str,
        palette: builtins.str,
        value: jsii.Number,
        custom_bg_color: typing.Optional[builtins.str] = None,
        custom_fg_color: typing.Optional[builtins.str] = None,
        hide_value: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        image_url: typing.Optional[builtins.str] = None,
        metric: typing.Optional[builtins.str] = None,
        timeframe: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param comparator: The comparator to use. Valid values are ``=``, ``>``, ``>=``, ``<``, ``<=``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#comparator Powerpack#comparator}
        :param palette: The color palette to apply. Valid values are ``blue``, ``custom_bg``, ``custom_image``, ``custom_text``, ``gray_on_white``, ``grey``, ``green``, ``orange``, ``red``, ``red_on_white``, ``white_on_gray``, ``white_on_green``, ``green_on_white``, ``white_on_red``, ``white_on_yellow``, ``yellow_on_white``, ``black_on_light_yellow``, ``black_on_light_green``, ``black_on_light_red``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette Powerpack#palette}
        :param value: A value for the comparator. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#value Powerpack#value}
        :param custom_bg_color: The color palette to apply to the background, same values available as palette. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom_bg_color Powerpack#custom_bg_color}
        :param custom_fg_color: The color palette to apply to the foreground, same values available as palette. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom_fg_color Powerpack#custom_fg_color}
        :param hide_value: Setting this to True hides values. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#hide_value Powerpack#hide_value}
        :param image_url: Displays an image as the background. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#image_url Powerpack#image_url}
        :param metric: The metric from the request to correlate with this conditional format. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        :param timeframe: Defines the displayed timeframe. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#timeframe Powerpack#timeframe}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0a2b4c134dbe4aceceb735dc8bc9ebcec83f05d1b60b180a12a6440c15a3d7af)
            check_type(argname="argument comparator", value=comparator, expected_type=type_hints["comparator"])
            check_type(argname="argument palette", value=palette, expected_type=type_hints["palette"])
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument custom_bg_color", value=custom_bg_color, expected_type=type_hints["custom_bg_color"])
            check_type(argname="argument custom_fg_color", value=custom_fg_color, expected_type=type_hints["custom_fg_color"])
            check_type(argname="argument hide_value", value=hide_value, expected_type=type_hints["hide_value"])
            check_type(argname="argument image_url", value=image_url, expected_type=type_hints["image_url"])
            check_type(argname="argument metric", value=metric, expected_type=type_hints["metric"])
            check_type(argname="argument timeframe", value=timeframe, expected_type=type_hints["timeframe"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "comparator": comparator,
            "palette": palette,
            "value": value,
        }
        if custom_bg_color is not None:
            self._values["custom_bg_color"] = custom_bg_color
        if custom_fg_color is not None:
            self._values["custom_fg_color"] = custom_fg_color
        if hide_value is not None:
            self._values["hide_value"] = hide_value
        if image_url is not None:
            self._values["image_url"] = image_url
        if metric is not None:
            self._values["metric"] = metric
        if timeframe is not None:
            self._values["timeframe"] = timeframe

    @builtins.property
    def comparator(self) -> builtins.str:
        '''The comparator to use. Valid values are ``=``, ``>``, ``>=``, ``<``, ``<=``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#comparator Powerpack#comparator}
        '''
        result = self._values.get("comparator")
        assert result is not None, "Required property 'comparator' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def palette(self) -> builtins.str:
        '''The color palette to apply.

        Valid values are ``blue``, ``custom_bg``, ``custom_image``, ``custom_text``, ``gray_on_white``, ``grey``, ``green``, ``orange``, ``red``, ``red_on_white``, ``white_on_gray``, ``white_on_green``, ``green_on_white``, ``white_on_red``, ``white_on_yellow``, ``yellow_on_white``, ``black_on_light_yellow``, ``black_on_light_green``, ``black_on_light_red``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette Powerpack#palette}
        '''
        result = self._values.get("palette")
        assert result is not None, "Required property 'palette' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def value(self) -> jsii.Number:
        '''A value for the comparator.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#value Powerpack#value}
        '''
        result = self._values.get("value")
        assert result is not None, "Required property 'value' is missing"
        return typing.cast(jsii.Number, result)

    @builtins.property
    def custom_bg_color(self) -> typing.Optional[builtins.str]:
        '''The color palette to apply to the background, same values available as palette.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom_bg_color Powerpack#custom_bg_color}
        '''
        result = self._values.get("custom_bg_color")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def custom_fg_color(self) -> typing.Optional[builtins.str]:
        '''The color palette to apply to the foreground, same values available as palette.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom_fg_color Powerpack#custom_fg_color}
        '''
        result = self._values.get("custom_fg_color")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def hide_value(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        '''Setting this to True hides values.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#hide_value Powerpack#hide_value}
        '''
        result = self._values.get("hide_value")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)

    @builtins.property
    def image_url(self) -> typing.Optional[builtins.str]:
        '''Displays an image as the background.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#image_url Powerpack#image_url}
        '''
        result = self._values.get("image_url")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def metric(self) -> typing.Optional[builtins.str]:
        '''The metric from the request to correlate with this conditional format.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        '''
        result = self._values.get("metric")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def timeframe(self) -> typing.Optional[builtins.str]:
        '''Defines the displayed timeframe.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#timeframe Powerpack#timeframe}
        '''
        result = self._values.get("timeframe")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetGeomapDefinitionRequestFormulaConditionalFormats(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetGeomapDefinitionRequestFormulaConditionalFormatsList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetGeomapDefinitionRequestFormulaConditionalFormatsList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6b654f763787850566c357e0068c11d36148d8b4cf04432de0adc608883513ac)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetGeomapDefinitionRequestFormulaConditionalFormatsOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1c7dd894095c5932919f45b0de7ee93154cd8d89a60668fa3a24811ff5c13e7e)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetGeomapDefinitionRequestFormulaConditionalFormatsOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__119f34697c4082006b6cc5e58460622d26031211c9498342087c402f57d347c3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9d48a914b4f4e22e26073215dc3cd2667ea4f19ea1576083adf14f835d29eb9c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c53470577932ed983cd40da23b1367a99c96c86c4b1cb2ddb3d0484eaa2f6d86)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetGeomapDefinitionRequestFormulaConditionalFormats]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetGeomapDefinitionRequestFormulaConditionalFormats]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetGeomapDefinitionRequestFormulaConditionalFormats]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b00c57f04767b89e98372c9bfddd592a0f8657f9c7f35e2284817a5f0260c065)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetGeomapDefinitionRequestFormulaConditionalFormatsOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetGeomapDefinitionRequestFormulaConditionalFormatsOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__987302ebf3d527506cba31f461c5e886926b9b7e2bcf2d3ad2a6157d103e71c9)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetCustomBgColor")
    def reset_custom_bg_color(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCustomBgColor", []))

    @jsii.member(jsii_name="resetCustomFgColor")
    def reset_custom_fg_color(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCustomFgColor", []))

    @jsii.member(jsii_name="resetHideValue")
    def reset_hide_value(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHideValue", []))

    @jsii.member(jsii_name="resetImageUrl")
    def reset_image_url(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetImageUrl", []))

    @jsii.member(jsii_name="resetMetric")
    def reset_metric(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMetric", []))

    @jsii.member(jsii_name="resetTimeframe")
    def reset_timeframe(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTimeframe", []))

    @builtins.property
    @jsii.member(jsii_name="comparatorInput")
    def comparator_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "comparatorInput"))

    @builtins.property
    @jsii.member(jsii_name="customBgColorInput")
    def custom_bg_color_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "customBgColorInput"))

    @builtins.property
    @jsii.member(jsii_name="customFgColorInput")
    def custom_fg_color_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "customFgColorInput"))

    @builtins.property
    @jsii.member(jsii_name="hideValueInput")
    def hide_value_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "hideValueInput"))

    @builtins.property
    @jsii.member(jsii_name="imageUrlInput")
    def image_url_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "imageUrlInput"))

    @builtins.property
    @jsii.member(jsii_name="metricInput")
    def metric_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "metricInput"))

    @builtins.property
    @jsii.member(jsii_name="paletteInput")
    def palette_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "paletteInput"))

    @builtins.property
    @jsii.member(jsii_name="timeframeInput")
    def timeframe_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "timeframeInput"))

    @builtins.property
    @jsii.member(jsii_name="valueInput")
    def value_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "valueInput"))

    @builtins.property
    @jsii.member(jsii_name="comparator")
    def comparator(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "comparator"))

    @comparator.setter
    def comparator(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__28781a2dcef916c15d6cd36bce4375f9c4ad8dbaf41011b7d9229a41c0a952f7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "comparator", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="customBgColor")
    def custom_bg_color(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "customBgColor"))

    @custom_bg_color.setter
    def custom_bg_color(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5d80be96070859d181b239dd293bdaabe8c9efe8db253181af4f7ff5d9183b50)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "customBgColor", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="customFgColor")
    def custom_fg_color(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "customFgColor"))

    @custom_fg_color.setter
    def custom_fg_color(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__930e4c3a729eaeb14da75630f6aceb2a7dc9b2dc12ca4041676cf0ec654667dd)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "customFgColor", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="hideValue")
    def hide_value(self) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "hideValue"))

    @hide_value.setter
    def hide_value(
        self,
        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8056146fe376ee411dd1af35109a09a08a0034355c97e20dbc8632047e10bf56)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "hideValue", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="imageUrl")
    def image_url(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "imageUrl"))

    @image_url.setter
    def image_url(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__941aa531b6ae232a85cf289a0f2aa47c2252c9e09b4da5a55cefbeb952d58a55)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "imageUrl", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="metric")
    def metric(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "metric"))

    @metric.setter
    def metric(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__36ab8cc7111966e4915479f9f2f5baf87900b70a6639af6deadf64cbb42ad826)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "metric", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="palette")
    def palette(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "palette"))

    @palette.setter
    def palette(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5ec793a1f800ec394de8a810e88b7e74899087d45fcb22c13687e5e64477ffc9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "palette", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="timeframe")
    def timeframe(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "timeframe"))

    @timeframe.setter
    def timeframe(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f39a7044d0aefd48e4abd8ba59007ead1b63e25924c40579cbf07f6a8ead008c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "timeframe", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="value")
    def value(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "value"))

    @value.setter
    def value(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__62aa599c0d79dd0f0cfe9ca3ed5bc931899bf2b5b88095d76771d8d50db5655f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "value", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetGeomapDefinitionRequestFormulaConditionalFormats]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetGeomapDefinitionRequestFormulaConditionalFormats]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetGeomapDefinitionRequestFormulaConditionalFormats]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2685c769d7ab322b1e6d84b39c4f4d7460cfc708095a1e66c7e4afc83bca077e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetGeomapDefinitionRequestFormulaLimit",
    jsii_struct_bases=[],
    name_mapping={"count": "count", "order": "order"},
)
class PowerpackWidgetGeomapDefinitionRequestFormulaLimit:
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        order: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param count: The number of results to return. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#count Powerpack#count}
        :param order: The direction of the sort. Valid values are ``asc``, ``desc``. Defaults to ``"desc"``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ad257f50ee33ebc1d0b70c1c8fc5ac4b55291db7b5d33991c34532aa6cddb2da)
            check_type(argname="argument count", value=count, expected_type=type_hints["count"])
            check_type(argname="argument order", value=order, expected_type=type_hints["order"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if count is not None:
            self._values["count"] = count
        if order is not None:
            self._values["order"] = order

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''The number of results to return.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#count Powerpack#count}
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def order(self) -> typing.Optional[builtins.str]:
        '''The direction of the sort. Valid values are ``asc``, ``desc``. Defaults to ``"desc"``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        result = self._values.get("order")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetGeomapDefinitionRequestFormulaLimit(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetGeomapDefinitionRequestFormulaLimitOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetGeomapDefinitionRequestFormulaLimitOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d08aead0b4d893f6d93d902097c5ca63ddd14b3a96c0335cdcb2e0ad9872fb25)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetCount")
    def reset_count(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCount", []))

    @jsii.member(jsii_name="resetOrder")
    def reset_order(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetOrder", []))

    @builtins.property
    @jsii.member(jsii_name="countInput")
    def count_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "countInput"))

    @builtins.property
    @jsii.member(jsii_name="orderInput")
    def order_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "orderInput"))

    @builtins.property
    @jsii.member(jsii_name="count")
    def count(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "count"))

    @count.setter
    def count(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__58ddfe54b18b94fe65a1c607491b45bb92a4eedfe367ae8ed10a817f37160613)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "count", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="order")
    def order(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "order"))

    @order.setter
    def order(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__06bebae2a8b820dea5301b79de5bf42c0ad10362ef44e39203a656bfdd866df9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "order", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetGeomapDefinitionRequestFormulaLimit]:
        return typing.cast(typing.Optional[PowerpackWidgetGeomapDefinitionRequestFormulaLimit], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetGeomapDefinitionRequestFormulaLimit],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b2e0001315d9d4a0ecc235b92375e97910007d02c26235af3f382e681451b684)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetGeomapDefinitionRequestFormulaList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetGeomapDefinitionRequestFormulaList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b1d2199ae74c8ca9149ac6dd104a85882cccb11014e4f6e636d9b3d40e7a1349)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetGeomapDefinitionRequestFormulaOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b82f31292d07bbd61a8ce55a323dde4fab2de97d57aea37333059c5d51edd9b8)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetGeomapDefinitionRequestFormulaOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b67192428f66e32b4e96e70f80e1a839ff93fc6dc81d572eb33f338614567f28)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__27c9e4e89039599cab010665da4a05e541a00a91ea5ee13d466dea5a6cb5b788)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a27a97c5eca1800c6b9035bf277885610cbee3d2fc2e93c0df07a0c7a9dae975)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetGeomapDefinitionRequestFormula]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetGeomapDefinitionRequestFormula]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetGeomapDefinitionRequestFormula]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__41a9a8791bb077c6a2c3c3b22d21eed28aea5bdebca4c0b9f24301456c5cb3ed)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormat",
    jsii_struct_bases=[],
    name_mapping={"unit": "unit", "unit_scale": "unitScale"},
)
class PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormat:
    def __init__(
        self,
        *,
        unit: typing.Union["PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormatUnit", typing.Dict[builtins.str, typing.Any]],
        unit_scale: typing.Optional[typing.Union["PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormatUnitScale", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param unit: unit block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit Powerpack#unit}
        :param unit_scale: unit_scale block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit_scale Powerpack#unit_scale}
        '''
        if isinstance(unit, dict):
            unit = PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormatUnit(**unit)
        if isinstance(unit_scale, dict):
            unit_scale = PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormatUnitScale(**unit_scale)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0f35e895ffbd43c367c7968cc49002ad740795eb274b8254f237e910b3f1596a)
            check_type(argname="argument unit", value=unit, expected_type=type_hints["unit"])
            check_type(argname="argument unit_scale", value=unit_scale, expected_type=type_hints["unit_scale"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "unit": unit,
        }
        if unit_scale is not None:
            self._values["unit_scale"] = unit_scale

    @builtins.property
    def unit(self) -> "PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormatUnit":
        '''unit block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit Powerpack#unit}
        '''
        result = self._values.get("unit")
        assert result is not None, "Required property 'unit' is missing"
        return typing.cast("PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormatUnit", result)

    @builtins.property
    def unit_scale(
        self,
    ) -> typing.Optional["PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormatUnitScale"]:
        '''unit_scale block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit_scale Powerpack#unit_scale}
        '''
        result = self._values.get("unit_scale")
        return typing.cast(typing.Optional["PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormatUnitScale"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormat(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormatOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormatOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7b78ce913694a53c8d8ab69f142a284fb3ac1a0acad2a8613a460facd60f190e)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putUnit")
    def put_unit(
        self,
        *,
        canonical: typing.Optional[typing.Union["PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormatUnitCanonical", typing.Dict[builtins.str, typing.Any]]] = None,
        custom: typing.Optional[typing.Union["PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormatUnitCustom", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param canonical: canonical block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#canonical Powerpack#canonical}
        :param custom: custom block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom Powerpack#custom}
        '''
        value = PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormatUnit(
            canonical=canonical, custom=custom
        )

        return typing.cast(None, jsii.invoke(self, "putUnit", [value]))

    @jsii.member(jsii_name="putUnitScale")
    def put_unit_scale(self, *, unit_name: builtins.str) -> None:
        '''
        :param unit_name: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit_name Powerpack#unit_name}.
        '''
        value = PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormatUnitScale(
            unit_name=unit_name
        )

        return typing.cast(None, jsii.invoke(self, "putUnitScale", [value]))

    @jsii.member(jsii_name="resetUnitScale")
    def reset_unit_scale(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetUnitScale", []))

    @builtins.property
    @jsii.member(jsii_name="unit")
    def unit(
        self,
    ) -> "PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormatUnitOutputReference":
        return typing.cast("PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormatUnitOutputReference", jsii.get(self, "unit"))

    @builtins.property
    @jsii.member(jsii_name="unitScale")
    def unit_scale(
        self,
    ) -> "PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormatUnitScaleOutputReference":
        return typing.cast("PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormatUnitScaleOutputReference", jsii.get(self, "unitScale"))

    @builtins.property
    @jsii.member(jsii_name="unitInput")
    def unit_input(
        self,
    ) -> typing.Optional["PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormatUnit"]:
        return typing.cast(typing.Optional["PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormatUnit"], jsii.get(self, "unitInput"))

    @builtins.property
    @jsii.member(jsii_name="unitScaleInput")
    def unit_scale_input(
        self,
    ) -> typing.Optional["PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormatUnitScale"]:
        return typing.cast(typing.Optional["PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormatUnitScale"], jsii.get(self, "unitScaleInput"))

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormat]:
        return typing.cast(typing.Optional[PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormat], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormat],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__398742b3f2f616aed4af0237c44df9cdcfbcb939be6022d824926696f23480a7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormatUnit",
    jsii_struct_bases=[],
    name_mapping={"canonical": "canonical", "custom": "custom"},
)
class PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormatUnit:
    def __init__(
        self,
        *,
        canonical: typing.Optional[typing.Union["PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormatUnitCanonical", typing.Dict[builtins.str, typing.Any]]] = None,
        custom: typing.Optional[typing.Union["PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormatUnitCustom", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param canonical: canonical block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#canonical Powerpack#canonical}
        :param custom: custom block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom Powerpack#custom}
        '''
        if isinstance(canonical, dict):
            canonical = PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormatUnitCanonical(**canonical)
        if isinstance(custom, dict):
            custom = PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormatUnitCustom(**custom)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bb139f26cdf7c24923a09ccd1f9ead3f4e78526385e3ad5539f5fe111bad6cee)
            check_type(argname="argument canonical", value=canonical, expected_type=type_hints["canonical"])
            check_type(argname="argument custom", value=custom, expected_type=type_hints["custom"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if canonical is not None:
            self._values["canonical"] = canonical
        if custom is not None:
            self._values["custom"] = custom

    @builtins.property
    def canonical(
        self,
    ) -> typing.Optional["PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormatUnitCanonical"]:
        '''canonical block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#canonical Powerpack#canonical}
        '''
        result = self._values.get("canonical")
        return typing.cast(typing.Optional["PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormatUnitCanonical"], result)

    @builtins.property
    def custom(
        self,
    ) -> typing.Optional["PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormatUnitCustom"]:
        '''custom block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom Powerpack#custom}
        '''
        result = self._values.get("custom")
        return typing.cast(typing.Optional["PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormatUnitCustom"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormatUnit(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormatUnitCanonical",
    jsii_struct_bases=[],
    name_mapping={"unit_name": "unitName", "per_unit_name": "perUnitName"},
)
class PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormatUnitCanonical:
    def __init__(
        self,
        *,
        unit_name: builtins.str,
        per_unit_name: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param unit_name: Unit name. It should be in singular form ('megabyte' and not 'megabytes'). Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit_name Powerpack#unit_name}
        :param per_unit_name: per unit name. If you want to represent megabytes/s, you set 'unit_name' = 'megabyte' and 'per_unit_name = 'second'. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#per_unit_name Powerpack#per_unit_name}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d2f8cd55698c9c9c092a61badd6cf065e9292cefb70e5a0d35b953bfa0229097)
            check_type(argname="argument unit_name", value=unit_name, expected_type=type_hints["unit_name"])
            check_type(argname="argument per_unit_name", value=per_unit_name, expected_type=type_hints["per_unit_name"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "unit_name": unit_name,
        }
        if per_unit_name is not None:
            self._values["per_unit_name"] = per_unit_name

    @builtins.property
    def unit_name(self) -> builtins.str:
        '''Unit name. It should be in singular form ('megabyte' and not 'megabytes').

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit_name Powerpack#unit_name}
        '''
        result = self._values.get("unit_name")
        assert result is not None, "Required property 'unit_name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def per_unit_name(self) -> typing.Optional[builtins.str]:
        '''per unit name. If you want to represent megabytes/s, you set 'unit_name' = 'megabyte' and 'per_unit_name = 'second'.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#per_unit_name Powerpack#per_unit_name}
        '''
        result = self._values.get("per_unit_name")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormatUnitCanonical(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormatUnitCanonicalOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormatUnitCanonicalOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__70e79e02486c53b25d50f13dbf21e4791fef9b16fc99609fc8c231d93fc6094b)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetPerUnitName")
    def reset_per_unit_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPerUnitName", []))

    @builtins.property
    @jsii.member(jsii_name="perUnitNameInput")
    def per_unit_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "perUnitNameInput"))

    @builtins.property
    @jsii.member(jsii_name="unitNameInput")
    def unit_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "unitNameInput"))

    @builtins.property
    @jsii.member(jsii_name="perUnitName")
    def per_unit_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "perUnitName"))

    @per_unit_name.setter
    def per_unit_name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0ec7188f435a199d27f3ba4e73d2fa4f76a901b7189e22309afd618dea0f9e03)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "perUnitName", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="unitName")
    def unit_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "unitName"))

    @unit_name.setter
    def unit_name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b7af477c9e9843c02474f6f75433fea67d3702afc09bd71a11f04f4cfa3e84f4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "unitName", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormatUnitCanonical]:
        return typing.cast(typing.Optional[PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormatUnitCanonical], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormatUnitCanonical],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5d48f593ad3e04f6d6070cf54299d175bc80209e4752c98e64fd42814acc9dd7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormatUnitCustom",
    jsii_struct_bases=[],
    name_mapping={"label": "label"},
)
class PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormatUnitCustom:
    def __init__(self, *, label: builtins.str) -> None:
        '''
        :param label: Unit label. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#label Powerpack#label}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__865b3766172380dc6d79676996b9038c9c7a2f5365a23826b322bbf715b3d1d9)
            check_type(argname="argument label", value=label, expected_type=type_hints["label"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "label": label,
        }

    @builtins.property
    def label(self) -> builtins.str:
        '''Unit label.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#label Powerpack#label}
        '''
        result = self._values.get("label")
        assert result is not None, "Required property 'label' is missing"
        return typing.cast(builtins.str, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormatUnitCustom(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormatUnitCustomOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormatUnitCustomOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bd44c3d334c9f5c01698624eabc1062f82afcf6b8ffdbde98b8039b857701322)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @builtins.property
    @jsii.member(jsii_name="labelInput")
    def label_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "labelInput"))

    @builtins.property
    @jsii.member(jsii_name="label")
    def label(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "label"))

    @label.setter
    def label(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__356469c56cc8be8acd8953ac46b05d739567e95c0590aa56eeb89a6c250b8022)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "label", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormatUnitCustom]:
        return typing.cast(typing.Optional[PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormatUnitCustom], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormatUnitCustom],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ad39396631fc75fc18abb225cb0a7210591f26f7f3ef16eb290cedcc474452b7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormatUnitOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormatUnitOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__804e21f641f37db6c86431ecaa336634c58ae316ec21bf27315e495cae262886)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putCanonical")
    def put_canonical(
        self,
        *,
        unit_name: builtins.str,
        per_unit_name: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param unit_name: Unit name. It should be in singular form ('megabyte' and not 'megabytes'). Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit_name Powerpack#unit_name}
        :param per_unit_name: per unit name. If you want to represent megabytes/s, you set 'unit_name' = 'megabyte' and 'per_unit_name = 'second'. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#per_unit_name Powerpack#per_unit_name}
        '''
        value = PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormatUnitCanonical(
            unit_name=unit_name, per_unit_name=per_unit_name
        )

        return typing.cast(None, jsii.invoke(self, "putCanonical", [value]))

    @jsii.member(jsii_name="putCustom")
    def put_custom(self, *, label: builtins.str) -> None:
        '''
        :param label: Unit label. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#label Powerpack#label}
        '''
        value = PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormatUnitCustom(
            label=label
        )

        return typing.cast(None, jsii.invoke(self, "putCustom", [value]))

    @jsii.member(jsii_name="resetCanonical")
    def reset_canonical(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCanonical", []))

    @jsii.member(jsii_name="resetCustom")
    def reset_custom(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCustom", []))

    @builtins.property
    @jsii.member(jsii_name="canonical")
    def canonical(
        self,
    ) -> PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormatUnitCanonicalOutputReference:
        return typing.cast(PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormatUnitCanonicalOutputReference, jsii.get(self, "canonical"))

    @builtins.property
    @jsii.member(jsii_name="custom")
    def custom(
        self,
    ) -> PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormatUnitCustomOutputReference:
        return typing.cast(PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormatUnitCustomOutputReference, jsii.get(self, "custom"))

    @builtins.property
    @jsii.member(jsii_name="canonicalInput")
    def canonical_input(
        self,
    ) -> typing.Optional[PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormatUnitCanonical]:
        return typing.cast(typing.Optional[PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormatUnitCanonical], jsii.get(self, "canonicalInput"))

    @builtins.property
    @jsii.member(jsii_name="customInput")
    def custom_input(
        self,
    ) -> typing.Optional[PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormatUnitCustom]:
        return typing.cast(typing.Optional[PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormatUnitCustom], jsii.get(self, "customInput"))

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormatUnit]:
        return typing.cast(typing.Optional[PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormatUnit], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormatUnit],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7901505f7f79fd60c42f1e890f68e8d3e0e36008dc1251806b121f01b29c6c07)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormatUnitScale",
    jsii_struct_bases=[],
    name_mapping={"unit_name": "unitName"},
)
class PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormatUnitScale:
    def __init__(self, *, unit_name: builtins.str) -> None:
        '''
        :param unit_name: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit_name Powerpack#unit_name}.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9dcbbaca0a699b35db81843ec384721b24806b6ce0abc3fdd28e26c827b19e16)
            check_type(argname="argument unit_name", value=unit_name, expected_type=type_hints["unit_name"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "unit_name": unit_name,
        }

    @builtins.property
    def unit_name(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit_name Powerpack#unit_name}.'''
        result = self._values.get("unit_name")
        assert result is not None, "Required property 'unit_name' is missing"
        return typing.cast(builtins.str, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormatUnitScale(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormatUnitScaleOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormatUnitScaleOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9e3555ca875ec41b3851aab4933cc511153ab648e654a88b2a4716cf5f97c80c)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @builtins.property
    @jsii.member(jsii_name="unitNameInput")
    def unit_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "unitNameInput"))

    @builtins.property
    @jsii.member(jsii_name="unitName")
    def unit_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "unitName"))

    @unit_name.setter
    def unit_name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1bd7ccfe758f12935d7448985a4d4f1ee7ea86a16be72e52f4c9d4a7475b57c2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "unitName", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormatUnitScale]:
        return typing.cast(typing.Optional[PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormatUnitScale], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormatUnitScale],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2b03b39e4dfdd831af0f67a33ee34e7146cf57c12072c191c67e6776f9356d03)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetGeomapDefinitionRequestFormulaOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetGeomapDefinitionRequestFormulaOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7a1c30581958adec7f3be59670b479787174e39dfa3d7e4c7770a3ca10f84e91)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putConditionalFormats")
    def put_conditional_formats(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetGeomapDefinitionRequestFormulaConditionalFormats, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__32c2f979a6287376b51ef755c3b006ea4b2e6836effa3ab47e842d8a2979ae87)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putConditionalFormats", [value]))

    @jsii.member(jsii_name="putLimit")
    def put_limit(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        order: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param count: The number of results to return. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#count Powerpack#count}
        :param order: The direction of the sort. Valid values are ``asc``, ``desc``. Defaults to ``"desc"``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        value = PowerpackWidgetGeomapDefinitionRequestFormulaLimit(
            count=count, order=order
        )

        return typing.cast(None, jsii.invoke(self, "putLimit", [value]))

    @jsii.member(jsii_name="putNumberFormat")
    def put_number_format(
        self,
        *,
        unit: typing.Union[PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormatUnit, typing.Dict[builtins.str, typing.Any]],
        unit_scale: typing.Optional[typing.Union[PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormatUnitScale, typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param unit: unit block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit Powerpack#unit}
        :param unit_scale: unit_scale block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit_scale Powerpack#unit_scale}
        '''
        value = PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormat(
            unit=unit, unit_scale=unit_scale
        )

        return typing.cast(None, jsii.invoke(self, "putNumberFormat", [value]))

    @jsii.member(jsii_name="putStyle")
    def put_style(
        self,
        *,
        palette: typing.Optional[builtins.str] = None,
        palette_index: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param palette: The color palette used to display the formula. A guide to the available color palettes can be found at https://docs.datadoghq.com/dashboards/guide/widget_colors. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette Powerpack#palette}
        :param palette_index: Index specifying which color to use within the palette. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette_index Powerpack#palette_index}
        '''
        value = PowerpackWidgetGeomapDefinitionRequestFormulaStyle(
            palette=palette, palette_index=palette_index
        )

        return typing.cast(None, jsii.invoke(self, "putStyle", [value]))

    @jsii.member(jsii_name="resetAlias")
    def reset_alias(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAlias", []))

    @jsii.member(jsii_name="resetCellDisplayMode")
    def reset_cell_display_mode(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCellDisplayMode", []))

    @jsii.member(jsii_name="resetConditionalFormats")
    def reset_conditional_formats(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetConditionalFormats", []))

    @jsii.member(jsii_name="resetLimit")
    def reset_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLimit", []))

    @jsii.member(jsii_name="resetNumberFormat")
    def reset_number_format(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetNumberFormat", []))

    @jsii.member(jsii_name="resetStyle")
    def reset_style(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetStyle", []))

    @builtins.property
    @jsii.member(jsii_name="conditionalFormats")
    def conditional_formats(
        self,
    ) -> PowerpackWidgetGeomapDefinitionRequestFormulaConditionalFormatsList:
        return typing.cast(PowerpackWidgetGeomapDefinitionRequestFormulaConditionalFormatsList, jsii.get(self, "conditionalFormats"))

    @builtins.property
    @jsii.member(jsii_name="limit")
    def limit(
        self,
    ) -> PowerpackWidgetGeomapDefinitionRequestFormulaLimitOutputReference:
        return typing.cast(PowerpackWidgetGeomapDefinitionRequestFormulaLimitOutputReference, jsii.get(self, "limit"))

    @builtins.property
    @jsii.member(jsii_name="numberFormat")
    def number_format(
        self,
    ) -> PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormatOutputReference:
        return typing.cast(PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormatOutputReference, jsii.get(self, "numberFormat"))

    @builtins.property
    @jsii.member(jsii_name="style")
    def style(
        self,
    ) -> "PowerpackWidgetGeomapDefinitionRequestFormulaStyleOutputReference":
        return typing.cast("PowerpackWidgetGeomapDefinitionRequestFormulaStyleOutputReference", jsii.get(self, "style"))

    @builtins.property
    @jsii.member(jsii_name="aliasInput")
    def alias_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aliasInput"))

    @builtins.property
    @jsii.member(jsii_name="cellDisplayModeInput")
    def cell_display_mode_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "cellDisplayModeInput"))

    @builtins.property
    @jsii.member(jsii_name="conditionalFormatsInput")
    def conditional_formats_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetGeomapDefinitionRequestFormulaConditionalFormats]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetGeomapDefinitionRequestFormulaConditionalFormats]]], jsii.get(self, "conditionalFormatsInput"))

    @builtins.property
    @jsii.member(jsii_name="formulaExpressionInput")
    def formula_expression_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "formulaExpressionInput"))

    @builtins.property
    @jsii.member(jsii_name="limitInput")
    def limit_input(
        self,
    ) -> typing.Optional[PowerpackWidgetGeomapDefinitionRequestFormulaLimit]:
        return typing.cast(typing.Optional[PowerpackWidgetGeomapDefinitionRequestFormulaLimit], jsii.get(self, "limitInput"))

    @builtins.property
    @jsii.member(jsii_name="numberFormatInput")
    def number_format_input(
        self,
    ) -> typing.Optional[PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormat]:
        return typing.cast(typing.Optional[PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormat], jsii.get(self, "numberFormatInput"))

    @builtins.property
    @jsii.member(jsii_name="styleInput")
    def style_input(
        self,
    ) -> typing.Optional["PowerpackWidgetGeomapDefinitionRequestFormulaStyle"]:
        return typing.cast(typing.Optional["PowerpackWidgetGeomapDefinitionRequestFormulaStyle"], jsii.get(self, "styleInput"))

    @builtins.property
    @jsii.member(jsii_name="alias")
    def alias(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "alias"))

    @alias.setter
    def alias(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b476f988760164aea8af56ffe449b305fcd64ade856e063e3c8f50b46e88766d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "alias", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="cellDisplayMode")
    def cell_display_mode(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "cellDisplayMode"))

    @cell_display_mode.setter
    def cell_display_mode(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ed02e8034814e3d1c861dfa135f00a8a1dab7f170a23159af272aae6f08a6c8f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "cellDisplayMode", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="formulaExpression")
    def formula_expression(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "formulaExpression"))

    @formula_expression.setter
    def formula_expression(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__60cc2f3451146c9cf970c3126f346409ea865bf3e9187558b54a8fbe95ea7bba)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "formulaExpression", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetGeomapDefinitionRequestFormula]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetGeomapDefinitionRequestFormula]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetGeomapDefinitionRequestFormula]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__97312d5f433f0bc134a8005b4aa3a93044a45fe1e34d618636cdc8672d81c426)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetGeomapDefinitionRequestFormulaStyle",
    jsii_struct_bases=[],
    name_mapping={"palette": "palette", "palette_index": "paletteIndex"},
)
class PowerpackWidgetGeomapDefinitionRequestFormulaStyle:
    def __init__(
        self,
        *,
        palette: typing.Optional[builtins.str] = None,
        palette_index: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param palette: The color palette used to display the formula. A guide to the available color palettes can be found at https://docs.datadoghq.com/dashboards/guide/widget_colors. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette Powerpack#palette}
        :param palette_index: Index specifying which color to use within the palette. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette_index Powerpack#palette_index}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5020be501265e4bc2ffcc1d32d8673efd7943917ecba941f8a1baefa95cc72e7)
            check_type(argname="argument palette", value=palette, expected_type=type_hints["palette"])
            check_type(argname="argument palette_index", value=palette_index, expected_type=type_hints["palette_index"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if palette is not None:
            self._values["palette"] = palette
        if palette_index is not None:
            self._values["palette_index"] = palette_index

    @builtins.property
    def palette(self) -> typing.Optional[builtins.str]:
        '''The color palette used to display the formula.

        A guide to the available color palettes can be found at https://docs.datadoghq.com/dashboards/guide/widget_colors.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette Powerpack#palette}
        '''
        result = self._values.get("palette")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def palette_index(self) -> typing.Optional[jsii.Number]:
        '''Index specifying which color to use within the palette.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette_index Powerpack#palette_index}
        '''
        result = self._values.get("palette_index")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetGeomapDefinitionRequestFormulaStyle(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetGeomapDefinitionRequestFormulaStyleOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetGeomapDefinitionRequestFormulaStyleOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e3ccf8ad4b5d03e3a35632df53e0ff1538ac317c40edd7965d7c8d9fd282ac18)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetPalette")
    def reset_palette(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPalette", []))

    @jsii.member(jsii_name="resetPaletteIndex")
    def reset_palette_index(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPaletteIndex", []))

    @builtins.property
    @jsii.member(jsii_name="paletteIndexInput")
    def palette_index_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "paletteIndexInput"))

    @builtins.property
    @jsii.member(jsii_name="paletteInput")
    def palette_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "paletteInput"))

    @builtins.property
    @jsii.member(jsii_name="palette")
    def palette(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "palette"))

    @palette.setter
    def palette(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__01d2389fc6b2abf8fd34b037b35922d7ebfd3ce425fee1b40d8554c7ad622046)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "palette", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="paletteIndex")
    def palette_index(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "paletteIndex"))

    @palette_index.setter
    def palette_index(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e5e9b2bcd615c9f6fd91320b41b606c8f3261482d47034edcaa29ec7b770f3a9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "paletteIndex", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetGeomapDefinitionRequestFormulaStyle]:
        return typing.cast(typing.Optional[PowerpackWidgetGeomapDefinitionRequestFormulaStyle], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetGeomapDefinitionRequestFormulaStyle],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a2c3b6d1e12b7dadcdb93d18da03601e47cf0eebc5d0ff962b381d73925ec6e1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetGeomapDefinitionRequestList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetGeomapDefinitionRequestList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8b135f8efc8e098c4f42b78d36b9790404b4884294bc2384feeb128d8d68ca64)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetGeomapDefinitionRequestOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1645c737f0bb86bc13d6432468f0cf1895f7538368b9136e40726c2513d3c0da)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetGeomapDefinitionRequestOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3abf091960f1240870e42dad7f0d292305ad576cee159eb37475c1522169c35e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__167187c962db71a82ebd803c9df23a08b1332ba9b65a2a6bca85d2e644055681)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6bac72b52959ff48e59956d75690ebb696c233e7ed0756f81456533536abe4f3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetGeomapDefinitionRequest]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetGeomapDefinitionRequest]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetGeomapDefinitionRequest]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__49eb8c109295ad0aeba6fec23d8edfb28c4476fd69fa83c7d829252f52b2f0a4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetGeomapDefinitionRequestLogQuery",
    jsii_struct_bases=[],
    name_mapping={
        "index": "index",
        "compute_query": "computeQuery",
        "group_by": "groupBy",
        "multi_compute": "multiCompute",
        "search_query": "searchQuery",
    },
)
class PowerpackWidgetGeomapDefinitionRequestLogQuery:
    def __init__(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union["PowerpackWidgetGeomapDefinitionRequestLogQueryComputeQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetGeomapDefinitionRequestLogQueryGroupBy", typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetGeomapDefinitionRequestLogQueryMultiCompute", typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        if isinstance(compute_query, dict):
            compute_query = PowerpackWidgetGeomapDefinitionRequestLogQueryComputeQuery(**compute_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f3917b81f2cc782750313d64e5b589772ec140e25852c442882092bd6a282acd)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
            check_type(argname="argument compute_query", value=compute_query, expected_type=type_hints["compute_query"])
            check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
            check_type(argname="argument multi_compute", value=multi_compute, expected_type=type_hints["multi_compute"])
            check_type(argname="argument search_query", value=search_query, expected_type=type_hints["search_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "index": index,
        }
        if compute_query is not None:
            self._values["compute_query"] = compute_query
        if group_by is not None:
            self._values["group_by"] = group_by
        if multi_compute is not None:
            self._values["multi_compute"] = multi_compute
        if search_query is not None:
            self._values["search_query"] = search_query

    @builtins.property
    def index(self) -> builtins.str:
        '''The name of the index to query.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        '''
        result = self._values.get("index")
        assert result is not None, "Required property 'index' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def compute_query(
        self,
    ) -> typing.Optional["PowerpackWidgetGeomapDefinitionRequestLogQueryComputeQuery"]:
        '''compute_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        '''
        result = self._values.get("compute_query")
        return typing.cast(typing.Optional["PowerpackWidgetGeomapDefinitionRequestLogQueryComputeQuery"], result)

    @builtins.property
    def group_by(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetGeomapDefinitionRequestLogQueryGroupBy"]]]:
        '''group_by block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        '''
        result = self._values.get("group_by")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetGeomapDefinitionRequestLogQueryGroupBy"]]], result)

    @builtins.property
    def multi_compute(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetGeomapDefinitionRequestLogQueryMultiCompute"]]]:
        '''multi_compute block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        '''
        result = self._values.get("multi_compute")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetGeomapDefinitionRequestLogQueryMultiCompute"]]], result)

    @builtins.property
    def search_query(self) -> typing.Optional[builtins.str]:
        '''The search query to use.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        result = self._values.get("search_query")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetGeomapDefinitionRequestLogQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetGeomapDefinitionRequestLogQueryComputeQuery",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetGeomapDefinitionRequestLogQueryComputeQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e62fde3df52992afaf9dc5787ab4e90981c6b3b8e6f4e0e5ea7106041c3f3bd1)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetGeomapDefinitionRequestLogQueryComputeQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetGeomapDefinitionRequestLogQueryComputeQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetGeomapDefinitionRequestLogQueryComputeQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5e79e9ff14268a7c2efc7773ed4284bab46d3f12a89d1a62d8b13e5068c73e65)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__706af005befe3cbdb4a30c0678556c6375099cab2837cebb0379a77f15819e99)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0dc461f1fb7b6dc9042e8e44f569cb4eb3fe232f1f96b1e407e1f0604e009a74)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__448c2d816005b7241ef03884c5ba6c06d7f533fa3964b62ddb3f4192d9ce780c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetGeomapDefinitionRequestLogQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetGeomapDefinitionRequestLogQueryComputeQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetGeomapDefinitionRequestLogQueryComputeQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__96ddb6079db390ee0717d5999dc0ded902cfbf057fc885a8db814ddb924e4f59)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetGeomapDefinitionRequestLogQueryGroupBy",
    jsii_struct_bases=[],
    name_mapping={"facet": "facet", "limit": "limit", "sort_query": "sortQuery"},
)
class PowerpackWidgetGeomapDefinitionRequestLogQueryGroupBy:
    def __init__(
        self,
        *,
        facet: typing.Optional[builtins.str] = None,
        limit: typing.Optional[jsii.Number] = None,
        sort_query: typing.Optional[typing.Union["PowerpackWidgetGeomapDefinitionRequestLogQueryGroupBySortQuery", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param limit: The maximum number of items in the group. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param sort_query: sort_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        if isinstance(sort_query, dict):
            sort_query = PowerpackWidgetGeomapDefinitionRequestLogQueryGroupBySortQuery(**sort_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__38bbf8cf4b6e6616a0a97ceeb4e4065dcbbec9314de44b00c53ad686b44d2be9)
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
            check_type(argname="argument sort_query", value=sort_query, expected_type=type_hints["sort_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if facet is not None:
            self._values["facet"] = facet
        if limit is not None:
            self._values["limit"] = limit
        if sort_query is not None:
            self._values["sort_query"] = sort_query

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def limit(self) -> typing.Optional[jsii.Number]:
        '''The maximum number of items in the group.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        '''
        result = self._values.get("limit")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def sort_query(
        self,
    ) -> typing.Optional["PowerpackWidgetGeomapDefinitionRequestLogQueryGroupBySortQuery"]:
        '''sort_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        result = self._values.get("sort_query")
        return typing.cast(typing.Optional["PowerpackWidgetGeomapDefinitionRequestLogQueryGroupBySortQuery"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetGeomapDefinitionRequestLogQueryGroupBy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetGeomapDefinitionRequestLogQueryGroupByList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetGeomapDefinitionRequestLogQueryGroupByList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7a40859f853d15c4f836275bb9335b40fba74d99334970e5b0ad6c78a0c906e8)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetGeomapDefinitionRequestLogQueryGroupByOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__136e5ecfaffcc731b154ee94f32f5b0e2e5f56e05a4ce1f5cb5a6553320327f9)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetGeomapDefinitionRequestLogQueryGroupByOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2d0ca90767612171294feaef88c967cef17eba9d1aae90adb2da61745f1f4013)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__075538fcca04c9b9abe213737299b57dcc10ff6f31785586b0e0badb5282a290)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0fddd65a685b1d092d0edd1edd70e48f26da0d37c14e214c939351b3074dba08)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetGeomapDefinitionRequestLogQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetGeomapDefinitionRequestLogQueryGroupBy]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetGeomapDefinitionRequestLogQueryGroupBy]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e84336d3999fb0f634fc8df511e9285f367b84499c232a6225cfa55574bb04be)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetGeomapDefinitionRequestLogQueryGroupByOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetGeomapDefinitionRequestLogQueryGroupByOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ae1001d053cdc7b00092f1c80fe40f953577495ea5b304b6d794087e7c5b6785)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putSortQuery")
    def put_sort_query(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        value = PowerpackWidgetGeomapDefinitionRequestLogQueryGroupBySortQuery(
            aggregation=aggregation, order=order, facet=facet
        )

        return typing.cast(None, jsii.invoke(self, "putSortQuery", [value]))

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetLimit")
    def reset_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLimit", []))

    @jsii.member(jsii_name="resetSortQuery")
    def reset_sort_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSortQuery", []))

    @builtins.property
    @jsii.member(jsii_name="sortQuery")
    def sort_query(
        self,
    ) -> "PowerpackWidgetGeomapDefinitionRequestLogQueryGroupBySortQueryOutputReference":
        return typing.cast("PowerpackWidgetGeomapDefinitionRequestLogQueryGroupBySortQueryOutputReference", jsii.get(self, "sortQuery"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="limitInput")
    def limit_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "limitInput"))

    @builtins.property
    @jsii.member(jsii_name="sortQueryInput")
    def sort_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetGeomapDefinitionRequestLogQueryGroupBySortQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetGeomapDefinitionRequestLogQueryGroupBySortQuery"], jsii.get(self, "sortQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b490d43d3f6a951b1522777f23e5dbd0a5f3cd9d0c6b841b84401c7aee350f14)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="limit")
    def limit(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "limit"))

    @limit.setter
    def limit(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1539853186580aa78e6c5867c257789073b11673679a0fd55d984068daa0b6af)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "limit", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetGeomapDefinitionRequestLogQueryGroupBy]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetGeomapDefinitionRequestLogQueryGroupBy]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetGeomapDefinitionRequestLogQueryGroupBy]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1ba171746917fcfed1325ab546af5f65f235ec59db5a21e07f584cdd94388ab1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetGeomapDefinitionRequestLogQueryGroupBySortQuery",
    jsii_struct_bases=[],
    name_mapping={"aggregation": "aggregation", "order": "order", "facet": "facet"},
)
class PowerpackWidgetGeomapDefinitionRequestLogQueryGroupBySortQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__19fa660d233a9f29bc4cb31a1784b528b55e1f512f01a03992154b2c954e311c)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument order", value=order, expected_type=type_hints["order"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
            "order": order,
        }
        if facet is not None:
            self._values["facet"] = facet

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def order(self) -> builtins.str:
        '''Widget sorting methods. Valid values are ``asc``, ``desc``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        result = self._values.get("order")
        assert result is not None, "Required property 'order' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetGeomapDefinitionRequestLogQueryGroupBySortQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetGeomapDefinitionRequestLogQueryGroupBySortQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetGeomapDefinitionRequestLogQueryGroupBySortQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8be2e2c2351adc8484fffa412f02f439aaac3e8c752dfb3c1d908646cc3c4037)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="orderInput")
    def order_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "orderInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0f19d6f39ca1d9d6a7fcb1b7e11d79726640dd1c77dad8d76fb21f5c89d5071b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e505c12d343faf4a478ca121fb7965fbaa999bc9d5fb37e423f91ac3d05cce5a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="order")
    def order(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "order"))

    @order.setter
    def order(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8a5702b93a492e6403f012260e7e76693dbcce88b39aa89ef8350497aab98872)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "order", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetGeomapDefinitionRequestLogQueryGroupBySortQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetGeomapDefinitionRequestLogQueryGroupBySortQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetGeomapDefinitionRequestLogQueryGroupBySortQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a063fe7e24d76338eb9f954b09f7bd3ab23244cec20ec1172da193938c1405c7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetGeomapDefinitionRequestLogQueryMultiCompute",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetGeomapDefinitionRequestLogQueryMultiCompute:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cea0cad7ec2595da67cf983d5a1acf926b43bcce5a50efb701cba4f65040cf54)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetGeomapDefinitionRequestLogQueryMultiCompute(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetGeomapDefinitionRequestLogQueryMultiComputeList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetGeomapDefinitionRequestLogQueryMultiComputeList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9c75169e6ade58ce126a1977e754a923c57652ff096b7cc60256ebfe868a26c8)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetGeomapDefinitionRequestLogQueryMultiComputeOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0970ea719b7eefa229d102a52c3c31e625d290e9d5306e812aac4be934704375)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetGeomapDefinitionRequestLogQueryMultiComputeOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f8a8393291aab67b4403435eb2dc2090686ca3200cde45c57b2a8679e2d1cc64)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__16d6b51f42be8fe56e5f915f278b0ea3a9fc71a9a204bc177686603d5df275f1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__147d285ad41088850a62388b0278f82e24faff7a42e9347b3eeb552738b212ee)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetGeomapDefinitionRequestLogQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetGeomapDefinitionRequestLogQueryMultiCompute]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetGeomapDefinitionRequestLogQueryMultiCompute]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__498eae70f044202592da8f4d00470558b6b4a95f1c0da33f1aa0c13e0ab45e41)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetGeomapDefinitionRequestLogQueryMultiComputeOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetGeomapDefinitionRequestLogQueryMultiComputeOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__40e7200e994d11917b4ae280531a66eed9a1058a76271eba70af9221f8b08776)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__761ced6c303e5f6aa7190071f973c3bd301d1af05a4fe9fe46a4afd3df44d675)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a48f25c3dfd80c178d6a576b26bad9c87516851c8231fb821b85639a967bedc5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__43088cb8a95d4cb6d199daf581e723a05c668ce05c7b581ef74c936e986bcae1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetGeomapDefinitionRequestLogQueryMultiCompute]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetGeomapDefinitionRequestLogQueryMultiCompute]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetGeomapDefinitionRequestLogQueryMultiCompute]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7fac72bc3b1628b982f04d2123225ad2067a0fc208fa0ffc970f98fcb4396c65)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetGeomapDefinitionRequestLogQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetGeomapDefinitionRequestLogQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3611bbed7a1ca2ee700287f4a0e235020d7036b83330a596c6224d2097b3d0b3)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putComputeQuery")
    def put_compute_query(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        value = PowerpackWidgetGeomapDefinitionRequestLogQueryComputeQuery(
            aggregation=aggregation, facet=facet, interval=interval
        )

        return typing.cast(None, jsii.invoke(self, "putComputeQuery", [value]))

    @jsii.member(jsii_name="putGroupBy")
    def put_group_by(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetGeomapDefinitionRequestLogQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1d8a32fcf61c26e49921fab6fb5cfbb44b1955fe423ce48b8bbbacf58a843333)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putGroupBy", [value]))

    @jsii.member(jsii_name="putMultiCompute")
    def put_multi_compute(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetGeomapDefinitionRequestLogQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__aab0023cba58e644a24a9e96aff9d6ca77f974a7eca086f1a2af246347d0014e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putMultiCompute", [value]))

    @jsii.member(jsii_name="resetComputeQuery")
    def reset_compute_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetComputeQuery", []))

    @jsii.member(jsii_name="resetGroupBy")
    def reset_group_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGroupBy", []))

    @jsii.member(jsii_name="resetMultiCompute")
    def reset_multi_compute(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMultiCompute", []))

    @jsii.member(jsii_name="resetSearchQuery")
    def reset_search_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSearchQuery", []))

    @builtins.property
    @jsii.member(jsii_name="computeQuery")
    def compute_query(
        self,
    ) -> PowerpackWidgetGeomapDefinitionRequestLogQueryComputeQueryOutputReference:
        return typing.cast(PowerpackWidgetGeomapDefinitionRequestLogQueryComputeQueryOutputReference, jsii.get(self, "computeQuery"))

    @builtins.property
    @jsii.member(jsii_name="groupBy")
    def group_by(self) -> PowerpackWidgetGeomapDefinitionRequestLogQueryGroupByList:
        return typing.cast(PowerpackWidgetGeomapDefinitionRequestLogQueryGroupByList, jsii.get(self, "groupBy"))

    @builtins.property
    @jsii.member(jsii_name="multiCompute")
    def multi_compute(
        self,
    ) -> PowerpackWidgetGeomapDefinitionRequestLogQueryMultiComputeList:
        return typing.cast(PowerpackWidgetGeomapDefinitionRequestLogQueryMultiComputeList, jsii.get(self, "multiCompute"))

    @builtins.property
    @jsii.member(jsii_name="computeQueryInput")
    def compute_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetGeomapDefinitionRequestLogQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetGeomapDefinitionRequestLogQueryComputeQuery], jsii.get(self, "computeQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="groupByInput")
    def group_by_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetGeomapDefinitionRequestLogQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetGeomapDefinitionRequestLogQueryGroupBy]]], jsii.get(self, "groupByInput"))

    @builtins.property
    @jsii.member(jsii_name="indexInput")
    def index_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "indexInput"))

    @builtins.property
    @jsii.member(jsii_name="multiComputeInput")
    def multi_compute_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetGeomapDefinitionRequestLogQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetGeomapDefinitionRequestLogQueryMultiCompute]]], jsii.get(self, "multiComputeInput"))

    @builtins.property
    @jsii.member(jsii_name="searchQueryInput")
    def search_query_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "searchQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="index")
    def index(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "index"))

    @index.setter
    def index(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d466ac5b24647f7077bbb81d8c10c9e4cd87a661dc6e45e044a04e44c066dca8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "index", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="searchQuery")
    def search_query(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "searchQuery"))

    @search_query.setter
    def search_query(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2abce68517a003abf118a57fd4b362a9faadd2c5d61b0be34839158a3e5597c2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "searchQuery", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetGeomapDefinitionRequestLogQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetGeomapDefinitionRequestLogQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetGeomapDefinitionRequestLogQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__12fdd0e8737f7b8109909808f38e68a8b9a3e40d4811d70f14bbbef83a0935e0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetGeomapDefinitionRequestOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetGeomapDefinitionRequestOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e31cf41ffefd2c17c35d491101263d2530c68694d75e373e74a13aadd9dbcb49)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putFormula")
    def put_formula(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetGeomapDefinitionRequestFormula, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6fbb79bd390f06eeb1ea7f72882b2d048bbea6835b8b3fbfa5ff556b645fae30)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putFormula", [value]))

    @jsii.member(jsii_name="putLogQuery")
    def put_log_query(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union[PowerpackWidgetGeomapDefinitionRequestLogQueryComputeQuery, typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetGeomapDefinitionRequestLogQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetGeomapDefinitionRequestLogQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        value = PowerpackWidgetGeomapDefinitionRequestLogQuery(
            index=index,
            compute_query=compute_query,
            group_by=group_by,
            multi_compute=multi_compute,
            search_query=search_query,
        )

        return typing.cast(None, jsii.invoke(self, "putLogQuery", [value]))

    @jsii.member(jsii_name="putQuery")
    def put_query(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetGeomapDefinitionRequestQuery", typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7d666c5172f5830a54156cde53e0476bad55cc058d3b4575cef78ac4c2ba578a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putQuery", [value]))

    @jsii.member(jsii_name="putRumQuery")
    def put_rum_query(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union["PowerpackWidgetGeomapDefinitionRequestRumQueryComputeQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetGeomapDefinitionRequestRumQueryGroupBy", typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetGeomapDefinitionRequestRumQueryMultiCompute", typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        value = PowerpackWidgetGeomapDefinitionRequestRumQuery(
            index=index,
            compute_query=compute_query,
            group_by=group_by,
            multi_compute=multi_compute,
            search_query=search_query,
        )

        return typing.cast(None, jsii.invoke(self, "putRumQuery", [value]))

    @jsii.member(jsii_name="resetFormula")
    def reset_formula(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFormula", []))

    @jsii.member(jsii_name="resetLogQuery")
    def reset_log_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLogQuery", []))

    @jsii.member(jsii_name="resetQ")
    def reset_q(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetQ", []))

    @jsii.member(jsii_name="resetQuery")
    def reset_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetQuery", []))

    @jsii.member(jsii_name="resetRumQuery")
    def reset_rum_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetRumQuery", []))

    @builtins.property
    @jsii.member(jsii_name="formula")
    def formula(self) -> PowerpackWidgetGeomapDefinitionRequestFormulaList:
        return typing.cast(PowerpackWidgetGeomapDefinitionRequestFormulaList, jsii.get(self, "formula"))

    @builtins.property
    @jsii.member(jsii_name="logQuery")
    def log_query(
        self,
    ) -> PowerpackWidgetGeomapDefinitionRequestLogQueryOutputReference:
        return typing.cast(PowerpackWidgetGeomapDefinitionRequestLogQueryOutputReference, jsii.get(self, "logQuery"))

    @builtins.property
    @jsii.member(jsii_name="query")
    def query(self) -> "PowerpackWidgetGeomapDefinitionRequestQueryList":
        return typing.cast("PowerpackWidgetGeomapDefinitionRequestQueryList", jsii.get(self, "query"))

    @builtins.property
    @jsii.member(jsii_name="rumQuery")
    def rum_query(
        self,
    ) -> "PowerpackWidgetGeomapDefinitionRequestRumQueryOutputReference":
        return typing.cast("PowerpackWidgetGeomapDefinitionRequestRumQueryOutputReference", jsii.get(self, "rumQuery"))

    @builtins.property
    @jsii.member(jsii_name="formulaInput")
    def formula_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetGeomapDefinitionRequestFormula]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetGeomapDefinitionRequestFormula]]], jsii.get(self, "formulaInput"))

    @builtins.property
    @jsii.member(jsii_name="logQueryInput")
    def log_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetGeomapDefinitionRequestLogQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetGeomapDefinitionRequestLogQuery], jsii.get(self, "logQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="qInput")
    def q_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "qInput"))

    @builtins.property
    @jsii.member(jsii_name="queryInput")
    def query_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetGeomapDefinitionRequestQuery"]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetGeomapDefinitionRequestQuery"]]], jsii.get(self, "queryInput"))

    @builtins.property
    @jsii.member(jsii_name="rumQueryInput")
    def rum_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetGeomapDefinitionRequestRumQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetGeomapDefinitionRequestRumQuery"], jsii.get(self, "rumQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="q")
    def q(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "q"))

    @q.setter
    def q(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__63da8cf88659eaf13a2bb6e9fe26f656d1d3c29b7c2198b18c8240f2968037ac)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "q", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetGeomapDefinitionRequest]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetGeomapDefinitionRequest]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetGeomapDefinitionRequest]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__be8f90ecc6b2241bcd21244a9808885ebe8d233d8985d982adf8414357358268)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetGeomapDefinitionRequestQuery",
    jsii_struct_bases=[],
    name_mapping={
        "apm_dependency_stats_query": "apmDependencyStatsQuery",
        "apm_resource_stats_query": "apmResourceStatsQuery",
        "cloud_cost_query": "cloudCostQuery",
        "event_query": "eventQuery",
        "metric_query": "metricQuery",
        "process_query": "processQuery",
        "slo_query": "sloQuery",
    },
)
class PowerpackWidgetGeomapDefinitionRequestQuery:
    def __init__(
        self,
        *,
        apm_dependency_stats_query: typing.Optional[typing.Union["PowerpackWidgetGeomapDefinitionRequestQueryApmDependencyStatsQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        apm_resource_stats_query: typing.Optional[typing.Union["PowerpackWidgetGeomapDefinitionRequestQueryApmResourceStatsQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        cloud_cost_query: typing.Optional[typing.Union["PowerpackWidgetGeomapDefinitionRequestQueryCloudCostQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        event_query: typing.Optional[typing.Union["PowerpackWidgetGeomapDefinitionRequestQueryEventQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        metric_query: typing.Optional[typing.Union["PowerpackWidgetGeomapDefinitionRequestQueryMetricQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        process_query: typing.Optional[typing.Union["PowerpackWidgetGeomapDefinitionRequestQueryProcessQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        slo_query: typing.Optional[typing.Union["PowerpackWidgetGeomapDefinitionRequestQuerySloQuery", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param apm_dependency_stats_query: apm_dependency_stats_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#apm_dependency_stats_query Powerpack#apm_dependency_stats_query}
        :param apm_resource_stats_query: apm_resource_stats_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#apm_resource_stats_query Powerpack#apm_resource_stats_query}
        :param cloud_cost_query: cloud_cost_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cloud_cost_query Powerpack#cloud_cost_query}
        :param event_query: event_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#event_query Powerpack#event_query}
        :param metric_query: metric_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric_query Powerpack#metric_query}
        :param process_query: process_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#process_query Powerpack#process_query}
        :param slo_query: slo_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#slo_query Powerpack#slo_query}
        '''
        if isinstance(apm_dependency_stats_query, dict):
            apm_dependency_stats_query = PowerpackWidgetGeomapDefinitionRequestQueryApmDependencyStatsQuery(**apm_dependency_stats_query)
        if isinstance(apm_resource_stats_query, dict):
            apm_resource_stats_query = PowerpackWidgetGeomapDefinitionRequestQueryApmResourceStatsQuery(**apm_resource_stats_query)
        if isinstance(cloud_cost_query, dict):
            cloud_cost_query = PowerpackWidgetGeomapDefinitionRequestQueryCloudCostQuery(**cloud_cost_query)
        if isinstance(event_query, dict):
            event_query = PowerpackWidgetGeomapDefinitionRequestQueryEventQuery(**event_query)
        if isinstance(metric_query, dict):
            metric_query = PowerpackWidgetGeomapDefinitionRequestQueryMetricQuery(**metric_query)
        if isinstance(process_query, dict):
            process_query = PowerpackWidgetGeomapDefinitionRequestQueryProcessQuery(**process_query)
        if isinstance(slo_query, dict):
            slo_query = PowerpackWidgetGeomapDefinitionRequestQuerySloQuery(**slo_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d6a4ce7b5e2a63a774fbb933dfa96f03018bacd87061dd3571826988b6cb4359)
            check_type(argname="argument apm_dependency_stats_query", value=apm_dependency_stats_query, expected_type=type_hints["apm_dependency_stats_query"])
            check_type(argname="argument apm_resource_stats_query", value=apm_resource_stats_query, expected_type=type_hints["apm_resource_stats_query"])
            check_type(argname="argument cloud_cost_query", value=cloud_cost_query, expected_type=type_hints["cloud_cost_query"])
            check_type(argname="argument event_query", value=event_query, expected_type=type_hints["event_query"])
            check_type(argname="argument metric_query", value=metric_query, expected_type=type_hints["metric_query"])
            check_type(argname="argument process_query", value=process_query, expected_type=type_hints["process_query"])
            check_type(argname="argument slo_query", value=slo_query, expected_type=type_hints["slo_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if apm_dependency_stats_query is not None:
            self._values["apm_dependency_stats_query"] = apm_dependency_stats_query
        if apm_resource_stats_query is not None:
            self._values["apm_resource_stats_query"] = apm_resource_stats_query
        if cloud_cost_query is not None:
            self._values["cloud_cost_query"] = cloud_cost_query
        if event_query is not None:
            self._values["event_query"] = event_query
        if metric_query is not None:
            self._values["metric_query"] = metric_query
        if process_query is not None:
            self._values["process_query"] = process_query
        if slo_query is not None:
            self._values["slo_query"] = slo_query

    @builtins.property
    def apm_dependency_stats_query(
        self,
    ) -> typing.Optional["PowerpackWidgetGeomapDefinitionRequestQueryApmDependencyStatsQuery"]:
        '''apm_dependency_stats_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#apm_dependency_stats_query Powerpack#apm_dependency_stats_query}
        '''
        result = self._values.get("apm_dependency_stats_query")
        return typing.cast(typing.Optional["PowerpackWidgetGeomapDefinitionRequestQueryApmDependencyStatsQuery"], result)

    @builtins.property
    def apm_resource_stats_query(
        self,
    ) -> typing.Optional["PowerpackWidgetGeomapDefinitionRequestQueryApmResourceStatsQuery"]:
        '''apm_resource_stats_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#apm_resource_stats_query Powerpack#apm_resource_stats_query}
        '''
        result = self._values.get("apm_resource_stats_query")
        return typing.cast(typing.Optional["PowerpackWidgetGeomapDefinitionRequestQueryApmResourceStatsQuery"], result)

    @builtins.property
    def cloud_cost_query(
        self,
    ) -> typing.Optional["PowerpackWidgetGeomapDefinitionRequestQueryCloudCostQuery"]:
        '''cloud_cost_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cloud_cost_query Powerpack#cloud_cost_query}
        '''
        result = self._values.get("cloud_cost_query")
        return typing.cast(typing.Optional["PowerpackWidgetGeomapDefinitionRequestQueryCloudCostQuery"], result)

    @builtins.property
    def event_query(
        self,
    ) -> typing.Optional["PowerpackWidgetGeomapDefinitionRequestQueryEventQuery"]:
        '''event_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#event_query Powerpack#event_query}
        '''
        result = self._values.get("event_query")
        return typing.cast(typing.Optional["PowerpackWidgetGeomapDefinitionRequestQueryEventQuery"], result)

    @builtins.property
    def metric_query(
        self,
    ) -> typing.Optional["PowerpackWidgetGeomapDefinitionRequestQueryMetricQuery"]:
        '''metric_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric_query Powerpack#metric_query}
        '''
        result = self._values.get("metric_query")
        return typing.cast(typing.Optional["PowerpackWidgetGeomapDefinitionRequestQueryMetricQuery"], result)

    @builtins.property
    def process_query(
        self,
    ) -> typing.Optional["PowerpackWidgetGeomapDefinitionRequestQueryProcessQuery"]:
        '''process_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#process_query Powerpack#process_query}
        '''
        result = self._values.get("process_query")
        return typing.cast(typing.Optional["PowerpackWidgetGeomapDefinitionRequestQueryProcessQuery"], result)

    @builtins.property
    def slo_query(
        self,
    ) -> typing.Optional["PowerpackWidgetGeomapDefinitionRequestQuerySloQuery"]:
        '''slo_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#slo_query Powerpack#slo_query}
        '''
        result = self._values.get("slo_query")
        return typing.cast(typing.Optional["PowerpackWidgetGeomapDefinitionRequestQuerySloQuery"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetGeomapDefinitionRequestQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetGeomapDefinitionRequestQueryApmDependencyStatsQuery",
    jsii_struct_bases=[],
    name_mapping={
        "data_source": "dataSource",
        "env": "env",
        "name": "name",
        "operation_name": "operationName",
        "resource_name": "resourceName",
        "service": "service",
        "stat": "stat",
        "cross_org_uuids": "crossOrgUuids",
        "is_upstream": "isUpstream",
        "primary_tag_name": "primaryTagName",
        "primary_tag_value": "primaryTagValue",
    },
)
class PowerpackWidgetGeomapDefinitionRequestQueryApmDependencyStatsQuery:
    def __init__(
        self,
        *,
        data_source: builtins.str,
        env: builtins.str,
        name: builtins.str,
        operation_name: builtins.str,
        resource_name: builtins.str,
        service: builtins.str,
        stat: builtins.str,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        is_upstream: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        primary_tag_name: typing.Optional[builtins.str] = None,
        primary_tag_value: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param data_source: The data source for APM Dependency Stats queries. Valid values are ``apm_dependency_stats``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param env: APM environment. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#env Powerpack#env}
        :param name: The name of query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param operation_name: Name of operation on service. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#operation_name Powerpack#operation_name}
        :param resource_name: APM resource. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#resource_name Powerpack#resource_name}
        :param service: APM service. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#service Powerpack#service}
        :param stat: APM statistic. Valid values are ``avg_duration``, ``avg_root_duration``, ``avg_spans_per_trace``, ``error_rate``, ``pct_exec_time``, ``pct_of_traces``, ``total_traces_count``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#stat Powerpack#stat}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param is_upstream: Determines whether stats for upstream or downstream dependencies should be queried. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#is_upstream Powerpack#is_upstream}
        :param primary_tag_name: The name of the second primary tag used within APM; required when ``primary_tag_value`` is specified. See https://docs.datadoghq.com/tracing/guide/setting_primary_tags_to_scope/#add-a-second-primary-tag-in-datadog. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_name Powerpack#primary_tag_name}
        :param primary_tag_value: Filter APM data by the second primary tag. ``primary_tag_name`` must also be specified. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_value Powerpack#primary_tag_value}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8010868ec37b4fdb2a17980472c3adf565b808d74ccd341a77b8b67bdc4d26b2)
            check_type(argname="argument data_source", value=data_source, expected_type=type_hints["data_source"])
            check_type(argname="argument env", value=env, expected_type=type_hints["env"])
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument operation_name", value=operation_name, expected_type=type_hints["operation_name"])
            check_type(argname="argument resource_name", value=resource_name, expected_type=type_hints["resource_name"])
            check_type(argname="argument service", value=service, expected_type=type_hints["service"])
            check_type(argname="argument stat", value=stat, expected_type=type_hints["stat"])
            check_type(argname="argument cross_org_uuids", value=cross_org_uuids, expected_type=type_hints["cross_org_uuids"])
            check_type(argname="argument is_upstream", value=is_upstream, expected_type=type_hints["is_upstream"])
            check_type(argname="argument primary_tag_name", value=primary_tag_name, expected_type=type_hints["primary_tag_name"])
            check_type(argname="argument primary_tag_value", value=primary_tag_value, expected_type=type_hints["primary_tag_value"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "data_source": data_source,
            "env": env,
            "name": name,
            "operation_name": operation_name,
            "resource_name": resource_name,
            "service": service,
            "stat": stat,
        }
        if cross_org_uuids is not None:
            self._values["cross_org_uuids"] = cross_org_uuids
        if is_upstream is not None:
            self._values["is_upstream"] = is_upstream
        if primary_tag_name is not None:
            self._values["primary_tag_name"] = primary_tag_name
        if primary_tag_value is not None:
            self._values["primary_tag_value"] = primary_tag_value

    @builtins.property
    def data_source(self) -> builtins.str:
        '''The data source for APM Dependency Stats queries. Valid values are ``apm_dependency_stats``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        '''
        result = self._values.get("data_source")
        assert result is not None, "Required property 'data_source' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def env(self) -> builtins.str:
        '''APM environment.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#env Powerpack#env}
        '''
        result = self._values.get("env")
        assert result is not None, "Required property 'env' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def name(self) -> builtins.str:
        '''The name of query for use in formulas.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        '''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def operation_name(self) -> builtins.str:
        '''Name of operation on service.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#operation_name Powerpack#operation_name}
        '''
        result = self._values.get("operation_name")
        assert result is not None, "Required property 'operation_name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def resource_name(self) -> builtins.str:
        '''APM resource.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#resource_name Powerpack#resource_name}
        '''
        result = self._values.get("resource_name")
        assert result is not None, "Required property 'resource_name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def service(self) -> builtins.str:
        '''APM service.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#service Powerpack#service}
        '''
        result = self._values.get("service")
        assert result is not None, "Required property 'service' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def stat(self) -> builtins.str:
        '''APM statistic. Valid values are ``avg_duration``, ``avg_root_duration``, ``avg_spans_per_trace``, ``error_rate``, ``pct_exec_time``, ``pct_of_traces``, ``total_traces_count``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#stat Powerpack#stat}
        '''
        result = self._values.get("stat")
        assert result is not None, "Required property 'stat' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def cross_org_uuids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''The source organization UUID for cross organization queries. Feature in Private Beta.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        '''
        result = self._values.get("cross_org_uuids")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def is_upstream(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        '''Determines whether stats for upstream or downstream dependencies should be queried.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#is_upstream Powerpack#is_upstream}
        '''
        result = self._values.get("is_upstream")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)

    @builtins.property
    def primary_tag_name(self) -> typing.Optional[builtins.str]:
        '''The name of the second primary tag used within APM; required when ``primary_tag_value`` is specified. See https://docs.datadoghq.com/tracing/guide/setting_primary_tags_to_scope/#add-a-second-primary-tag-in-datadog.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_name Powerpack#primary_tag_name}
        '''
        result = self._values.get("primary_tag_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def primary_tag_value(self) -> typing.Optional[builtins.str]:
        '''Filter APM data by the second primary tag. ``primary_tag_name`` must also be specified.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_value Powerpack#primary_tag_value}
        '''
        result = self._values.get("primary_tag_value")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetGeomapDefinitionRequestQueryApmDependencyStatsQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetGeomapDefinitionRequestQueryApmDependencyStatsQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetGeomapDefinitionRequestQueryApmDependencyStatsQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__77f34c2c639357c374a390e983eb7c63f214ed9b3fcf4d7b85fb1c0808bc4b67)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetCrossOrgUuids")
    def reset_cross_org_uuids(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCrossOrgUuids", []))

    @jsii.member(jsii_name="resetIsUpstream")
    def reset_is_upstream(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetIsUpstream", []))

    @jsii.member(jsii_name="resetPrimaryTagName")
    def reset_primary_tag_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPrimaryTagName", []))

    @jsii.member(jsii_name="resetPrimaryTagValue")
    def reset_primary_tag_value(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPrimaryTagValue", []))

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuidsInput")
    def cross_org_uuids_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "crossOrgUuidsInput"))

    @builtins.property
    @jsii.member(jsii_name="dataSourceInput")
    def data_source_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "dataSourceInput"))

    @builtins.property
    @jsii.member(jsii_name="envInput")
    def env_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "envInput"))

    @builtins.property
    @jsii.member(jsii_name="isUpstreamInput")
    def is_upstream_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "isUpstreamInput"))

    @builtins.property
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property
    @jsii.member(jsii_name="operationNameInput")
    def operation_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "operationNameInput"))

    @builtins.property
    @jsii.member(jsii_name="primaryTagNameInput")
    def primary_tag_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "primaryTagNameInput"))

    @builtins.property
    @jsii.member(jsii_name="primaryTagValueInput")
    def primary_tag_value_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "primaryTagValueInput"))

    @builtins.property
    @jsii.member(jsii_name="resourceNameInput")
    def resource_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "resourceNameInput"))

    @builtins.property
    @jsii.member(jsii_name="serviceInput")
    def service_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "serviceInput"))

    @builtins.property
    @jsii.member(jsii_name="statInput")
    def stat_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "statInput"))

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuids")
    def cross_org_uuids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "crossOrgUuids"))

    @cross_org_uuids.setter
    def cross_org_uuids(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__15827bef2b2753cb3ea3f540719de695ce2018ddaef9414081fed83a8b53c934)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "crossOrgUuids", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="dataSource")
    def data_source(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "dataSource"))

    @data_source.setter
    def data_source(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__440a0498b637f0cd56d52d87ce36467a48f0220fd664fa61ecb7260d1b98f0bd)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "dataSource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="env")
    def env(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "env"))

    @env.setter
    def env(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__302470a5b3c4003d071313eaa7f864077d80fa0aee21ddf984029e3b0ba4c3fb)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "env", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="isUpstream")
    def is_upstream(self) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "isUpstream"))

    @is_upstream.setter
    def is_upstream(
        self,
        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__768751bb84d8c608fca957fcd1dfdd359faa96936f45b05e370a4742dd58324f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "isUpstream", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__451c6ff4d5b29ab3a8574ed30ee7569f29651aa61d03d0efb0712e487264e5ad)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "name", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="operationName")
    def operation_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "operationName"))

    @operation_name.setter
    def operation_name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0f1a2065e6f850310124b4d94ac39fb352b6e0f3d61973d91967b66a79036c99)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "operationName", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="primaryTagName")
    def primary_tag_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "primaryTagName"))

    @primary_tag_name.setter
    def primary_tag_name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4e938e2b6303ed3c756858489e9cad14993854969619154424d83533e82220c1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "primaryTagName", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="primaryTagValue")
    def primary_tag_value(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "primaryTagValue"))

    @primary_tag_value.setter
    def primary_tag_value(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e04f69b96a0a77b0551d1f6ba242a2ed55d236ac388d8a8444e83a98a5d9c796)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "primaryTagValue", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="resourceName")
    def resource_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "resourceName"))

    @resource_name.setter
    def resource_name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bb341c7f04d53306ecf276c543cf075fc8349ac26ae5d815ceaea280504c2755)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "resourceName", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="service")
    def service(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "service"))

    @service.setter
    def service(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5144dc1538207c06a44fc96754afceb0dd96a38eafb54b7e0e26739047994d7a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "service", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="stat")
    def stat(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "stat"))

    @stat.setter
    def stat(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3dcad1828c7d04870bfff7c82871424194376376215be8219ed4d6ae656c93a7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "stat", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetGeomapDefinitionRequestQueryApmDependencyStatsQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetGeomapDefinitionRequestQueryApmDependencyStatsQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetGeomapDefinitionRequestQueryApmDependencyStatsQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e734d99a1691e2bcee47cb122dd2e88e848422a969015c16b686ebe2d3aa9bcc)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetGeomapDefinitionRequestQueryApmResourceStatsQuery",
    jsii_struct_bases=[],
    name_mapping={
        "data_source": "dataSource",
        "env": "env",
        "name": "name",
        "service": "service",
        "stat": "stat",
        "cross_org_uuids": "crossOrgUuids",
        "group_by": "groupBy",
        "operation_name": "operationName",
        "primary_tag_name": "primaryTagName",
        "primary_tag_value": "primaryTagValue",
        "resource_name": "resourceName",
    },
)
class PowerpackWidgetGeomapDefinitionRequestQueryApmResourceStatsQuery:
    def __init__(
        self,
        *,
        data_source: builtins.str,
        env: builtins.str,
        name: builtins.str,
        service: builtins.str,
        stat: builtins.str,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        group_by: typing.Optional[typing.Sequence[builtins.str]] = None,
        operation_name: typing.Optional[builtins.str] = None,
        primary_tag_name: typing.Optional[builtins.str] = None,
        primary_tag_value: typing.Optional[builtins.str] = None,
        resource_name: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param data_source: The data source for APM Resource Stats queries. Valid values are ``apm_resource_stats``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param env: APM environment. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#env Powerpack#env}
        :param name: The name of query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param service: APM service. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#service Powerpack#service}
        :param stat: APM statistic. Valid values are ``errors``, ``error_rate``, ``hits``, ``latency_avg``, ``latency_distribution``, ``latency_max``, ``latency_p50``, ``latency_p75``, ``latency_p90``, ``latency_p95``, ``latency_p99``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#stat Powerpack#stat}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param group_by: Array of fields to group results by. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param operation_name: Name of operation on service. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#operation_name Powerpack#operation_name}
        :param primary_tag_name: The name of the second primary tag used within APM; required when ``primary_tag_value`` is specified. See https://docs.datadoghq.com/tracing/guide/setting_primary_tags_to_scope/#add-a-second-primary-tag-in-datadog. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_name Powerpack#primary_tag_name}
        :param primary_tag_value: Filter APM data by the second primary tag. ``primary_tag_name`` must also be specified. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_value Powerpack#primary_tag_value}
        :param resource_name: APM resource. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#resource_name Powerpack#resource_name}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2c652cfa836642f21ba3d2c136be2c9a2b16d3eedd9bbdfb1a2a80caa97b7ef0)
            check_type(argname="argument data_source", value=data_source, expected_type=type_hints["data_source"])
            check_type(argname="argument env", value=env, expected_type=type_hints["env"])
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument service", value=service, expected_type=type_hints["service"])
            check_type(argname="argument stat", value=stat, expected_type=type_hints["stat"])
            check_type(argname="argument cross_org_uuids", value=cross_org_uuids, expected_type=type_hints["cross_org_uuids"])
            check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
            check_type(argname="argument operation_name", value=operation_name, expected_type=type_hints["operation_name"])
            check_type(argname="argument primary_tag_name", value=primary_tag_name, expected_type=type_hints["primary_tag_name"])
            check_type(argname="argument primary_tag_value", value=primary_tag_value, expected_type=type_hints["primary_tag_value"])
            check_type(argname="argument resource_name", value=resource_name, expected_type=type_hints["resource_name"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "data_source": data_source,
            "env": env,
            "name": name,
            "service": service,
            "stat": stat,
        }
        if cross_org_uuids is not None:
            self._values["cross_org_uuids"] = cross_org_uuids
        if group_by is not None:
            self._values["group_by"] = group_by
        if operation_name is not None:
            self._values["operation_name"] = operation_name
        if primary_tag_name is not None:
            self._values["primary_tag_name"] = primary_tag_name
        if primary_tag_value is not None:
            self._values["primary_tag_value"] = primary_tag_value
        if resource_name is not None:
            self._values["resource_name"] = resource_name

    @builtins.property
    def data_source(self) -> builtins.str:
        '''The data source for APM Resource Stats queries. Valid values are ``apm_resource_stats``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        '''
        result = self._values.get("data_source")
        assert result is not None, "Required property 'data_source' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def env(self) -> builtins.str:
        '''APM environment.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#env Powerpack#env}
        '''
        result = self._values.get("env")
        assert result is not None, "Required property 'env' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def name(self) -> builtins.str:
        '''The name of query for use in formulas.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        '''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def service(self) -> builtins.str:
        '''APM service.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#service Powerpack#service}
        '''
        result = self._values.get("service")
        assert result is not None, "Required property 'service' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def stat(self) -> builtins.str:
        '''APM statistic. Valid values are ``errors``, ``error_rate``, ``hits``, ``latency_avg``, ``latency_distribution``, ``latency_max``, ``latency_p50``, ``latency_p75``, ``latency_p90``, ``latency_p95``, ``latency_p99``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#stat Powerpack#stat}
        '''
        result = self._values.get("stat")
        assert result is not None, "Required property 'stat' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def cross_org_uuids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''The source organization UUID for cross organization queries. Feature in Private Beta.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        '''
        result = self._values.get("cross_org_uuids")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def group_by(self) -> typing.Optional[typing.List[builtins.str]]:
        '''Array of fields to group results by.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        '''
        result = self._values.get("group_by")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def operation_name(self) -> typing.Optional[builtins.str]:
        '''Name of operation on service.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#operation_name Powerpack#operation_name}
        '''
        result = self._values.get("operation_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def primary_tag_name(self) -> typing.Optional[builtins.str]:
        '''The name of the second primary tag used within APM; required when ``primary_tag_value`` is specified. See https://docs.datadoghq.com/tracing/guide/setting_primary_tags_to_scope/#add-a-second-primary-tag-in-datadog.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_name Powerpack#primary_tag_name}
        '''
        result = self._values.get("primary_tag_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def primary_tag_value(self) -> typing.Optional[builtins.str]:
        '''Filter APM data by the second primary tag. ``primary_tag_name`` must also be specified.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_value Powerpack#primary_tag_value}
        '''
        result = self._values.get("primary_tag_value")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def resource_name(self) -> typing.Optional[builtins.str]:
        '''APM resource.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#resource_name Powerpack#resource_name}
        '''
        result = self._values.get("resource_name")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetGeomapDefinitionRequestQueryApmResourceStatsQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetGeomapDefinitionRequestQueryApmResourceStatsQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetGeomapDefinitionRequestQueryApmResourceStatsQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__74ea168c0a421c2348f50d221068168c2e17f4380b6cc6e31a33a33c35be5ccc)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetCrossOrgUuids")
    def reset_cross_org_uuids(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCrossOrgUuids", []))

    @jsii.member(jsii_name="resetGroupBy")
    def reset_group_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGroupBy", []))

    @jsii.member(jsii_name="resetOperationName")
    def reset_operation_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetOperationName", []))

    @jsii.member(jsii_name="resetPrimaryTagName")
    def reset_primary_tag_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPrimaryTagName", []))

    @jsii.member(jsii_name="resetPrimaryTagValue")
    def reset_primary_tag_value(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPrimaryTagValue", []))

    @jsii.member(jsii_name="resetResourceName")
    def reset_resource_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetResourceName", []))

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuidsInput")
    def cross_org_uuids_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "crossOrgUuidsInput"))

    @builtins.property
    @jsii.member(jsii_name="dataSourceInput")
    def data_source_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "dataSourceInput"))

    @builtins.property
    @jsii.member(jsii_name="envInput")
    def env_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "envInput"))

    @builtins.property
    @jsii.member(jsii_name="groupByInput")
    def group_by_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "groupByInput"))

    @builtins.property
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property
    @jsii.member(jsii_name="operationNameInput")
    def operation_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "operationNameInput"))

    @builtins.property
    @jsii.member(jsii_name="primaryTagNameInput")
    def primary_tag_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "primaryTagNameInput"))

    @builtins.property
    @jsii.member(jsii_name="primaryTagValueInput")
    def primary_tag_value_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "primaryTagValueInput"))

    @builtins.property
    @jsii.member(jsii_name="resourceNameInput")
    def resource_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "resourceNameInput"))

    @builtins.property
    @jsii.member(jsii_name="serviceInput")
    def service_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "serviceInput"))

    @builtins.property
    @jsii.member(jsii_name="statInput")
    def stat_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "statInput"))

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuids")
    def cross_org_uuids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "crossOrgUuids"))

    @cross_org_uuids.setter
    def cross_org_uuids(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4b74cb6495912ea2da327d0a1384c9d4a6ab1c4ea3d2643ce6ac171a5a915fb4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "crossOrgUuids", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="dataSource")
    def data_source(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "dataSource"))

    @data_source.setter
    def data_source(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c9fcef4440354a9b66221b4fede7d5df25e7254d58615d7d99bc8936e880e77c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "dataSource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="env")
    def env(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "env"))

    @env.setter
    def env(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1b2eb46929d7a9510375afc45577c901beb376cb426bebd48e5eef7e0ed26d4b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "env", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="groupBy")
    def group_by(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "groupBy"))

    @group_by.setter
    def group_by(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__43c11830219e19700a9058e34e8b82bbf37ac7d95dc54c89211d9920afe6da57)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "groupBy", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c84320ec1fe82c6528028659c38544012c4d5ce07f7d5096a3b7555fccf11975)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "name", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="operationName")
    def operation_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "operationName"))

    @operation_name.setter
    def operation_name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0594b382cee1f9cfc7d91fb55595d2b8dbc4f387de75e1207d277f176e88029c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "operationName", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="primaryTagName")
    def primary_tag_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "primaryTagName"))

    @primary_tag_name.setter
    def primary_tag_name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cb44fd286e6d71f6e848c45a3ccd339a9aee746ce67d8a2b58b985e10e835a1e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "primaryTagName", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="primaryTagValue")
    def primary_tag_value(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "primaryTagValue"))

    @primary_tag_value.setter
    def primary_tag_value(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1defad82a889a99b9396be4ee3d3f33e717bff5b404af6104d76bc748397f7d9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "primaryTagValue", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="resourceName")
    def resource_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "resourceName"))

    @resource_name.setter
    def resource_name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b1474f7bc1faf66da9e0747abd46d5c66a9dcd03de43f8887c06850103ff425f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "resourceName", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="service")
    def service(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "service"))

    @service.setter
    def service(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8226e989aea0f9049abec3b8b01a93c37a912c3867a29b9dfa08060af5a5e046)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "service", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="stat")
    def stat(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "stat"))

    @stat.setter
    def stat(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a691ab271bdd208dd83d8fb102a3fae7d2bca8abfdabbdff135b88207ce554a7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "stat", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetGeomapDefinitionRequestQueryApmResourceStatsQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetGeomapDefinitionRequestQueryApmResourceStatsQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetGeomapDefinitionRequestQueryApmResourceStatsQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3ee85acdb5c2af26d12ff631d0e8e09fda03c3aaa94061e4290fc61e9f224eb2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetGeomapDefinitionRequestQueryCloudCostQuery",
    jsii_struct_bases=[],
    name_mapping={
        "data_source": "dataSource",
        "name": "name",
        "query": "query",
        "aggregator": "aggregator",
        "cross_org_uuids": "crossOrgUuids",
    },
)
class PowerpackWidgetGeomapDefinitionRequestQueryCloudCostQuery:
    def __init__(
        self,
        *,
        data_source: builtins.str,
        name: builtins.str,
        query: builtins.str,
        aggregator: typing.Optional[builtins.str] = None,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
    ) -> None:
        '''
        :param data_source: The data source for cloud cost queries. Valid values are ``cloud_cost``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param name: The name of the query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param query: The cloud cost query definition. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        :param aggregator: The aggregation methods available for cloud cost queries. Valid values are ``avg``, ``last``, ``max``, ``min``, ``sum``, ``percentile``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregator Powerpack#aggregator}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f73637b3a7471caf34463903671d0c038a82de0f4885667e207f6c2eceedcd8b)
            check_type(argname="argument data_source", value=data_source, expected_type=type_hints["data_source"])
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument query", value=query, expected_type=type_hints["query"])
            check_type(argname="argument aggregator", value=aggregator, expected_type=type_hints["aggregator"])
            check_type(argname="argument cross_org_uuids", value=cross_org_uuids, expected_type=type_hints["cross_org_uuids"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "data_source": data_source,
            "name": name,
            "query": query,
        }
        if aggregator is not None:
            self._values["aggregator"] = aggregator
        if cross_org_uuids is not None:
            self._values["cross_org_uuids"] = cross_org_uuids

    @builtins.property
    def data_source(self) -> builtins.str:
        '''The data source for cloud cost queries. Valid values are ``cloud_cost``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        '''
        result = self._values.get("data_source")
        assert result is not None, "Required property 'data_source' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def name(self) -> builtins.str:
        '''The name of the query for use in formulas.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        '''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def query(self) -> builtins.str:
        '''The cloud cost query definition.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        '''
        result = self._values.get("query")
        assert result is not None, "Required property 'query' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def aggregator(self) -> typing.Optional[builtins.str]:
        '''The aggregation methods available for cloud cost queries. Valid values are ``avg``, ``last``, ``max``, ``min``, ``sum``, ``percentile``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregator Powerpack#aggregator}
        '''
        result = self._values.get("aggregator")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def cross_org_uuids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''The source organization UUID for cross organization queries. Feature in Private Beta.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        '''
        result = self._values.get("cross_org_uuids")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetGeomapDefinitionRequestQueryCloudCostQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetGeomapDefinitionRequestQueryCloudCostQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetGeomapDefinitionRequestQueryCloudCostQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__18404c8677f8ba8ef7c132c9b1f1501f5028646b72eb7ec5615201891a86809a)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetAggregator")
    def reset_aggregator(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAggregator", []))

    @jsii.member(jsii_name="resetCrossOrgUuids")
    def reset_cross_org_uuids(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCrossOrgUuids", []))

    @builtins.property
    @jsii.member(jsii_name="aggregatorInput")
    def aggregator_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregatorInput"))

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuidsInput")
    def cross_org_uuids_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "crossOrgUuidsInput"))

    @builtins.property
    @jsii.member(jsii_name="dataSourceInput")
    def data_source_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "dataSourceInput"))

    @builtins.property
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property
    @jsii.member(jsii_name="queryInput")
    def query_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "queryInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregator")
    def aggregator(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregator"))

    @aggregator.setter
    def aggregator(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bb6457f045759fa7cf1f7f3e1fe66324cfb04d7299ff9b22cf66e61f6969433b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregator", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuids")
    def cross_org_uuids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "crossOrgUuids"))

    @cross_org_uuids.setter
    def cross_org_uuids(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2cb9f7a7b469378368d3b7903e0ee434e2c771b26ed137ef6378f14eed490d34)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "crossOrgUuids", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="dataSource")
    def data_source(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "dataSource"))

    @data_source.setter
    def data_source(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ba6cc48b4004b9505eb67f5ff23f0d6a279127b5841e46fa0820ccd868b25174)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "dataSource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dc31dab87c485c7f83e9052953d54e5bfd192a72e0c54fb8a75615dbcb6b8468)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "name", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="query")
    def query(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "query"))

    @query.setter
    def query(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0b15c92fe00cdf0d3430b18605c1f8823121565d4ed5e1f24035ea5804c596ad)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "query", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetGeomapDefinitionRequestQueryCloudCostQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetGeomapDefinitionRequestQueryCloudCostQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetGeomapDefinitionRequestQueryCloudCostQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__df0b09638ef11184812d97117e53a45b0c0b1d3442eb16c6d30a48e753f9c1fa)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetGeomapDefinitionRequestQueryEventQuery",
    jsii_struct_bases=[],
    name_mapping={
        "compute": "compute",
        "data_source": "dataSource",
        "name": "name",
        "cross_org_uuids": "crossOrgUuids",
        "group_by": "groupBy",
        "indexes": "indexes",
        "search": "search",
        "storage": "storage",
    },
)
class PowerpackWidgetGeomapDefinitionRequestQueryEventQuery:
    def __init__(
        self,
        *,
        compute: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetGeomapDefinitionRequestQueryEventQueryCompute", typing.Dict[builtins.str, typing.Any]]]],
        data_source: builtins.str,
        name: builtins.str,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetGeomapDefinitionRequestQueryEventQueryGroupBy", typing.Dict[builtins.str, typing.Any]]]]] = None,
        indexes: typing.Optional[typing.Sequence[builtins.str]] = None,
        search: typing.Optional[typing.Union["PowerpackWidgetGeomapDefinitionRequestQueryEventQuerySearch", typing.Dict[builtins.str, typing.Any]]] = None,
        storage: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param compute: compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute Powerpack#compute}
        :param data_source: The data source for event platform-based queries. Valid values are ``logs``, ``spans``, ``network``, ``rum``, ``security_signals``, ``profiles``, ``audit``, ``events``, ``ci_tests``, ``ci_pipelines``, ``incident_analytics``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param name: The name of query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param indexes: An array of index names to query in the stream. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#indexes Powerpack#indexes}
        :param search: search block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search Powerpack#search}
        :param storage: Storage location (private beta). Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#storage Powerpack#storage}
        '''
        if isinstance(search, dict):
            search = PowerpackWidgetGeomapDefinitionRequestQueryEventQuerySearch(**search)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2053b442e31ca0df58981a79409e7a1193fdeaa686f20d6f01a0da88890fe3c8)
            check_type(argname="argument compute", value=compute, expected_type=type_hints["compute"])
            check_type(argname="argument data_source", value=data_source, expected_type=type_hints["data_source"])
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument cross_org_uuids", value=cross_org_uuids, expected_type=type_hints["cross_org_uuids"])
            check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
            check_type(argname="argument indexes", value=indexes, expected_type=type_hints["indexes"])
            check_type(argname="argument search", value=search, expected_type=type_hints["search"])
            check_type(argname="argument storage", value=storage, expected_type=type_hints["storage"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "compute": compute,
            "data_source": data_source,
            "name": name,
        }
        if cross_org_uuids is not None:
            self._values["cross_org_uuids"] = cross_org_uuids
        if group_by is not None:
            self._values["group_by"] = group_by
        if indexes is not None:
            self._values["indexes"] = indexes
        if search is not None:
            self._values["search"] = search
        if storage is not None:
            self._values["storage"] = storage

    @builtins.property
    def compute(
        self,
    ) -> typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetGeomapDefinitionRequestQueryEventQueryCompute"]]:
        '''compute block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute Powerpack#compute}
        '''
        result = self._values.get("compute")
        assert result is not None, "Required property 'compute' is missing"
        return typing.cast(typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetGeomapDefinitionRequestQueryEventQueryCompute"]], result)

    @builtins.property
    def data_source(self) -> builtins.str:
        '''The data source for event platform-based queries.

        Valid values are ``logs``, ``spans``, ``network``, ``rum``, ``security_signals``, ``profiles``, ``audit``, ``events``, ``ci_tests``, ``ci_pipelines``, ``incident_analytics``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        '''
        result = self._values.get("data_source")
        assert result is not None, "Required property 'data_source' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def name(self) -> builtins.str:
        '''The name of query for use in formulas.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        '''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def cross_org_uuids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''The source organization UUID for cross organization queries. Feature in Private Beta.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        '''
        result = self._values.get("cross_org_uuids")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def group_by(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetGeomapDefinitionRequestQueryEventQueryGroupBy"]]]:
        '''group_by block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        '''
        result = self._values.get("group_by")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetGeomapDefinitionRequestQueryEventQueryGroupBy"]]], result)

    @builtins.property
    def indexes(self) -> typing.Optional[typing.List[builtins.str]]:
        '''An array of index names to query in the stream.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#indexes Powerpack#indexes}
        '''
        result = self._values.get("indexes")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def search(
        self,
    ) -> typing.Optional["PowerpackWidgetGeomapDefinitionRequestQueryEventQuerySearch"]:
        '''search block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search Powerpack#search}
        '''
        result = self._values.get("search")
        return typing.cast(typing.Optional["PowerpackWidgetGeomapDefinitionRequestQueryEventQuerySearch"], result)

    @builtins.property
    def storage(self) -> typing.Optional[builtins.str]:
        '''Storage location (private beta).

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#storage Powerpack#storage}
        '''
        result = self._values.get("storage")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetGeomapDefinitionRequestQueryEventQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetGeomapDefinitionRequestQueryEventQueryCompute",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "interval": "interval",
        "metric": "metric",
    },
)
class PowerpackWidgetGeomapDefinitionRequestQueryEventQueryCompute:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        interval: typing.Optional[jsii.Number] = None,
        metric: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation methods for event platform queries. Valid values are ``count``, ``cardinality``, ``median``, ``pc75``, ``pc90``, ``pc95``, ``pc98``, ``pc99``, ``sum``, ``min``, ``max``, ``avg``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param interval: A time interval in milliseconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        :param metric: The measurable attribute to compute. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a23c59ecb93c5d795e2064f471dc2e4cdd48aa2adeb5862e94c9b58261f45536)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
            check_type(argname="argument metric", value=metric, expected_type=type_hints["metric"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if interval is not None:
            self._values["interval"] = interval
        if metric is not None:
            self._values["metric"] = metric

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation methods for event platform queries.

        Valid values are ``count``, ``cardinality``, ``median``, ``pc75``, ``pc90``, ``pc95``, ``pc98``, ``pc99``, ``sum``, ``min``, ``max``, ``avg``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''A time interval in milliseconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def metric(self) -> typing.Optional[builtins.str]:
        '''The measurable attribute to compute.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        '''
        result = self._values.get("metric")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetGeomapDefinitionRequestQueryEventQueryCompute(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetGeomapDefinitionRequestQueryEventQueryComputeList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetGeomapDefinitionRequestQueryEventQueryComputeList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7dae259908034d6d6f79e0d287ab149a8ef877805c777ae052c49752438017fb)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetGeomapDefinitionRequestQueryEventQueryComputeOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__18f8b28819d86c9c88fc3e5e05344ccf8b2e2078f193fddda8d4c48280121587)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetGeomapDefinitionRequestQueryEventQueryComputeOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__696bd1fbe21c61535fd1ba43d32011e3caec3a1f137b0ed8eb2d34ac461131b7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f17fc80e6b85e15930d1ce005a9aa419b35a5b93c5a6d8d955326217f4827c3d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e7910cf6c4fa25d296311cd9d62f6e22046ba839ed18d161ae47d6e59cdd10fe)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetGeomapDefinitionRequestQueryEventQueryCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetGeomapDefinitionRequestQueryEventQueryCompute]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetGeomapDefinitionRequestQueryEventQueryCompute]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1e138fdcbafaf6087e568fb09a440a89194cd66c214395d709cfee18128f06a2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetGeomapDefinitionRequestQueryEventQueryComputeOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetGeomapDefinitionRequestQueryEventQueryComputeOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ec04a767e86ad364ab4b109c931687fe88d410496a093ec29e6093ccba923674)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @jsii.member(jsii_name="resetMetric")
    def reset_metric(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMetric", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="metricInput")
    def metric_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "metricInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e2ea2fb2b71c4c492a77fe3eeee85111ac3da6e061170a421e4ce19d15a52363)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__aa2cc1265afdce3f81246f2f2e970463d9f576b79aec63a3de4fecc9923628d6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="metric")
    def metric(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "metric"))

    @metric.setter
    def metric(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c870de12bb7f773aa760056b228a59cd74b35070f823e0b4617cc4771593548c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "metric", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetGeomapDefinitionRequestQueryEventQueryCompute]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetGeomapDefinitionRequestQueryEventQueryCompute]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetGeomapDefinitionRequestQueryEventQueryCompute]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5d9f03b6f856565685fd452d231adc50029a82c083c3d1875b3b744b321b24dc)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetGeomapDefinitionRequestQueryEventQueryGroupBy",
    jsii_struct_bases=[],
    name_mapping={"facet": "facet", "limit": "limit", "sort": "sort"},
)
class PowerpackWidgetGeomapDefinitionRequestQueryEventQueryGroupBy:
    def __init__(
        self,
        *,
        facet: builtins.str,
        limit: typing.Optional[jsii.Number] = None,
        sort: typing.Optional[typing.Union["PowerpackWidgetGeomapDefinitionRequestQueryEventQueryGroupBySort", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param facet: The event facet. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param limit: The number of groups to return. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param sort: sort block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort Powerpack#sort}
        '''
        if isinstance(sort, dict):
            sort = PowerpackWidgetGeomapDefinitionRequestQueryEventQueryGroupBySort(**sort)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__642ea5edfbfbbdd0b6401cc1276980c6b4b65b0736958309e04f803a64db6de8)
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
            check_type(argname="argument sort", value=sort, expected_type=type_hints["sort"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "facet": facet,
        }
        if limit is not None:
            self._values["limit"] = limit
        if sort is not None:
            self._values["sort"] = sort

    @builtins.property
    def facet(self) -> builtins.str:
        '''The event facet.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        assert result is not None, "Required property 'facet' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def limit(self) -> typing.Optional[jsii.Number]:
        '''The number of groups to return.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        '''
        result = self._values.get("limit")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def sort(
        self,
    ) -> typing.Optional["PowerpackWidgetGeomapDefinitionRequestQueryEventQueryGroupBySort"]:
        '''sort block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort Powerpack#sort}
        '''
        result = self._values.get("sort")
        return typing.cast(typing.Optional["PowerpackWidgetGeomapDefinitionRequestQueryEventQueryGroupBySort"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetGeomapDefinitionRequestQueryEventQueryGroupBy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetGeomapDefinitionRequestQueryEventQueryGroupByList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetGeomapDefinitionRequestQueryEventQueryGroupByList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c2dcac9a7447687144a492073ef45f43fdcf2100c75d8d7befaf3c07dcffe453)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetGeomapDefinitionRequestQueryEventQueryGroupByOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7b705553707b76e3d2894bf1a7e2d261a5da4a08206431336dfb72c94411cfe8)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetGeomapDefinitionRequestQueryEventQueryGroupByOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__599a98c701ef78be090f198cd6483e8fe250940178014397bbfa9c6ac977eaf1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__176c78b51cb982d1bfce6aa40d3c1da9db46a64996ba8623f17274ee31eab267)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fa77c4a4ffe53b99a625162e1ef0594dc6b0080eecf78c91691c5bf58459ff5e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetGeomapDefinitionRequestQueryEventQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetGeomapDefinitionRequestQueryEventQueryGroupBy]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetGeomapDefinitionRequestQueryEventQueryGroupBy]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__90f05a455ff042dc5ec031cb9100e2f0c061af3e83685ada304d26796b916b43)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetGeomapDefinitionRequestQueryEventQueryGroupByOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetGeomapDefinitionRequestQueryEventQueryGroupByOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__53546784c542d8fbda46d6fbc3d70f58714838b633a2001874897bfd954a8975)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putSort")
    def put_sort(
        self,
        *,
        aggregation: builtins.str,
        metric: typing.Optional[builtins.str] = None,
        order: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation methods for the event platform queries. Valid values are ``count``, ``cardinality``, ``median``, ``pc75``, ``pc90``, ``pc95``, ``pc98``, ``pc99``, ``sum``, ``min``, ``max``, ``avg``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param metric: The metric used for sorting group by results. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        :param order: Direction of sort. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        value = PowerpackWidgetGeomapDefinitionRequestQueryEventQueryGroupBySort(
            aggregation=aggregation, metric=metric, order=order
        )

        return typing.cast(None, jsii.invoke(self, "putSort", [value]))

    @jsii.member(jsii_name="resetLimit")
    def reset_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLimit", []))

    @jsii.member(jsii_name="resetSort")
    def reset_sort(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSort", []))

    @builtins.property
    @jsii.member(jsii_name="sort")
    def sort(
        self,
    ) -> "PowerpackWidgetGeomapDefinitionRequestQueryEventQueryGroupBySortOutputReference":
        return typing.cast("PowerpackWidgetGeomapDefinitionRequestQueryEventQueryGroupBySortOutputReference", jsii.get(self, "sort"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="limitInput")
    def limit_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "limitInput"))

    @builtins.property
    @jsii.member(jsii_name="sortInput")
    def sort_input(
        self,
    ) -> typing.Optional["PowerpackWidgetGeomapDefinitionRequestQueryEventQueryGroupBySort"]:
        return typing.cast(typing.Optional["PowerpackWidgetGeomapDefinitionRequestQueryEventQueryGroupBySort"], jsii.get(self, "sortInput"))

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__421af328d3356b398f5a48dd230db18924f1096ec344c09158dac5fc5bf24af0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="limit")
    def limit(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "limit"))

    @limit.setter
    def limit(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7c8335625a72a6665fcca8ac4e15e9aaa15ec6075b1d4152c50b0e722dc49593)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "limit", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetGeomapDefinitionRequestQueryEventQueryGroupBy]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetGeomapDefinitionRequestQueryEventQueryGroupBy]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetGeomapDefinitionRequestQueryEventQueryGroupBy]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f7d099b2dbcf39d3a570f213ef9a7ce5110820b6d84a589a1abc6df77e1a8fbc)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetGeomapDefinitionRequestQueryEventQueryGroupBySort",
    jsii_struct_bases=[],
    name_mapping={"aggregation": "aggregation", "metric": "metric", "order": "order"},
)
class PowerpackWidgetGeomapDefinitionRequestQueryEventQueryGroupBySort:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        metric: typing.Optional[builtins.str] = None,
        order: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation methods for the event platform queries. Valid values are ``count``, ``cardinality``, ``median``, ``pc75``, ``pc90``, ``pc95``, ``pc98``, ``pc99``, ``sum``, ``min``, ``max``, ``avg``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param metric: The metric used for sorting group by results. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        :param order: Direction of sort. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__42b9d6ab975ce2fafb053e1aeab2ae21570103645422b694d863c0ed2e30cd5f)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument metric", value=metric, expected_type=type_hints["metric"])
            check_type(argname="argument order", value=order, expected_type=type_hints["order"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if metric is not None:
            self._values["metric"] = metric
        if order is not None:
            self._values["order"] = order

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation methods for the event platform queries.

        Valid values are ``count``, ``cardinality``, ``median``, ``pc75``, ``pc90``, ``pc95``, ``pc98``, ``pc99``, ``sum``, ``min``, ``max``, ``avg``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def metric(self) -> typing.Optional[builtins.str]:
        '''The metric used for sorting group by results.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        '''
        result = self._values.get("metric")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def order(self) -> typing.Optional[builtins.str]:
        '''Direction of sort. Valid values are ``asc``, ``desc``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        result = self._values.get("order")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetGeomapDefinitionRequestQueryEventQueryGroupBySort(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetGeomapDefinitionRequestQueryEventQueryGroupBySortOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetGeomapDefinitionRequestQueryEventQueryGroupBySortOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__05e6b82f482c5cd97d62b11b3b2c46d9bea0f58d612ca95fbd8263b99628890e)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetMetric")
    def reset_metric(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMetric", []))

    @jsii.member(jsii_name="resetOrder")
    def reset_order(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetOrder", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="metricInput")
    def metric_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "metricInput"))

    @builtins.property
    @jsii.member(jsii_name="orderInput")
    def order_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "orderInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__644e17757caa2db58b1871f13781031e4614650d16fbc29d58aef7ec135c5d8f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="metric")
    def metric(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "metric"))

    @metric.setter
    def metric(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__948fd3ee39d191d7a2938adf9d178db010e17d533ebebdde6daec0deb411fa84)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "metric", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="order")
    def order(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "order"))

    @order.setter
    def order(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b666cd4e77be56bb368a7ecc94e9fbaa82ec4ee6eaaae203de946792cc66d3c2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "order", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetGeomapDefinitionRequestQueryEventQueryGroupBySort]:
        return typing.cast(typing.Optional[PowerpackWidgetGeomapDefinitionRequestQueryEventQueryGroupBySort], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetGeomapDefinitionRequestQueryEventQueryGroupBySort],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ab2f88cba6634286c66184ff969bb5d7396c31bfec1c872cab90c1aee0e4e815)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetGeomapDefinitionRequestQueryEventQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetGeomapDefinitionRequestQueryEventQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3a58af5e36efcdcb89b382d0ae4861a08f3324ccfef8b1a981d244a1216a61b6)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putCompute")
    def put_compute(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetGeomapDefinitionRequestQueryEventQueryCompute, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f72de3b0fb436763eb1625b27a356b0666dac4dc08b690cdc3a58eac2e60f400)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putCompute", [value]))

    @jsii.member(jsii_name="putGroupBy")
    def put_group_by(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetGeomapDefinitionRequestQueryEventQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4acede0469c65f578471002a9e2dae8b1d206ca2f31f5c78720ff4b83b1f1959)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putGroupBy", [value]))

    @jsii.member(jsii_name="putSearch")
    def put_search(self, *, query: builtins.str) -> None:
        '''
        :param query: The events search string. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        '''
        value = PowerpackWidgetGeomapDefinitionRequestQueryEventQuerySearch(
            query=query
        )

        return typing.cast(None, jsii.invoke(self, "putSearch", [value]))

    @jsii.member(jsii_name="resetCrossOrgUuids")
    def reset_cross_org_uuids(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCrossOrgUuids", []))

    @jsii.member(jsii_name="resetGroupBy")
    def reset_group_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGroupBy", []))

    @jsii.member(jsii_name="resetIndexes")
    def reset_indexes(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetIndexes", []))

    @jsii.member(jsii_name="resetSearch")
    def reset_search(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSearch", []))

    @jsii.member(jsii_name="resetStorage")
    def reset_storage(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetStorage", []))

    @builtins.property
    @jsii.member(jsii_name="compute")
    def compute(
        self,
    ) -> PowerpackWidgetGeomapDefinitionRequestQueryEventQueryComputeList:
        return typing.cast(PowerpackWidgetGeomapDefinitionRequestQueryEventQueryComputeList, jsii.get(self, "compute"))

    @builtins.property
    @jsii.member(jsii_name="groupBy")
    def group_by(
        self,
    ) -> PowerpackWidgetGeomapDefinitionRequestQueryEventQueryGroupByList:
        return typing.cast(PowerpackWidgetGeomapDefinitionRequestQueryEventQueryGroupByList, jsii.get(self, "groupBy"))

    @builtins.property
    @jsii.member(jsii_name="search")
    def search(
        self,
    ) -> "PowerpackWidgetGeomapDefinitionRequestQueryEventQuerySearchOutputReference":
        return typing.cast("PowerpackWidgetGeomapDefinitionRequestQueryEventQuerySearchOutputReference", jsii.get(self, "search"))

    @builtins.property
    @jsii.member(jsii_name="computeInput")
    def compute_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetGeomapDefinitionRequestQueryEventQueryCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetGeomapDefinitionRequestQueryEventQueryCompute]]], jsii.get(self, "computeInput"))

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuidsInput")
    def cross_org_uuids_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "crossOrgUuidsInput"))

    @builtins.property
    @jsii.member(jsii_name="dataSourceInput")
    def data_source_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "dataSourceInput"))

    @builtins.property
    @jsii.member(jsii_name="groupByInput")
    def group_by_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetGeomapDefinitionRequestQueryEventQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetGeomapDefinitionRequestQueryEventQueryGroupBy]]], jsii.get(self, "groupByInput"))

    @builtins.property
    @jsii.member(jsii_name="indexesInput")
    def indexes_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "indexesInput"))

    @builtins.property
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property
    @jsii.member(jsii_name="searchInput")
    def search_input(
        self,
    ) -> typing.Optional["PowerpackWidgetGeomapDefinitionRequestQueryEventQuerySearch"]:
        return typing.cast(typing.Optional["PowerpackWidgetGeomapDefinitionRequestQueryEventQuerySearch"], jsii.get(self, "searchInput"))

    @builtins.property
    @jsii.member(jsii_name="storageInput")
    def storage_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "storageInput"))

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuids")
    def cross_org_uuids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "crossOrgUuids"))

    @cross_org_uuids.setter
    def cross_org_uuids(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c1bd3bdf5e1bb803ed53ff74f4e843141f318bd08cbca31a4a227248a3820c03)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "crossOrgUuids", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="dataSource")
    def data_source(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "dataSource"))

    @data_source.setter
    def data_source(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2d78b6b73661abbfd8d3fdef1450e0aaa961896f01f2911387fe80066e40534f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "dataSource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="indexes")
    def indexes(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "indexes"))

    @indexes.setter
    def indexes(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__174238d2f6e57bd2218a98427f2cae63b8c902c41792a61b90984d02d0424d9c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "indexes", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e358cf36de247593a0ef0115b1205604dc61e63026398a4d83a750825ac8ab08)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "name", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="storage")
    def storage(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "storage"))

    @storage.setter
    def storage(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__29aaa5d06439f77f594205fe76959ea5f4c68b5f927f9bf473a54900584aaf8c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "storage", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetGeomapDefinitionRequestQueryEventQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetGeomapDefinitionRequestQueryEventQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetGeomapDefinitionRequestQueryEventQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3a4d4eb7c8b8bc987a238da87a0fa5503b946dea1e91217d89e0415609a8eaf0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetGeomapDefinitionRequestQueryEventQuerySearch",
    jsii_struct_bases=[],
    name_mapping={"query": "query"},
)
class PowerpackWidgetGeomapDefinitionRequestQueryEventQuerySearch:
    def __init__(self, *, query: builtins.str) -> None:
        '''
        :param query: The events search string. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__575e148090df77688e28b85f11f538b285bbf593f143501884ed0fdbf423c428)
            check_type(argname="argument query", value=query, expected_type=type_hints["query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "query": query,
        }

    @builtins.property
    def query(self) -> builtins.str:
        '''The events search string.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        '''
        result = self._values.get("query")
        assert result is not None, "Required property 'query' is missing"
        return typing.cast(builtins.str, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetGeomapDefinitionRequestQueryEventQuerySearch(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetGeomapDefinitionRequestQueryEventQuerySearchOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetGeomapDefinitionRequestQueryEventQuerySearchOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c4c8ae7990471b74fc91e3c1f88cb5a9f05bd049f72fea69b7ab5637db202ca8)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @builtins.property
    @jsii.member(jsii_name="queryInput")
    def query_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "queryInput"))

    @builtins.property
    @jsii.member(jsii_name="query")
    def query(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "query"))

    @query.setter
    def query(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8810483761391a5d173ddf45b4cf364b205de5ccf1202e76b5a04042eec065a9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "query", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetGeomapDefinitionRequestQueryEventQuerySearch]:
        return typing.cast(typing.Optional[PowerpackWidgetGeomapDefinitionRequestQueryEventQuerySearch], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetGeomapDefinitionRequestQueryEventQuerySearch],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2e2a851ff32f996ac16019c3556a2c960fef024bb10e589f3ab448a3d333872e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetGeomapDefinitionRequestQueryList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetGeomapDefinitionRequestQueryList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f92e00312e09ec0faafbab1f697471744a03120386415a249a2db04a56a5b58f)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetGeomapDefinitionRequestQueryOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__86af510f1afd9ed35668340f3dff85eef8fe5fbf6796fab6bd41f15428d74264)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetGeomapDefinitionRequestQueryOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2904f631774f138ee06699d7a64b5741bbf826926256c79a29b6f46f8bfa0982)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9bb2e38a17135216d81af4b1377ec711f4325f934468b4c8621c5a394a87ffc3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a9b94262d82ea1a8dc6ef1d5fd085d5da1adb6329a49e3fc923e206eefb764cc)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetGeomapDefinitionRequestQuery]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetGeomapDefinitionRequestQuery]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetGeomapDefinitionRequestQuery]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1f8c65c762e8ef7c5c843350f68b8fd2e13b0b0bdabcc53999cbb4433d68ff1a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetGeomapDefinitionRequestQueryMetricQuery",
    jsii_struct_bases=[],
    name_mapping={
        "name": "name",
        "query": "query",
        "aggregator": "aggregator",
        "cross_org_uuids": "crossOrgUuids",
        "data_source": "dataSource",
    },
)
class PowerpackWidgetGeomapDefinitionRequestQueryMetricQuery:
    def __init__(
        self,
        *,
        name: builtins.str,
        query: builtins.str,
        aggregator: typing.Optional[builtins.str] = None,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        data_source: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param name: The name of the query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param query: The metrics query definition. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        :param aggregator: The aggregation methods available for metrics queries. Valid values are ``avg``, ``min``, ``max``, ``sum``, ``last``, ``area``, ``l2norm``, ``percentile``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregator Powerpack#aggregator}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param data_source: The data source for metrics queries. Defaults to ``"metrics"``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c7bb9b39d4093adcc0a783f83ee24217f9c63c0a8ed3ec1f7bbc602b464bfd8c)
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument query", value=query, expected_type=type_hints["query"])
            check_type(argname="argument aggregator", value=aggregator, expected_type=type_hints["aggregator"])
            check_type(argname="argument cross_org_uuids", value=cross_org_uuids, expected_type=type_hints["cross_org_uuids"])
            check_type(argname="argument data_source", value=data_source, expected_type=type_hints["data_source"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "name": name,
            "query": query,
        }
        if aggregator is not None:
            self._values["aggregator"] = aggregator
        if cross_org_uuids is not None:
            self._values["cross_org_uuids"] = cross_org_uuids
        if data_source is not None:
            self._values["data_source"] = data_source

    @builtins.property
    def name(self) -> builtins.str:
        '''The name of the query for use in formulas.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        '''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def query(self) -> builtins.str:
        '''The metrics query definition.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        '''
        result = self._values.get("query")
        assert result is not None, "Required property 'query' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def aggregator(self) -> typing.Optional[builtins.str]:
        '''The aggregation methods available for metrics queries. Valid values are ``avg``, ``min``, ``max``, ``sum``, ``last``, ``area``, ``l2norm``, ``percentile``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregator Powerpack#aggregator}
        '''
        result = self._values.get("aggregator")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def cross_org_uuids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''The source organization UUID for cross organization queries. Feature in Private Beta.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        '''
        result = self._values.get("cross_org_uuids")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def data_source(self) -> typing.Optional[builtins.str]:
        '''The data source for metrics queries. Defaults to ``"metrics"``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        '''
        result = self._values.get("data_source")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetGeomapDefinitionRequestQueryMetricQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetGeomapDefinitionRequestQueryMetricQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetGeomapDefinitionRequestQueryMetricQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4b9c531210b460d5a6c51aa645d3f992f449041d0b8794f0bdab4426561d4d4d)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetAggregator")
    def reset_aggregator(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAggregator", []))

    @jsii.member(jsii_name="resetCrossOrgUuids")
    def reset_cross_org_uuids(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCrossOrgUuids", []))

    @jsii.member(jsii_name="resetDataSource")
    def reset_data_source(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDataSource", []))

    @builtins.property
    @jsii.member(jsii_name="aggregatorInput")
    def aggregator_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregatorInput"))

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuidsInput")
    def cross_org_uuids_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "crossOrgUuidsInput"))

    @builtins.property
    @jsii.member(jsii_name="dataSourceInput")
    def data_source_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "dataSourceInput"))

    @builtins.property
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property
    @jsii.member(jsii_name="queryInput")
    def query_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "queryInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregator")
    def aggregator(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregator"))

    @aggregator.setter
    def aggregator(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__49f76c0dcbfe3ea478e076e5f360d592f76e0e8e307bc261e45037e8f33a17cd)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregator", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuids")
    def cross_org_uuids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "crossOrgUuids"))

    @cross_org_uuids.setter
    def cross_org_uuids(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4616aa64650246765039788d79e13b8c543928757be19ae1b75d594e160130f3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "crossOrgUuids", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="dataSource")
    def data_source(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "dataSource"))

    @data_source.setter
    def data_source(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__12a254cd99c7030a21081c92cec5da92436c16cf4fd8f7b093f985ee9b417c68)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "dataSource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4c6a3347a2bfdd03ca9010b6cd5d7f6f73140d0d2c0f0a0c839785fe1d74f854)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "name", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="query")
    def query(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "query"))

    @query.setter
    def query(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__964ce79a518c80ec9139fac4d936312d3ff3c8aacf5f6af4e598b1d8308f7d8f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "query", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetGeomapDefinitionRequestQueryMetricQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetGeomapDefinitionRequestQueryMetricQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetGeomapDefinitionRequestQueryMetricQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4717a5a11295d8d5a5dbda05bca90a499213440677094e623b1d39d7d17f4e54)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetGeomapDefinitionRequestQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetGeomapDefinitionRequestQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fa0c032d048fc60b651ead199d5c17bea8b583926d7a86f81e19bf42dfbc6ff1)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putApmDependencyStatsQuery")
    def put_apm_dependency_stats_query(
        self,
        *,
        data_source: builtins.str,
        env: builtins.str,
        name: builtins.str,
        operation_name: builtins.str,
        resource_name: builtins.str,
        service: builtins.str,
        stat: builtins.str,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        is_upstream: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        primary_tag_name: typing.Optional[builtins.str] = None,
        primary_tag_value: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param data_source: The data source for APM Dependency Stats queries. Valid values are ``apm_dependency_stats``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param env: APM environment. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#env Powerpack#env}
        :param name: The name of query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param operation_name: Name of operation on service. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#operation_name Powerpack#operation_name}
        :param resource_name: APM resource. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#resource_name Powerpack#resource_name}
        :param service: APM service. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#service Powerpack#service}
        :param stat: APM statistic. Valid values are ``avg_duration``, ``avg_root_duration``, ``avg_spans_per_trace``, ``error_rate``, ``pct_exec_time``, ``pct_of_traces``, ``total_traces_count``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#stat Powerpack#stat}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param is_upstream: Determines whether stats for upstream or downstream dependencies should be queried. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#is_upstream Powerpack#is_upstream}
        :param primary_tag_name: The name of the second primary tag used within APM; required when ``primary_tag_value`` is specified. See https://docs.datadoghq.com/tracing/guide/setting_primary_tags_to_scope/#add-a-second-primary-tag-in-datadog. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_name Powerpack#primary_tag_name}
        :param primary_tag_value: Filter APM data by the second primary tag. ``primary_tag_name`` must also be specified. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_value Powerpack#primary_tag_value}
        '''
        value = PowerpackWidgetGeomapDefinitionRequestQueryApmDependencyStatsQuery(
            data_source=data_source,
            env=env,
            name=name,
            operation_name=operation_name,
            resource_name=resource_name,
            service=service,
            stat=stat,
            cross_org_uuids=cross_org_uuids,
            is_upstream=is_upstream,
            primary_tag_name=primary_tag_name,
            primary_tag_value=primary_tag_value,
        )

        return typing.cast(None, jsii.invoke(self, "putApmDependencyStatsQuery", [value]))

    @jsii.member(jsii_name="putApmResourceStatsQuery")
    def put_apm_resource_stats_query(
        self,
        *,
        data_source: builtins.str,
        env: builtins.str,
        name: builtins.str,
        service: builtins.str,
        stat: builtins.str,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        group_by: typing.Optional[typing.Sequence[builtins.str]] = None,
        operation_name: typing.Optional[builtins.str] = None,
        primary_tag_name: typing.Optional[builtins.str] = None,
        primary_tag_value: typing.Optional[builtins.str] = None,
        resource_name: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param data_source: The data source for APM Resource Stats queries. Valid values are ``apm_resource_stats``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param env: APM environment. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#env Powerpack#env}
        :param name: The name of query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param service: APM service. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#service Powerpack#service}
        :param stat: APM statistic. Valid values are ``errors``, ``error_rate``, ``hits``, ``latency_avg``, ``latency_distribution``, ``latency_max``, ``latency_p50``, ``latency_p75``, ``latency_p90``, ``latency_p95``, ``latency_p99``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#stat Powerpack#stat}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param group_by: Array of fields to group results by. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param operation_name: Name of operation on service. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#operation_name Powerpack#operation_name}
        :param primary_tag_name: The name of the second primary tag used within APM; required when ``primary_tag_value`` is specified. See https://docs.datadoghq.com/tracing/guide/setting_primary_tags_to_scope/#add-a-second-primary-tag-in-datadog. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_name Powerpack#primary_tag_name}
        :param primary_tag_value: Filter APM data by the second primary tag. ``primary_tag_name`` must also be specified. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_value Powerpack#primary_tag_value}
        :param resource_name: APM resource. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#resource_name Powerpack#resource_name}
        '''
        value = PowerpackWidgetGeomapDefinitionRequestQueryApmResourceStatsQuery(
            data_source=data_source,
            env=env,
            name=name,
            service=service,
            stat=stat,
            cross_org_uuids=cross_org_uuids,
            group_by=group_by,
            operation_name=operation_name,
            primary_tag_name=primary_tag_name,
            primary_tag_value=primary_tag_value,
            resource_name=resource_name,
        )

        return typing.cast(None, jsii.invoke(self, "putApmResourceStatsQuery", [value]))

    @jsii.member(jsii_name="putCloudCostQuery")
    def put_cloud_cost_query(
        self,
        *,
        data_source: builtins.str,
        name: builtins.str,
        query: builtins.str,
        aggregator: typing.Optional[builtins.str] = None,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
    ) -> None:
        '''
        :param data_source: The data source for cloud cost queries. Valid values are ``cloud_cost``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param name: The name of the query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param query: The cloud cost query definition. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        :param aggregator: The aggregation methods available for cloud cost queries. Valid values are ``avg``, ``last``, ``max``, ``min``, ``sum``, ``percentile``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregator Powerpack#aggregator}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        '''
        value = PowerpackWidgetGeomapDefinitionRequestQueryCloudCostQuery(
            data_source=data_source,
            name=name,
            query=query,
            aggregator=aggregator,
            cross_org_uuids=cross_org_uuids,
        )

        return typing.cast(None, jsii.invoke(self, "putCloudCostQuery", [value]))

    @jsii.member(jsii_name="putEventQuery")
    def put_event_query(
        self,
        *,
        compute: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetGeomapDefinitionRequestQueryEventQueryCompute, typing.Dict[builtins.str, typing.Any]]]],
        data_source: builtins.str,
        name: builtins.str,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetGeomapDefinitionRequestQueryEventQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
        indexes: typing.Optional[typing.Sequence[builtins.str]] = None,
        search: typing.Optional[typing.Union[PowerpackWidgetGeomapDefinitionRequestQueryEventQuerySearch, typing.Dict[builtins.str, typing.Any]]] = None,
        storage: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param compute: compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute Powerpack#compute}
        :param data_source: The data source for event platform-based queries. Valid values are ``logs``, ``spans``, ``network``, ``rum``, ``security_signals``, ``profiles``, ``audit``, ``events``, ``ci_tests``, ``ci_pipelines``, ``incident_analytics``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param name: The name of query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param indexes: An array of index names to query in the stream. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#indexes Powerpack#indexes}
        :param search: search block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search Powerpack#search}
        :param storage: Storage location (private beta). Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#storage Powerpack#storage}
        '''
        value = PowerpackWidgetGeomapDefinitionRequestQueryEventQuery(
            compute=compute,
            data_source=data_source,
            name=name,
            cross_org_uuids=cross_org_uuids,
            group_by=group_by,
            indexes=indexes,
            search=search,
            storage=storage,
        )

        return typing.cast(None, jsii.invoke(self, "putEventQuery", [value]))

    @jsii.member(jsii_name="putMetricQuery")
    def put_metric_query(
        self,
        *,
        name: builtins.str,
        query: builtins.str,
        aggregator: typing.Optional[builtins.str] = None,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        data_source: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param name: The name of the query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param query: The metrics query definition. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        :param aggregator: The aggregation methods available for metrics queries. Valid values are ``avg``, ``min``, ``max``, ``sum``, ``last``, ``area``, ``l2norm``, ``percentile``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregator Powerpack#aggregator}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param data_source: The data source for metrics queries. Defaults to ``"metrics"``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        '''
        value = PowerpackWidgetGeomapDefinitionRequestQueryMetricQuery(
            name=name,
            query=query,
            aggregator=aggregator,
            cross_org_uuids=cross_org_uuids,
            data_source=data_source,
        )

        return typing.cast(None, jsii.invoke(self, "putMetricQuery", [value]))

    @jsii.member(jsii_name="putProcessQuery")
    def put_process_query(
        self,
        *,
        data_source: builtins.str,
        metric: builtins.str,
        name: builtins.str,
        aggregator: typing.Optional[builtins.str] = None,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        is_normalized_cpu: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        limit: typing.Optional[jsii.Number] = None,
        sort: typing.Optional[builtins.str] = None,
        tag_filters: typing.Optional[typing.Sequence[builtins.str]] = None,
        text_filter: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param data_source: The data source for process queries. Valid values are ``process``, ``container``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param metric: The process metric name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        :param name: The name of query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param aggregator: The aggregation methods available for metrics queries. Valid values are ``avg``, ``min``, ``max``, ``sum``, ``last``, ``area``, ``l2norm``, ``percentile``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregator Powerpack#aggregator}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param is_normalized_cpu: Whether to normalize the CPU percentages. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#is_normalized_cpu Powerpack#is_normalized_cpu}
        :param limit: The number of hits to return. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param sort: The direction of the sort. Valid values are ``asc``, ``desc``. Defaults to ``"desc"``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort Powerpack#sort}
        :param tag_filters: An array of tags to filter by. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#tag_filters Powerpack#tag_filters}
        :param text_filter: The text to use as a filter. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#text_filter Powerpack#text_filter}
        '''
        value = PowerpackWidgetGeomapDefinitionRequestQueryProcessQuery(
            data_source=data_source,
            metric=metric,
            name=name,
            aggregator=aggregator,
            cross_org_uuids=cross_org_uuids,
            is_normalized_cpu=is_normalized_cpu,
            limit=limit,
            sort=sort,
            tag_filters=tag_filters,
            text_filter=text_filter,
        )

        return typing.cast(None, jsii.invoke(self, "putProcessQuery", [value]))

    @jsii.member(jsii_name="putSloQuery")
    def put_slo_query(
        self,
        *,
        data_source: builtins.str,
        measure: builtins.str,
        slo_id: builtins.str,
        additional_query_filters: typing.Optional[builtins.str] = None,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        group_mode: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
        slo_query_type: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param data_source: The data source for SLO queries. Valid values are ``slo``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param measure: SLO measures queries. Valid values are ``good_events``, ``bad_events``, ``good_minutes``, ``bad_minutes``, ``slo_status``, ``error_budget_remaining``, ``burn_rate``, ``error_budget_burndown``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#measure Powerpack#measure}
        :param slo_id: ID of an SLO to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#slo_id Powerpack#slo_id}
        :param additional_query_filters: Additional filters applied to the SLO query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#additional_query_filters Powerpack#additional_query_filters}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param group_mode: Group mode to query measures. Valid values are ``overall``, ``components``. Defaults to ``"overall"``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_mode Powerpack#group_mode}
        :param name: The name of query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param slo_query_type: type of the SLO to query. Valid values are ``metric``, ``monitor``, ``time_slice``. Defaults to ``"metric"``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#slo_query_type Powerpack#slo_query_type}
        '''
        value = PowerpackWidgetGeomapDefinitionRequestQuerySloQuery(
            data_source=data_source,
            measure=measure,
            slo_id=slo_id,
            additional_query_filters=additional_query_filters,
            cross_org_uuids=cross_org_uuids,
            group_mode=group_mode,
            name=name,
            slo_query_type=slo_query_type,
        )

        return typing.cast(None, jsii.invoke(self, "putSloQuery", [value]))

    @jsii.member(jsii_name="resetApmDependencyStatsQuery")
    def reset_apm_dependency_stats_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetApmDependencyStatsQuery", []))

    @jsii.member(jsii_name="resetApmResourceStatsQuery")
    def reset_apm_resource_stats_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetApmResourceStatsQuery", []))

    @jsii.member(jsii_name="resetCloudCostQuery")
    def reset_cloud_cost_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCloudCostQuery", []))

    @jsii.member(jsii_name="resetEventQuery")
    def reset_event_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetEventQuery", []))

    @jsii.member(jsii_name="resetMetricQuery")
    def reset_metric_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMetricQuery", []))

    @jsii.member(jsii_name="resetProcessQuery")
    def reset_process_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetProcessQuery", []))

    @jsii.member(jsii_name="resetSloQuery")
    def reset_slo_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSloQuery", []))

    @builtins.property
    @jsii.member(jsii_name="apmDependencyStatsQuery")
    def apm_dependency_stats_query(
        self,
    ) -> PowerpackWidgetGeomapDefinitionRequestQueryApmDependencyStatsQueryOutputReference:
        return typing.cast(PowerpackWidgetGeomapDefinitionRequestQueryApmDependencyStatsQueryOutputReference, jsii.get(self, "apmDependencyStatsQuery"))

    @builtins.property
    @jsii.member(jsii_name="apmResourceStatsQuery")
    def apm_resource_stats_query(
        self,
    ) -> PowerpackWidgetGeomapDefinitionRequestQueryApmResourceStatsQueryOutputReference:
        return typing.cast(PowerpackWidgetGeomapDefinitionRequestQueryApmResourceStatsQueryOutputReference, jsii.get(self, "apmResourceStatsQuery"))

    @builtins.property
    @jsii.member(jsii_name="cloudCostQuery")
    def cloud_cost_query(
        self,
    ) -> PowerpackWidgetGeomapDefinitionRequestQueryCloudCostQueryOutputReference:
        return typing.cast(PowerpackWidgetGeomapDefinitionRequestQueryCloudCostQueryOutputReference, jsii.get(self, "cloudCostQuery"))

    @builtins.property
    @jsii.member(jsii_name="eventQuery")
    def event_query(
        self,
    ) -> PowerpackWidgetGeomapDefinitionRequestQueryEventQueryOutputReference:
        return typing.cast(PowerpackWidgetGeomapDefinitionRequestQueryEventQueryOutputReference, jsii.get(self, "eventQuery"))

    @builtins.property
    @jsii.member(jsii_name="metricQuery")
    def metric_query(
        self,
    ) -> PowerpackWidgetGeomapDefinitionRequestQueryMetricQueryOutputReference:
        return typing.cast(PowerpackWidgetGeomapDefinitionRequestQueryMetricQueryOutputReference, jsii.get(self, "metricQuery"))

    @builtins.property
    @jsii.member(jsii_name="processQuery")
    def process_query(
        self,
    ) -> "PowerpackWidgetGeomapDefinitionRequestQueryProcessQueryOutputReference":
        return typing.cast("PowerpackWidgetGeomapDefinitionRequestQueryProcessQueryOutputReference", jsii.get(self, "processQuery"))

    @builtins.property
    @jsii.member(jsii_name="sloQuery")
    def slo_query(
        self,
    ) -> "PowerpackWidgetGeomapDefinitionRequestQuerySloQueryOutputReference":
        return typing.cast("PowerpackWidgetGeomapDefinitionRequestQuerySloQueryOutputReference", jsii.get(self, "sloQuery"))

    @builtins.property
    @jsii.member(jsii_name="apmDependencyStatsQueryInput")
    def apm_dependency_stats_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetGeomapDefinitionRequestQueryApmDependencyStatsQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetGeomapDefinitionRequestQueryApmDependencyStatsQuery], jsii.get(self, "apmDependencyStatsQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="apmResourceStatsQueryInput")
    def apm_resource_stats_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetGeomapDefinitionRequestQueryApmResourceStatsQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetGeomapDefinitionRequestQueryApmResourceStatsQuery], jsii.get(self, "apmResourceStatsQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="cloudCostQueryInput")
    def cloud_cost_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetGeomapDefinitionRequestQueryCloudCostQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetGeomapDefinitionRequestQueryCloudCostQuery], jsii.get(self, "cloudCostQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="eventQueryInput")
    def event_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetGeomapDefinitionRequestQueryEventQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetGeomapDefinitionRequestQueryEventQuery], jsii.get(self, "eventQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="metricQueryInput")
    def metric_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetGeomapDefinitionRequestQueryMetricQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetGeomapDefinitionRequestQueryMetricQuery], jsii.get(self, "metricQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="processQueryInput")
    def process_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetGeomapDefinitionRequestQueryProcessQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetGeomapDefinitionRequestQueryProcessQuery"], jsii.get(self, "processQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="sloQueryInput")
    def slo_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetGeomapDefinitionRequestQuerySloQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetGeomapDefinitionRequestQuerySloQuery"], jsii.get(self, "sloQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetGeomapDefinitionRequestQuery]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetGeomapDefinitionRequestQuery]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetGeomapDefinitionRequestQuery]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__467bb69adb09d0893a6b6e939179594e02c12b991bcad033c71fd8df0e1920a9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetGeomapDefinitionRequestQueryProcessQuery",
    jsii_struct_bases=[],
    name_mapping={
        "data_source": "dataSource",
        "metric": "metric",
        "name": "name",
        "aggregator": "aggregator",
        "cross_org_uuids": "crossOrgUuids",
        "is_normalized_cpu": "isNormalizedCpu",
        "limit": "limit",
        "sort": "sort",
        "tag_filters": "tagFilters",
        "text_filter": "textFilter",
    },
)
class PowerpackWidgetGeomapDefinitionRequestQueryProcessQuery:
    def __init__(
        self,
        *,
        data_source: builtins.str,
        metric: builtins.str,
        name: builtins.str,
        aggregator: typing.Optional[builtins.str] = None,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        is_normalized_cpu: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        limit: typing.Optional[jsii.Number] = None,
        sort: typing.Optional[builtins.str] = None,
        tag_filters: typing.Optional[typing.Sequence[builtins.str]] = None,
        text_filter: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param data_source: The data source for process queries. Valid values are ``process``, ``container``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param metric: The process metric name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        :param name: The name of query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param aggregator: The aggregation methods available for metrics queries. Valid values are ``avg``, ``min``, ``max``, ``sum``, ``last``, ``area``, ``l2norm``, ``percentile``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregator Powerpack#aggregator}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param is_normalized_cpu: Whether to normalize the CPU percentages. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#is_normalized_cpu Powerpack#is_normalized_cpu}
        :param limit: The number of hits to return. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param sort: The direction of the sort. Valid values are ``asc``, ``desc``. Defaults to ``"desc"``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort Powerpack#sort}
        :param tag_filters: An array of tags to filter by. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#tag_filters Powerpack#tag_filters}
        :param text_filter: The text to use as a filter. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#text_filter Powerpack#text_filter}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__52f9cae55a860946bfd00f9f59bc74df403eb80830c6ab451f2faf25c3829f9a)
            check_type(argname="argument data_source", value=data_source, expected_type=type_hints["data_source"])
            check_type(argname="argument metric", value=metric, expected_type=type_hints["metric"])
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument aggregator", value=aggregator, expected_type=type_hints["aggregator"])
            check_type(argname="argument cross_org_uuids", value=cross_org_uuids, expected_type=type_hints["cross_org_uuids"])
            check_type(argname="argument is_normalized_cpu", value=is_normalized_cpu, expected_type=type_hints["is_normalized_cpu"])
            check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
            check_type(argname="argument sort", value=sort, expected_type=type_hints["sort"])
            check_type(argname="argument tag_filters", value=tag_filters, expected_type=type_hints["tag_filters"])
            check_type(argname="argument text_filter", value=text_filter, expected_type=type_hints["text_filter"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "data_source": data_source,
            "metric": metric,
            "name": name,
        }
        if aggregator is not None:
            self._values["aggregator"] = aggregator
        if cross_org_uuids is not None:
            self._values["cross_org_uuids"] = cross_org_uuids
        if is_normalized_cpu is not None:
            self._values["is_normalized_cpu"] = is_normalized_cpu
        if limit is not None:
            self._values["limit"] = limit
        if sort is not None:
            self._values["sort"] = sort
        if tag_filters is not None:
            self._values["tag_filters"] = tag_filters
        if text_filter is not None:
            self._values["text_filter"] = text_filter

    @builtins.property
    def data_source(self) -> builtins.str:
        '''The data source for process queries. Valid values are ``process``, ``container``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        '''
        result = self._values.get("data_source")
        assert result is not None, "Required property 'data_source' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def metric(self) -> builtins.str:
        '''The process metric name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        '''
        result = self._values.get("metric")
        assert result is not None, "Required property 'metric' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def name(self) -> builtins.str:
        '''The name of query for use in formulas.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        '''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def aggregator(self) -> typing.Optional[builtins.str]:
        '''The aggregation methods available for metrics queries. Valid values are ``avg``, ``min``, ``max``, ``sum``, ``last``, ``area``, ``l2norm``, ``percentile``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregator Powerpack#aggregator}
        '''
        result = self._values.get("aggregator")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def cross_org_uuids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''The source organization UUID for cross organization queries. Feature in Private Beta.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        '''
        result = self._values.get("cross_org_uuids")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def is_normalized_cpu(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        '''Whether to normalize the CPU percentages.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#is_normalized_cpu Powerpack#is_normalized_cpu}
        '''
        result = self._values.get("is_normalized_cpu")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)

    @builtins.property
    def limit(self) -> typing.Optional[jsii.Number]:
        '''The number of hits to return.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        '''
        result = self._values.get("limit")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def sort(self) -> typing.Optional[builtins.str]:
        '''The direction of the sort. Valid values are ``asc``, ``desc``. Defaults to ``"desc"``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort Powerpack#sort}
        '''
        result = self._values.get("sort")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def tag_filters(self) -> typing.Optional[typing.List[builtins.str]]:
        '''An array of tags to filter by.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#tag_filters Powerpack#tag_filters}
        '''
        result = self._values.get("tag_filters")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def text_filter(self) -> typing.Optional[builtins.str]:
        '''The text to use as a filter.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#text_filter Powerpack#text_filter}
        '''
        result = self._values.get("text_filter")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetGeomapDefinitionRequestQueryProcessQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetGeomapDefinitionRequestQueryProcessQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetGeomapDefinitionRequestQueryProcessQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8db84c94f3c0a6ee718d9bb0cca6befee8ebb3f026bd229f993ced110da27f75)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetAggregator")
    def reset_aggregator(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAggregator", []))

    @jsii.member(jsii_name="resetCrossOrgUuids")
    def reset_cross_org_uuids(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCrossOrgUuids", []))

    @jsii.member(jsii_name="resetIsNormalizedCpu")
    def reset_is_normalized_cpu(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetIsNormalizedCpu", []))

    @jsii.member(jsii_name="resetLimit")
    def reset_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLimit", []))

    @jsii.member(jsii_name="resetSort")
    def reset_sort(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSort", []))

    @jsii.member(jsii_name="resetTagFilters")
    def reset_tag_filters(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTagFilters", []))

    @jsii.member(jsii_name="resetTextFilter")
    def reset_text_filter(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTextFilter", []))

    @builtins.property
    @jsii.member(jsii_name="aggregatorInput")
    def aggregator_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregatorInput"))

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuidsInput")
    def cross_org_uuids_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "crossOrgUuidsInput"))

    @builtins.property
    @jsii.member(jsii_name="dataSourceInput")
    def data_source_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "dataSourceInput"))

    @builtins.property
    @jsii.member(jsii_name="isNormalizedCpuInput")
    def is_normalized_cpu_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "isNormalizedCpuInput"))

    @builtins.property
    @jsii.member(jsii_name="limitInput")
    def limit_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "limitInput"))

    @builtins.property
    @jsii.member(jsii_name="metricInput")
    def metric_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "metricInput"))

    @builtins.property
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property
    @jsii.member(jsii_name="sortInput")
    def sort_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "sortInput"))

    @builtins.property
    @jsii.member(jsii_name="tagFiltersInput")
    def tag_filters_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "tagFiltersInput"))

    @builtins.property
    @jsii.member(jsii_name="textFilterInput")
    def text_filter_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "textFilterInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregator")
    def aggregator(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregator"))

    @aggregator.setter
    def aggregator(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cc16cc0d6db5d36e89b4125a7a0500ee10644e02fcf33a2ec4fc88e8a80b5076)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregator", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuids")
    def cross_org_uuids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "crossOrgUuids"))

    @cross_org_uuids.setter
    def cross_org_uuids(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__49b8c8496ecb4bde06a734210f06f8f489fcd25875199f9ea0aa619b57e93023)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "crossOrgUuids", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="dataSource")
    def data_source(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "dataSource"))

    @data_source.setter
    def data_source(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a4035aee36f1cdfd4725ee2e2733a421f0b474efe06f037af5b8da46beef609d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "dataSource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="isNormalizedCpu")
    def is_normalized_cpu(
        self,
    ) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "isNormalizedCpu"))

    @is_normalized_cpu.setter
    def is_normalized_cpu(
        self,
        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9f7666fae9df8e6a771bdc8625199ee3d2d5be1d616e16c8c81c256b2c6b0740)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "isNormalizedCpu", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="limit")
    def limit(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "limit"))

    @limit.setter
    def limit(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__77ef1ff4cedf001e6a971cdebc174c8e50f9fcdcd6f96cccbec8312e0fc61868)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "limit", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="metric")
    def metric(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "metric"))

    @metric.setter
    def metric(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bb9cc80c65930bf02e3034256df5b8b717ee3d00f9d61df0062331bec7cbc5e3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "metric", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4a4d128222593a643640eb26d3bca15c868c1bda1d578ecc458162b05b08c3ee)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "name", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="sort")
    def sort(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "sort"))

    @sort.setter
    def sort(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cfc914980eed154ab269b7f74bca9604a8ce54f40d28d889e725b7c0ec8fa267)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "sort", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="tagFilters")
    def tag_filters(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "tagFilters"))

    @tag_filters.setter
    def tag_filters(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3b79f5992dadd6d4d929b3584d4783c3e8a0b4fd1b23a1b1c23909dc66dd9a71)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "tagFilters", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="textFilter")
    def text_filter(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "textFilter"))

    @text_filter.setter
    def text_filter(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ec23e07782d21f1388cf1726b575dfc9b2c566cd534dc35fef4c3fd59097b205)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "textFilter", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetGeomapDefinitionRequestQueryProcessQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetGeomapDefinitionRequestQueryProcessQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetGeomapDefinitionRequestQueryProcessQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__900ffb9e802152378b2ad95cb18849df766d675ccaf48a332bcb7f1a6c188844)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetGeomapDefinitionRequestQuerySloQuery",
    jsii_struct_bases=[],
    name_mapping={
        "data_source": "dataSource",
        "measure": "measure",
        "slo_id": "sloId",
        "additional_query_filters": "additionalQueryFilters",
        "cross_org_uuids": "crossOrgUuids",
        "group_mode": "groupMode",
        "name": "name",
        "slo_query_type": "sloQueryType",
    },
)
class PowerpackWidgetGeomapDefinitionRequestQuerySloQuery:
    def __init__(
        self,
        *,
        data_source: builtins.str,
        measure: builtins.str,
        slo_id: builtins.str,
        additional_query_filters: typing.Optional[builtins.str] = None,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        group_mode: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
        slo_query_type: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param data_source: The data source for SLO queries. Valid values are ``slo``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param measure: SLO measures queries. Valid values are ``good_events``, ``bad_events``, ``good_minutes``, ``bad_minutes``, ``slo_status``, ``error_budget_remaining``, ``burn_rate``, ``error_budget_burndown``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#measure Powerpack#measure}
        :param slo_id: ID of an SLO to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#slo_id Powerpack#slo_id}
        :param additional_query_filters: Additional filters applied to the SLO query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#additional_query_filters Powerpack#additional_query_filters}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param group_mode: Group mode to query measures. Valid values are ``overall``, ``components``. Defaults to ``"overall"``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_mode Powerpack#group_mode}
        :param name: The name of query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param slo_query_type: type of the SLO to query. Valid values are ``metric``, ``monitor``, ``time_slice``. Defaults to ``"metric"``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#slo_query_type Powerpack#slo_query_type}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__56a1b16ef1c7755a15cfd2291545b2191629fdefcac527d36bb795a3d425c35f)
            check_type(argname="argument data_source", value=data_source, expected_type=type_hints["data_source"])
            check_type(argname="argument measure", value=measure, expected_type=type_hints["measure"])
            check_type(argname="argument slo_id", value=slo_id, expected_type=type_hints["slo_id"])
            check_type(argname="argument additional_query_filters", value=additional_query_filters, expected_type=type_hints["additional_query_filters"])
            check_type(argname="argument cross_org_uuids", value=cross_org_uuids, expected_type=type_hints["cross_org_uuids"])
            check_type(argname="argument group_mode", value=group_mode, expected_type=type_hints["group_mode"])
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument slo_query_type", value=slo_query_type, expected_type=type_hints["slo_query_type"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "data_source": data_source,
            "measure": measure,
            "slo_id": slo_id,
        }
        if additional_query_filters is not None:
            self._values["additional_query_filters"] = additional_query_filters
        if cross_org_uuids is not None:
            self._values["cross_org_uuids"] = cross_org_uuids
        if group_mode is not None:
            self._values["group_mode"] = group_mode
        if name is not None:
            self._values["name"] = name
        if slo_query_type is not None:
            self._values["slo_query_type"] = slo_query_type

    @builtins.property
    def data_source(self) -> builtins.str:
        '''The data source for SLO queries. Valid values are ``slo``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        '''
        result = self._values.get("data_source")
        assert result is not None, "Required property 'data_source' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def measure(self) -> builtins.str:
        '''SLO measures queries. Valid values are ``good_events``, ``bad_events``, ``good_minutes``, ``bad_minutes``, ``slo_status``, ``error_budget_remaining``, ``burn_rate``, ``error_budget_burndown``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#measure Powerpack#measure}
        '''
        result = self._values.get("measure")
        assert result is not None, "Required property 'measure' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def slo_id(self) -> builtins.str:
        '''ID of an SLO to query.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#slo_id Powerpack#slo_id}
        '''
        result = self._values.get("slo_id")
        assert result is not None, "Required property 'slo_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def additional_query_filters(self) -> typing.Optional[builtins.str]:
        '''Additional filters applied to the SLO query.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#additional_query_filters Powerpack#additional_query_filters}
        '''
        result = self._values.get("additional_query_filters")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def cross_org_uuids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''The source organization UUID for cross organization queries. Feature in Private Beta.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        '''
        result = self._values.get("cross_org_uuids")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def group_mode(self) -> typing.Optional[builtins.str]:
        '''Group mode to query measures. Valid values are ``overall``, ``components``. Defaults to ``"overall"``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_mode Powerpack#group_mode}
        '''
        result = self._values.get("group_mode")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''The name of query for use in formulas.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        '''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def slo_query_type(self) -> typing.Optional[builtins.str]:
        '''type of the SLO to query. Valid values are ``metric``, ``monitor``, ``time_slice``. Defaults to ``"metric"``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#slo_query_type Powerpack#slo_query_type}
        '''
        result = self._values.get("slo_query_type")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetGeomapDefinitionRequestQuerySloQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetGeomapDefinitionRequestQuerySloQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetGeomapDefinitionRequestQuerySloQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5ffd7ce42dfa6beac1c5f77146d4c0d1a825691b24f6229003dfaf24f68e9584)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetAdditionalQueryFilters")
    def reset_additional_query_filters(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAdditionalQueryFilters", []))

    @jsii.member(jsii_name="resetCrossOrgUuids")
    def reset_cross_org_uuids(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCrossOrgUuids", []))

    @jsii.member(jsii_name="resetGroupMode")
    def reset_group_mode(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGroupMode", []))

    @jsii.member(jsii_name="resetName")
    def reset_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetName", []))

    @jsii.member(jsii_name="resetSloQueryType")
    def reset_slo_query_type(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSloQueryType", []))

    @builtins.property
    @jsii.member(jsii_name="additionalQueryFiltersInput")
    def additional_query_filters_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "additionalQueryFiltersInput"))

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuidsInput")
    def cross_org_uuids_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "crossOrgUuidsInput"))

    @builtins.property
    @jsii.member(jsii_name="dataSourceInput")
    def data_source_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "dataSourceInput"))

    @builtins.property
    @jsii.member(jsii_name="groupModeInput")
    def group_mode_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "groupModeInput"))

    @builtins.property
    @jsii.member(jsii_name="measureInput")
    def measure_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "measureInput"))

    @builtins.property
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property
    @jsii.member(jsii_name="sloIdInput")
    def slo_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "sloIdInput"))

    @builtins.property
    @jsii.member(jsii_name="sloQueryTypeInput")
    def slo_query_type_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "sloQueryTypeInput"))

    @builtins.property
    @jsii.member(jsii_name="additionalQueryFilters")
    def additional_query_filters(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "additionalQueryFilters"))

    @additional_query_filters.setter
    def additional_query_filters(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ece0c06d88059eb87ae14552733f7c3055b26e71a56a0e15bb8f70d216c489fe)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "additionalQueryFilters", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuids")
    def cross_org_uuids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "crossOrgUuids"))

    @cross_org_uuids.setter
    def cross_org_uuids(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__55baac6251ae540e1095c4dc2413097bcff02f222662ffa5fbe40de3a172bf41)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "crossOrgUuids", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="dataSource")
    def data_source(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "dataSource"))

    @data_source.setter
    def data_source(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a83d27b019433cfbd62dd2816d0a32f0697c0f7a5388d9c3aec34fdec5d45564)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "dataSource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="groupMode")
    def group_mode(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "groupMode"))

    @group_mode.setter
    def group_mode(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__11a752007a488e119713b4395d891ae5bdb1be557be87050bd5b5ca2eb31dbb6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "groupMode", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="measure")
    def measure(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "measure"))

    @measure.setter
    def measure(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__341e57df3a008ccf79dc98dbe772cdeab931830315d74ab65601ca7281714033)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "measure", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dee44d21bbaf479b24cea27b33adc47980f1165524cc3c3a3c3974a7127f253c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "name", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="sloId")
    def slo_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "sloId"))

    @slo_id.setter
    def slo_id(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f3178dd76d894cddf19e6719ffd3e3652ce751209bf22640c60f68265f1012c3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "sloId", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="sloQueryType")
    def slo_query_type(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "sloQueryType"))

    @slo_query_type.setter
    def slo_query_type(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3e0eefb36ac099e798db2b9c735db14dacf0dd320c5cacc8dac296be59f1186a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "sloQueryType", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetGeomapDefinitionRequestQuerySloQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetGeomapDefinitionRequestQuerySloQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetGeomapDefinitionRequestQuerySloQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b720f9bd71f0cae56594d4e75f35bbb96ed5e01812571cbcb2859089c9305e8e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetGeomapDefinitionRequestRumQuery",
    jsii_struct_bases=[],
    name_mapping={
        "index": "index",
        "compute_query": "computeQuery",
        "group_by": "groupBy",
        "multi_compute": "multiCompute",
        "search_query": "searchQuery",
    },
)
class PowerpackWidgetGeomapDefinitionRequestRumQuery:
    def __init__(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union["PowerpackWidgetGeomapDefinitionRequestRumQueryComputeQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetGeomapDefinitionRequestRumQueryGroupBy", typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetGeomapDefinitionRequestRumQueryMultiCompute", typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        if isinstance(compute_query, dict):
            compute_query = PowerpackWidgetGeomapDefinitionRequestRumQueryComputeQuery(**compute_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__587a84af720a880486539c27459522a6f3707c5a69bba918e36d47087d8eba92)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
            check_type(argname="argument compute_query", value=compute_query, expected_type=type_hints["compute_query"])
            check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
            check_type(argname="argument multi_compute", value=multi_compute, expected_type=type_hints["multi_compute"])
            check_type(argname="argument search_query", value=search_query, expected_type=type_hints["search_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "index": index,
        }
        if compute_query is not None:
            self._values["compute_query"] = compute_query
        if group_by is not None:
            self._values["group_by"] = group_by
        if multi_compute is not None:
            self._values["multi_compute"] = multi_compute
        if search_query is not None:
            self._values["search_query"] = search_query

    @builtins.property
    def index(self) -> builtins.str:
        '''The name of the index to query.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        '''
        result = self._values.get("index")
        assert result is not None, "Required property 'index' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def compute_query(
        self,
    ) -> typing.Optional["PowerpackWidgetGeomapDefinitionRequestRumQueryComputeQuery"]:
        '''compute_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        '''
        result = self._values.get("compute_query")
        return typing.cast(typing.Optional["PowerpackWidgetGeomapDefinitionRequestRumQueryComputeQuery"], result)

    @builtins.property
    def group_by(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetGeomapDefinitionRequestRumQueryGroupBy"]]]:
        '''group_by block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        '''
        result = self._values.get("group_by")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetGeomapDefinitionRequestRumQueryGroupBy"]]], result)

    @builtins.property
    def multi_compute(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetGeomapDefinitionRequestRumQueryMultiCompute"]]]:
        '''multi_compute block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        '''
        result = self._values.get("multi_compute")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetGeomapDefinitionRequestRumQueryMultiCompute"]]], result)

    @builtins.property
    def search_query(self) -> typing.Optional[builtins.str]:
        '''The search query to use.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        result = self._values.get("search_query")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetGeomapDefinitionRequestRumQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetGeomapDefinitionRequestRumQueryComputeQuery",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetGeomapDefinitionRequestRumQueryComputeQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__88488d28eed6ccebaf12ca5edd8cb5ce3fda649cd2a0991fd47d9ee50039b49e)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetGeomapDefinitionRequestRumQueryComputeQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetGeomapDefinitionRequestRumQueryComputeQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetGeomapDefinitionRequestRumQueryComputeQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7596380ebc17e151dd455b5cbda38b0ba185fd5ec154237075982399a4f8f5c6)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c0691d53e3567e3e1a259dba639aa1cc10571326a209719e79327f0a5a8bac30)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1cbc5d561b39a683b29aa2d8d4ee8ee4eb785826a4ffeb84c7b73a7d2d85e804)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0896f5bb1d2928be45fb2c383e1aa396a19da83dc258daf487e0f96631b1aa58)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetGeomapDefinitionRequestRumQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetGeomapDefinitionRequestRumQueryComputeQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetGeomapDefinitionRequestRumQueryComputeQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__efbcb06bb757dce3fa1e90510e1296318b1f08ee97e3abced9fe0c385976eaa7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetGeomapDefinitionRequestRumQueryGroupBy",
    jsii_struct_bases=[],
    name_mapping={"facet": "facet", "limit": "limit", "sort_query": "sortQuery"},
)
class PowerpackWidgetGeomapDefinitionRequestRumQueryGroupBy:
    def __init__(
        self,
        *,
        facet: typing.Optional[builtins.str] = None,
        limit: typing.Optional[jsii.Number] = None,
        sort_query: typing.Optional[typing.Union["PowerpackWidgetGeomapDefinitionRequestRumQueryGroupBySortQuery", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param limit: The maximum number of items in the group. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param sort_query: sort_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        if isinstance(sort_query, dict):
            sort_query = PowerpackWidgetGeomapDefinitionRequestRumQueryGroupBySortQuery(**sort_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__13d136923134def89511d910bf50bb5762b147e56cca91fa0614b69c706b97e2)
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
            check_type(argname="argument sort_query", value=sort_query, expected_type=type_hints["sort_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if facet is not None:
            self._values["facet"] = facet
        if limit is not None:
            self._values["limit"] = limit
        if sort_query is not None:
            self._values["sort_query"] = sort_query

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def limit(self) -> typing.Optional[jsii.Number]:
        '''The maximum number of items in the group.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        '''
        result = self._values.get("limit")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def sort_query(
        self,
    ) -> typing.Optional["PowerpackWidgetGeomapDefinitionRequestRumQueryGroupBySortQuery"]:
        '''sort_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        result = self._values.get("sort_query")
        return typing.cast(typing.Optional["PowerpackWidgetGeomapDefinitionRequestRumQueryGroupBySortQuery"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetGeomapDefinitionRequestRumQueryGroupBy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetGeomapDefinitionRequestRumQueryGroupByList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetGeomapDefinitionRequestRumQueryGroupByList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3c8a4dbcfc385eb5bd8cc00410cbe4c0b30cbf494974d6b6746781cc99b1e46d)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetGeomapDefinitionRequestRumQueryGroupByOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9ef357be268ccbb45286d706c1632877006c4da77d675474d0b2052f7510efa9)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetGeomapDefinitionRequestRumQueryGroupByOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3fabaf2324f0e71a5b235ac5da20bc324d2da30b120320acfbec7f3c2a06ee18)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4d40492bdae1c7bead1eda1a842d1293cb34c4216a3cf541f597af72dbf0f95b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__877d5563f30efedd1c329633a4b2eeb68dd0caba3afe5efb69201015b02e9c14)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetGeomapDefinitionRequestRumQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetGeomapDefinitionRequestRumQueryGroupBy]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetGeomapDefinitionRequestRumQueryGroupBy]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f9ade2cb1a53b9341482735e41bf688d51e3394fbe3eabd119c3a658955151f8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetGeomapDefinitionRequestRumQueryGroupByOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetGeomapDefinitionRequestRumQueryGroupByOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__09d15f7dc2497241171ad06543198667fb8c3d9aed640c29b8365aea3e958253)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putSortQuery")
    def put_sort_query(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        value = PowerpackWidgetGeomapDefinitionRequestRumQueryGroupBySortQuery(
            aggregation=aggregation, order=order, facet=facet
        )

        return typing.cast(None, jsii.invoke(self, "putSortQuery", [value]))

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetLimit")
    def reset_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLimit", []))

    @jsii.member(jsii_name="resetSortQuery")
    def reset_sort_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSortQuery", []))

    @builtins.property
    @jsii.member(jsii_name="sortQuery")
    def sort_query(
        self,
    ) -> "PowerpackWidgetGeomapDefinitionRequestRumQueryGroupBySortQueryOutputReference":
        return typing.cast("PowerpackWidgetGeomapDefinitionRequestRumQueryGroupBySortQueryOutputReference", jsii.get(self, "sortQuery"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="limitInput")
    def limit_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "limitInput"))

    @builtins.property
    @jsii.member(jsii_name="sortQueryInput")
    def sort_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetGeomapDefinitionRequestRumQueryGroupBySortQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetGeomapDefinitionRequestRumQueryGroupBySortQuery"], jsii.get(self, "sortQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__233baf77a215cea3913ccbd848be43add74a6f14bb7f2f22a48cd3b946a7bd66)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="limit")
    def limit(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "limit"))

    @limit.setter
    def limit(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c3d3f7959b9e06c37964dc29d5e35b6db754c2c230a654f7b543c4f8e1d3903c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "limit", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetGeomapDefinitionRequestRumQueryGroupBy]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetGeomapDefinitionRequestRumQueryGroupBy]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetGeomapDefinitionRequestRumQueryGroupBy]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ab3c2eb512299adc9c2ee68cfc55eae7200f029144db16645d1a5c81ddd52260)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetGeomapDefinitionRequestRumQueryGroupBySortQuery",
    jsii_struct_bases=[],
    name_mapping={"aggregation": "aggregation", "order": "order", "facet": "facet"},
)
class PowerpackWidgetGeomapDefinitionRequestRumQueryGroupBySortQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b9bf572a540faba6278c65be7cbef952233f3b19d063c0c6cfbb6a69c74af8bc)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument order", value=order, expected_type=type_hints["order"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
            "order": order,
        }
        if facet is not None:
            self._values["facet"] = facet

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def order(self) -> builtins.str:
        '''Widget sorting methods. Valid values are ``asc``, ``desc``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        result = self._values.get("order")
        assert result is not None, "Required property 'order' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetGeomapDefinitionRequestRumQueryGroupBySortQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetGeomapDefinitionRequestRumQueryGroupBySortQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetGeomapDefinitionRequestRumQueryGroupBySortQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d8abc5cd65cc5b28ea80fd2e45e2e77153261393623bc6eefe79a5613c3ba7f0)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="orderInput")
    def order_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "orderInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b3b92a428adb67205468b83775da92f02f75596732b8798e047eb9a6264b4399)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__315e0f46757e88e2e5fef194fa8302dedc6ac758b0e5b4855dfabe8adc7aed04)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="order")
    def order(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "order"))

    @order.setter
    def order(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4763159fc5f8883f771af6c0eaa83e4927461c020a2686cf755589cfae9fa0b0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "order", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetGeomapDefinitionRequestRumQueryGroupBySortQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetGeomapDefinitionRequestRumQueryGroupBySortQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetGeomapDefinitionRequestRumQueryGroupBySortQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__08be40084c4aec48a7940d2666fbb3c466922927567abf89e13928126b1d1d82)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetGeomapDefinitionRequestRumQueryMultiCompute",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetGeomapDefinitionRequestRumQueryMultiCompute:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__97496eb8750dfd8f36ba0cd1d8ae077275ee37f8314e15f89cb3989154fcb9f7)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetGeomapDefinitionRequestRumQueryMultiCompute(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetGeomapDefinitionRequestRumQueryMultiComputeList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetGeomapDefinitionRequestRumQueryMultiComputeList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8c88471fd1e05e5e480d14ff3e38af17a2e1ca32e47a54e109eebfdb0a54ad0e)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetGeomapDefinitionRequestRumQueryMultiComputeOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__88ca1698c94b05f9df481d44480b848ef40026bce20a0cba529e584cd6665f2f)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetGeomapDefinitionRequestRumQueryMultiComputeOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8fd8a71633608d73b1a1cedf47fa0adb8b121bfffe4dff4c1fcd2b6800a31d57)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bd5c642172e91819123d5ccae038f7ea14ef8690970b4c64cbf99d201e3928ae)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__91fd1b4bde0784f6c03b1a168c7a692c0539b2e80b6ecd41c10571d4cac922bf)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetGeomapDefinitionRequestRumQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetGeomapDefinitionRequestRumQueryMultiCompute]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetGeomapDefinitionRequestRumQueryMultiCompute]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a40e071a06ac74b92d69d2628018d7ae78c10309653bc1799436263e977bc9dd)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetGeomapDefinitionRequestRumQueryMultiComputeOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetGeomapDefinitionRequestRumQueryMultiComputeOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__822e5de7e69e36e18d054a2dd5f44ffe7f586db3aaeb8d517be862eea41c71a9)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c18d337c8a199808bcc776968922cfc1b00da9bbe1ac2114cbf465d502765282)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1b4f2ed0da46a2aebccee4bdfb2feb0aabebaa834ac36ac9d3e5513ed6fdad84)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9bdbea0f7fddf212b7aae11a7090a89d128c9249f0143fa7f4b0ae56cc532835)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetGeomapDefinitionRequestRumQueryMultiCompute]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetGeomapDefinitionRequestRumQueryMultiCompute]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetGeomapDefinitionRequestRumQueryMultiCompute]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1474b860075e80f6ee5cbac17201bc4e460094874ed564fd103607b1c61a33ef)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetGeomapDefinitionRequestRumQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetGeomapDefinitionRequestRumQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ae9753622ee9c0a44ea0e615c8a8e4592393c417ee9890a2748c9adb73a2872d)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putComputeQuery")
    def put_compute_query(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        value = PowerpackWidgetGeomapDefinitionRequestRumQueryComputeQuery(
            aggregation=aggregation, facet=facet, interval=interval
        )

        return typing.cast(None, jsii.invoke(self, "putComputeQuery", [value]))

    @jsii.member(jsii_name="putGroupBy")
    def put_group_by(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetGeomapDefinitionRequestRumQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2aa4ba4ea16745a2f2f673746244eb35aa963e64795750a4fe965b30122a96b8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putGroupBy", [value]))

    @jsii.member(jsii_name="putMultiCompute")
    def put_multi_compute(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetGeomapDefinitionRequestRumQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d30604bc032e4ccb7f9ea23a5ba059616daa4979ef64eaeba7cac92e862c01ab)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putMultiCompute", [value]))

    @jsii.member(jsii_name="resetComputeQuery")
    def reset_compute_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetComputeQuery", []))

    @jsii.member(jsii_name="resetGroupBy")
    def reset_group_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGroupBy", []))

    @jsii.member(jsii_name="resetMultiCompute")
    def reset_multi_compute(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMultiCompute", []))

    @jsii.member(jsii_name="resetSearchQuery")
    def reset_search_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSearchQuery", []))

    @builtins.property
    @jsii.member(jsii_name="computeQuery")
    def compute_query(
        self,
    ) -> PowerpackWidgetGeomapDefinitionRequestRumQueryComputeQueryOutputReference:
        return typing.cast(PowerpackWidgetGeomapDefinitionRequestRumQueryComputeQueryOutputReference, jsii.get(self, "computeQuery"))

    @builtins.property
    @jsii.member(jsii_name="groupBy")
    def group_by(self) -> PowerpackWidgetGeomapDefinitionRequestRumQueryGroupByList:
        return typing.cast(PowerpackWidgetGeomapDefinitionRequestRumQueryGroupByList, jsii.get(self, "groupBy"))

    @builtins.property
    @jsii.member(jsii_name="multiCompute")
    def multi_compute(
        self,
    ) -> PowerpackWidgetGeomapDefinitionRequestRumQueryMultiComputeList:
        return typing.cast(PowerpackWidgetGeomapDefinitionRequestRumQueryMultiComputeList, jsii.get(self, "multiCompute"))

    @builtins.property
    @jsii.member(jsii_name="computeQueryInput")
    def compute_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetGeomapDefinitionRequestRumQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetGeomapDefinitionRequestRumQueryComputeQuery], jsii.get(self, "computeQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="groupByInput")
    def group_by_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetGeomapDefinitionRequestRumQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetGeomapDefinitionRequestRumQueryGroupBy]]], jsii.get(self, "groupByInput"))

    @builtins.property
    @jsii.member(jsii_name="indexInput")
    def index_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "indexInput"))

    @builtins.property
    @jsii.member(jsii_name="multiComputeInput")
    def multi_compute_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetGeomapDefinitionRequestRumQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetGeomapDefinitionRequestRumQueryMultiCompute]]], jsii.get(self, "multiComputeInput"))

    @builtins.property
    @jsii.member(jsii_name="searchQueryInput")
    def search_query_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "searchQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="index")
    def index(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "index"))

    @index.setter
    def index(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__93e25232930391cb2c570b7c50a63aece7954b005a60198daedd3211ec0baf60)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "index", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="searchQuery")
    def search_query(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "searchQuery"))

    @search_query.setter
    def search_query(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ea595d1dbee6c7a9568278d8de5488200d1afe103316675eadbb419bd371d908)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "searchQuery", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetGeomapDefinitionRequestRumQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetGeomapDefinitionRequestRumQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetGeomapDefinitionRequestRumQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f7f6f36512bbc946c7f0a741cb3da82513e1612fb5ef3733a936ce7f67ac2dd5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetGeomapDefinitionStyle",
    jsii_struct_bases=[],
    name_mapping={"palette": "palette", "palette_flip": "paletteFlip"},
)
class PowerpackWidgetGeomapDefinitionStyle:
    def __init__(
        self,
        *,
        palette: builtins.str,
        palette_flip: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
    ) -> None:
        '''
        :param palette: The color palette to apply to the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette Powerpack#palette}
        :param palette_flip: A Boolean indicating whether to flip the palette tones. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette_flip Powerpack#palette_flip}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ab8d95f3b77df54052804ec9f16f92adcb8c81e9ba8211aec0d1337354b2a9eb)
            check_type(argname="argument palette", value=palette, expected_type=type_hints["palette"])
            check_type(argname="argument palette_flip", value=palette_flip, expected_type=type_hints["palette_flip"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "palette": palette,
            "palette_flip": palette_flip,
        }

    @builtins.property
    def palette(self) -> builtins.str:
        '''The color palette to apply to the widget.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette Powerpack#palette}
        '''
        result = self._values.get("palette")
        assert result is not None, "Required property 'palette' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def palette_flip(self) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
        '''A Boolean indicating whether to flip the palette tones.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette_flip Powerpack#palette_flip}
        '''
        result = self._values.get("palette_flip")
        assert result is not None, "Required property 'palette_flip' is missing"
        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetGeomapDefinitionStyle(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetGeomapDefinitionStyleOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetGeomapDefinitionStyleOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__48908e8e75c342da8700792b20b3ac9861513515b735927a7472a094ca2417e8)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @builtins.property
    @jsii.member(jsii_name="paletteFlipInput")
    def palette_flip_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "paletteFlipInput"))

    @builtins.property
    @jsii.member(jsii_name="paletteInput")
    def palette_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "paletteInput"))

    @builtins.property
    @jsii.member(jsii_name="palette")
    def palette(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "palette"))

    @palette.setter
    def palette(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ffded09540e6f2f80a7d64ee0b936d476b92581da5510bc92767eb7c7531298f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "palette", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="paletteFlip")
    def palette_flip(self) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "paletteFlip"))

    @palette_flip.setter
    def palette_flip(
        self,
        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bd2a68d97f5794d4214ab81909fda0e050566c125d0573460c4531578e53a566)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "paletteFlip", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[PowerpackWidgetGeomapDefinitionStyle]:
        return typing.cast(typing.Optional[PowerpackWidgetGeomapDefinitionStyle], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetGeomapDefinitionStyle],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dfbc54f59a4379820f56c292948824817152b118386079a36e670ce19230de56)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetGeomapDefinitionView",
    jsii_struct_bases=[],
    name_mapping={"focus": "focus"},
)
class PowerpackWidgetGeomapDefinitionView:
    def __init__(self, *, focus: builtins.str) -> None:
        '''
        :param focus: The two-letter ISO code of a country to focus the map on (or ``WORLD``). Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#focus Powerpack#focus}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8ddf7eac1b7ae94af68e62adb095f36966b9d74f6c30a1f959791225c1c8efa7)
            check_type(argname="argument focus", value=focus, expected_type=type_hints["focus"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "focus": focus,
        }

    @builtins.property
    def focus(self) -> builtins.str:
        '''The two-letter ISO code of a country to focus the map on (or ``WORLD``).

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#focus Powerpack#focus}
        '''
        result = self._values.get("focus")
        assert result is not None, "Required property 'focus' is missing"
        return typing.cast(builtins.str, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetGeomapDefinitionView(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetGeomapDefinitionViewOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetGeomapDefinitionViewOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2baad96978f12359a74dd656448ccab667cb124e2a9e0b77a6098ad15c0267f1)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @builtins.property
    @jsii.member(jsii_name="focusInput")
    def focus_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "focusInput"))

    @builtins.property
    @jsii.member(jsii_name="focus")
    def focus(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "focus"))

    @focus.setter
    def focus(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__62c654f86d551f9d1c063a18fd18952a99dfda13fe5f1a572eface9f50746b52)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "focus", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[PowerpackWidgetGeomapDefinitionView]:
        return typing.cast(typing.Optional[PowerpackWidgetGeomapDefinitionView], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetGeomapDefinitionView],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fe60fba9293cf7857cc4ee5207d9cc5520528342016a1cb66b5b7b0e8713b9f0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinition",
    jsii_struct_bases=[],
    name_mapping={
        "custom_link": "customLink",
        "event": "event",
        "legend_size": "legendSize",
        "live_span": "liveSpan",
        "request": "request",
        "show_legend": "showLegend",
        "title": "title",
        "title_align": "titleAlign",
        "title_size": "titleSize",
        "yaxis": "yaxis",
    },
)
class PowerpackWidgetHeatmapDefinition:
    def __init__(
        self,
        *,
        custom_link: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetHeatmapDefinitionCustomLink", typing.Dict[builtins.str, typing.Any]]]]] = None,
        event: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetHeatmapDefinitionEvent", typing.Dict[builtins.str, typing.Any]]]]] = None,
        legend_size: typing.Optional[builtins.str] = None,
        live_span: typing.Optional[builtins.str] = None,
        request: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetHeatmapDefinitionRequest", typing.Dict[builtins.str, typing.Any]]]]] = None,
        show_legend: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        title: typing.Optional[builtins.str] = None,
        title_align: typing.Optional[builtins.str] = None,
        title_size: typing.Optional[builtins.str] = None,
        yaxis: typing.Optional[typing.Union["PowerpackWidgetHeatmapDefinitionYaxis", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param custom_link: custom_link block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom_link Powerpack#custom_link}
        :param event: event block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#event Powerpack#event}
        :param legend_size: The size of the legend displayed in the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#legend_size Powerpack#legend_size}
        :param live_span: The timeframe to use when displaying the widget. Valid values are ``1m``, ``5m``, ``10m``, ``15m``, ``30m``, ``1h``, ``4h``, ``1d``, ``2d``, ``1w``, ``1mo``, ``3mo``, ``6mo``, ``week_to_date``, ``month_to_date``, ``1y``, ``alert``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#live_span Powerpack#live_span}
        :param request: request block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#request Powerpack#request}
        :param show_legend: Whether or not to show the legend on this widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#show_legend Powerpack#show_legend}
        :param title: The title of the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title Powerpack#title}
        :param title_align: The alignment of the widget's title. Valid values are ``center``, ``left``, ``right``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_align Powerpack#title_align}
        :param title_size: The size of the widget's title (defaults to 16). Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_size Powerpack#title_size}
        :param yaxis: yaxis block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#yaxis Powerpack#yaxis}
        '''
        if isinstance(yaxis, dict):
            yaxis = PowerpackWidgetHeatmapDefinitionYaxis(**yaxis)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7bbffb9c1c70f9d6ce94658f681e559e2792bac0aa28f98b3b8d821a05972e25)
            check_type(argname="argument custom_link", value=custom_link, expected_type=type_hints["custom_link"])
            check_type(argname="argument event", value=event, expected_type=type_hints["event"])
            check_type(argname="argument legend_size", value=legend_size, expected_type=type_hints["legend_size"])
            check_type(argname="argument live_span", value=live_span, expected_type=type_hints["live_span"])
            check_type(argname="argument request", value=request, expected_type=type_hints["request"])
            check_type(argname="argument show_legend", value=show_legend, expected_type=type_hints["show_legend"])
            check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            check_type(argname="argument title_align", value=title_align, expected_type=type_hints["title_align"])
            check_type(argname="argument title_size", value=title_size, expected_type=type_hints["title_size"])
            check_type(argname="argument yaxis", value=yaxis, expected_type=type_hints["yaxis"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if custom_link is not None:
            self._values["custom_link"] = custom_link
        if event is not None:
            self._values["event"] = event
        if legend_size is not None:
            self._values["legend_size"] = legend_size
        if live_span is not None:
            self._values["live_span"] = live_span
        if request is not None:
            self._values["request"] = request
        if show_legend is not None:
            self._values["show_legend"] = show_legend
        if title is not None:
            self._values["title"] = title
        if title_align is not None:
            self._values["title_align"] = title_align
        if title_size is not None:
            self._values["title_size"] = title_size
        if yaxis is not None:
            self._values["yaxis"] = yaxis

    @builtins.property
    def custom_link(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetHeatmapDefinitionCustomLink"]]]:
        '''custom_link block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom_link Powerpack#custom_link}
        '''
        result = self._values.get("custom_link")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetHeatmapDefinitionCustomLink"]]], result)

    @builtins.property
    def event(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetHeatmapDefinitionEvent"]]]:
        '''event block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#event Powerpack#event}
        '''
        result = self._values.get("event")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetHeatmapDefinitionEvent"]]], result)

    @builtins.property
    def legend_size(self) -> typing.Optional[builtins.str]:
        '''The size of the legend displayed in the widget.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#legend_size Powerpack#legend_size}
        '''
        result = self._values.get("legend_size")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def live_span(self) -> typing.Optional[builtins.str]:
        '''The timeframe to use when displaying the widget.

        Valid values are ``1m``, ``5m``, ``10m``, ``15m``, ``30m``, ``1h``, ``4h``, ``1d``, ``2d``, ``1w``, ``1mo``, ``3mo``, ``6mo``, ``week_to_date``, ``month_to_date``, ``1y``, ``alert``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#live_span Powerpack#live_span}
        '''
        result = self._values.get("live_span")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def request(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetHeatmapDefinitionRequest"]]]:
        '''request block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#request Powerpack#request}
        '''
        result = self._values.get("request")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetHeatmapDefinitionRequest"]]], result)

    @builtins.property
    def show_legend(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        '''Whether or not to show the legend on this widget.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#show_legend Powerpack#show_legend}
        '''
        result = self._values.get("show_legend")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)

    @builtins.property
    def title(self) -> typing.Optional[builtins.str]:
        '''The title of the widget.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title Powerpack#title}
        '''
        result = self._values.get("title")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def title_align(self) -> typing.Optional[builtins.str]:
        '''The alignment of the widget's title. Valid values are ``center``, ``left``, ``right``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_align Powerpack#title_align}
        '''
        result = self._values.get("title_align")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def title_size(self) -> typing.Optional[builtins.str]:
        '''The size of the widget's title (defaults to 16).

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_size Powerpack#title_size}
        '''
        result = self._values.get("title_size")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def yaxis(self) -> typing.Optional["PowerpackWidgetHeatmapDefinitionYaxis"]:
        '''yaxis block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#yaxis Powerpack#yaxis}
        '''
        result = self._values.get("yaxis")
        return typing.cast(typing.Optional["PowerpackWidgetHeatmapDefinitionYaxis"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetHeatmapDefinition(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionCustomLink",
    jsii_struct_bases=[],
    name_mapping={
        "is_hidden": "isHidden",
        "label": "label",
        "link": "link",
        "override_label": "overrideLabel",
    },
)
class PowerpackWidgetHeatmapDefinitionCustomLink:
    def __init__(
        self,
        *,
        is_hidden: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        label: typing.Optional[builtins.str] = None,
        link: typing.Optional[builtins.str] = None,
        override_label: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param is_hidden: The flag for toggling context menu link visibility. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#is_hidden Powerpack#is_hidden}
        :param label: The label for the custom link URL. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#label Powerpack#label}
        :param link: The URL of the custom link. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#link Powerpack#link}
        :param override_label: The label ID that refers to a context menu link item. When ``override_label`` is provided, the client request omits the label field. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#override_label Powerpack#override_label}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4bb03188e82f81a392c0dce817574c022fd24f7056f10ea469f5fa1462782219)
            check_type(argname="argument is_hidden", value=is_hidden, expected_type=type_hints["is_hidden"])
            check_type(argname="argument label", value=label, expected_type=type_hints["label"])
            check_type(argname="argument link", value=link, expected_type=type_hints["link"])
            check_type(argname="argument override_label", value=override_label, expected_type=type_hints["override_label"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if is_hidden is not None:
            self._values["is_hidden"] = is_hidden
        if label is not None:
            self._values["label"] = label
        if link is not None:
            self._values["link"] = link
        if override_label is not None:
            self._values["override_label"] = override_label

    @builtins.property
    def is_hidden(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        '''The flag for toggling context menu link visibility.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#is_hidden Powerpack#is_hidden}
        '''
        result = self._values.get("is_hidden")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)

    @builtins.property
    def label(self) -> typing.Optional[builtins.str]:
        '''The label for the custom link URL.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#label Powerpack#label}
        '''
        result = self._values.get("label")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def link(self) -> typing.Optional[builtins.str]:
        '''The URL of the custom link.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#link Powerpack#link}
        '''
        result = self._values.get("link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def override_label(self) -> typing.Optional[builtins.str]:
        '''The label ID that refers to a context menu link item.

        When ``override_label`` is provided, the client request omits the label field.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#override_label Powerpack#override_label}
        '''
        result = self._values.get("override_label")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetHeatmapDefinitionCustomLink(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetHeatmapDefinitionCustomLinkList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionCustomLinkList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__480d80a70526a8b26ebb29fb5e93e5854fcb8e6a8eef7d00d41bfff214e1dcc1)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetHeatmapDefinitionCustomLinkOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__45025584adece1f5e21b7e4d4b84154221d35ca919005fa06d5f84355afd0d4d)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetHeatmapDefinitionCustomLinkOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__05e6233e6f3801fc24d140df6977a4366672f043cf963e20f5e10432befc76ac)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3a4e842137549d99141f2f84bdf0770bc0ad5cad19107886d35bf7ebddb26bae)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__05430027cd8763e202b41966e2ba4b286b11efb1e08fe355fe56f3a432d7da3a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHeatmapDefinitionCustomLink]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHeatmapDefinitionCustomLink]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHeatmapDefinitionCustomLink]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__aea8f70c32564382be8f6e6f625bb4d815182b917bded1556da71cbf9d110eb4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetHeatmapDefinitionCustomLinkOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionCustomLinkOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b0ca9169c1d300e7b8990d2e18f3fb48d989343a6ac723b87b83b6bd3bd1820f)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetIsHidden")
    def reset_is_hidden(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetIsHidden", []))

    @jsii.member(jsii_name="resetLabel")
    def reset_label(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLabel", []))

    @jsii.member(jsii_name="resetLink")
    def reset_link(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLink", []))

    @jsii.member(jsii_name="resetOverrideLabel")
    def reset_override_label(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetOverrideLabel", []))

    @builtins.property
    @jsii.member(jsii_name="isHiddenInput")
    def is_hidden_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "isHiddenInput"))

    @builtins.property
    @jsii.member(jsii_name="labelInput")
    def label_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "labelInput"))

    @builtins.property
    @jsii.member(jsii_name="linkInput")
    def link_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "linkInput"))

    @builtins.property
    @jsii.member(jsii_name="overrideLabelInput")
    def override_label_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "overrideLabelInput"))

    @builtins.property
    @jsii.member(jsii_name="isHidden")
    def is_hidden(self) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "isHidden"))

    @is_hidden.setter
    def is_hidden(
        self,
        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__779fd575f61723c73c84fe0ee626a9655d1cc7e30bd9418cef9801b420af0c82)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "isHidden", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="label")
    def label(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "label"))

    @label.setter
    def label(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__be073d17af47d7a97360d393374b2861df80479e04345e45bd1355d68da9a755)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "label", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="link")
    def link(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "link"))

    @link.setter
    def link(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__24e0f56eb99f59335f8efd6a864ea549b77264e200edb9a2e21fe907dd72136d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "link", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="overrideLabel")
    def override_label(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "overrideLabel"))

    @override_label.setter
    def override_label(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__58f2a13335b07198f938d51d1c884b88280ce7aa07af10f90e282e1fb2eb67db)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "overrideLabel", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHeatmapDefinitionCustomLink]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHeatmapDefinitionCustomLink]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHeatmapDefinitionCustomLink]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cf9b01d868acfd9a64917d3b677cce543c6ba45614e81f9ec0eda2980b335579)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionEvent",
    jsii_struct_bases=[],
    name_mapping={"q": "q", "tags_execution": "tagsExecution"},
)
class PowerpackWidgetHeatmapDefinitionEvent:
    def __init__(
        self,
        *,
        q: builtins.str,
        tags_execution: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param q: The event query to use in the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#q Powerpack#q}
        :param tags_execution: The execution method for multi-value filters. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#tags_execution Powerpack#tags_execution}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4a725c94cfa4c426b4ace3d4efb5929929b572c6b81a46f9437ceb6cf460494e)
            check_type(argname="argument q", value=q, expected_type=type_hints["q"])
            check_type(argname="argument tags_execution", value=tags_execution, expected_type=type_hints["tags_execution"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "q": q,
        }
        if tags_execution is not None:
            self._values["tags_execution"] = tags_execution

    @builtins.property
    def q(self) -> builtins.str:
        '''The event query to use in the widget.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#q Powerpack#q}
        '''
        result = self._values.get("q")
        assert result is not None, "Required property 'q' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def tags_execution(self) -> typing.Optional[builtins.str]:
        '''The execution method for multi-value filters.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#tags_execution Powerpack#tags_execution}
        '''
        result = self._values.get("tags_execution")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetHeatmapDefinitionEvent(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetHeatmapDefinitionEventList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionEventList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ce8bea8ef1a37bd48d3321599882be9e719fef546a3fd988efa9288fe67f2424)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetHeatmapDefinitionEventOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__463ab6ec4debda09f52f4f9670bc1f97772110b9b653c98c58c6d74ea3b488a2)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetHeatmapDefinitionEventOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c9956ca2e4050bbce44b6de2bf8de4a618180bc3e71803be706b818722267201)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f826385a2e9cad2a125996a31f206cfbaa8515c4ca1ffdd65de2880a14d5602c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__695108c7e7d3fa2128009097515db132793f73d0b0105d94575aca1b5dec9d3a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHeatmapDefinitionEvent]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHeatmapDefinitionEvent]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHeatmapDefinitionEvent]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3e7f5610cf27386bf2bbef81308e853622375bb68211f819ae35dccdbd1ef033)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetHeatmapDefinitionEventOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionEventOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b0865b75071d0d5411f55a6c13663b50c5379dcf19b07b7eb0a6a35a415a0a29)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetTagsExecution")
    def reset_tags_execution(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTagsExecution", []))

    @builtins.property
    @jsii.member(jsii_name="qInput")
    def q_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "qInput"))

    @builtins.property
    @jsii.member(jsii_name="tagsExecutionInput")
    def tags_execution_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "tagsExecutionInput"))

    @builtins.property
    @jsii.member(jsii_name="q")
    def q(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "q"))

    @q.setter
    def q(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bb36201cf55a8910f7c5fc32ed46102bba117955e0c100bb01f47dff1fab5db6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "q", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="tagsExecution")
    def tags_execution(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "tagsExecution"))

    @tags_execution.setter
    def tags_execution(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1a2c5894f51b928bc0e11eecd5f2549ed20dd0bf5f28e1cd0c12c6e10329e16f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "tagsExecution", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHeatmapDefinitionEvent]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHeatmapDefinitionEvent]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHeatmapDefinitionEvent]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__01ae49b77d6bb5e4219338927d823446eb46ab2cb036f3dc43ec559a06992a7f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetHeatmapDefinitionOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bff8f266854deae33fd6b2d102e6f3707a748ebce06056588097db0f7ea35ca0)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putCustomLink")
    def put_custom_link(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHeatmapDefinitionCustomLink, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__47881c44079d9a2779aad6e2e7a877ec582c50de1849213cb054b0462f484d30)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putCustomLink", [value]))

    @jsii.member(jsii_name="putEvent")
    def put_event(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHeatmapDefinitionEvent, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__825777bac18deff3977568c97608871f886cdf7b73e6e27c4c206aa816521ab3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putEvent", [value]))

    @jsii.member(jsii_name="putRequest")
    def put_request(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetHeatmapDefinitionRequest", typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d9c0b0803046cf0c8adc664c03f9dd3c94542b24997aac067a7ed8e23022a850)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putRequest", [value]))

    @jsii.member(jsii_name="putYaxis")
    def put_yaxis(
        self,
        *,
        include_zero: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        label: typing.Optional[builtins.str] = None,
        max: typing.Optional[builtins.str] = None,
        min: typing.Optional[builtins.str] = None,
        scale: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param include_zero: Always include zero or fit the axis to the data range. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#include_zero Powerpack#include_zero}
        :param label: The label of the axis to display on the graph. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#label Powerpack#label}
        :param max: Specify the maximum value to show on the Y-axis. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#max Powerpack#max}
        :param min: Specify the minimum value to show on the Y-axis. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#min Powerpack#min}
        :param scale: Specify the scale type, options: ``linear``, ``log``, ``pow``, ``sqrt``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#scale Powerpack#scale}
        '''
        value = PowerpackWidgetHeatmapDefinitionYaxis(
            include_zero=include_zero, label=label, max=max, min=min, scale=scale
        )

        return typing.cast(None, jsii.invoke(self, "putYaxis", [value]))

    @jsii.member(jsii_name="resetCustomLink")
    def reset_custom_link(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCustomLink", []))

    @jsii.member(jsii_name="resetEvent")
    def reset_event(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetEvent", []))

    @jsii.member(jsii_name="resetLegendSize")
    def reset_legend_size(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLegendSize", []))

    @jsii.member(jsii_name="resetLiveSpan")
    def reset_live_span(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLiveSpan", []))

    @jsii.member(jsii_name="resetRequest")
    def reset_request(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetRequest", []))

    @jsii.member(jsii_name="resetShowLegend")
    def reset_show_legend(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetShowLegend", []))

    @jsii.member(jsii_name="resetTitle")
    def reset_title(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTitle", []))

    @jsii.member(jsii_name="resetTitleAlign")
    def reset_title_align(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTitleAlign", []))

    @jsii.member(jsii_name="resetTitleSize")
    def reset_title_size(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTitleSize", []))

    @jsii.member(jsii_name="resetYaxis")
    def reset_yaxis(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetYaxis", []))

    @builtins.property
    @jsii.member(jsii_name="customLink")
    def custom_link(self) -> PowerpackWidgetHeatmapDefinitionCustomLinkList:
        return typing.cast(PowerpackWidgetHeatmapDefinitionCustomLinkList, jsii.get(self, "customLink"))

    @builtins.property
    @jsii.member(jsii_name="event")
    def event(self) -> PowerpackWidgetHeatmapDefinitionEventList:
        return typing.cast(PowerpackWidgetHeatmapDefinitionEventList, jsii.get(self, "event"))

    @builtins.property
    @jsii.member(jsii_name="request")
    def request(self) -> "PowerpackWidgetHeatmapDefinitionRequestList":
        return typing.cast("PowerpackWidgetHeatmapDefinitionRequestList", jsii.get(self, "request"))

    @builtins.property
    @jsii.member(jsii_name="yaxis")
    def yaxis(self) -> "PowerpackWidgetHeatmapDefinitionYaxisOutputReference":
        return typing.cast("PowerpackWidgetHeatmapDefinitionYaxisOutputReference", jsii.get(self, "yaxis"))

    @builtins.property
    @jsii.member(jsii_name="customLinkInput")
    def custom_link_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHeatmapDefinitionCustomLink]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHeatmapDefinitionCustomLink]]], jsii.get(self, "customLinkInput"))

    @builtins.property
    @jsii.member(jsii_name="eventInput")
    def event_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHeatmapDefinitionEvent]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHeatmapDefinitionEvent]]], jsii.get(self, "eventInput"))

    @builtins.property
    @jsii.member(jsii_name="legendSizeInput")
    def legend_size_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "legendSizeInput"))

    @builtins.property
    @jsii.member(jsii_name="liveSpanInput")
    def live_span_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "liveSpanInput"))

    @builtins.property
    @jsii.member(jsii_name="requestInput")
    def request_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetHeatmapDefinitionRequest"]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetHeatmapDefinitionRequest"]]], jsii.get(self, "requestInput"))

    @builtins.property
    @jsii.member(jsii_name="showLegendInput")
    def show_legend_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "showLegendInput"))

    @builtins.property
    @jsii.member(jsii_name="titleAlignInput")
    def title_align_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "titleAlignInput"))

    @builtins.property
    @jsii.member(jsii_name="titleInput")
    def title_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "titleInput"))

    @builtins.property
    @jsii.member(jsii_name="titleSizeInput")
    def title_size_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "titleSizeInput"))

    @builtins.property
    @jsii.member(jsii_name="yaxisInput")
    def yaxis_input(self) -> typing.Optional["PowerpackWidgetHeatmapDefinitionYaxis"]:
        return typing.cast(typing.Optional["PowerpackWidgetHeatmapDefinitionYaxis"], jsii.get(self, "yaxisInput"))

    @builtins.property
    @jsii.member(jsii_name="legendSize")
    def legend_size(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "legendSize"))

    @legend_size.setter
    def legend_size(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8d51f3d97beb2ec2aec8748fafbbd6f953b3bcfb73cf8eca89bd4dcc745796ee)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "legendSize", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="liveSpan")
    def live_span(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "liveSpan"))

    @live_span.setter
    def live_span(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d509ad3bbbfdf0e7eaab43637980a863cdbd2ddca60529625b2577df40961dd6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "liveSpan", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="showLegend")
    def show_legend(self) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "showLegend"))

    @show_legend.setter
    def show_legend(
        self,
        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__17fc17b88f3d89448cea073496a0452f410deeaed101f2b5bee48522cd93ea3c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "showLegend", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="title")
    def title(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "title"))

    @title.setter
    def title(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b2ee1da405ea861b5c50f6685875801bb2062bb827e5448f018b6b96812d6b16)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "title", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="titleAlign")
    def title_align(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "titleAlign"))

    @title_align.setter
    def title_align(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4af6b009290dae9b62b039ff477d069ec490a45f693b053c0869e49a791befc9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "titleAlign", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="titleSize")
    def title_size(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "titleSize"))

    @title_size.setter
    def title_size(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__843e93367e238d6c731d1189cad3ef1ae777cb043d78759326ad3d2297f9e265)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "titleSize", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[PowerpackWidgetHeatmapDefinition]:
        return typing.cast(typing.Optional[PowerpackWidgetHeatmapDefinition], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetHeatmapDefinition],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6995727ef2f1dfe571199fa7d68162385ab5976cbe619141abdef63a2f5f2ede)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionRequest",
    jsii_struct_bases=[],
    name_mapping={
        "apm_query": "apmQuery",
        "formula": "formula",
        "log_query": "logQuery",
        "process_query": "processQuery",
        "q": "q",
        "query": "query",
        "rum_query": "rumQuery",
        "security_query": "securityQuery",
        "style": "style",
    },
)
class PowerpackWidgetHeatmapDefinitionRequest:
    def __init__(
        self,
        *,
        apm_query: typing.Optional[typing.Union["PowerpackWidgetHeatmapDefinitionRequestApmQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        formula: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetHeatmapDefinitionRequestFormula", typing.Dict[builtins.str, typing.Any]]]]] = None,
        log_query: typing.Optional[typing.Union["PowerpackWidgetHeatmapDefinitionRequestLogQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        process_query: typing.Optional[typing.Union["PowerpackWidgetHeatmapDefinitionRequestProcessQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        q: typing.Optional[builtins.str] = None,
        query: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetHeatmapDefinitionRequestQuery", typing.Dict[builtins.str, typing.Any]]]]] = None,
        rum_query: typing.Optional[typing.Union["PowerpackWidgetHeatmapDefinitionRequestRumQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        security_query: typing.Optional[typing.Union["PowerpackWidgetHeatmapDefinitionRequestSecurityQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        style: typing.Optional[typing.Union["PowerpackWidgetHeatmapDefinitionRequestStyle", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param apm_query: apm_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#apm_query Powerpack#apm_query}
        :param formula: formula block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#formula Powerpack#formula}
        :param log_query: log_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#log_query Powerpack#log_query}
        :param process_query: process_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#process_query Powerpack#process_query}
        :param q: The metric query to use for this widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#q Powerpack#q}
        :param query: query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        :param rum_query: rum_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#rum_query Powerpack#rum_query}
        :param security_query: security_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#security_query Powerpack#security_query}
        :param style: style block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#style Powerpack#style}
        '''
        if isinstance(apm_query, dict):
            apm_query = PowerpackWidgetHeatmapDefinitionRequestApmQuery(**apm_query)
        if isinstance(log_query, dict):
            log_query = PowerpackWidgetHeatmapDefinitionRequestLogQuery(**log_query)
        if isinstance(process_query, dict):
            process_query = PowerpackWidgetHeatmapDefinitionRequestProcessQuery(**process_query)
        if isinstance(rum_query, dict):
            rum_query = PowerpackWidgetHeatmapDefinitionRequestRumQuery(**rum_query)
        if isinstance(security_query, dict):
            security_query = PowerpackWidgetHeatmapDefinitionRequestSecurityQuery(**security_query)
        if isinstance(style, dict):
            style = PowerpackWidgetHeatmapDefinitionRequestStyle(**style)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b81a656765f8206ed38c931754c8ea1ee90b7f8588739a1ece46b0c4e0f0bb0d)
            check_type(argname="argument apm_query", value=apm_query, expected_type=type_hints["apm_query"])
            check_type(argname="argument formula", value=formula, expected_type=type_hints["formula"])
            check_type(argname="argument log_query", value=log_query, expected_type=type_hints["log_query"])
            check_type(argname="argument process_query", value=process_query, expected_type=type_hints["process_query"])
            check_type(argname="argument q", value=q, expected_type=type_hints["q"])
            check_type(argname="argument query", value=query, expected_type=type_hints["query"])
            check_type(argname="argument rum_query", value=rum_query, expected_type=type_hints["rum_query"])
            check_type(argname="argument security_query", value=security_query, expected_type=type_hints["security_query"])
            check_type(argname="argument style", value=style, expected_type=type_hints["style"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if apm_query is not None:
            self._values["apm_query"] = apm_query
        if formula is not None:
            self._values["formula"] = formula
        if log_query is not None:
            self._values["log_query"] = log_query
        if process_query is not None:
            self._values["process_query"] = process_query
        if q is not None:
            self._values["q"] = q
        if query is not None:
            self._values["query"] = query
        if rum_query is not None:
            self._values["rum_query"] = rum_query
        if security_query is not None:
            self._values["security_query"] = security_query
        if style is not None:
            self._values["style"] = style

    @builtins.property
    def apm_query(
        self,
    ) -> typing.Optional["PowerpackWidgetHeatmapDefinitionRequestApmQuery"]:
        '''apm_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#apm_query Powerpack#apm_query}
        '''
        result = self._values.get("apm_query")
        return typing.cast(typing.Optional["PowerpackWidgetHeatmapDefinitionRequestApmQuery"], result)

    @builtins.property
    def formula(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetHeatmapDefinitionRequestFormula"]]]:
        '''formula block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#formula Powerpack#formula}
        '''
        result = self._values.get("formula")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetHeatmapDefinitionRequestFormula"]]], result)

    @builtins.property
    def log_query(
        self,
    ) -> typing.Optional["PowerpackWidgetHeatmapDefinitionRequestLogQuery"]:
        '''log_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#log_query Powerpack#log_query}
        '''
        result = self._values.get("log_query")
        return typing.cast(typing.Optional["PowerpackWidgetHeatmapDefinitionRequestLogQuery"], result)

    @builtins.property
    def process_query(
        self,
    ) -> typing.Optional["PowerpackWidgetHeatmapDefinitionRequestProcessQuery"]:
        '''process_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#process_query Powerpack#process_query}
        '''
        result = self._values.get("process_query")
        return typing.cast(typing.Optional["PowerpackWidgetHeatmapDefinitionRequestProcessQuery"], result)

    @builtins.property
    def q(self) -> typing.Optional[builtins.str]:
        '''The metric query to use for this widget.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#q Powerpack#q}
        '''
        result = self._values.get("q")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def query(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetHeatmapDefinitionRequestQuery"]]]:
        '''query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        '''
        result = self._values.get("query")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetHeatmapDefinitionRequestQuery"]]], result)

    @builtins.property
    def rum_query(
        self,
    ) -> typing.Optional["PowerpackWidgetHeatmapDefinitionRequestRumQuery"]:
        '''rum_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#rum_query Powerpack#rum_query}
        '''
        result = self._values.get("rum_query")
        return typing.cast(typing.Optional["PowerpackWidgetHeatmapDefinitionRequestRumQuery"], result)

    @builtins.property
    def security_query(
        self,
    ) -> typing.Optional["PowerpackWidgetHeatmapDefinitionRequestSecurityQuery"]:
        '''security_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#security_query Powerpack#security_query}
        '''
        result = self._values.get("security_query")
        return typing.cast(typing.Optional["PowerpackWidgetHeatmapDefinitionRequestSecurityQuery"], result)

    @builtins.property
    def style(self) -> typing.Optional["PowerpackWidgetHeatmapDefinitionRequestStyle"]:
        '''style block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#style Powerpack#style}
        '''
        result = self._values.get("style")
        return typing.cast(typing.Optional["PowerpackWidgetHeatmapDefinitionRequestStyle"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetHeatmapDefinitionRequest(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionRequestApmQuery",
    jsii_struct_bases=[],
    name_mapping={
        "index": "index",
        "compute_query": "computeQuery",
        "group_by": "groupBy",
        "multi_compute": "multiCompute",
        "search_query": "searchQuery",
    },
)
class PowerpackWidgetHeatmapDefinitionRequestApmQuery:
    def __init__(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union["PowerpackWidgetHeatmapDefinitionRequestApmQueryComputeQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetHeatmapDefinitionRequestApmQueryGroupBy", typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetHeatmapDefinitionRequestApmQueryMultiCompute", typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        if isinstance(compute_query, dict):
            compute_query = PowerpackWidgetHeatmapDefinitionRequestApmQueryComputeQuery(**compute_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7525676279af0477ef4ff139b99acdd7cc7ad301ae861f4dd5f36889877bac72)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
            check_type(argname="argument compute_query", value=compute_query, expected_type=type_hints["compute_query"])
            check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
            check_type(argname="argument multi_compute", value=multi_compute, expected_type=type_hints["multi_compute"])
            check_type(argname="argument search_query", value=search_query, expected_type=type_hints["search_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "index": index,
        }
        if compute_query is not None:
            self._values["compute_query"] = compute_query
        if group_by is not None:
            self._values["group_by"] = group_by
        if multi_compute is not None:
            self._values["multi_compute"] = multi_compute
        if search_query is not None:
            self._values["search_query"] = search_query

    @builtins.property
    def index(self) -> builtins.str:
        '''The name of the index to query.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        '''
        result = self._values.get("index")
        assert result is not None, "Required property 'index' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def compute_query(
        self,
    ) -> typing.Optional["PowerpackWidgetHeatmapDefinitionRequestApmQueryComputeQuery"]:
        '''compute_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        '''
        result = self._values.get("compute_query")
        return typing.cast(typing.Optional["PowerpackWidgetHeatmapDefinitionRequestApmQueryComputeQuery"], result)

    @builtins.property
    def group_by(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetHeatmapDefinitionRequestApmQueryGroupBy"]]]:
        '''group_by block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        '''
        result = self._values.get("group_by")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetHeatmapDefinitionRequestApmQueryGroupBy"]]], result)

    @builtins.property
    def multi_compute(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetHeatmapDefinitionRequestApmQueryMultiCompute"]]]:
        '''multi_compute block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        '''
        result = self._values.get("multi_compute")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetHeatmapDefinitionRequestApmQueryMultiCompute"]]], result)

    @builtins.property
    def search_query(self) -> typing.Optional[builtins.str]:
        '''The search query to use.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        result = self._values.get("search_query")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetHeatmapDefinitionRequestApmQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionRequestApmQueryComputeQuery",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetHeatmapDefinitionRequestApmQueryComputeQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6baa2239d5cfb78f1795c7ad2969caa15840c62aa96ea667888d1257587d0a74)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetHeatmapDefinitionRequestApmQueryComputeQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetHeatmapDefinitionRequestApmQueryComputeQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionRequestApmQueryComputeQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__63fb9cb88c47232ed22afbbef47e4707d283ef35969161c5dc49105136481557)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__444879c6f3481d31ee56319b64e8a92794c95bb33d57f837a43fe1bb86e51b18)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a70c2c4b35f82744a878b950b583971ec2633f0b0b23b4c509877b28db00dc26)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__98359623937aa05ebff42cad1449ab007e29c4e71ddd447d8146e52b2e3604eb)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetHeatmapDefinitionRequestApmQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetHeatmapDefinitionRequestApmQueryComputeQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetHeatmapDefinitionRequestApmQueryComputeQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e3787af7f4e5105b5ff4a1eeb3aea5afb03fce105b7d76eba2bda3d8c5ee83f8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionRequestApmQueryGroupBy",
    jsii_struct_bases=[],
    name_mapping={"facet": "facet", "limit": "limit", "sort_query": "sortQuery"},
)
class PowerpackWidgetHeatmapDefinitionRequestApmQueryGroupBy:
    def __init__(
        self,
        *,
        facet: typing.Optional[builtins.str] = None,
        limit: typing.Optional[jsii.Number] = None,
        sort_query: typing.Optional[typing.Union["PowerpackWidgetHeatmapDefinitionRequestApmQueryGroupBySortQuery", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param limit: The maximum number of items in the group. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param sort_query: sort_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        if isinstance(sort_query, dict):
            sort_query = PowerpackWidgetHeatmapDefinitionRequestApmQueryGroupBySortQuery(**sort_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__25309b1257166cd1b50dc2d8289e176416b015a62e6ca4f280583109e843cde8)
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
            check_type(argname="argument sort_query", value=sort_query, expected_type=type_hints["sort_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if facet is not None:
            self._values["facet"] = facet
        if limit is not None:
            self._values["limit"] = limit
        if sort_query is not None:
            self._values["sort_query"] = sort_query

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def limit(self) -> typing.Optional[jsii.Number]:
        '''The maximum number of items in the group.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        '''
        result = self._values.get("limit")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def sort_query(
        self,
    ) -> typing.Optional["PowerpackWidgetHeatmapDefinitionRequestApmQueryGroupBySortQuery"]:
        '''sort_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        result = self._values.get("sort_query")
        return typing.cast(typing.Optional["PowerpackWidgetHeatmapDefinitionRequestApmQueryGroupBySortQuery"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetHeatmapDefinitionRequestApmQueryGroupBy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetHeatmapDefinitionRequestApmQueryGroupByList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionRequestApmQueryGroupByList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8e26c2a7805acafa1734474372254651b6e98aa9b30c1eb610b5797b96decb1b)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetHeatmapDefinitionRequestApmQueryGroupByOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__09d6b794624f7e5821c01a589c5ca24e4d0217ae5dc8b920754d43ecfa7acf97)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetHeatmapDefinitionRequestApmQueryGroupByOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6c47cac3dbd75231d4e4cb1767ef44ace7cf5c5938614a8801d80392b66af6c3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3d621809cdf50b57049336d68544dd2e29c0b92449c92dc80a992c1315b87a00)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5d3405c5518eb2cfee791dc3d35baca889bf594ba3cfe47d5d8d7cfd25f433f5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHeatmapDefinitionRequestApmQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHeatmapDefinitionRequestApmQueryGroupBy]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHeatmapDefinitionRequestApmQueryGroupBy]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c56cdb0ac01a757097f150ad8bf78b26049d42e708ad6287f2ba875e3a475b90)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetHeatmapDefinitionRequestApmQueryGroupByOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionRequestApmQueryGroupByOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9b8ed8f54f9effd2c3f6acefc672cee401f432b164867c38ef2d7402c031c6d7)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putSortQuery")
    def put_sort_query(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        value = PowerpackWidgetHeatmapDefinitionRequestApmQueryGroupBySortQuery(
            aggregation=aggregation, order=order, facet=facet
        )

        return typing.cast(None, jsii.invoke(self, "putSortQuery", [value]))

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetLimit")
    def reset_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLimit", []))

    @jsii.member(jsii_name="resetSortQuery")
    def reset_sort_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSortQuery", []))

    @builtins.property
    @jsii.member(jsii_name="sortQuery")
    def sort_query(
        self,
    ) -> "PowerpackWidgetHeatmapDefinitionRequestApmQueryGroupBySortQueryOutputReference":
        return typing.cast("PowerpackWidgetHeatmapDefinitionRequestApmQueryGroupBySortQueryOutputReference", jsii.get(self, "sortQuery"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="limitInput")
    def limit_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "limitInput"))

    @builtins.property
    @jsii.member(jsii_name="sortQueryInput")
    def sort_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetHeatmapDefinitionRequestApmQueryGroupBySortQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetHeatmapDefinitionRequestApmQueryGroupBySortQuery"], jsii.get(self, "sortQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a71258ef1d2deff31bc81342e4e505ee0862c19b7bc1f234a22b4141e53efd20)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="limit")
    def limit(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "limit"))

    @limit.setter
    def limit(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a2dd0ea0d868e1cdaac3b7279db3cc6480db01359862075a30e28124181a7fef)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "limit", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHeatmapDefinitionRequestApmQueryGroupBy]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHeatmapDefinitionRequestApmQueryGroupBy]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHeatmapDefinitionRequestApmQueryGroupBy]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5c49d57ebb6ea01a1a17b8f85e3dc95927348de52c098efaad9d8eaf45a130de)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionRequestApmQueryGroupBySortQuery",
    jsii_struct_bases=[],
    name_mapping={"aggregation": "aggregation", "order": "order", "facet": "facet"},
)
class PowerpackWidgetHeatmapDefinitionRequestApmQueryGroupBySortQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__909d86847e006f39c843188a5da8a3c7d5f302a112eddbe5d445213b63138d0d)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument order", value=order, expected_type=type_hints["order"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
            "order": order,
        }
        if facet is not None:
            self._values["facet"] = facet

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def order(self) -> builtins.str:
        '''Widget sorting methods. Valid values are ``asc``, ``desc``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        result = self._values.get("order")
        assert result is not None, "Required property 'order' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetHeatmapDefinitionRequestApmQueryGroupBySortQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetHeatmapDefinitionRequestApmQueryGroupBySortQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionRequestApmQueryGroupBySortQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__283a3397914da5e307ea78ac4abcee32bee0be487fb4ba0401e3018f0fde16ad)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="orderInput")
    def order_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "orderInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bd88854d198f3d1a370841c7272601b26453996a6a6e02dff48f6a37c9101558)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0b46c0da293af6323af8a92b60a8498f5d9ff4b519ba4a26c0b725a4ea25c937)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="order")
    def order(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "order"))

    @order.setter
    def order(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a348e453c61f1cc2016f4dabe4944734a454a069c79030521171b5fa4fde6aa3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "order", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetHeatmapDefinitionRequestApmQueryGroupBySortQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetHeatmapDefinitionRequestApmQueryGroupBySortQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetHeatmapDefinitionRequestApmQueryGroupBySortQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1cbde35b626d3ae7b0f07d140dddd3fbff43b1d38ad24ec3dcd175de6fda6621)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionRequestApmQueryMultiCompute",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetHeatmapDefinitionRequestApmQueryMultiCompute:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3d523535c795d992a421938861dc1d1c286f35f0442d20a0d49dc568065b883a)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetHeatmapDefinitionRequestApmQueryMultiCompute(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetHeatmapDefinitionRequestApmQueryMultiComputeList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionRequestApmQueryMultiComputeList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__16b8c368e464723dd82087146516e2c503cd8b2ba3476f3b86a1803dac93dfb0)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetHeatmapDefinitionRequestApmQueryMultiComputeOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bbcbb0b597cf86becfeebd42c56ba77999f84328f764b5d73907772d4b7f9d5f)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetHeatmapDefinitionRequestApmQueryMultiComputeOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8050e02cb45bc120f506c4cef25d8df348995257a94556e9166881370bb982cc)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__716260de6abdea5edcac2bf061c59dfb6ea0c12c6d26515a26d4925dd91d1472)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e86115b6dbec7758c22234504c273ffc1873564d82ad1f016e34488970c55a47)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHeatmapDefinitionRequestApmQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHeatmapDefinitionRequestApmQueryMultiCompute]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHeatmapDefinitionRequestApmQueryMultiCompute]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4cbc2dedd6d0588c21cb4e1ace37f4bf1887f5783fa7e2e13ea96610659701fd)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetHeatmapDefinitionRequestApmQueryMultiComputeOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionRequestApmQueryMultiComputeOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__13420f7f634f74c1ea6969006c2bcfb303d1a325da453b69c22661e2b1475b99)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__278a41e5156b1ffc5d67898b9ddb90b8df8e1342ea4cb658925c6ecc77513cdc)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c720521479e1f1717c5222bc65f8e8346a94922e76d9eddbd571bbc70abb10cd)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e5bdf3e72b144437e83143ed0392f4f3882aa64a7e02008c51a90f13734305ee)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHeatmapDefinitionRequestApmQueryMultiCompute]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHeatmapDefinitionRequestApmQueryMultiCompute]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHeatmapDefinitionRequestApmQueryMultiCompute]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__56e9f62a17adee7034ab24bece2232ae18dbb86d870a46c89d8151fc98454031)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetHeatmapDefinitionRequestApmQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionRequestApmQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c9e114a375afca059892bc93dd721e0b6826679039ed6e1112a2bec24701f70e)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putComputeQuery")
    def put_compute_query(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        value = PowerpackWidgetHeatmapDefinitionRequestApmQueryComputeQuery(
            aggregation=aggregation, facet=facet, interval=interval
        )

        return typing.cast(None, jsii.invoke(self, "putComputeQuery", [value]))

    @jsii.member(jsii_name="putGroupBy")
    def put_group_by(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHeatmapDefinitionRequestApmQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3204ea87bffb5ee84a8cf821d4e9bdbeeb026cca75cdcd841522f9de9cf82b57)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putGroupBy", [value]))

    @jsii.member(jsii_name="putMultiCompute")
    def put_multi_compute(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHeatmapDefinitionRequestApmQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1ba58db89c52a0c90f15337d4285f6c654a4bc8aa2becc7289b8952153a13f43)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putMultiCompute", [value]))

    @jsii.member(jsii_name="resetComputeQuery")
    def reset_compute_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetComputeQuery", []))

    @jsii.member(jsii_name="resetGroupBy")
    def reset_group_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGroupBy", []))

    @jsii.member(jsii_name="resetMultiCompute")
    def reset_multi_compute(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMultiCompute", []))

    @jsii.member(jsii_name="resetSearchQuery")
    def reset_search_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSearchQuery", []))

    @builtins.property
    @jsii.member(jsii_name="computeQuery")
    def compute_query(
        self,
    ) -> PowerpackWidgetHeatmapDefinitionRequestApmQueryComputeQueryOutputReference:
        return typing.cast(PowerpackWidgetHeatmapDefinitionRequestApmQueryComputeQueryOutputReference, jsii.get(self, "computeQuery"))

    @builtins.property
    @jsii.member(jsii_name="groupBy")
    def group_by(self) -> PowerpackWidgetHeatmapDefinitionRequestApmQueryGroupByList:
        return typing.cast(PowerpackWidgetHeatmapDefinitionRequestApmQueryGroupByList, jsii.get(self, "groupBy"))

    @builtins.property
    @jsii.member(jsii_name="multiCompute")
    def multi_compute(
        self,
    ) -> PowerpackWidgetHeatmapDefinitionRequestApmQueryMultiComputeList:
        return typing.cast(PowerpackWidgetHeatmapDefinitionRequestApmQueryMultiComputeList, jsii.get(self, "multiCompute"))

    @builtins.property
    @jsii.member(jsii_name="computeQueryInput")
    def compute_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetHeatmapDefinitionRequestApmQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetHeatmapDefinitionRequestApmQueryComputeQuery], jsii.get(self, "computeQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="groupByInput")
    def group_by_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHeatmapDefinitionRequestApmQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHeatmapDefinitionRequestApmQueryGroupBy]]], jsii.get(self, "groupByInput"))

    @builtins.property
    @jsii.member(jsii_name="indexInput")
    def index_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "indexInput"))

    @builtins.property
    @jsii.member(jsii_name="multiComputeInput")
    def multi_compute_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHeatmapDefinitionRequestApmQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHeatmapDefinitionRequestApmQueryMultiCompute]]], jsii.get(self, "multiComputeInput"))

    @builtins.property
    @jsii.member(jsii_name="searchQueryInput")
    def search_query_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "searchQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="index")
    def index(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "index"))

    @index.setter
    def index(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__29169977369c9775d0e66c460dd1f534dbeb2ccc7058699ba8d9a507b2b451c4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "index", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="searchQuery")
    def search_query(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "searchQuery"))

    @search_query.setter
    def search_query(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b0c8591622298e0c75b51e0bbe56be526c87b1a4c80f2961585c039c6e8ed6c1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "searchQuery", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetHeatmapDefinitionRequestApmQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetHeatmapDefinitionRequestApmQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetHeatmapDefinitionRequestApmQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e9965b468972870e6549b8b38d50ba18eaf38fbfda9e4c75c521252de9e91f39)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionRequestFormula",
    jsii_struct_bases=[],
    name_mapping={
        "formula_expression": "formulaExpression",
        "alias": "alias",
        "cell_display_mode": "cellDisplayMode",
        "conditional_formats": "conditionalFormats",
        "limit": "limit",
        "number_format": "numberFormat",
        "style": "style",
    },
)
class PowerpackWidgetHeatmapDefinitionRequestFormula:
    def __init__(
        self,
        *,
        formula_expression: builtins.str,
        alias: typing.Optional[builtins.str] = None,
        cell_display_mode: typing.Optional[builtins.str] = None,
        conditional_formats: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetHeatmapDefinitionRequestFormulaConditionalFormats", typing.Dict[builtins.str, typing.Any]]]]] = None,
        limit: typing.Optional[typing.Union["PowerpackWidgetHeatmapDefinitionRequestFormulaLimit", typing.Dict[builtins.str, typing.Any]]] = None,
        number_format: typing.Optional[typing.Union["PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormat", typing.Dict[builtins.str, typing.Any]]] = None,
        style: typing.Optional[typing.Union["PowerpackWidgetHeatmapDefinitionRequestFormulaStyle", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param formula_expression: A string expression built from queries, formulas, and functions. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#formula_expression Powerpack#formula_expression}
        :param alias: An expression alias. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#alias Powerpack#alias}
        :param cell_display_mode: A list of display modes for each table cell. Valid values are ``number``, ``bar``, ``trend``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cell_display_mode Powerpack#cell_display_mode}
        :param conditional_formats: conditional_formats block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#conditional_formats Powerpack#conditional_formats}
        :param limit: limit block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param number_format: number_format block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#number_format Powerpack#number_format}
        :param style: style block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#style Powerpack#style}
        '''
        if isinstance(limit, dict):
            limit = PowerpackWidgetHeatmapDefinitionRequestFormulaLimit(**limit)
        if isinstance(number_format, dict):
            number_format = PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormat(**number_format)
        if isinstance(style, dict):
            style = PowerpackWidgetHeatmapDefinitionRequestFormulaStyle(**style)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a996fbab5ca475063ccc6889e19da6bde4efea34a8aab4fb131d97f8e7fca425)
            check_type(argname="argument formula_expression", value=formula_expression, expected_type=type_hints["formula_expression"])
            check_type(argname="argument alias", value=alias, expected_type=type_hints["alias"])
            check_type(argname="argument cell_display_mode", value=cell_display_mode, expected_type=type_hints["cell_display_mode"])
            check_type(argname="argument conditional_formats", value=conditional_formats, expected_type=type_hints["conditional_formats"])
            check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
            check_type(argname="argument number_format", value=number_format, expected_type=type_hints["number_format"])
            check_type(argname="argument style", value=style, expected_type=type_hints["style"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "formula_expression": formula_expression,
        }
        if alias is not None:
            self._values["alias"] = alias
        if cell_display_mode is not None:
            self._values["cell_display_mode"] = cell_display_mode
        if conditional_formats is not None:
            self._values["conditional_formats"] = conditional_formats
        if limit is not None:
            self._values["limit"] = limit
        if number_format is not None:
            self._values["number_format"] = number_format
        if style is not None:
            self._values["style"] = style

    @builtins.property
    def formula_expression(self) -> builtins.str:
        '''A string expression built from queries, formulas, and functions.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#formula_expression Powerpack#formula_expression}
        '''
        result = self._values.get("formula_expression")
        assert result is not None, "Required property 'formula_expression' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def alias(self) -> typing.Optional[builtins.str]:
        '''An expression alias.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#alias Powerpack#alias}
        '''
        result = self._values.get("alias")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def cell_display_mode(self) -> typing.Optional[builtins.str]:
        '''A list of display modes for each table cell. Valid values are ``number``, ``bar``, ``trend``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cell_display_mode Powerpack#cell_display_mode}
        '''
        result = self._values.get("cell_display_mode")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def conditional_formats(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetHeatmapDefinitionRequestFormulaConditionalFormats"]]]:
        '''conditional_formats block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#conditional_formats Powerpack#conditional_formats}
        '''
        result = self._values.get("conditional_formats")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetHeatmapDefinitionRequestFormulaConditionalFormats"]]], result)

    @builtins.property
    def limit(
        self,
    ) -> typing.Optional["PowerpackWidgetHeatmapDefinitionRequestFormulaLimit"]:
        '''limit block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        '''
        result = self._values.get("limit")
        return typing.cast(typing.Optional["PowerpackWidgetHeatmapDefinitionRequestFormulaLimit"], result)

    @builtins.property
    def number_format(
        self,
    ) -> typing.Optional["PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormat"]:
        '''number_format block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#number_format Powerpack#number_format}
        '''
        result = self._values.get("number_format")
        return typing.cast(typing.Optional["PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormat"], result)

    @builtins.property
    def style(
        self,
    ) -> typing.Optional["PowerpackWidgetHeatmapDefinitionRequestFormulaStyle"]:
        '''style block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#style Powerpack#style}
        '''
        result = self._values.get("style")
        return typing.cast(typing.Optional["PowerpackWidgetHeatmapDefinitionRequestFormulaStyle"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetHeatmapDefinitionRequestFormula(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionRequestFormulaConditionalFormats",
    jsii_struct_bases=[],
    name_mapping={
        "comparator": "comparator",
        "palette": "palette",
        "value": "value",
        "custom_bg_color": "customBgColor",
        "custom_fg_color": "customFgColor",
        "hide_value": "hideValue",
        "image_url": "imageUrl",
        "metric": "metric",
        "timeframe": "timeframe",
    },
)
class PowerpackWidgetHeatmapDefinitionRequestFormulaConditionalFormats:
    def __init__(
        self,
        *,
        comparator: builtins.str,
        palette: builtins.str,
        value: jsii.Number,
        custom_bg_color: typing.Optional[builtins.str] = None,
        custom_fg_color: typing.Optional[builtins.str] = None,
        hide_value: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        image_url: typing.Optional[builtins.str] = None,
        metric: typing.Optional[builtins.str] = None,
        timeframe: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param comparator: The comparator to use. Valid values are ``=``, ``>``, ``>=``, ``<``, ``<=``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#comparator Powerpack#comparator}
        :param palette: The color palette to apply. Valid values are ``blue``, ``custom_bg``, ``custom_image``, ``custom_text``, ``gray_on_white``, ``grey``, ``green``, ``orange``, ``red``, ``red_on_white``, ``white_on_gray``, ``white_on_green``, ``green_on_white``, ``white_on_red``, ``white_on_yellow``, ``yellow_on_white``, ``black_on_light_yellow``, ``black_on_light_green``, ``black_on_light_red``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette Powerpack#palette}
        :param value: A value for the comparator. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#value Powerpack#value}
        :param custom_bg_color: The color palette to apply to the background, same values available as palette. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom_bg_color Powerpack#custom_bg_color}
        :param custom_fg_color: The color palette to apply to the foreground, same values available as palette. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom_fg_color Powerpack#custom_fg_color}
        :param hide_value: Setting this to True hides values. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#hide_value Powerpack#hide_value}
        :param image_url: Displays an image as the background. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#image_url Powerpack#image_url}
        :param metric: The metric from the request to correlate with this conditional format. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        :param timeframe: Defines the displayed timeframe. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#timeframe Powerpack#timeframe}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3a8d153931af24804008d64c1fc77ed41c07712376fea63a9cbc66a714863f16)
            check_type(argname="argument comparator", value=comparator, expected_type=type_hints["comparator"])
            check_type(argname="argument palette", value=palette, expected_type=type_hints["palette"])
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument custom_bg_color", value=custom_bg_color, expected_type=type_hints["custom_bg_color"])
            check_type(argname="argument custom_fg_color", value=custom_fg_color, expected_type=type_hints["custom_fg_color"])
            check_type(argname="argument hide_value", value=hide_value, expected_type=type_hints["hide_value"])
            check_type(argname="argument image_url", value=image_url, expected_type=type_hints["image_url"])
            check_type(argname="argument metric", value=metric, expected_type=type_hints["metric"])
            check_type(argname="argument timeframe", value=timeframe, expected_type=type_hints["timeframe"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "comparator": comparator,
            "palette": palette,
            "value": value,
        }
        if custom_bg_color is not None:
            self._values["custom_bg_color"] = custom_bg_color
        if custom_fg_color is not None:
            self._values["custom_fg_color"] = custom_fg_color
        if hide_value is not None:
            self._values["hide_value"] = hide_value
        if image_url is not None:
            self._values["image_url"] = image_url
        if metric is not None:
            self._values["metric"] = metric
        if timeframe is not None:
            self._values["timeframe"] = timeframe

    @builtins.property
    def comparator(self) -> builtins.str:
        '''The comparator to use. Valid values are ``=``, ``>``, ``>=``, ``<``, ``<=``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#comparator Powerpack#comparator}
        '''
        result = self._values.get("comparator")
        assert result is not None, "Required property 'comparator' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def palette(self) -> builtins.str:
        '''The color palette to apply.

        Valid values are ``blue``, ``custom_bg``, ``custom_image``, ``custom_text``, ``gray_on_white``, ``grey``, ``green``, ``orange``, ``red``, ``red_on_white``, ``white_on_gray``, ``white_on_green``, ``green_on_white``, ``white_on_red``, ``white_on_yellow``, ``yellow_on_white``, ``black_on_light_yellow``, ``black_on_light_green``, ``black_on_light_red``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette Powerpack#palette}
        '''
        result = self._values.get("palette")
        assert result is not None, "Required property 'palette' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def value(self) -> jsii.Number:
        '''A value for the comparator.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#value Powerpack#value}
        '''
        result = self._values.get("value")
        assert result is not None, "Required property 'value' is missing"
        return typing.cast(jsii.Number, result)

    @builtins.property
    def custom_bg_color(self) -> typing.Optional[builtins.str]:
        '''The color palette to apply to the background, same values available as palette.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom_bg_color Powerpack#custom_bg_color}
        '''
        result = self._values.get("custom_bg_color")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def custom_fg_color(self) -> typing.Optional[builtins.str]:
        '''The color palette to apply to the foreground, same values available as palette.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom_fg_color Powerpack#custom_fg_color}
        '''
        result = self._values.get("custom_fg_color")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def hide_value(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        '''Setting this to True hides values.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#hide_value Powerpack#hide_value}
        '''
        result = self._values.get("hide_value")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)

    @builtins.property
    def image_url(self) -> typing.Optional[builtins.str]:
        '''Displays an image as the background.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#image_url Powerpack#image_url}
        '''
        result = self._values.get("image_url")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def metric(self) -> typing.Optional[builtins.str]:
        '''The metric from the request to correlate with this conditional format.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        '''
        result = self._values.get("metric")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def timeframe(self) -> typing.Optional[builtins.str]:
        '''Defines the displayed timeframe.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#timeframe Powerpack#timeframe}
        '''
        result = self._values.get("timeframe")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetHeatmapDefinitionRequestFormulaConditionalFormats(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetHeatmapDefinitionRequestFormulaConditionalFormatsList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionRequestFormulaConditionalFormatsList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__153bf94efcc02977952a8644426eda72a2481848f9bbe71b1e4dcffda3d67d43)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetHeatmapDefinitionRequestFormulaConditionalFormatsOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c8b818e1c62cf041db6e4a2e6cbfc2830cf7e48ad9f945daeb937a6802d56105)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetHeatmapDefinitionRequestFormulaConditionalFormatsOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2c4fc149cb381d68deb6e678e4c93188749d950b407c5a444918c479fd8a75b0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7d0cbd684fca66c0d1558592e8754f9df47d1ae840bc517abda19a11b0b0ac07)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6e247b30765dc442ae61880ed4104b16c392a0d0e14c0ec6083087d19052a210)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHeatmapDefinitionRequestFormulaConditionalFormats]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHeatmapDefinitionRequestFormulaConditionalFormats]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHeatmapDefinitionRequestFormulaConditionalFormats]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8c455b115aaa603d68d5af4d48de5d923140236cb91bfb66a85aa7766b6c572a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetHeatmapDefinitionRequestFormulaConditionalFormatsOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionRequestFormulaConditionalFormatsOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c378227ca718a05095284564455ac46a79fc267e117f623d91fc7ed6977aeec4)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetCustomBgColor")
    def reset_custom_bg_color(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCustomBgColor", []))

    @jsii.member(jsii_name="resetCustomFgColor")
    def reset_custom_fg_color(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCustomFgColor", []))

    @jsii.member(jsii_name="resetHideValue")
    def reset_hide_value(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHideValue", []))

    @jsii.member(jsii_name="resetImageUrl")
    def reset_image_url(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetImageUrl", []))

    @jsii.member(jsii_name="resetMetric")
    def reset_metric(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMetric", []))

    @jsii.member(jsii_name="resetTimeframe")
    def reset_timeframe(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTimeframe", []))

    @builtins.property
    @jsii.member(jsii_name="comparatorInput")
    def comparator_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "comparatorInput"))

    @builtins.property
    @jsii.member(jsii_name="customBgColorInput")
    def custom_bg_color_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "customBgColorInput"))

    @builtins.property
    @jsii.member(jsii_name="customFgColorInput")
    def custom_fg_color_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "customFgColorInput"))

    @builtins.property
    @jsii.member(jsii_name="hideValueInput")
    def hide_value_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "hideValueInput"))

    @builtins.property
    @jsii.member(jsii_name="imageUrlInput")
    def image_url_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "imageUrlInput"))

    @builtins.property
    @jsii.member(jsii_name="metricInput")
    def metric_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "metricInput"))

    @builtins.property
    @jsii.member(jsii_name="paletteInput")
    def palette_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "paletteInput"))

    @builtins.property
    @jsii.member(jsii_name="timeframeInput")
    def timeframe_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "timeframeInput"))

    @builtins.property
    @jsii.member(jsii_name="valueInput")
    def value_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "valueInput"))

    @builtins.property
    @jsii.member(jsii_name="comparator")
    def comparator(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "comparator"))

    @comparator.setter
    def comparator(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c3a49a197c0cdcfd31ae2690ea1cc035d3042c29e31448b5d175f0199f665358)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "comparator", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="customBgColor")
    def custom_bg_color(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "customBgColor"))

    @custom_bg_color.setter
    def custom_bg_color(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f057fceb1f95f24afe4729ec7eb4d6adfca6e7d5074ebb14cdf7cfa77a609c52)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "customBgColor", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="customFgColor")
    def custom_fg_color(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "customFgColor"))

    @custom_fg_color.setter
    def custom_fg_color(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__94e0320b2331476b1e2bb6377aa0d1b120e5fa3791c0904d5b1b555c735e989b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "customFgColor", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="hideValue")
    def hide_value(self) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "hideValue"))

    @hide_value.setter
    def hide_value(
        self,
        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9d955abbf0dd3a19ca2ea9a9157d1d4e62d4863757770c1eaa8a5a35336ea0ce)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "hideValue", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="imageUrl")
    def image_url(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "imageUrl"))

    @image_url.setter
    def image_url(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ad4ece6b39ee53584111679eeadd2d4e7459805b60c8bb6e916526d641004992)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "imageUrl", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="metric")
    def metric(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "metric"))

    @metric.setter
    def metric(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4bb61b58a029b09ffd3bbf90d937a39f8808e4a07299feda3de23700f191a115)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "metric", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="palette")
    def palette(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "palette"))

    @palette.setter
    def palette(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__03f4b34ef78bff32d55a92a69478b3debdf484738dc4ef3a91d18e0b8204cb86)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "palette", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="timeframe")
    def timeframe(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "timeframe"))

    @timeframe.setter
    def timeframe(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7ab79c6a3dc461448a24ee34d8a70a4f96c3d7293ca8d68729f7330ccda997f6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "timeframe", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="value")
    def value(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "value"))

    @value.setter
    def value(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f3f2c504d6359617e46e270319f3bfe926f7efb04ef803ae78f5d2fecfa8b079)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "value", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHeatmapDefinitionRequestFormulaConditionalFormats]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHeatmapDefinitionRequestFormulaConditionalFormats]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHeatmapDefinitionRequestFormulaConditionalFormats]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f95321c23edc96533c44d7f2613b7220466a343ba79802fd2b00877a596158ba)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionRequestFormulaLimit",
    jsii_struct_bases=[],
    name_mapping={"count": "count", "order": "order"},
)
class PowerpackWidgetHeatmapDefinitionRequestFormulaLimit:
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        order: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param count: The number of results to return. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#count Powerpack#count}
        :param order: The direction of the sort. Valid values are ``asc``, ``desc``. Defaults to ``"desc"``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3df8f10772ba1f1565572ac0327158ccd5914e01f66e2f04309039cdc7b1caa5)
            check_type(argname="argument count", value=count, expected_type=type_hints["count"])
            check_type(argname="argument order", value=order, expected_type=type_hints["order"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if count is not None:
            self._values["count"] = count
        if order is not None:
            self._values["order"] = order

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''The number of results to return.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#count Powerpack#count}
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def order(self) -> typing.Optional[builtins.str]:
        '''The direction of the sort. Valid values are ``asc``, ``desc``. Defaults to ``"desc"``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        result = self._values.get("order")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetHeatmapDefinitionRequestFormulaLimit(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetHeatmapDefinitionRequestFormulaLimitOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionRequestFormulaLimitOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bc32ce2078100a38b726a14dd18425313a9a432ca7ea0fabd1234878269d5d8f)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetCount")
    def reset_count(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCount", []))

    @jsii.member(jsii_name="resetOrder")
    def reset_order(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetOrder", []))

    @builtins.property
    @jsii.member(jsii_name="countInput")
    def count_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "countInput"))

    @builtins.property
    @jsii.member(jsii_name="orderInput")
    def order_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "orderInput"))

    @builtins.property
    @jsii.member(jsii_name="count")
    def count(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "count"))

    @count.setter
    def count(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__546539467be86f72566f6b1763c7c8f77db1f7af10d23c4887be61becbbe6bb9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "count", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="order")
    def order(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "order"))

    @order.setter
    def order(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__134dbb541659921fa23f446ed837bbb6d32f574e3b2c4b5a964dff2cc6f4d9a3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "order", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetHeatmapDefinitionRequestFormulaLimit]:
        return typing.cast(typing.Optional[PowerpackWidgetHeatmapDefinitionRequestFormulaLimit], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetHeatmapDefinitionRequestFormulaLimit],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ae24e4f96177506f68cdee1f04af68437a308b2aef471bf1657a05130bb6a721)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetHeatmapDefinitionRequestFormulaList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionRequestFormulaList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b2c22bd11ffcc892784e2f33f0133b44bf57323c766741a5ab81eb4361baddf2)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetHeatmapDefinitionRequestFormulaOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__466d9d4afed54a0e711768bb58981ad81ece72b3d89814e8721b0ee073f69320)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetHeatmapDefinitionRequestFormulaOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3b89c3cf6ce575e6ed775eb469a8fc00e5da28f423720eebb77859b55d1d9e8b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__65cd184011939cea6e9ec9b0f06dab625ecbb1e6b33c820dbec11f9a80cb3b27)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__36a61e963a71a3b5b4df43e6addab5db8801546df7f4e9ce9f11c1e7093bb753)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHeatmapDefinitionRequestFormula]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHeatmapDefinitionRequestFormula]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHeatmapDefinitionRequestFormula]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__36414f96fead330d2ac4185de9bff5494b614ed885a75063879e502b33c5abd2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormat",
    jsii_struct_bases=[],
    name_mapping={"unit": "unit", "unit_scale": "unitScale"},
)
class PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormat:
    def __init__(
        self,
        *,
        unit: typing.Union["PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormatUnit", typing.Dict[builtins.str, typing.Any]],
        unit_scale: typing.Optional[typing.Union["PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormatUnitScale", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param unit: unit block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit Powerpack#unit}
        :param unit_scale: unit_scale block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit_scale Powerpack#unit_scale}
        '''
        if isinstance(unit, dict):
            unit = PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormatUnit(**unit)
        if isinstance(unit_scale, dict):
            unit_scale = PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormatUnitScale(**unit_scale)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__558aa8e55034f2caf5b0f2ef949f5bd56c711257359ea57824112c4bc1ab798e)
            check_type(argname="argument unit", value=unit, expected_type=type_hints["unit"])
            check_type(argname="argument unit_scale", value=unit_scale, expected_type=type_hints["unit_scale"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "unit": unit,
        }
        if unit_scale is not None:
            self._values["unit_scale"] = unit_scale

    @builtins.property
    def unit(self) -> "PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormatUnit":
        '''unit block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit Powerpack#unit}
        '''
        result = self._values.get("unit")
        assert result is not None, "Required property 'unit' is missing"
        return typing.cast("PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormatUnit", result)

    @builtins.property
    def unit_scale(
        self,
    ) -> typing.Optional["PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormatUnitScale"]:
        '''unit_scale block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit_scale Powerpack#unit_scale}
        '''
        result = self._values.get("unit_scale")
        return typing.cast(typing.Optional["PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormatUnitScale"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormat(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormatOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormatOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0c49cd2d2fbf9c048ff0afb082076a112800cfd97fbc1ef10a4bf00da5a916dd)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putUnit")
    def put_unit(
        self,
        *,
        canonical: typing.Optional[typing.Union["PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormatUnitCanonical", typing.Dict[builtins.str, typing.Any]]] = None,
        custom: typing.Optional[typing.Union["PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormatUnitCustom", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param canonical: canonical block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#canonical Powerpack#canonical}
        :param custom: custom block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom Powerpack#custom}
        '''
        value = PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormatUnit(
            canonical=canonical, custom=custom
        )

        return typing.cast(None, jsii.invoke(self, "putUnit", [value]))

    @jsii.member(jsii_name="putUnitScale")
    def put_unit_scale(self, *, unit_name: builtins.str) -> None:
        '''
        :param unit_name: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit_name Powerpack#unit_name}.
        '''
        value = PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormatUnitScale(
            unit_name=unit_name
        )

        return typing.cast(None, jsii.invoke(self, "putUnitScale", [value]))

    @jsii.member(jsii_name="resetUnitScale")
    def reset_unit_scale(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetUnitScale", []))

    @builtins.property
    @jsii.member(jsii_name="unit")
    def unit(
        self,
    ) -> "PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormatUnitOutputReference":
        return typing.cast("PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormatUnitOutputReference", jsii.get(self, "unit"))

    @builtins.property
    @jsii.member(jsii_name="unitScale")
    def unit_scale(
        self,
    ) -> "PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormatUnitScaleOutputReference":
        return typing.cast("PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormatUnitScaleOutputReference", jsii.get(self, "unitScale"))

    @builtins.property
    @jsii.member(jsii_name="unitInput")
    def unit_input(
        self,
    ) -> typing.Optional["PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormatUnit"]:
        return typing.cast(typing.Optional["PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormatUnit"], jsii.get(self, "unitInput"))

    @builtins.property
    @jsii.member(jsii_name="unitScaleInput")
    def unit_scale_input(
        self,
    ) -> typing.Optional["PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormatUnitScale"]:
        return typing.cast(typing.Optional["PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormatUnitScale"], jsii.get(self, "unitScaleInput"))

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormat]:
        return typing.cast(typing.Optional[PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormat], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormat],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dc97f3ec0798bd1ee34113d6ccfa9a8043d5481c8094a78a630a202911f9132b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormatUnit",
    jsii_struct_bases=[],
    name_mapping={"canonical": "canonical", "custom": "custom"},
)
class PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormatUnit:
    def __init__(
        self,
        *,
        canonical: typing.Optional[typing.Union["PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormatUnitCanonical", typing.Dict[builtins.str, typing.Any]]] = None,
        custom: typing.Optional[typing.Union["PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormatUnitCustom", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param canonical: canonical block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#canonical Powerpack#canonical}
        :param custom: custom block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom Powerpack#custom}
        '''
        if isinstance(canonical, dict):
            canonical = PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormatUnitCanonical(**canonical)
        if isinstance(custom, dict):
            custom = PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormatUnitCustom(**custom)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6ca2a252e128313e8e4c26dd39582ac5f927eba6202ad2995e410aee2aaab24f)
            check_type(argname="argument canonical", value=canonical, expected_type=type_hints["canonical"])
            check_type(argname="argument custom", value=custom, expected_type=type_hints["custom"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if canonical is not None:
            self._values["canonical"] = canonical
        if custom is not None:
            self._values["custom"] = custom

    @builtins.property
    def canonical(
        self,
    ) -> typing.Optional["PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormatUnitCanonical"]:
        '''canonical block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#canonical Powerpack#canonical}
        '''
        result = self._values.get("canonical")
        return typing.cast(typing.Optional["PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormatUnitCanonical"], result)

    @builtins.property
    def custom(
        self,
    ) -> typing.Optional["PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormatUnitCustom"]:
        '''custom block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom Powerpack#custom}
        '''
        result = self._values.get("custom")
        return typing.cast(typing.Optional["PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormatUnitCustom"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormatUnit(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormatUnitCanonical",
    jsii_struct_bases=[],
    name_mapping={"unit_name": "unitName", "per_unit_name": "perUnitName"},
)
class PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormatUnitCanonical:
    def __init__(
        self,
        *,
        unit_name: builtins.str,
        per_unit_name: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param unit_name: Unit name. It should be in singular form ('megabyte' and not 'megabytes'). Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit_name Powerpack#unit_name}
        :param per_unit_name: per unit name. If you want to represent megabytes/s, you set 'unit_name' = 'megabyte' and 'per_unit_name = 'second'. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#per_unit_name Powerpack#per_unit_name}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9551f618bd6aa2cff266d2a614de64f593dd64b4ddf0e2636a390db7e3b748d9)
            check_type(argname="argument unit_name", value=unit_name, expected_type=type_hints["unit_name"])
            check_type(argname="argument per_unit_name", value=per_unit_name, expected_type=type_hints["per_unit_name"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "unit_name": unit_name,
        }
        if per_unit_name is not None:
            self._values["per_unit_name"] = per_unit_name

    @builtins.property
    def unit_name(self) -> builtins.str:
        '''Unit name. It should be in singular form ('megabyte' and not 'megabytes').

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit_name Powerpack#unit_name}
        '''
        result = self._values.get("unit_name")
        assert result is not None, "Required property 'unit_name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def per_unit_name(self) -> typing.Optional[builtins.str]:
        '''per unit name. If you want to represent megabytes/s, you set 'unit_name' = 'megabyte' and 'per_unit_name = 'second'.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#per_unit_name Powerpack#per_unit_name}
        '''
        result = self._values.get("per_unit_name")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormatUnitCanonical(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormatUnitCanonicalOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormatUnitCanonicalOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0ceb3a8e8a9a257f67b4bd92aae706520d696960cb6c9e8f8547f2dad9a4a6a5)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetPerUnitName")
    def reset_per_unit_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPerUnitName", []))

    @builtins.property
    @jsii.member(jsii_name="perUnitNameInput")
    def per_unit_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "perUnitNameInput"))

    @builtins.property
    @jsii.member(jsii_name="unitNameInput")
    def unit_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "unitNameInput"))

    @builtins.property
    @jsii.member(jsii_name="perUnitName")
    def per_unit_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "perUnitName"))

    @per_unit_name.setter
    def per_unit_name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e01f55bcaa8e56affb15a17e95fccde97a827d17a037fded369dccae596c1cae)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "perUnitName", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="unitName")
    def unit_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "unitName"))

    @unit_name.setter
    def unit_name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f7e931df744336cfc5aa46f79a060b559a54b49fc2c23bd1334515de616e1296)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "unitName", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormatUnitCanonical]:
        return typing.cast(typing.Optional[PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormatUnitCanonical], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormatUnitCanonical],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1d0971ea087db1314cadc70bf2bfc69996d6193090e025f1628086eae862d3bf)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormatUnitCustom",
    jsii_struct_bases=[],
    name_mapping={"label": "label"},
)
class PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormatUnitCustom:
    def __init__(self, *, label: builtins.str) -> None:
        '''
        :param label: Unit label. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#label Powerpack#label}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__27ca40aa2615aca0d2d918e9639bcd9110ed8e72c8cd782f5fa04e0b5d8d3562)
            check_type(argname="argument label", value=label, expected_type=type_hints["label"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "label": label,
        }

    @builtins.property
    def label(self) -> builtins.str:
        '''Unit label.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#label Powerpack#label}
        '''
        result = self._values.get("label")
        assert result is not None, "Required property 'label' is missing"
        return typing.cast(builtins.str, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormatUnitCustom(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormatUnitCustomOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormatUnitCustomOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__11115c1e3b5c46b0ed9f50b67faed807d9005b81b169907b3a56c95ed6656b41)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @builtins.property
    @jsii.member(jsii_name="labelInput")
    def label_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "labelInput"))

    @builtins.property
    @jsii.member(jsii_name="label")
    def label(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "label"))

    @label.setter
    def label(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7cb3b879667a893fc054ddc5232400cf49d2f1d884795ed4b39b8f29028e6110)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "label", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormatUnitCustom]:
        return typing.cast(typing.Optional[PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormatUnitCustom], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormatUnitCustom],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fbc4300639378488e900f0d9176c10f3f7495966c6b77c77ba78afc16b71c86c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormatUnitOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormatUnitOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0f032255ff5a410c83da80461c22b2179dd5a23e30c4e2542bb06c5e0e270392)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putCanonical")
    def put_canonical(
        self,
        *,
        unit_name: builtins.str,
        per_unit_name: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param unit_name: Unit name. It should be in singular form ('megabyte' and not 'megabytes'). Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit_name Powerpack#unit_name}
        :param per_unit_name: per unit name. If you want to represent megabytes/s, you set 'unit_name' = 'megabyte' and 'per_unit_name = 'second'. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#per_unit_name Powerpack#per_unit_name}
        '''
        value = PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormatUnitCanonical(
            unit_name=unit_name, per_unit_name=per_unit_name
        )

        return typing.cast(None, jsii.invoke(self, "putCanonical", [value]))

    @jsii.member(jsii_name="putCustom")
    def put_custom(self, *, label: builtins.str) -> None:
        '''
        :param label: Unit label. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#label Powerpack#label}
        '''
        value = PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormatUnitCustom(
            label=label
        )

        return typing.cast(None, jsii.invoke(self, "putCustom", [value]))

    @jsii.member(jsii_name="resetCanonical")
    def reset_canonical(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCanonical", []))

    @jsii.member(jsii_name="resetCustom")
    def reset_custom(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCustom", []))

    @builtins.property
    @jsii.member(jsii_name="canonical")
    def canonical(
        self,
    ) -> PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormatUnitCanonicalOutputReference:
        return typing.cast(PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormatUnitCanonicalOutputReference, jsii.get(self, "canonical"))

    @builtins.property
    @jsii.member(jsii_name="custom")
    def custom(
        self,
    ) -> PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormatUnitCustomOutputReference:
        return typing.cast(PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormatUnitCustomOutputReference, jsii.get(self, "custom"))

    @builtins.property
    @jsii.member(jsii_name="canonicalInput")
    def canonical_input(
        self,
    ) -> typing.Optional[PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormatUnitCanonical]:
        return typing.cast(typing.Optional[PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormatUnitCanonical], jsii.get(self, "canonicalInput"))

    @builtins.property
    @jsii.member(jsii_name="customInput")
    def custom_input(
        self,
    ) -> typing.Optional[PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormatUnitCustom]:
        return typing.cast(typing.Optional[PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormatUnitCustom], jsii.get(self, "customInput"))

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormatUnit]:
        return typing.cast(typing.Optional[PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormatUnit], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormatUnit],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__acca4a7973c57cedf84c0af8bbf87e7f1d3fd11d27fd34fcd28ba8e1ff4fc1af)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormatUnitScale",
    jsii_struct_bases=[],
    name_mapping={"unit_name": "unitName"},
)
class PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormatUnitScale:
    def __init__(self, *, unit_name: builtins.str) -> None:
        '''
        :param unit_name: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit_name Powerpack#unit_name}.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__75e582812addecf9072a067ef54aeede8c7aede88f7872e7199ad0020bae0acf)
            check_type(argname="argument unit_name", value=unit_name, expected_type=type_hints["unit_name"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "unit_name": unit_name,
        }

    @builtins.property
    def unit_name(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit_name Powerpack#unit_name}.'''
        result = self._values.get("unit_name")
        assert result is not None, "Required property 'unit_name' is missing"
        return typing.cast(builtins.str, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormatUnitScale(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormatUnitScaleOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormatUnitScaleOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dcec20f1254443863e4de5b224fb97093604b253db526409649800141cac17dd)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @builtins.property
    @jsii.member(jsii_name="unitNameInput")
    def unit_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "unitNameInput"))

    @builtins.property
    @jsii.member(jsii_name="unitName")
    def unit_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "unitName"))

    @unit_name.setter
    def unit_name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7cc34154d64edfe060bf698be2d9670e0b9da09399a13c5b71608912cfb310f1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "unitName", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormatUnitScale]:
        return typing.cast(typing.Optional[PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormatUnitScale], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormatUnitScale],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cab76e5a1e2202c33d4101f90815bab620cb79fb142f28f3ebdf6da3ead68896)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetHeatmapDefinitionRequestFormulaOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionRequestFormulaOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ef3e483e61274ba769b429d612853e6a71942296c1fa7bedee2489b9a9e2db55)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putConditionalFormats")
    def put_conditional_formats(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHeatmapDefinitionRequestFormulaConditionalFormats, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2f94282169032be02b4397457a71d9062b6a8db038fc9a20da77b5849c263cce)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putConditionalFormats", [value]))

    @jsii.member(jsii_name="putLimit")
    def put_limit(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        order: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param count: The number of results to return. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#count Powerpack#count}
        :param order: The direction of the sort. Valid values are ``asc``, ``desc``. Defaults to ``"desc"``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        value = PowerpackWidgetHeatmapDefinitionRequestFormulaLimit(
            count=count, order=order
        )

        return typing.cast(None, jsii.invoke(self, "putLimit", [value]))

    @jsii.member(jsii_name="putNumberFormat")
    def put_number_format(
        self,
        *,
        unit: typing.Union[PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormatUnit, typing.Dict[builtins.str, typing.Any]],
        unit_scale: typing.Optional[typing.Union[PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormatUnitScale, typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param unit: unit block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit Powerpack#unit}
        :param unit_scale: unit_scale block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit_scale Powerpack#unit_scale}
        '''
        value = PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormat(
            unit=unit, unit_scale=unit_scale
        )

        return typing.cast(None, jsii.invoke(self, "putNumberFormat", [value]))

    @jsii.member(jsii_name="putStyle")
    def put_style(
        self,
        *,
        palette: typing.Optional[builtins.str] = None,
        palette_index: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param palette: The color palette used to display the formula. A guide to the available color palettes can be found at https://docs.datadoghq.com/dashboards/guide/widget_colors. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette Powerpack#palette}
        :param palette_index: Index specifying which color to use within the palette. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette_index Powerpack#palette_index}
        '''
        value = PowerpackWidgetHeatmapDefinitionRequestFormulaStyle(
            palette=palette, palette_index=palette_index
        )

        return typing.cast(None, jsii.invoke(self, "putStyle", [value]))

    @jsii.member(jsii_name="resetAlias")
    def reset_alias(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAlias", []))

    @jsii.member(jsii_name="resetCellDisplayMode")
    def reset_cell_display_mode(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCellDisplayMode", []))

    @jsii.member(jsii_name="resetConditionalFormats")
    def reset_conditional_formats(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetConditionalFormats", []))

    @jsii.member(jsii_name="resetLimit")
    def reset_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLimit", []))

    @jsii.member(jsii_name="resetNumberFormat")
    def reset_number_format(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetNumberFormat", []))

    @jsii.member(jsii_name="resetStyle")
    def reset_style(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetStyle", []))

    @builtins.property
    @jsii.member(jsii_name="conditionalFormats")
    def conditional_formats(
        self,
    ) -> PowerpackWidgetHeatmapDefinitionRequestFormulaConditionalFormatsList:
        return typing.cast(PowerpackWidgetHeatmapDefinitionRequestFormulaConditionalFormatsList, jsii.get(self, "conditionalFormats"))

    @builtins.property
    @jsii.member(jsii_name="limit")
    def limit(
        self,
    ) -> PowerpackWidgetHeatmapDefinitionRequestFormulaLimitOutputReference:
        return typing.cast(PowerpackWidgetHeatmapDefinitionRequestFormulaLimitOutputReference, jsii.get(self, "limit"))

    @builtins.property
    @jsii.member(jsii_name="numberFormat")
    def number_format(
        self,
    ) -> PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormatOutputReference:
        return typing.cast(PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormatOutputReference, jsii.get(self, "numberFormat"))

    @builtins.property
    @jsii.member(jsii_name="style")
    def style(
        self,
    ) -> "PowerpackWidgetHeatmapDefinitionRequestFormulaStyleOutputReference":
        return typing.cast("PowerpackWidgetHeatmapDefinitionRequestFormulaStyleOutputReference", jsii.get(self, "style"))

    @builtins.property
    @jsii.member(jsii_name="aliasInput")
    def alias_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aliasInput"))

    @builtins.property
    @jsii.member(jsii_name="cellDisplayModeInput")
    def cell_display_mode_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "cellDisplayModeInput"))

    @builtins.property
    @jsii.member(jsii_name="conditionalFormatsInput")
    def conditional_formats_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHeatmapDefinitionRequestFormulaConditionalFormats]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHeatmapDefinitionRequestFormulaConditionalFormats]]], jsii.get(self, "conditionalFormatsInput"))

    @builtins.property
    @jsii.member(jsii_name="formulaExpressionInput")
    def formula_expression_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "formulaExpressionInput"))

    @builtins.property
    @jsii.member(jsii_name="limitInput")
    def limit_input(
        self,
    ) -> typing.Optional[PowerpackWidgetHeatmapDefinitionRequestFormulaLimit]:
        return typing.cast(typing.Optional[PowerpackWidgetHeatmapDefinitionRequestFormulaLimit], jsii.get(self, "limitInput"))

    @builtins.property
    @jsii.member(jsii_name="numberFormatInput")
    def number_format_input(
        self,
    ) -> typing.Optional[PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormat]:
        return typing.cast(typing.Optional[PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormat], jsii.get(self, "numberFormatInput"))

    @builtins.property
    @jsii.member(jsii_name="styleInput")
    def style_input(
        self,
    ) -> typing.Optional["PowerpackWidgetHeatmapDefinitionRequestFormulaStyle"]:
        return typing.cast(typing.Optional["PowerpackWidgetHeatmapDefinitionRequestFormulaStyle"], jsii.get(self, "styleInput"))

    @builtins.property
    @jsii.member(jsii_name="alias")
    def alias(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "alias"))

    @alias.setter
    def alias(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e8aa3371414c9a48e9fd178f4971290c97a313cca2bd88811dfa073e90e82a2a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "alias", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="cellDisplayMode")
    def cell_display_mode(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "cellDisplayMode"))

    @cell_display_mode.setter
    def cell_display_mode(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2ea4b376b1e55ed58e7934d64c214f6e64ebcc8fd6e40049bdcd44dfea5a03a5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "cellDisplayMode", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="formulaExpression")
    def formula_expression(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "formulaExpression"))

    @formula_expression.setter
    def formula_expression(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__be051d5d334ffdf0bc3a5618e69e9f0fb2237c768e0c7fb5fa67ca24f492363c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "formulaExpression", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHeatmapDefinitionRequestFormula]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHeatmapDefinitionRequestFormula]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHeatmapDefinitionRequestFormula]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6ac18ceb856f73a87b67687210becc6394e7aa05217d1f59758b8c15641430b1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionRequestFormulaStyle",
    jsii_struct_bases=[],
    name_mapping={"palette": "palette", "palette_index": "paletteIndex"},
)
class PowerpackWidgetHeatmapDefinitionRequestFormulaStyle:
    def __init__(
        self,
        *,
        palette: typing.Optional[builtins.str] = None,
        palette_index: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param palette: The color palette used to display the formula. A guide to the available color palettes can be found at https://docs.datadoghq.com/dashboards/guide/widget_colors. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette Powerpack#palette}
        :param palette_index: Index specifying which color to use within the palette. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette_index Powerpack#palette_index}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f9f78f7c139a48905c7c498ffd579dbb71b4893202ff2c63c425a8cc8cc28956)
            check_type(argname="argument palette", value=palette, expected_type=type_hints["palette"])
            check_type(argname="argument palette_index", value=palette_index, expected_type=type_hints["palette_index"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if palette is not None:
            self._values["palette"] = palette
        if palette_index is not None:
            self._values["palette_index"] = palette_index

    @builtins.property
    def palette(self) -> typing.Optional[builtins.str]:
        '''The color palette used to display the formula.

        A guide to the available color palettes can be found at https://docs.datadoghq.com/dashboards/guide/widget_colors.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette Powerpack#palette}
        '''
        result = self._values.get("palette")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def palette_index(self) -> typing.Optional[jsii.Number]:
        '''Index specifying which color to use within the palette.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette_index Powerpack#palette_index}
        '''
        result = self._values.get("palette_index")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetHeatmapDefinitionRequestFormulaStyle(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetHeatmapDefinitionRequestFormulaStyleOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionRequestFormulaStyleOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__43cd80df7d712d38686a4aa8b5b9a3fc3271c0e73a48067655eb0b51f965c79e)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetPalette")
    def reset_palette(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPalette", []))

    @jsii.member(jsii_name="resetPaletteIndex")
    def reset_palette_index(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPaletteIndex", []))

    @builtins.property
    @jsii.member(jsii_name="paletteIndexInput")
    def palette_index_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "paletteIndexInput"))

    @builtins.property
    @jsii.member(jsii_name="paletteInput")
    def palette_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "paletteInput"))

    @builtins.property
    @jsii.member(jsii_name="palette")
    def palette(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "palette"))

    @palette.setter
    def palette(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__608233835e6c769069a8fd6bc85381ab691ec911f7795c02aeba4586b2325a68)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "palette", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="paletteIndex")
    def palette_index(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "paletteIndex"))

    @palette_index.setter
    def palette_index(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4601a8583e1792fd4f7cb4199a34691547ca6d188ac1eb01742f936fd494b7d7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "paletteIndex", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetHeatmapDefinitionRequestFormulaStyle]:
        return typing.cast(typing.Optional[PowerpackWidgetHeatmapDefinitionRequestFormulaStyle], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetHeatmapDefinitionRequestFormulaStyle],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c432e303caf292c39e609230aec089647376e98ed1183090d5b0a00aaf8305e2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetHeatmapDefinitionRequestList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionRequestList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__77a0e7958162c1c2253edcbef7a1154a0f9c8c5dd67a1dcbbb0b9dd940ff18c9)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetHeatmapDefinitionRequestOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cccbaca314b6af8c9c926190d05dcc36fbb69c087b3b5e6f7fb135c40f04182d)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetHeatmapDefinitionRequestOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__09697bd2aaca26e34ff7bdb996a9308fae91f1533da0ffb6e96ec3d2cd2cb94b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__57172e280b6d60841c9d2812cba117c1fb2ef29f52445e88baec93563718693a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ad35041600e35b77e1697a144f1007ed049f277fba9216f2e1b5b87ae5888d7d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHeatmapDefinitionRequest]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHeatmapDefinitionRequest]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHeatmapDefinitionRequest]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__83d9e42e03cdf9b26455a9cacd4b660e88bfcf156d029315a7d1c501ffa101fe)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionRequestLogQuery",
    jsii_struct_bases=[],
    name_mapping={
        "index": "index",
        "compute_query": "computeQuery",
        "group_by": "groupBy",
        "multi_compute": "multiCompute",
        "search_query": "searchQuery",
    },
)
class PowerpackWidgetHeatmapDefinitionRequestLogQuery:
    def __init__(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union["PowerpackWidgetHeatmapDefinitionRequestLogQueryComputeQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetHeatmapDefinitionRequestLogQueryGroupBy", typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetHeatmapDefinitionRequestLogQueryMultiCompute", typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        if isinstance(compute_query, dict):
            compute_query = PowerpackWidgetHeatmapDefinitionRequestLogQueryComputeQuery(**compute_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__db13133562be5643b1a16abce0b5e5cebb28d9e54365530153c94ff978fc4910)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
            check_type(argname="argument compute_query", value=compute_query, expected_type=type_hints["compute_query"])
            check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
            check_type(argname="argument multi_compute", value=multi_compute, expected_type=type_hints["multi_compute"])
            check_type(argname="argument search_query", value=search_query, expected_type=type_hints["search_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "index": index,
        }
        if compute_query is not None:
            self._values["compute_query"] = compute_query
        if group_by is not None:
            self._values["group_by"] = group_by
        if multi_compute is not None:
            self._values["multi_compute"] = multi_compute
        if search_query is not None:
            self._values["search_query"] = search_query

    @builtins.property
    def index(self) -> builtins.str:
        '''The name of the index to query.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        '''
        result = self._values.get("index")
        assert result is not None, "Required property 'index' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def compute_query(
        self,
    ) -> typing.Optional["PowerpackWidgetHeatmapDefinitionRequestLogQueryComputeQuery"]:
        '''compute_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        '''
        result = self._values.get("compute_query")
        return typing.cast(typing.Optional["PowerpackWidgetHeatmapDefinitionRequestLogQueryComputeQuery"], result)

    @builtins.property
    def group_by(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetHeatmapDefinitionRequestLogQueryGroupBy"]]]:
        '''group_by block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        '''
        result = self._values.get("group_by")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetHeatmapDefinitionRequestLogQueryGroupBy"]]], result)

    @builtins.property
    def multi_compute(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetHeatmapDefinitionRequestLogQueryMultiCompute"]]]:
        '''multi_compute block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        '''
        result = self._values.get("multi_compute")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetHeatmapDefinitionRequestLogQueryMultiCompute"]]], result)

    @builtins.property
    def search_query(self) -> typing.Optional[builtins.str]:
        '''The search query to use.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        result = self._values.get("search_query")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetHeatmapDefinitionRequestLogQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionRequestLogQueryComputeQuery",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetHeatmapDefinitionRequestLogQueryComputeQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a81d4b2e4085d77e6dd7813435f2a1b465138b0fcdcea17d5cf56e8827c96215)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetHeatmapDefinitionRequestLogQueryComputeQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetHeatmapDefinitionRequestLogQueryComputeQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionRequestLogQueryComputeQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f9393e67378c46320c99e7896a9823fc676df7c473ae91be394cd2b88b3e1b7e)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__597e11609fb54584d26caca08916625884bb29b7764b4635a1a3ad0913e21203)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__935e34fcc3fb227f20f9769f51743bf647c31b2e0c29381e267726a4c0b44154)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__72be43034391346df771e7b7e29a12f75da67c81da9ff8f7235e20e5c1df318d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetHeatmapDefinitionRequestLogQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetHeatmapDefinitionRequestLogQueryComputeQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetHeatmapDefinitionRequestLogQueryComputeQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bec8d6a1c6a5f6942c81772f06d793ceaca699f22763b8e23d7c3967c4d36e44)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionRequestLogQueryGroupBy",
    jsii_struct_bases=[],
    name_mapping={"facet": "facet", "limit": "limit", "sort_query": "sortQuery"},
)
class PowerpackWidgetHeatmapDefinitionRequestLogQueryGroupBy:
    def __init__(
        self,
        *,
        facet: typing.Optional[builtins.str] = None,
        limit: typing.Optional[jsii.Number] = None,
        sort_query: typing.Optional[typing.Union["PowerpackWidgetHeatmapDefinitionRequestLogQueryGroupBySortQuery", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param limit: The maximum number of items in the group. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param sort_query: sort_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        if isinstance(sort_query, dict):
            sort_query = PowerpackWidgetHeatmapDefinitionRequestLogQueryGroupBySortQuery(**sort_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__64c312f03bdad05644fb97d8ac6a94c2c9f7ccb02187fd9274c89573c261a111)
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
            check_type(argname="argument sort_query", value=sort_query, expected_type=type_hints["sort_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if facet is not None:
            self._values["facet"] = facet
        if limit is not None:
            self._values["limit"] = limit
        if sort_query is not None:
            self._values["sort_query"] = sort_query

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def limit(self) -> typing.Optional[jsii.Number]:
        '''The maximum number of items in the group.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        '''
        result = self._values.get("limit")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def sort_query(
        self,
    ) -> typing.Optional["PowerpackWidgetHeatmapDefinitionRequestLogQueryGroupBySortQuery"]:
        '''sort_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        result = self._values.get("sort_query")
        return typing.cast(typing.Optional["PowerpackWidgetHeatmapDefinitionRequestLogQueryGroupBySortQuery"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetHeatmapDefinitionRequestLogQueryGroupBy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetHeatmapDefinitionRequestLogQueryGroupByList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionRequestLogQueryGroupByList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c4bd15f847cab96c99226bcb4ae2794cf5adf723b6699af47dc96e310ebf5be2)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetHeatmapDefinitionRequestLogQueryGroupByOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2ad403ade74e5251a06c894c6f7036ad40d5c371ce04146cc12f396edd05b6e3)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetHeatmapDefinitionRequestLogQueryGroupByOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a5a600d079703dbd9909640528199fcaacd782d5b4bd703af6115e9310df9624)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e85eed0b1d7c5292225d6a50b6be404cf9acf25e85d2dea3cd239dce8c947112)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__35b337da96b1a8364d7d07f4e3c3c150a4f8c4908f76f103c71a6ec3bd964098)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHeatmapDefinitionRequestLogQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHeatmapDefinitionRequestLogQueryGroupBy]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHeatmapDefinitionRequestLogQueryGroupBy]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2caea8e05587aa181d70563e964aaea55b59e04127ba1696b99d70ea18c82ed0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetHeatmapDefinitionRequestLogQueryGroupByOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionRequestLogQueryGroupByOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d0c9900f8e9db507c7697805526dcfbb49cec84b9065085e40449c4d25fd2d7b)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putSortQuery")
    def put_sort_query(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        value = PowerpackWidgetHeatmapDefinitionRequestLogQueryGroupBySortQuery(
            aggregation=aggregation, order=order, facet=facet
        )

        return typing.cast(None, jsii.invoke(self, "putSortQuery", [value]))

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetLimit")
    def reset_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLimit", []))

    @jsii.member(jsii_name="resetSortQuery")
    def reset_sort_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSortQuery", []))

    @builtins.property
    @jsii.member(jsii_name="sortQuery")
    def sort_query(
        self,
    ) -> "PowerpackWidgetHeatmapDefinitionRequestLogQueryGroupBySortQueryOutputReference":
        return typing.cast("PowerpackWidgetHeatmapDefinitionRequestLogQueryGroupBySortQueryOutputReference", jsii.get(self, "sortQuery"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="limitInput")
    def limit_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "limitInput"))

    @builtins.property
    @jsii.member(jsii_name="sortQueryInput")
    def sort_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetHeatmapDefinitionRequestLogQueryGroupBySortQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetHeatmapDefinitionRequestLogQueryGroupBySortQuery"], jsii.get(self, "sortQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__75b10452573df6bd35439af5c930bba46007137ab7c905cc360a2e2b8451d5b9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="limit")
    def limit(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "limit"))

    @limit.setter
    def limit(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2be85332e231f50dce249bd3203b0e501d8e3d4e17568fbe1d855c6a6835fa2a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "limit", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHeatmapDefinitionRequestLogQueryGroupBy]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHeatmapDefinitionRequestLogQueryGroupBy]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHeatmapDefinitionRequestLogQueryGroupBy]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ed6121b31c7253baa90019a22219fa0ed4f7a2dd2c8cbdd483e2112d5fe82be3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionRequestLogQueryGroupBySortQuery",
    jsii_struct_bases=[],
    name_mapping={"aggregation": "aggregation", "order": "order", "facet": "facet"},
)
class PowerpackWidgetHeatmapDefinitionRequestLogQueryGroupBySortQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__25b1f3c7752f80fe403b348f283dd0c8d18c99f6a50f31324c6801427b8c2bf5)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument order", value=order, expected_type=type_hints["order"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
            "order": order,
        }
        if facet is not None:
            self._values["facet"] = facet

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def order(self) -> builtins.str:
        '''Widget sorting methods. Valid values are ``asc``, ``desc``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        result = self._values.get("order")
        assert result is not None, "Required property 'order' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetHeatmapDefinitionRequestLogQueryGroupBySortQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetHeatmapDefinitionRequestLogQueryGroupBySortQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionRequestLogQueryGroupBySortQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d65cdaa72e4d7e5ee77ee4f2b4e93af39fd6c2c9efe9aefa16c827e08369e2f2)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="orderInput")
    def order_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "orderInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e1a3866d31216bc160df3436abda68d2cb4bf12120efa96b028e924fbe037ef2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__eddf101cb7b8f990347bf6946e52b8a61a3dbfa37d1b97482a0e7dca007b27cc)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="order")
    def order(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "order"))

    @order.setter
    def order(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4925ec7c574f7813e87ebccd21a3786aa535f97563d162dd317d8798cffb3583)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "order", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetHeatmapDefinitionRequestLogQueryGroupBySortQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetHeatmapDefinitionRequestLogQueryGroupBySortQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetHeatmapDefinitionRequestLogQueryGroupBySortQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__99b02b62ecb0836148a815daabf1b7e1ffe282d156020b7a2c462a5d139ad321)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionRequestLogQueryMultiCompute",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetHeatmapDefinitionRequestLogQueryMultiCompute:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4031bd28b5cba83342a7dcb04cef1d91b3ec9c1a0521faf34b0eb7f4d4b8b2ed)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetHeatmapDefinitionRequestLogQueryMultiCompute(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetHeatmapDefinitionRequestLogQueryMultiComputeList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionRequestLogQueryMultiComputeList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__78d1e6fabcf0a2edd960e78b965e1e649116d7474d77f72ff3112b68e63ba8a0)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetHeatmapDefinitionRequestLogQueryMultiComputeOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__70cde8d3084522a602d78569577421d1b74832aafe4c2423546eea0da1b67bea)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetHeatmapDefinitionRequestLogQueryMultiComputeOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__39e278240fa402683656d966ad4ae0c8938a8d81a19bfb14b0966d6f81d1670f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c10e8bd776c5783f8c819bc34fb07132337e9f803d54ebab0f826335eedb8bf0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__515b15609132ec1a8a53141e390fae03fbadf20b51c16ff90c761d410f867d02)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHeatmapDefinitionRequestLogQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHeatmapDefinitionRequestLogQueryMultiCompute]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHeatmapDefinitionRequestLogQueryMultiCompute]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__752243b4dc22199bd571abc0374372118fef3133a0e42379163509d9b4e6cd9b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetHeatmapDefinitionRequestLogQueryMultiComputeOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionRequestLogQueryMultiComputeOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e406df8fee18d70f91944216ccd7079df62a656703908f6ef8300287ed4e9577)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c8e313d298141aa3feddd4688dce6f555163f67888b7fae3a3c1476c9850575a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__599fb95140c163a1507e065becff36f5c40e61cc1cc2e7064b34ffcad386e5ab)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d25d8872cf61e2c44af6751d2d6bc6863ee5f53fc4d573692b9d86a033dd3f8c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHeatmapDefinitionRequestLogQueryMultiCompute]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHeatmapDefinitionRequestLogQueryMultiCompute]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHeatmapDefinitionRequestLogQueryMultiCompute]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9b37b6b0694f5303f04d71734e035b7368c42a789fb45ab0c657c6b15c7131e1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetHeatmapDefinitionRequestLogQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionRequestLogQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ff7690252fa005cd5679682a634ff881d22eec8a577def9dda64597994628442)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putComputeQuery")
    def put_compute_query(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        value = PowerpackWidgetHeatmapDefinitionRequestLogQueryComputeQuery(
            aggregation=aggregation, facet=facet, interval=interval
        )

        return typing.cast(None, jsii.invoke(self, "putComputeQuery", [value]))

    @jsii.member(jsii_name="putGroupBy")
    def put_group_by(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHeatmapDefinitionRequestLogQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__befb37dee1b5caaaa4ccbbc4581502aaab88e860bc02222731e897aaefee152a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putGroupBy", [value]))

    @jsii.member(jsii_name="putMultiCompute")
    def put_multi_compute(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHeatmapDefinitionRequestLogQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__92a88bc81df15ff297ee81bb9cc6fed82900490e7866cb0f3f8f18163fee9b03)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putMultiCompute", [value]))

    @jsii.member(jsii_name="resetComputeQuery")
    def reset_compute_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetComputeQuery", []))

    @jsii.member(jsii_name="resetGroupBy")
    def reset_group_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGroupBy", []))

    @jsii.member(jsii_name="resetMultiCompute")
    def reset_multi_compute(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMultiCompute", []))

    @jsii.member(jsii_name="resetSearchQuery")
    def reset_search_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSearchQuery", []))

    @builtins.property
    @jsii.member(jsii_name="computeQuery")
    def compute_query(
        self,
    ) -> PowerpackWidgetHeatmapDefinitionRequestLogQueryComputeQueryOutputReference:
        return typing.cast(PowerpackWidgetHeatmapDefinitionRequestLogQueryComputeQueryOutputReference, jsii.get(self, "computeQuery"))

    @builtins.property
    @jsii.member(jsii_name="groupBy")
    def group_by(self) -> PowerpackWidgetHeatmapDefinitionRequestLogQueryGroupByList:
        return typing.cast(PowerpackWidgetHeatmapDefinitionRequestLogQueryGroupByList, jsii.get(self, "groupBy"))

    @builtins.property
    @jsii.member(jsii_name="multiCompute")
    def multi_compute(
        self,
    ) -> PowerpackWidgetHeatmapDefinitionRequestLogQueryMultiComputeList:
        return typing.cast(PowerpackWidgetHeatmapDefinitionRequestLogQueryMultiComputeList, jsii.get(self, "multiCompute"))

    @builtins.property
    @jsii.member(jsii_name="computeQueryInput")
    def compute_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetHeatmapDefinitionRequestLogQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetHeatmapDefinitionRequestLogQueryComputeQuery], jsii.get(self, "computeQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="groupByInput")
    def group_by_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHeatmapDefinitionRequestLogQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHeatmapDefinitionRequestLogQueryGroupBy]]], jsii.get(self, "groupByInput"))

    @builtins.property
    @jsii.member(jsii_name="indexInput")
    def index_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "indexInput"))

    @builtins.property
    @jsii.member(jsii_name="multiComputeInput")
    def multi_compute_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHeatmapDefinitionRequestLogQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHeatmapDefinitionRequestLogQueryMultiCompute]]], jsii.get(self, "multiComputeInput"))

    @builtins.property
    @jsii.member(jsii_name="searchQueryInput")
    def search_query_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "searchQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="index")
    def index(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "index"))

    @index.setter
    def index(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f05beccf7ee495f1ea2996444fd61f1132fc168b79e1cbd6217a5766663eab01)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "index", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="searchQuery")
    def search_query(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "searchQuery"))

    @search_query.setter
    def search_query(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c16659bc4d5f2d1d84aaac5519b5b9efdf2bc1d35d382e48f4187952f9fd9193)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "searchQuery", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetHeatmapDefinitionRequestLogQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetHeatmapDefinitionRequestLogQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetHeatmapDefinitionRequestLogQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3e591853e1e1890f9aad0ee63dad4d168595c8baac29ab9ef1ac2e6a7da2f355)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetHeatmapDefinitionRequestOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionRequestOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__80ac84e6e0aa181244fbc5b0b652a672da0242b137b9c32cd32b2a7d4c7714e1)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putApmQuery")
    def put_apm_query(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union[PowerpackWidgetHeatmapDefinitionRequestApmQueryComputeQuery, typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHeatmapDefinitionRequestApmQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHeatmapDefinitionRequestApmQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        value = PowerpackWidgetHeatmapDefinitionRequestApmQuery(
            index=index,
            compute_query=compute_query,
            group_by=group_by,
            multi_compute=multi_compute,
            search_query=search_query,
        )

        return typing.cast(None, jsii.invoke(self, "putApmQuery", [value]))

    @jsii.member(jsii_name="putFormula")
    def put_formula(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHeatmapDefinitionRequestFormula, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c0d3d7cec00cb61dfe750641ed4c53b8bb4b6890e87513725931caefd8028ef8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putFormula", [value]))

    @jsii.member(jsii_name="putLogQuery")
    def put_log_query(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union[PowerpackWidgetHeatmapDefinitionRequestLogQueryComputeQuery, typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHeatmapDefinitionRequestLogQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHeatmapDefinitionRequestLogQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        value = PowerpackWidgetHeatmapDefinitionRequestLogQuery(
            index=index,
            compute_query=compute_query,
            group_by=group_by,
            multi_compute=multi_compute,
            search_query=search_query,
        )

        return typing.cast(None, jsii.invoke(self, "putLogQuery", [value]))

    @jsii.member(jsii_name="putProcessQuery")
    def put_process_query(
        self,
        *,
        metric: builtins.str,
        filter_by: typing.Optional[typing.Sequence[builtins.str]] = None,
        limit: typing.Optional[jsii.Number] = None,
        search_by: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param metric: Your chosen metric. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        :param filter_by: A list of processes. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#filter_by Powerpack#filter_by}
        :param limit: The max number of items in the filter list. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param search_by: Your chosen search term. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_by Powerpack#search_by}
        '''
        value = PowerpackWidgetHeatmapDefinitionRequestProcessQuery(
            metric=metric, filter_by=filter_by, limit=limit, search_by=search_by
        )

        return typing.cast(None, jsii.invoke(self, "putProcessQuery", [value]))

    @jsii.member(jsii_name="putQuery")
    def put_query(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetHeatmapDefinitionRequestQuery", typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cfe347caec10ab1e2df5bd27ea3bea00617e76b659e4783b07f602b0e3734223)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putQuery", [value]))

    @jsii.member(jsii_name="putRumQuery")
    def put_rum_query(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union["PowerpackWidgetHeatmapDefinitionRequestRumQueryComputeQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetHeatmapDefinitionRequestRumQueryGroupBy", typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetHeatmapDefinitionRequestRumQueryMultiCompute", typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        value = PowerpackWidgetHeatmapDefinitionRequestRumQuery(
            index=index,
            compute_query=compute_query,
            group_by=group_by,
            multi_compute=multi_compute,
            search_query=search_query,
        )

        return typing.cast(None, jsii.invoke(self, "putRumQuery", [value]))

    @jsii.member(jsii_name="putSecurityQuery")
    def put_security_query(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union["PowerpackWidgetHeatmapDefinitionRequestSecurityQueryComputeQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetHeatmapDefinitionRequestSecurityQueryGroupBy", typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetHeatmapDefinitionRequestSecurityQueryMultiCompute", typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        value = PowerpackWidgetHeatmapDefinitionRequestSecurityQuery(
            index=index,
            compute_query=compute_query,
            group_by=group_by,
            multi_compute=multi_compute,
            search_query=search_query,
        )

        return typing.cast(None, jsii.invoke(self, "putSecurityQuery", [value]))

    @jsii.member(jsii_name="putStyle")
    def put_style(self, *, palette: typing.Optional[builtins.str] = None) -> None:
        '''
        :param palette: A color palette to apply to the widget. The available options are available at: https://docs.datadoghq.com/dashboards/widgets/timeseries/#appearance. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette Powerpack#palette}
        '''
        value = PowerpackWidgetHeatmapDefinitionRequestStyle(palette=palette)

        return typing.cast(None, jsii.invoke(self, "putStyle", [value]))

    @jsii.member(jsii_name="resetApmQuery")
    def reset_apm_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetApmQuery", []))

    @jsii.member(jsii_name="resetFormula")
    def reset_formula(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFormula", []))

    @jsii.member(jsii_name="resetLogQuery")
    def reset_log_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLogQuery", []))

    @jsii.member(jsii_name="resetProcessQuery")
    def reset_process_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetProcessQuery", []))

    @jsii.member(jsii_name="resetQ")
    def reset_q(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetQ", []))

    @jsii.member(jsii_name="resetQuery")
    def reset_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetQuery", []))

    @jsii.member(jsii_name="resetRumQuery")
    def reset_rum_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetRumQuery", []))

    @jsii.member(jsii_name="resetSecurityQuery")
    def reset_security_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSecurityQuery", []))

    @jsii.member(jsii_name="resetStyle")
    def reset_style(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetStyle", []))

    @builtins.property
    @jsii.member(jsii_name="apmQuery")
    def apm_query(
        self,
    ) -> PowerpackWidgetHeatmapDefinitionRequestApmQueryOutputReference:
        return typing.cast(PowerpackWidgetHeatmapDefinitionRequestApmQueryOutputReference, jsii.get(self, "apmQuery"))

    @builtins.property
    @jsii.member(jsii_name="formula")
    def formula(self) -> PowerpackWidgetHeatmapDefinitionRequestFormulaList:
        return typing.cast(PowerpackWidgetHeatmapDefinitionRequestFormulaList, jsii.get(self, "formula"))

    @builtins.property
    @jsii.member(jsii_name="logQuery")
    def log_query(
        self,
    ) -> PowerpackWidgetHeatmapDefinitionRequestLogQueryOutputReference:
        return typing.cast(PowerpackWidgetHeatmapDefinitionRequestLogQueryOutputReference, jsii.get(self, "logQuery"))

    @builtins.property
    @jsii.member(jsii_name="processQuery")
    def process_query(
        self,
    ) -> "PowerpackWidgetHeatmapDefinitionRequestProcessQueryOutputReference":
        return typing.cast("PowerpackWidgetHeatmapDefinitionRequestProcessQueryOutputReference", jsii.get(self, "processQuery"))

    @builtins.property
    @jsii.member(jsii_name="query")
    def query(self) -> "PowerpackWidgetHeatmapDefinitionRequestQueryList":
        return typing.cast("PowerpackWidgetHeatmapDefinitionRequestQueryList", jsii.get(self, "query"))

    @builtins.property
    @jsii.member(jsii_name="rumQuery")
    def rum_query(
        self,
    ) -> "PowerpackWidgetHeatmapDefinitionRequestRumQueryOutputReference":
        return typing.cast("PowerpackWidgetHeatmapDefinitionRequestRumQueryOutputReference", jsii.get(self, "rumQuery"))

    @builtins.property
    @jsii.member(jsii_name="securityQuery")
    def security_query(
        self,
    ) -> "PowerpackWidgetHeatmapDefinitionRequestSecurityQueryOutputReference":
        return typing.cast("PowerpackWidgetHeatmapDefinitionRequestSecurityQueryOutputReference", jsii.get(self, "securityQuery"))

    @builtins.property
    @jsii.member(jsii_name="style")
    def style(self) -> "PowerpackWidgetHeatmapDefinitionRequestStyleOutputReference":
        return typing.cast("PowerpackWidgetHeatmapDefinitionRequestStyleOutputReference", jsii.get(self, "style"))

    @builtins.property
    @jsii.member(jsii_name="apmQueryInput")
    def apm_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetHeatmapDefinitionRequestApmQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetHeatmapDefinitionRequestApmQuery], jsii.get(self, "apmQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="formulaInput")
    def formula_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHeatmapDefinitionRequestFormula]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHeatmapDefinitionRequestFormula]]], jsii.get(self, "formulaInput"))

    @builtins.property
    @jsii.member(jsii_name="logQueryInput")
    def log_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetHeatmapDefinitionRequestLogQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetHeatmapDefinitionRequestLogQuery], jsii.get(self, "logQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="processQueryInput")
    def process_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetHeatmapDefinitionRequestProcessQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetHeatmapDefinitionRequestProcessQuery"], jsii.get(self, "processQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="qInput")
    def q_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "qInput"))

    @builtins.property
    @jsii.member(jsii_name="queryInput")
    def query_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetHeatmapDefinitionRequestQuery"]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetHeatmapDefinitionRequestQuery"]]], jsii.get(self, "queryInput"))

    @builtins.property
    @jsii.member(jsii_name="rumQueryInput")
    def rum_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetHeatmapDefinitionRequestRumQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetHeatmapDefinitionRequestRumQuery"], jsii.get(self, "rumQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="securityQueryInput")
    def security_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetHeatmapDefinitionRequestSecurityQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetHeatmapDefinitionRequestSecurityQuery"], jsii.get(self, "securityQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="styleInput")
    def style_input(
        self,
    ) -> typing.Optional["PowerpackWidgetHeatmapDefinitionRequestStyle"]:
        return typing.cast(typing.Optional["PowerpackWidgetHeatmapDefinitionRequestStyle"], jsii.get(self, "styleInput"))

    @builtins.property
    @jsii.member(jsii_name="q")
    def q(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "q"))

    @q.setter
    def q(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7a1d15e5cf584b4d65f1f6f96ef282a45a4e164f257748fc3200845df22414d7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "q", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHeatmapDefinitionRequest]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHeatmapDefinitionRequest]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHeatmapDefinitionRequest]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dd21424f41b82d329d025d782f471246a337a211211b07582e02680f04ffbba5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionRequestProcessQuery",
    jsii_struct_bases=[],
    name_mapping={
        "metric": "metric",
        "filter_by": "filterBy",
        "limit": "limit",
        "search_by": "searchBy",
    },
)
class PowerpackWidgetHeatmapDefinitionRequestProcessQuery:
    def __init__(
        self,
        *,
        metric: builtins.str,
        filter_by: typing.Optional[typing.Sequence[builtins.str]] = None,
        limit: typing.Optional[jsii.Number] = None,
        search_by: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param metric: Your chosen metric. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        :param filter_by: A list of processes. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#filter_by Powerpack#filter_by}
        :param limit: The max number of items in the filter list. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param search_by: Your chosen search term. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_by Powerpack#search_by}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__58a5460cc2c148cf18d53fe170768e7c483f03e6cf38aefa4220f555f1922873)
            check_type(argname="argument metric", value=metric, expected_type=type_hints["metric"])
            check_type(argname="argument filter_by", value=filter_by, expected_type=type_hints["filter_by"])
            check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
            check_type(argname="argument search_by", value=search_by, expected_type=type_hints["search_by"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "metric": metric,
        }
        if filter_by is not None:
            self._values["filter_by"] = filter_by
        if limit is not None:
            self._values["limit"] = limit
        if search_by is not None:
            self._values["search_by"] = search_by

    @builtins.property
    def metric(self) -> builtins.str:
        '''Your chosen metric.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        '''
        result = self._values.get("metric")
        assert result is not None, "Required property 'metric' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def filter_by(self) -> typing.Optional[typing.List[builtins.str]]:
        '''A list of processes.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#filter_by Powerpack#filter_by}
        '''
        result = self._values.get("filter_by")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def limit(self) -> typing.Optional[jsii.Number]:
        '''The max number of items in the filter list.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        '''
        result = self._values.get("limit")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def search_by(self) -> typing.Optional[builtins.str]:
        '''Your chosen search term.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_by Powerpack#search_by}
        '''
        result = self._values.get("search_by")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetHeatmapDefinitionRequestProcessQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetHeatmapDefinitionRequestProcessQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionRequestProcessQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__67b4d8c6146f730403c4646635698d52d5ee723c102591d06957b520f01f17fa)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFilterBy")
    def reset_filter_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFilterBy", []))

    @jsii.member(jsii_name="resetLimit")
    def reset_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLimit", []))

    @jsii.member(jsii_name="resetSearchBy")
    def reset_search_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSearchBy", []))

    @builtins.property
    @jsii.member(jsii_name="filterByInput")
    def filter_by_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "filterByInput"))

    @builtins.property
    @jsii.member(jsii_name="limitInput")
    def limit_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "limitInput"))

    @builtins.property
    @jsii.member(jsii_name="metricInput")
    def metric_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "metricInput"))

    @builtins.property
    @jsii.member(jsii_name="searchByInput")
    def search_by_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "searchByInput"))

    @builtins.property
    @jsii.member(jsii_name="filterBy")
    def filter_by(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "filterBy"))

    @filter_by.setter
    def filter_by(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__870e5bf805be3bdede3622035c667282000004c11b5aa0de00858a614e056c30)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "filterBy", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="limit")
    def limit(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "limit"))

    @limit.setter
    def limit(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__899fec60f3b70a7e802f434b2e46c3f2dfd561011416fc37f77b591a91a1bd0f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "limit", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="metric")
    def metric(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "metric"))

    @metric.setter
    def metric(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a2c8406ef4f411d972dc6e6d3c88be1ec482e7781ef01ae288d1f16316529172)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "metric", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="searchBy")
    def search_by(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "searchBy"))

    @search_by.setter
    def search_by(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__42953e44b12ab78d6d7cf0e98043f43ef78f7b360505ac9fa503d9871560946c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "searchBy", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetHeatmapDefinitionRequestProcessQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetHeatmapDefinitionRequestProcessQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetHeatmapDefinitionRequestProcessQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b6ebb918ca3e4f76c8301a5ca109aaca7c554403da94a8de7bcf679428868310)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionRequestQuery",
    jsii_struct_bases=[],
    name_mapping={
        "apm_dependency_stats_query": "apmDependencyStatsQuery",
        "apm_resource_stats_query": "apmResourceStatsQuery",
        "cloud_cost_query": "cloudCostQuery",
        "event_query": "eventQuery",
        "metric_query": "metricQuery",
        "process_query": "processQuery",
        "slo_query": "sloQuery",
    },
)
class PowerpackWidgetHeatmapDefinitionRequestQuery:
    def __init__(
        self,
        *,
        apm_dependency_stats_query: typing.Optional[typing.Union["PowerpackWidgetHeatmapDefinitionRequestQueryApmDependencyStatsQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        apm_resource_stats_query: typing.Optional[typing.Union["PowerpackWidgetHeatmapDefinitionRequestQueryApmResourceStatsQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        cloud_cost_query: typing.Optional[typing.Union["PowerpackWidgetHeatmapDefinitionRequestQueryCloudCostQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        event_query: typing.Optional[typing.Union["PowerpackWidgetHeatmapDefinitionRequestQueryEventQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        metric_query: typing.Optional[typing.Union["PowerpackWidgetHeatmapDefinitionRequestQueryMetricQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        process_query: typing.Optional[typing.Union["PowerpackWidgetHeatmapDefinitionRequestQueryProcessQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        slo_query: typing.Optional[typing.Union["PowerpackWidgetHeatmapDefinitionRequestQuerySloQuery", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param apm_dependency_stats_query: apm_dependency_stats_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#apm_dependency_stats_query Powerpack#apm_dependency_stats_query}
        :param apm_resource_stats_query: apm_resource_stats_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#apm_resource_stats_query Powerpack#apm_resource_stats_query}
        :param cloud_cost_query: cloud_cost_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cloud_cost_query Powerpack#cloud_cost_query}
        :param event_query: event_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#event_query Powerpack#event_query}
        :param metric_query: metric_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric_query Powerpack#metric_query}
        :param process_query: process_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#process_query Powerpack#process_query}
        :param slo_query: slo_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#slo_query Powerpack#slo_query}
        '''
        if isinstance(apm_dependency_stats_query, dict):
            apm_dependency_stats_query = PowerpackWidgetHeatmapDefinitionRequestQueryApmDependencyStatsQuery(**apm_dependency_stats_query)
        if isinstance(apm_resource_stats_query, dict):
            apm_resource_stats_query = PowerpackWidgetHeatmapDefinitionRequestQueryApmResourceStatsQuery(**apm_resource_stats_query)
        if isinstance(cloud_cost_query, dict):
            cloud_cost_query = PowerpackWidgetHeatmapDefinitionRequestQueryCloudCostQuery(**cloud_cost_query)
        if isinstance(event_query, dict):
            event_query = PowerpackWidgetHeatmapDefinitionRequestQueryEventQuery(**event_query)
        if isinstance(metric_query, dict):
            metric_query = PowerpackWidgetHeatmapDefinitionRequestQueryMetricQuery(**metric_query)
        if isinstance(process_query, dict):
            process_query = PowerpackWidgetHeatmapDefinitionRequestQueryProcessQuery(**process_query)
        if isinstance(slo_query, dict):
            slo_query = PowerpackWidgetHeatmapDefinitionRequestQuerySloQuery(**slo_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f09e4055b8316edb403a6c969bb9918ca3df3879fffeb88bcd1cbdf28c8a9168)
            check_type(argname="argument apm_dependency_stats_query", value=apm_dependency_stats_query, expected_type=type_hints["apm_dependency_stats_query"])
            check_type(argname="argument apm_resource_stats_query", value=apm_resource_stats_query, expected_type=type_hints["apm_resource_stats_query"])
            check_type(argname="argument cloud_cost_query", value=cloud_cost_query, expected_type=type_hints["cloud_cost_query"])
            check_type(argname="argument event_query", value=event_query, expected_type=type_hints["event_query"])
            check_type(argname="argument metric_query", value=metric_query, expected_type=type_hints["metric_query"])
            check_type(argname="argument process_query", value=process_query, expected_type=type_hints["process_query"])
            check_type(argname="argument slo_query", value=slo_query, expected_type=type_hints["slo_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if apm_dependency_stats_query is not None:
            self._values["apm_dependency_stats_query"] = apm_dependency_stats_query
        if apm_resource_stats_query is not None:
            self._values["apm_resource_stats_query"] = apm_resource_stats_query
        if cloud_cost_query is not None:
            self._values["cloud_cost_query"] = cloud_cost_query
        if event_query is not None:
            self._values["event_query"] = event_query
        if metric_query is not None:
            self._values["metric_query"] = metric_query
        if process_query is not None:
            self._values["process_query"] = process_query
        if slo_query is not None:
            self._values["slo_query"] = slo_query

    @builtins.property
    def apm_dependency_stats_query(
        self,
    ) -> typing.Optional["PowerpackWidgetHeatmapDefinitionRequestQueryApmDependencyStatsQuery"]:
        '''apm_dependency_stats_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#apm_dependency_stats_query Powerpack#apm_dependency_stats_query}
        '''
        result = self._values.get("apm_dependency_stats_query")
        return typing.cast(typing.Optional["PowerpackWidgetHeatmapDefinitionRequestQueryApmDependencyStatsQuery"], result)

    @builtins.property
    def apm_resource_stats_query(
        self,
    ) -> typing.Optional["PowerpackWidgetHeatmapDefinitionRequestQueryApmResourceStatsQuery"]:
        '''apm_resource_stats_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#apm_resource_stats_query Powerpack#apm_resource_stats_query}
        '''
        result = self._values.get("apm_resource_stats_query")
        return typing.cast(typing.Optional["PowerpackWidgetHeatmapDefinitionRequestQueryApmResourceStatsQuery"], result)

    @builtins.property
    def cloud_cost_query(
        self,
    ) -> typing.Optional["PowerpackWidgetHeatmapDefinitionRequestQueryCloudCostQuery"]:
        '''cloud_cost_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cloud_cost_query Powerpack#cloud_cost_query}
        '''
        result = self._values.get("cloud_cost_query")
        return typing.cast(typing.Optional["PowerpackWidgetHeatmapDefinitionRequestQueryCloudCostQuery"], result)

    @builtins.property
    def event_query(
        self,
    ) -> typing.Optional["PowerpackWidgetHeatmapDefinitionRequestQueryEventQuery"]:
        '''event_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#event_query Powerpack#event_query}
        '''
        result = self._values.get("event_query")
        return typing.cast(typing.Optional["PowerpackWidgetHeatmapDefinitionRequestQueryEventQuery"], result)

    @builtins.property
    def metric_query(
        self,
    ) -> typing.Optional["PowerpackWidgetHeatmapDefinitionRequestQueryMetricQuery"]:
        '''metric_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric_query Powerpack#metric_query}
        '''
        result = self._values.get("metric_query")
        return typing.cast(typing.Optional["PowerpackWidgetHeatmapDefinitionRequestQueryMetricQuery"], result)

    @builtins.property
    def process_query(
        self,
    ) -> typing.Optional["PowerpackWidgetHeatmapDefinitionRequestQueryProcessQuery"]:
        '''process_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#process_query Powerpack#process_query}
        '''
        result = self._values.get("process_query")
        return typing.cast(typing.Optional["PowerpackWidgetHeatmapDefinitionRequestQueryProcessQuery"], result)

    @builtins.property
    def slo_query(
        self,
    ) -> typing.Optional["PowerpackWidgetHeatmapDefinitionRequestQuerySloQuery"]:
        '''slo_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#slo_query Powerpack#slo_query}
        '''
        result = self._values.get("slo_query")
        return typing.cast(typing.Optional["PowerpackWidgetHeatmapDefinitionRequestQuerySloQuery"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetHeatmapDefinitionRequestQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionRequestQueryApmDependencyStatsQuery",
    jsii_struct_bases=[],
    name_mapping={
        "data_source": "dataSource",
        "env": "env",
        "name": "name",
        "operation_name": "operationName",
        "resource_name": "resourceName",
        "service": "service",
        "stat": "stat",
        "cross_org_uuids": "crossOrgUuids",
        "is_upstream": "isUpstream",
        "primary_tag_name": "primaryTagName",
        "primary_tag_value": "primaryTagValue",
    },
)
class PowerpackWidgetHeatmapDefinitionRequestQueryApmDependencyStatsQuery:
    def __init__(
        self,
        *,
        data_source: builtins.str,
        env: builtins.str,
        name: builtins.str,
        operation_name: builtins.str,
        resource_name: builtins.str,
        service: builtins.str,
        stat: builtins.str,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        is_upstream: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        primary_tag_name: typing.Optional[builtins.str] = None,
        primary_tag_value: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param data_source: The data source for APM Dependency Stats queries. Valid values are ``apm_dependency_stats``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param env: APM environment. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#env Powerpack#env}
        :param name: The name of query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param operation_name: Name of operation on service. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#operation_name Powerpack#operation_name}
        :param resource_name: APM resource. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#resource_name Powerpack#resource_name}
        :param service: APM service. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#service Powerpack#service}
        :param stat: APM statistic. Valid values are ``avg_duration``, ``avg_root_duration``, ``avg_spans_per_trace``, ``error_rate``, ``pct_exec_time``, ``pct_of_traces``, ``total_traces_count``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#stat Powerpack#stat}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param is_upstream: Determines whether stats for upstream or downstream dependencies should be queried. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#is_upstream Powerpack#is_upstream}
        :param primary_tag_name: The name of the second primary tag used within APM; required when ``primary_tag_value`` is specified. See https://docs.datadoghq.com/tracing/guide/setting_primary_tags_to_scope/#add-a-second-primary-tag-in-datadog. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_name Powerpack#primary_tag_name}
        :param primary_tag_value: Filter APM data by the second primary tag. ``primary_tag_name`` must also be specified. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_value Powerpack#primary_tag_value}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__aa7da6179480e17f18bc6ee79f37940c5cde7544827b96e4f8350dd22bad123f)
            check_type(argname="argument data_source", value=data_source, expected_type=type_hints["data_source"])
            check_type(argname="argument env", value=env, expected_type=type_hints["env"])
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument operation_name", value=operation_name, expected_type=type_hints["operation_name"])
            check_type(argname="argument resource_name", value=resource_name, expected_type=type_hints["resource_name"])
            check_type(argname="argument service", value=service, expected_type=type_hints["service"])
            check_type(argname="argument stat", value=stat, expected_type=type_hints["stat"])
            check_type(argname="argument cross_org_uuids", value=cross_org_uuids, expected_type=type_hints["cross_org_uuids"])
            check_type(argname="argument is_upstream", value=is_upstream, expected_type=type_hints["is_upstream"])
            check_type(argname="argument primary_tag_name", value=primary_tag_name, expected_type=type_hints["primary_tag_name"])
            check_type(argname="argument primary_tag_value", value=primary_tag_value, expected_type=type_hints["primary_tag_value"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "data_source": data_source,
            "env": env,
            "name": name,
            "operation_name": operation_name,
            "resource_name": resource_name,
            "service": service,
            "stat": stat,
        }
        if cross_org_uuids is not None:
            self._values["cross_org_uuids"] = cross_org_uuids
        if is_upstream is not None:
            self._values["is_upstream"] = is_upstream
        if primary_tag_name is not None:
            self._values["primary_tag_name"] = primary_tag_name
        if primary_tag_value is not None:
            self._values["primary_tag_value"] = primary_tag_value

    @builtins.property
    def data_source(self) -> builtins.str:
        '''The data source for APM Dependency Stats queries. Valid values are ``apm_dependency_stats``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        '''
        result = self._values.get("data_source")
        assert result is not None, "Required property 'data_source' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def env(self) -> builtins.str:
        '''APM environment.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#env Powerpack#env}
        '''
        result = self._values.get("env")
        assert result is not None, "Required property 'env' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def name(self) -> builtins.str:
        '''The name of query for use in formulas.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        '''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def operation_name(self) -> builtins.str:
        '''Name of operation on service.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#operation_name Powerpack#operation_name}
        '''
        result = self._values.get("operation_name")
        assert result is not None, "Required property 'operation_name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def resource_name(self) -> builtins.str:
        '''APM resource.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#resource_name Powerpack#resource_name}
        '''
        result = self._values.get("resource_name")
        assert result is not None, "Required property 'resource_name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def service(self) -> builtins.str:
        '''APM service.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#service Powerpack#service}
        '''
        result = self._values.get("service")
        assert result is not None, "Required property 'service' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def stat(self) -> builtins.str:
        '''APM statistic. Valid values are ``avg_duration``, ``avg_root_duration``, ``avg_spans_per_trace``, ``error_rate``, ``pct_exec_time``, ``pct_of_traces``, ``total_traces_count``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#stat Powerpack#stat}
        '''
        result = self._values.get("stat")
        assert result is not None, "Required property 'stat' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def cross_org_uuids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''The source organization UUID for cross organization queries. Feature in Private Beta.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        '''
        result = self._values.get("cross_org_uuids")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def is_upstream(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        '''Determines whether stats for upstream or downstream dependencies should be queried.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#is_upstream Powerpack#is_upstream}
        '''
        result = self._values.get("is_upstream")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)

    @builtins.property
    def primary_tag_name(self) -> typing.Optional[builtins.str]:
        '''The name of the second primary tag used within APM; required when ``primary_tag_value`` is specified. See https://docs.datadoghq.com/tracing/guide/setting_primary_tags_to_scope/#add-a-second-primary-tag-in-datadog.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_name Powerpack#primary_tag_name}
        '''
        result = self._values.get("primary_tag_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def primary_tag_value(self) -> typing.Optional[builtins.str]:
        '''Filter APM data by the second primary tag. ``primary_tag_name`` must also be specified.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_value Powerpack#primary_tag_value}
        '''
        result = self._values.get("primary_tag_value")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetHeatmapDefinitionRequestQueryApmDependencyStatsQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetHeatmapDefinitionRequestQueryApmDependencyStatsQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionRequestQueryApmDependencyStatsQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__842c1d17518ead6eb6b7aaca4c6609412598fa8e600176a6eff6b7c85d8b1955)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetCrossOrgUuids")
    def reset_cross_org_uuids(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCrossOrgUuids", []))

    @jsii.member(jsii_name="resetIsUpstream")
    def reset_is_upstream(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetIsUpstream", []))

    @jsii.member(jsii_name="resetPrimaryTagName")
    def reset_primary_tag_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPrimaryTagName", []))

    @jsii.member(jsii_name="resetPrimaryTagValue")
    def reset_primary_tag_value(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPrimaryTagValue", []))

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuidsInput")
    def cross_org_uuids_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "crossOrgUuidsInput"))

    @builtins.property
    @jsii.member(jsii_name="dataSourceInput")
    def data_source_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "dataSourceInput"))

    @builtins.property
    @jsii.member(jsii_name="envInput")
    def env_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "envInput"))

    @builtins.property
    @jsii.member(jsii_name="isUpstreamInput")
    def is_upstream_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "isUpstreamInput"))

    @builtins.property
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property
    @jsii.member(jsii_name="operationNameInput")
    def operation_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "operationNameInput"))

    @builtins.property
    @jsii.member(jsii_name="primaryTagNameInput")
    def primary_tag_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "primaryTagNameInput"))

    @builtins.property
    @jsii.member(jsii_name="primaryTagValueInput")
    def primary_tag_value_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "primaryTagValueInput"))

    @builtins.property
    @jsii.member(jsii_name="resourceNameInput")
    def resource_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "resourceNameInput"))

    @builtins.property
    @jsii.member(jsii_name="serviceInput")
    def service_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "serviceInput"))

    @builtins.property
    @jsii.member(jsii_name="statInput")
    def stat_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "statInput"))

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuids")
    def cross_org_uuids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "crossOrgUuids"))

    @cross_org_uuids.setter
    def cross_org_uuids(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4d5f0acd1ec70794cadfeb4cd7a817944769299436d9284aa4485eaa88b42081)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "crossOrgUuids", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="dataSource")
    def data_source(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "dataSource"))

    @data_source.setter
    def data_source(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ef3efaeefda82b7dd55ea433f8637e7f9630b02b50d92fbb5f486a3ef9258067)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "dataSource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="env")
    def env(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "env"))

    @env.setter
    def env(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__094bda402d5f323b5ade6962c09d242ea7b18a6b4ef86e751cdccedcf7538450)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "env", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="isUpstream")
    def is_upstream(self) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "isUpstream"))

    @is_upstream.setter
    def is_upstream(
        self,
        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4010c07b9bc852d91f021038ede57c86305b55d3197e374ab392c2cc9d8e9967)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "isUpstream", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ab63dc78f569929be5d91feae4a4ff1ae87c52de60f644af719bcf7c1eaf6200)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "name", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="operationName")
    def operation_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "operationName"))

    @operation_name.setter
    def operation_name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__25611818880935675d326e598bd22d3df8b5ad50735b83042131330f4ca8f462)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "operationName", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="primaryTagName")
    def primary_tag_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "primaryTagName"))

    @primary_tag_name.setter
    def primary_tag_name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a4aba587d40bcdb6a4082610c0179c49af163aade34dd26e5737eefcf1a97dde)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "primaryTagName", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="primaryTagValue")
    def primary_tag_value(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "primaryTagValue"))

    @primary_tag_value.setter
    def primary_tag_value(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6b7cc4ed4b28f720f6460b9d849d32572ea9aaf6433e5c3eb967dba268edb2ad)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "primaryTagValue", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="resourceName")
    def resource_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "resourceName"))

    @resource_name.setter
    def resource_name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__66a45cbd5221110a893570d28771f647e8e770b3c5af101713bee3a2aad16ec2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "resourceName", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="service")
    def service(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "service"))

    @service.setter
    def service(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__98f81fa724b47d0173e905e57013bfbc76f9282bdf9f37533145d38c6e357d04)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "service", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="stat")
    def stat(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "stat"))

    @stat.setter
    def stat(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2ec5ab654655d5b7e843630a222c25f0767ea06c9baa5b576891cad2a411d04e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "stat", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetHeatmapDefinitionRequestQueryApmDependencyStatsQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetHeatmapDefinitionRequestQueryApmDependencyStatsQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetHeatmapDefinitionRequestQueryApmDependencyStatsQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fc036318d4dab1dcd4aadb4b7e4b3de5ab4ac967ee5f35c5c474503b07652b2d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionRequestQueryApmResourceStatsQuery",
    jsii_struct_bases=[],
    name_mapping={
        "data_source": "dataSource",
        "env": "env",
        "name": "name",
        "service": "service",
        "stat": "stat",
        "cross_org_uuids": "crossOrgUuids",
        "group_by": "groupBy",
        "operation_name": "operationName",
        "primary_tag_name": "primaryTagName",
        "primary_tag_value": "primaryTagValue",
        "resource_name": "resourceName",
    },
)
class PowerpackWidgetHeatmapDefinitionRequestQueryApmResourceStatsQuery:
    def __init__(
        self,
        *,
        data_source: builtins.str,
        env: builtins.str,
        name: builtins.str,
        service: builtins.str,
        stat: builtins.str,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        group_by: typing.Optional[typing.Sequence[builtins.str]] = None,
        operation_name: typing.Optional[builtins.str] = None,
        primary_tag_name: typing.Optional[builtins.str] = None,
        primary_tag_value: typing.Optional[builtins.str] = None,
        resource_name: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param data_source: The data source for APM Resource Stats queries. Valid values are ``apm_resource_stats``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param env: APM environment. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#env Powerpack#env}
        :param name: The name of query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param service: APM service. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#service Powerpack#service}
        :param stat: APM statistic. Valid values are ``errors``, ``error_rate``, ``hits``, ``latency_avg``, ``latency_distribution``, ``latency_max``, ``latency_p50``, ``latency_p75``, ``latency_p90``, ``latency_p95``, ``latency_p99``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#stat Powerpack#stat}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param group_by: Array of fields to group results by. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param operation_name: Name of operation on service. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#operation_name Powerpack#operation_name}
        :param primary_tag_name: The name of the second primary tag used within APM; required when ``primary_tag_value`` is specified. See https://docs.datadoghq.com/tracing/guide/setting_primary_tags_to_scope/#add-a-second-primary-tag-in-datadog. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_name Powerpack#primary_tag_name}
        :param primary_tag_value: Filter APM data by the second primary tag. ``primary_tag_name`` must also be specified. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_value Powerpack#primary_tag_value}
        :param resource_name: APM resource. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#resource_name Powerpack#resource_name}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7d58d10486ab7cafef7a1d80493a55f1723b105cc81b42984147c8feecf0d580)
            check_type(argname="argument data_source", value=data_source, expected_type=type_hints["data_source"])
            check_type(argname="argument env", value=env, expected_type=type_hints["env"])
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument service", value=service, expected_type=type_hints["service"])
            check_type(argname="argument stat", value=stat, expected_type=type_hints["stat"])
            check_type(argname="argument cross_org_uuids", value=cross_org_uuids, expected_type=type_hints["cross_org_uuids"])
            check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
            check_type(argname="argument operation_name", value=operation_name, expected_type=type_hints["operation_name"])
            check_type(argname="argument primary_tag_name", value=primary_tag_name, expected_type=type_hints["primary_tag_name"])
            check_type(argname="argument primary_tag_value", value=primary_tag_value, expected_type=type_hints["primary_tag_value"])
            check_type(argname="argument resource_name", value=resource_name, expected_type=type_hints["resource_name"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "data_source": data_source,
            "env": env,
            "name": name,
            "service": service,
            "stat": stat,
        }
        if cross_org_uuids is not None:
            self._values["cross_org_uuids"] = cross_org_uuids
        if group_by is not None:
            self._values["group_by"] = group_by
        if operation_name is not None:
            self._values["operation_name"] = operation_name
        if primary_tag_name is not None:
            self._values["primary_tag_name"] = primary_tag_name
        if primary_tag_value is not None:
            self._values["primary_tag_value"] = primary_tag_value
        if resource_name is not None:
            self._values["resource_name"] = resource_name

    @builtins.property
    def data_source(self) -> builtins.str:
        '''The data source for APM Resource Stats queries. Valid values are ``apm_resource_stats``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        '''
        result = self._values.get("data_source")
        assert result is not None, "Required property 'data_source' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def env(self) -> builtins.str:
        '''APM environment.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#env Powerpack#env}
        '''
        result = self._values.get("env")
        assert result is not None, "Required property 'env' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def name(self) -> builtins.str:
        '''The name of query for use in formulas.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        '''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def service(self) -> builtins.str:
        '''APM service.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#service Powerpack#service}
        '''
        result = self._values.get("service")
        assert result is not None, "Required property 'service' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def stat(self) -> builtins.str:
        '''APM statistic. Valid values are ``errors``, ``error_rate``, ``hits``, ``latency_avg``, ``latency_distribution``, ``latency_max``, ``latency_p50``, ``latency_p75``, ``latency_p90``, ``latency_p95``, ``latency_p99``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#stat Powerpack#stat}
        '''
        result = self._values.get("stat")
        assert result is not None, "Required property 'stat' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def cross_org_uuids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''The source organization UUID for cross organization queries. Feature in Private Beta.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        '''
        result = self._values.get("cross_org_uuids")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def group_by(self) -> typing.Optional[typing.List[builtins.str]]:
        '''Array of fields to group results by.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        '''
        result = self._values.get("group_by")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def operation_name(self) -> typing.Optional[builtins.str]:
        '''Name of operation on service.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#operation_name Powerpack#operation_name}
        '''
        result = self._values.get("operation_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def primary_tag_name(self) -> typing.Optional[builtins.str]:
        '''The name of the second primary tag used within APM; required when ``primary_tag_value`` is specified. See https://docs.datadoghq.com/tracing/guide/setting_primary_tags_to_scope/#add-a-second-primary-tag-in-datadog.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_name Powerpack#primary_tag_name}
        '''
        result = self._values.get("primary_tag_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def primary_tag_value(self) -> typing.Optional[builtins.str]:
        '''Filter APM data by the second primary tag. ``primary_tag_name`` must also be specified.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_value Powerpack#primary_tag_value}
        '''
        result = self._values.get("primary_tag_value")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def resource_name(self) -> typing.Optional[builtins.str]:
        '''APM resource.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#resource_name Powerpack#resource_name}
        '''
        result = self._values.get("resource_name")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetHeatmapDefinitionRequestQueryApmResourceStatsQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetHeatmapDefinitionRequestQueryApmResourceStatsQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionRequestQueryApmResourceStatsQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9596a24c2737fbd1e6d26658074866dc0331a8eff571cf42b1ff387b574abb7d)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetCrossOrgUuids")
    def reset_cross_org_uuids(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCrossOrgUuids", []))

    @jsii.member(jsii_name="resetGroupBy")
    def reset_group_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGroupBy", []))

    @jsii.member(jsii_name="resetOperationName")
    def reset_operation_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetOperationName", []))

    @jsii.member(jsii_name="resetPrimaryTagName")
    def reset_primary_tag_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPrimaryTagName", []))

    @jsii.member(jsii_name="resetPrimaryTagValue")
    def reset_primary_tag_value(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPrimaryTagValue", []))

    @jsii.member(jsii_name="resetResourceName")
    def reset_resource_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetResourceName", []))

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuidsInput")
    def cross_org_uuids_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "crossOrgUuidsInput"))

    @builtins.property
    @jsii.member(jsii_name="dataSourceInput")
    def data_source_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "dataSourceInput"))

    @builtins.property
    @jsii.member(jsii_name="envInput")
    def env_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "envInput"))

    @builtins.property
    @jsii.member(jsii_name="groupByInput")
    def group_by_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "groupByInput"))

    @builtins.property
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property
    @jsii.member(jsii_name="operationNameInput")
    def operation_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "operationNameInput"))

    @builtins.property
    @jsii.member(jsii_name="primaryTagNameInput")
    def primary_tag_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "primaryTagNameInput"))

    @builtins.property
    @jsii.member(jsii_name="primaryTagValueInput")
    def primary_tag_value_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "primaryTagValueInput"))

    @builtins.property
    @jsii.member(jsii_name="resourceNameInput")
    def resource_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "resourceNameInput"))

    @builtins.property
    @jsii.member(jsii_name="serviceInput")
    def service_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "serviceInput"))

    @builtins.property
    @jsii.member(jsii_name="statInput")
    def stat_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "statInput"))

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuids")
    def cross_org_uuids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "crossOrgUuids"))

    @cross_org_uuids.setter
    def cross_org_uuids(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b3971f1ee8ce76ff9a3b3eb07ba29c29264b8f5d3918277f54c1ff84ab6ac042)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "crossOrgUuids", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="dataSource")
    def data_source(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "dataSource"))

    @data_source.setter
    def data_source(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__060de5e54945552caccd040ef49bded47a2c3a7eba679f32bd080a2c4f4f636d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "dataSource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="env")
    def env(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "env"))

    @env.setter
    def env(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a1f5619f54b6cada34b186bbcc56013dfd5e3e00a83cc2b3e1b83b936db38cfe)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "env", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="groupBy")
    def group_by(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "groupBy"))

    @group_by.setter
    def group_by(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ebca92a0b9762de4be05555416cc06927ccf9b958dea482031bd40ab90905864)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "groupBy", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f70eeee594282e7598e64bd78c5995118c66f19893e0e3c144292fef6e4f67d8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "name", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="operationName")
    def operation_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "operationName"))

    @operation_name.setter
    def operation_name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7d1e11f46fe46b636cd5add7e05bf04363a5b8f9b7f53b719878d22f620b7423)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "operationName", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="primaryTagName")
    def primary_tag_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "primaryTagName"))

    @primary_tag_name.setter
    def primary_tag_name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fad533ac091ced9e395c04606b011a12abaf7567e46b6cf89ecbdd37da15ced3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "primaryTagName", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="primaryTagValue")
    def primary_tag_value(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "primaryTagValue"))

    @primary_tag_value.setter
    def primary_tag_value(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__827133a8c3f18ed265dbe9fd9ed063ab560655b05dfb4c55fc03fbaaec3ec42b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "primaryTagValue", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="resourceName")
    def resource_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "resourceName"))

    @resource_name.setter
    def resource_name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f43c93f61e6b96f3842135a0f066e2ee2147b988d9812b759ac1cf5a2f4367a1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "resourceName", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="service")
    def service(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "service"))

    @service.setter
    def service(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9a2d94b377250085292d71bb49a9645fe40c07668dd263913747e63262ee51eb)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "service", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="stat")
    def stat(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "stat"))

    @stat.setter
    def stat(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__950908693f7696b060a8fc555d9729860e9681df10590ce9cc542daca9e9951a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "stat", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetHeatmapDefinitionRequestQueryApmResourceStatsQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetHeatmapDefinitionRequestQueryApmResourceStatsQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetHeatmapDefinitionRequestQueryApmResourceStatsQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__899c9718f2d366e58d494201ef36fbcb8137d71782bb2cca90ade2e9b6c0de13)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionRequestQueryCloudCostQuery",
    jsii_struct_bases=[],
    name_mapping={
        "data_source": "dataSource",
        "name": "name",
        "query": "query",
        "aggregator": "aggregator",
        "cross_org_uuids": "crossOrgUuids",
    },
)
class PowerpackWidgetHeatmapDefinitionRequestQueryCloudCostQuery:
    def __init__(
        self,
        *,
        data_source: builtins.str,
        name: builtins.str,
        query: builtins.str,
        aggregator: typing.Optional[builtins.str] = None,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
    ) -> None:
        '''
        :param data_source: The data source for cloud cost queries. Valid values are ``cloud_cost``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param name: The name of the query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param query: The cloud cost query definition. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        :param aggregator: The aggregation methods available for cloud cost queries. Valid values are ``avg``, ``last``, ``max``, ``min``, ``sum``, ``percentile``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregator Powerpack#aggregator}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e29204b367379cb5fdd1ede6f7afe693bb0f0be920f80c6ecc9c532f3b9fa977)
            check_type(argname="argument data_source", value=data_source, expected_type=type_hints["data_source"])
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument query", value=query, expected_type=type_hints["query"])
            check_type(argname="argument aggregator", value=aggregator, expected_type=type_hints["aggregator"])
            check_type(argname="argument cross_org_uuids", value=cross_org_uuids, expected_type=type_hints["cross_org_uuids"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "data_source": data_source,
            "name": name,
            "query": query,
        }
        if aggregator is not None:
            self._values["aggregator"] = aggregator
        if cross_org_uuids is not None:
            self._values["cross_org_uuids"] = cross_org_uuids

    @builtins.property
    def data_source(self) -> builtins.str:
        '''The data source for cloud cost queries. Valid values are ``cloud_cost``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        '''
        result = self._values.get("data_source")
        assert result is not None, "Required property 'data_source' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def name(self) -> builtins.str:
        '''The name of the query for use in formulas.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        '''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def query(self) -> builtins.str:
        '''The cloud cost query definition.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        '''
        result = self._values.get("query")
        assert result is not None, "Required property 'query' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def aggregator(self) -> typing.Optional[builtins.str]:
        '''The aggregation methods available for cloud cost queries. Valid values are ``avg``, ``last``, ``max``, ``min``, ``sum``, ``percentile``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregator Powerpack#aggregator}
        '''
        result = self._values.get("aggregator")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def cross_org_uuids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''The source organization UUID for cross organization queries. Feature in Private Beta.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        '''
        result = self._values.get("cross_org_uuids")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetHeatmapDefinitionRequestQueryCloudCostQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetHeatmapDefinitionRequestQueryCloudCostQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionRequestQueryCloudCostQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4a902041579a099fa46c0b4750b6ed7fa2ba49cd5fa37c30650b127c3c397430)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetAggregator")
    def reset_aggregator(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAggregator", []))

    @jsii.member(jsii_name="resetCrossOrgUuids")
    def reset_cross_org_uuids(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCrossOrgUuids", []))

    @builtins.property
    @jsii.member(jsii_name="aggregatorInput")
    def aggregator_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregatorInput"))

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuidsInput")
    def cross_org_uuids_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "crossOrgUuidsInput"))

    @builtins.property
    @jsii.member(jsii_name="dataSourceInput")
    def data_source_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "dataSourceInput"))

    @builtins.property
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property
    @jsii.member(jsii_name="queryInput")
    def query_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "queryInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregator")
    def aggregator(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregator"))

    @aggregator.setter
    def aggregator(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4556ef93f736b73c1c6d486af7d8fcb02f05674e9ec096489660ba50f464d3a8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregator", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuids")
    def cross_org_uuids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "crossOrgUuids"))

    @cross_org_uuids.setter
    def cross_org_uuids(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__02e1c9b9a741018814d95f3318ccd575872ce8c79d1fd56db39cd181a58809ca)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "crossOrgUuids", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="dataSource")
    def data_source(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "dataSource"))

    @data_source.setter
    def data_source(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d6225a47a938b037f148fbe997eba31b177bbd5612fe2e54d054d58fb26bef61)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "dataSource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d950ada4e6941d00d818f09cad597e6763302a406cf7cfb5733730a1c8d392aa)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "name", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="query")
    def query(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "query"))

    @query.setter
    def query(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c2d9125d20c770421f1e7b5466b6d3cb0b87e7a0880a27c73fbfa7ddd08b4f34)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "query", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetHeatmapDefinitionRequestQueryCloudCostQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetHeatmapDefinitionRequestQueryCloudCostQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetHeatmapDefinitionRequestQueryCloudCostQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1be973e8e452b83079f3991fd25e9cb860ba148bec4b4bc124201e359ef2c2fa)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionRequestQueryEventQuery",
    jsii_struct_bases=[],
    name_mapping={
        "compute": "compute",
        "data_source": "dataSource",
        "name": "name",
        "cross_org_uuids": "crossOrgUuids",
        "group_by": "groupBy",
        "indexes": "indexes",
        "search": "search",
        "storage": "storage",
    },
)
class PowerpackWidgetHeatmapDefinitionRequestQueryEventQuery:
    def __init__(
        self,
        *,
        compute: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetHeatmapDefinitionRequestQueryEventQueryCompute", typing.Dict[builtins.str, typing.Any]]]],
        data_source: builtins.str,
        name: builtins.str,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetHeatmapDefinitionRequestQueryEventQueryGroupBy", typing.Dict[builtins.str, typing.Any]]]]] = None,
        indexes: typing.Optional[typing.Sequence[builtins.str]] = None,
        search: typing.Optional[typing.Union["PowerpackWidgetHeatmapDefinitionRequestQueryEventQuerySearch", typing.Dict[builtins.str, typing.Any]]] = None,
        storage: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param compute: compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute Powerpack#compute}
        :param data_source: The data source for event platform-based queries. Valid values are ``logs``, ``spans``, ``network``, ``rum``, ``security_signals``, ``profiles``, ``audit``, ``events``, ``ci_tests``, ``ci_pipelines``, ``incident_analytics``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param name: The name of query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param indexes: An array of index names to query in the stream. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#indexes Powerpack#indexes}
        :param search: search block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search Powerpack#search}
        :param storage: Storage location (private beta). Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#storage Powerpack#storage}
        '''
        if isinstance(search, dict):
            search = PowerpackWidgetHeatmapDefinitionRequestQueryEventQuerySearch(**search)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7fdafe8f8b22a7afcdb4cf94a2366ec8b07cc09832bdef98397558042725a28e)
            check_type(argname="argument compute", value=compute, expected_type=type_hints["compute"])
            check_type(argname="argument data_source", value=data_source, expected_type=type_hints["data_source"])
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument cross_org_uuids", value=cross_org_uuids, expected_type=type_hints["cross_org_uuids"])
            check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
            check_type(argname="argument indexes", value=indexes, expected_type=type_hints["indexes"])
            check_type(argname="argument search", value=search, expected_type=type_hints["search"])
            check_type(argname="argument storage", value=storage, expected_type=type_hints["storage"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "compute": compute,
            "data_source": data_source,
            "name": name,
        }
        if cross_org_uuids is not None:
            self._values["cross_org_uuids"] = cross_org_uuids
        if group_by is not None:
            self._values["group_by"] = group_by
        if indexes is not None:
            self._values["indexes"] = indexes
        if search is not None:
            self._values["search"] = search
        if storage is not None:
            self._values["storage"] = storage

    @builtins.property
    def compute(
        self,
    ) -> typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetHeatmapDefinitionRequestQueryEventQueryCompute"]]:
        '''compute block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute Powerpack#compute}
        '''
        result = self._values.get("compute")
        assert result is not None, "Required property 'compute' is missing"
        return typing.cast(typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetHeatmapDefinitionRequestQueryEventQueryCompute"]], result)

    @builtins.property
    def data_source(self) -> builtins.str:
        '''The data source for event platform-based queries.

        Valid values are ``logs``, ``spans``, ``network``, ``rum``, ``security_signals``, ``profiles``, ``audit``, ``events``, ``ci_tests``, ``ci_pipelines``, ``incident_analytics``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        '''
        result = self._values.get("data_source")
        assert result is not None, "Required property 'data_source' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def name(self) -> builtins.str:
        '''The name of query for use in formulas.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        '''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def cross_org_uuids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''The source organization UUID for cross organization queries. Feature in Private Beta.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        '''
        result = self._values.get("cross_org_uuids")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def group_by(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetHeatmapDefinitionRequestQueryEventQueryGroupBy"]]]:
        '''group_by block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        '''
        result = self._values.get("group_by")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetHeatmapDefinitionRequestQueryEventQueryGroupBy"]]], result)

    @builtins.property
    def indexes(self) -> typing.Optional[typing.List[builtins.str]]:
        '''An array of index names to query in the stream.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#indexes Powerpack#indexes}
        '''
        result = self._values.get("indexes")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def search(
        self,
    ) -> typing.Optional["PowerpackWidgetHeatmapDefinitionRequestQueryEventQuerySearch"]:
        '''search block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search Powerpack#search}
        '''
        result = self._values.get("search")
        return typing.cast(typing.Optional["PowerpackWidgetHeatmapDefinitionRequestQueryEventQuerySearch"], result)

    @builtins.property
    def storage(self) -> typing.Optional[builtins.str]:
        '''Storage location (private beta).

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#storage Powerpack#storage}
        '''
        result = self._values.get("storage")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetHeatmapDefinitionRequestQueryEventQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionRequestQueryEventQueryCompute",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "interval": "interval",
        "metric": "metric",
    },
)
class PowerpackWidgetHeatmapDefinitionRequestQueryEventQueryCompute:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        interval: typing.Optional[jsii.Number] = None,
        metric: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation methods for event platform queries. Valid values are ``count``, ``cardinality``, ``median``, ``pc75``, ``pc90``, ``pc95``, ``pc98``, ``pc99``, ``sum``, ``min``, ``max``, ``avg``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param interval: A time interval in milliseconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        :param metric: The measurable attribute to compute. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1789ade7ba3f1c98182af230fe04d172880d2947ee4e3c1f01cf39e9b401c73e)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
            check_type(argname="argument metric", value=metric, expected_type=type_hints["metric"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if interval is not None:
            self._values["interval"] = interval
        if metric is not None:
            self._values["metric"] = metric

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation methods for event platform queries.

        Valid values are ``count``, ``cardinality``, ``median``, ``pc75``, ``pc90``, ``pc95``, ``pc98``, ``pc99``, ``sum``, ``min``, ``max``, ``avg``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''A time interval in milliseconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def metric(self) -> typing.Optional[builtins.str]:
        '''The measurable attribute to compute.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        '''
        result = self._values.get("metric")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetHeatmapDefinitionRequestQueryEventQueryCompute(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetHeatmapDefinitionRequestQueryEventQueryComputeList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionRequestQueryEventQueryComputeList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8797ea07304fd44fe65efc1ab213bf15d2acd30ba23088bcc039eadb45bbdb27)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetHeatmapDefinitionRequestQueryEventQueryComputeOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__84cb6c268e9b1664b0afa1da5dc534af04293d44b7b7712fba29c1b5465ea918)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetHeatmapDefinitionRequestQueryEventQueryComputeOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a6b576529c25c126fa215d887de01d67c41869bbb661158d314be238d2f68ea5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0055e0913b8c69b87d3baf6220f330041e2573c99a92eeb0bf646ab666c5e4f4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__963423daba4d5b527f1a3b065e17cc467c79bedd019711bfe3795afe4c1ffab0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHeatmapDefinitionRequestQueryEventQueryCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHeatmapDefinitionRequestQueryEventQueryCompute]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHeatmapDefinitionRequestQueryEventQueryCompute]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8ce229c31dc00096414f765f6681d90c36a3e1d1d36eb739c72bc4f0652822cf)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetHeatmapDefinitionRequestQueryEventQueryComputeOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionRequestQueryEventQueryComputeOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a9e32b47ca1163d86e251c83916bf6f8e0d7e71f2af43bd39309049154307886)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @jsii.member(jsii_name="resetMetric")
    def reset_metric(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMetric", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="metricInput")
    def metric_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "metricInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9daac4b4fb5215f176bbfa11ed378f50f6a461d293b4ff097f964642951f5e42)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6ea7ceaf0ebab6e0e7820301ee21d2fdbb3f2e79522c72230bb2eba64e62a429)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="metric")
    def metric(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "metric"))

    @metric.setter
    def metric(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6e3ce8de3fe180e1a2ac95e614cd85253e7a7020e809063bcc25141344ead0dc)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "metric", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHeatmapDefinitionRequestQueryEventQueryCompute]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHeatmapDefinitionRequestQueryEventQueryCompute]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHeatmapDefinitionRequestQueryEventQueryCompute]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5957e6030a137b5e3642c6c47787c16d09fd88b38aaa84240bf888ed359d7f4f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionRequestQueryEventQueryGroupBy",
    jsii_struct_bases=[],
    name_mapping={"facet": "facet", "limit": "limit", "sort": "sort"},
)
class PowerpackWidgetHeatmapDefinitionRequestQueryEventQueryGroupBy:
    def __init__(
        self,
        *,
        facet: builtins.str,
        limit: typing.Optional[jsii.Number] = None,
        sort: typing.Optional[typing.Union["PowerpackWidgetHeatmapDefinitionRequestQueryEventQueryGroupBySort", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param facet: The event facet. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param limit: The number of groups to return. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param sort: sort block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort Powerpack#sort}
        '''
        if isinstance(sort, dict):
            sort = PowerpackWidgetHeatmapDefinitionRequestQueryEventQueryGroupBySort(**sort)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5c8555ff7d6fccf92db72a9a20c22ed6f7f61316e116a9311145f219533a834e)
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
            check_type(argname="argument sort", value=sort, expected_type=type_hints["sort"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "facet": facet,
        }
        if limit is not None:
            self._values["limit"] = limit
        if sort is not None:
            self._values["sort"] = sort

    @builtins.property
    def facet(self) -> builtins.str:
        '''The event facet.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        assert result is not None, "Required property 'facet' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def limit(self) -> typing.Optional[jsii.Number]:
        '''The number of groups to return.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        '''
        result = self._values.get("limit")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def sort(
        self,
    ) -> typing.Optional["PowerpackWidgetHeatmapDefinitionRequestQueryEventQueryGroupBySort"]:
        '''sort block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort Powerpack#sort}
        '''
        result = self._values.get("sort")
        return typing.cast(typing.Optional["PowerpackWidgetHeatmapDefinitionRequestQueryEventQueryGroupBySort"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetHeatmapDefinitionRequestQueryEventQueryGroupBy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetHeatmapDefinitionRequestQueryEventQueryGroupByList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionRequestQueryEventQueryGroupByList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2dc43b958e54efba377481daa45cf11225df6fbf133cf0f4187e80f59688cf11)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetHeatmapDefinitionRequestQueryEventQueryGroupByOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c3ebaf96b8021ef074750883e35f096803ae5bff4400786f54fb6b4b2a3fb022)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetHeatmapDefinitionRequestQueryEventQueryGroupByOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__10a95dad2fce857db3a027807c0934b9f90558bb80e67699de2cd2255d827a8f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__af3e5d45b9d9e558a4a78f2ab3e4602b4cccc38bf98e741432938d2c026b4212)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__af062549c8d86e0393cbfebce9c6e90054c5e18823c5350f79775091e52195fe)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHeatmapDefinitionRequestQueryEventQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHeatmapDefinitionRequestQueryEventQueryGroupBy]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHeatmapDefinitionRequestQueryEventQueryGroupBy]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__07a1c361ebeca11f615284f902d2523c659c1834d3c7dd5208cd91a1dad17e95)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetHeatmapDefinitionRequestQueryEventQueryGroupByOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionRequestQueryEventQueryGroupByOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8a86297afe9f33593c945438332eb37d791e107b8718f228799ffc1ee1a3a0e2)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putSort")
    def put_sort(
        self,
        *,
        aggregation: builtins.str,
        metric: typing.Optional[builtins.str] = None,
        order: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation methods for the event platform queries. Valid values are ``count``, ``cardinality``, ``median``, ``pc75``, ``pc90``, ``pc95``, ``pc98``, ``pc99``, ``sum``, ``min``, ``max``, ``avg``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param metric: The metric used for sorting group by results. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        :param order: Direction of sort. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        value = PowerpackWidgetHeatmapDefinitionRequestQueryEventQueryGroupBySort(
            aggregation=aggregation, metric=metric, order=order
        )

        return typing.cast(None, jsii.invoke(self, "putSort", [value]))

    @jsii.member(jsii_name="resetLimit")
    def reset_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLimit", []))

    @jsii.member(jsii_name="resetSort")
    def reset_sort(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSort", []))

    @builtins.property
    @jsii.member(jsii_name="sort")
    def sort(
        self,
    ) -> "PowerpackWidgetHeatmapDefinitionRequestQueryEventQueryGroupBySortOutputReference":
        return typing.cast("PowerpackWidgetHeatmapDefinitionRequestQueryEventQueryGroupBySortOutputReference", jsii.get(self, "sort"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="limitInput")
    def limit_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "limitInput"))

    @builtins.property
    @jsii.member(jsii_name="sortInput")
    def sort_input(
        self,
    ) -> typing.Optional["PowerpackWidgetHeatmapDefinitionRequestQueryEventQueryGroupBySort"]:
        return typing.cast(typing.Optional["PowerpackWidgetHeatmapDefinitionRequestQueryEventQueryGroupBySort"], jsii.get(self, "sortInput"))

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__234ddf5d216dc78cdd8ecbe5f017e4e0a939e732538dff541b1fca8a1f131d34)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="limit")
    def limit(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "limit"))

    @limit.setter
    def limit(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4833992b2ee90db934d1fd2303a0092d780bab09d66cda5768ba690f6a35add2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "limit", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHeatmapDefinitionRequestQueryEventQueryGroupBy]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHeatmapDefinitionRequestQueryEventQueryGroupBy]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHeatmapDefinitionRequestQueryEventQueryGroupBy]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8ef41c396a11117a9766c79bad3056670c3cd8998b00722264d2ec8be2b2c2ce)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionRequestQueryEventQueryGroupBySort",
    jsii_struct_bases=[],
    name_mapping={"aggregation": "aggregation", "metric": "metric", "order": "order"},
)
class PowerpackWidgetHeatmapDefinitionRequestQueryEventQueryGroupBySort:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        metric: typing.Optional[builtins.str] = None,
        order: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation methods for the event platform queries. Valid values are ``count``, ``cardinality``, ``median``, ``pc75``, ``pc90``, ``pc95``, ``pc98``, ``pc99``, ``sum``, ``min``, ``max``, ``avg``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param metric: The metric used for sorting group by results. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        :param order: Direction of sort. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fb976e2ad571a1d64df131ecbac0235404a8514e67a799daaa9a63449be71bdd)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument metric", value=metric, expected_type=type_hints["metric"])
            check_type(argname="argument order", value=order, expected_type=type_hints["order"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if metric is not None:
            self._values["metric"] = metric
        if order is not None:
            self._values["order"] = order

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation methods for the event platform queries.

        Valid values are ``count``, ``cardinality``, ``median``, ``pc75``, ``pc90``, ``pc95``, ``pc98``, ``pc99``, ``sum``, ``min``, ``max``, ``avg``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def metric(self) -> typing.Optional[builtins.str]:
        '''The metric used for sorting group by results.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        '''
        result = self._values.get("metric")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def order(self) -> typing.Optional[builtins.str]:
        '''Direction of sort. Valid values are ``asc``, ``desc``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        result = self._values.get("order")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetHeatmapDefinitionRequestQueryEventQueryGroupBySort(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetHeatmapDefinitionRequestQueryEventQueryGroupBySortOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionRequestQueryEventQueryGroupBySortOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8edce651b537a398eaba02bf64220fab5fdc2f0d64d395c7d3728adc1510100b)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetMetric")
    def reset_metric(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMetric", []))

    @jsii.member(jsii_name="resetOrder")
    def reset_order(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetOrder", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="metricInput")
    def metric_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "metricInput"))

    @builtins.property
    @jsii.member(jsii_name="orderInput")
    def order_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "orderInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1676b63c5f9f92ca41069c934c31237acc6895c542a9a0f565e78e0b3ae44300)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="metric")
    def metric(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "metric"))

    @metric.setter
    def metric(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__535b2f978a3b46290337ea37a298dccad0b55aa801be6054eb3ef5507e7aed0e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "metric", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="order")
    def order(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "order"))

    @order.setter
    def order(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e1fbdbf76f9e314dd58f9edba7d91c93fd91f8309e4ddc5a8054f43644454a56)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "order", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetHeatmapDefinitionRequestQueryEventQueryGroupBySort]:
        return typing.cast(typing.Optional[PowerpackWidgetHeatmapDefinitionRequestQueryEventQueryGroupBySort], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetHeatmapDefinitionRequestQueryEventQueryGroupBySort],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__daf6aa37694a44a260c20d782e7f8f7dac295d34beb3280947ced9a5d493bd5c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetHeatmapDefinitionRequestQueryEventQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionRequestQueryEventQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ab154ec04e48d5ce389da97ba3deb7a6680455945cfa9affed72156f093a19eb)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putCompute")
    def put_compute(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHeatmapDefinitionRequestQueryEventQueryCompute, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a5cdcac96ed0a60e6dabdb041cc8a0da7c014ef1699ceaf9ff978c4492400da8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putCompute", [value]))

    @jsii.member(jsii_name="putGroupBy")
    def put_group_by(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHeatmapDefinitionRequestQueryEventQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a8e27cb11db976b7d46be8f998c47b1cf6748239b4f82676a63315562c1bc645)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putGroupBy", [value]))

    @jsii.member(jsii_name="putSearch")
    def put_search(self, *, query: builtins.str) -> None:
        '''
        :param query: The events search string. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        '''
        value = PowerpackWidgetHeatmapDefinitionRequestQueryEventQuerySearch(
            query=query
        )

        return typing.cast(None, jsii.invoke(self, "putSearch", [value]))

    @jsii.member(jsii_name="resetCrossOrgUuids")
    def reset_cross_org_uuids(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCrossOrgUuids", []))

    @jsii.member(jsii_name="resetGroupBy")
    def reset_group_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGroupBy", []))

    @jsii.member(jsii_name="resetIndexes")
    def reset_indexes(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetIndexes", []))

    @jsii.member(jsii_name="resetSearch")
    def reset_search(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSearch", []))

    @jsii.member(jsii_name="resetStorage")
    def reset_storage(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetStorage", []))

    @builtins.property
    @jsii.member(jsii_name="compute")
    def compute(
        self,
    ) -> PowerpackWidgetHeatmapDefinitionRequestQueryEventQueryComputeList:
        return typing.cast(PowerpackWidgetHeatmapDefinitionRequestQueryEventQueryComputeList, jsii.get(self, "compute"))

    @builtins.property
    @jsii.member(jsii_name="groupBy")
    def group_by(
        self,
    ) -> PowerpackWidgetHeatmapDefinitionRequestQueryEventQueryGroupByList:
        return typing.cast(PowerpackWidgetHeatmapDefinitionRequestQueryEventQueryGroupByList, jsii.get(self, "groupBy"))

    @builtins.property
    @jsii.member(jsii_name="search")
    def search(
        self,
    ) -> "PowerpackWidgetHeatmapDefinitionRequestQueryEventQuerySearchOutputReference":
        return typing.cast("PowerpackWidgetHeatmapDefinitionRequestQueryEventQuerySearchOutputReference", jsii.get(self, "search"))

    @builtins.property
    @jsii.member(jsii_name="computeInput")
    def compute_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHeatmapDefinitionRequestQueryEventQueryCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHeatmapDefinitionRequestQueryEventQueryCompute]]], jsii.get(self, "computeInput"))

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuidsInput")
    def cross_org_uuids_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "crossOrgUuidsInput"))

    @builtins.property
    @jsii.member(jsii_name="dataSourceInput")
    def data_source_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "dataSourceInput"))

    @builtins.property
    @jsii.member(jsii_name="groupByInput")
    def group_by_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHeatmapDefinitionRequestQueryEventQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHeatmapDefinitionRequestQueryEventQueryGroupBy]]], jsii.get(self, "groupByInput"))

    @builtins.property
    @jsii.member(jsii_name="indexesInput")
    def indexes_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "indexesInput"))

    @builtins.property
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property
    @jsii.member(jsii_name="searchInput")
    def search_input(
        self,
    ) -> typing.Optional["PowerpackWidgetHeatmapDefinitionRequestQueryEventQuerySearch"]:
        return typing.cast(typing.Optional["PowerpackWidgetHeatmapDefinitionRequestQueryEventQuerySearch"], jsii.get(self, "searchInput"))

    @builtins.property
    @jsii.member(jsii_name="storageInput")
    def storage_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "storageInput"))

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuids")
    def cross_org_uuids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "crossOrgUuids"))

    @cross_org_uuids.setter
    def cross_org_uuids(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3b6e1e9c631be0afdf14aa9b31b7b72e9425308cc3b3753e81b7ba5278105dde)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "crossOrgUuids", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="dataSource")
    def data_source(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "dataSource"))

    @data_source.setter
    def data_source(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0437fc3f9ad2a454b8d7070174072ad737a5d26446241eeba896db20c5e76beb)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "dataSource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="indexes")
    def indexes(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "indexes"))

    @indexes.setter
    def indexes(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__84f12d7028a053b98b556effbfb76c12963853a04ea50aa26a44d8f7a67a8b69)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "indexes", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ca3bab05aca442b912f720c29518fe0822cd7526bbd2da0a551738c263ff4ab0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "name", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="storage")
    def storage(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "storage"))

    @storage.setter
    def storage(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__44e21a41a181ccbdcd2720abe0d63c55ef46f01931d53a2f98fa52cb3ec9028e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "storage", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetHeatmapDefinitionRequestQueryEventQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetHeatmapDefinitionRequestQueryEventQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetHeatmapDefinitionRequestQueryEventQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a6200e88ee4290f5759228d1c2ca3d8b63c6009041b4576f00f0befba0fe8433)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionRequestQueryEventQuerySearch",
    jsii_struct_bases=[],
    name_mapping={"query": "query"},
)
class PowerpackWidgetHeatmapDefinitionRequestQueryEventQuerySearch:
    def __init__(self, *, query: builtins.str) -> None:
        '''
        :param query: The events search string. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3f3bbbcc034f5387eefaae82ad54aaae2596b4cfa0018e1c60de232c0c1bb014)
            check_type(argname="argument query", value=query, expected_type=type_hints["query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "query": query,
        }

    @builtins.property
    def query(self) -> builtins.str:
        '''The events search string.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        '''
        result = self._values.get("query")
        assert result is not None, "Required property 'query' is missing"
        return typing.cast(builtins.str, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetHeatmapDefinitionRequestQueryEventQuerySearch(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetHeatmapDefinitionRequestQueryEventQuerySearchOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionRequestQueryEventQuerySearchOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1326c029351dd8a9d2f1cf56c2fef0db167e3da7dc5a9787f99db055f7d2c979)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @builtins.property
    @jsii.member(jsii_name="queryInput")
    def query_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "queryInput"))

    @builtins.property
    @jsii.member(jsii_name="query")
    def query(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "query"))

    @query.setter
    def query(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c26708d4cc5e1924f88bd8262d02b2f9ab01c7b8f85c3f4f302c3f49270f2067)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "query", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetHeatmapDefinitionRequestQueryEventQuerySearch]:
        return typing.cast(typing.Optional[PowerpackWidgetHeatmapDefinitionRequestQueryEventQuerySearch], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetHeatmapDefinitionRequestQueryEventQuerySearch],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6f27c12f480bf69109a851f72cf5dbc1793e7461b4a27e04ecd7da5c2c41c242)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetHeatmapDefinitionRequestQueryList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionRequestQueryList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__39a34a29ffefcd65dcbaf31fedd8cb35ddf76542d3f2c844317e9275ca938439)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetHeatmapDefinitionRequestQueryOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a6ce3d56d901d0d290db38cff33ea462bef29d90a3a7513232ba3d76c39a7e18)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetHeatmapDefinitionRequestQueryOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__afb6e85983eee283235280ac6bb0a95efe47af44bb6f85574d77ace7ad167f3f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7d96acfda853852c248c78e416b270acc9f8fed67d17aa714acd17e58f5fcb43)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f2e1de43aa08c2c5e989f8ec8f5e475c69672a391143ca4479717ed7bda34448)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHeatmapDefinitionRequestQuery]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHeatmapDefinitionRequestQuery]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHeatmapDefinitionRequestQuery]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cacc04f9e90d3e8fb179e2aa26926a014a8b4a5ef4ca5d2f19474e12cec40c8e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionRequestQueryMetricQuery",
    jsii_struct_bases=[],
    name_mapping={
        "name": "name",
        "query": "query",
        "aggregator": "aggregator",
        "cross_org_uuids": "crossOrgUuids",
        "data_source": "dataSource",
    },
)
class PowerpackWidgetHeatmapDefinitionRequestQueryMetricQuery:
    def __init__(
        self,
        *,
        name: builtins.str,
        query: builtins.str,
        aggregator: typing.Optional[builtins.str] = None,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        data_source: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param name: The name of the query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param query: The metrics query definition. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        :param aggregator: The aggregation methods available for metrics queries. Valid values are ``avg``, ``min``, ``max``, ``sum``, ``last``, ``area``, ``l2norm``, ``percentile``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregator Powerpack#aggregator}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param data_source: The data source for metrics queries. Defaults to ``"metrics"``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a4c10c3e60727edb826fc9951000890a933214f8b8e69ebd4bf503b1ed2d310b)
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument query", value=query, expected_type=type_hints["query"])
            check_type(argname="argument aggregator", value=aggregator, expected_type=type_hints["aggregator"])
            check_type(argname="argument cross_org_uuids", value=cross_org_uuids, expected_type=type_hints["cross_org_uuids"])
            check_type(argname="argument data_source", value=data_source, expected_type=type_hints["data_source"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "name": name,
            "query": query,
        }
        if aggregator is not None:
            self._values["aggregator"] = aggregator
        if cross_org_uuids is not None:
            self._values["cross_org_uuids"] = cross_org_uuids
        if data_source is not None:
            self._values["data_source"] = data_source

    @builtins.property
    def name(self) -> builtins.str:
        '''The name of the query for use in formulas.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        '''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def query(self) -> builtins.str:
        '''The metrics query definition.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        '''
        result = self._values.get("query")
        assert result is not None, "Required property 'query' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def aggregator(self) -> typing.Optional[builtins.str]:
        '''The aggregation methods available for metrics queries. Valid values are ``avg``, ``min``, ``max``, ``sum``, ``last``, ``area``, ``l2norm``, ``percentile``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregator Powerpack#aggregator}
        '''
        result = self._values.get("aggregator")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def cross_org_uuids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''The source organization UUID for cross organization queries. Feature in Private Beta.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        '''
        result = self._values.get("cross_org_uuids")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def data_source(self) -> typing.Optional[builtins.str]:
        '''The data source for metrics queries. Defaults to ``"metrics"``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        '''
        result = self._values.get("data_source")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetHeatmapDefinitionRequestQueryMetricQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetHeatmapDefinitionRequestQueryMetricQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionRequestQueryMetricQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__18c40cf23410ce05aeeef7f370d86eb64ac2c57be4196f96f88fc7ae915e0ec2)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetAggregator")
    def reset_aggregator(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAggregator", []))

    @jsii.member(jsii_name="resetCrossOrgUuids")
    def reset_cross_org_uuids(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCrossOrgUuids", []))

    @jsii.member(jsii_name="resetDataSource")
    def reset_data_source(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDataSource", []))

    @builtins.property
    @jsii.member(jsii_name="aggregatorInput")
    def aggregator_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregatorInput"))

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuidsInput")
    def cross_org_uuids_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "crossOrgUuidsInput"))

    @builtins.property
    @jsii.member(jsii_name="dataSourceInput")
    def data_source_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "dataSourceInput"))

    @builtins.property
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property
    @jsii.member(jsii_name="queryInput")
    def query_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "queryInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregator")
    def aggregator(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregator"))

    @aggregator.setter
    def aggregator(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__55f204c8f509831b1a67da70cd3605998a2d51521dd6178cd01613c198b38d5c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregator", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuids")
    def cross_org_uuids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "crossOrgUuids"))

    @cross_org_uuids.setter
    def cross_org_uuids(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8efbf78349f50b09bba0a2ee4d47b6ccabaaf10d11fb49c064132e1549b13222)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "crossOrgUuids", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="dataSource")
    def data_source(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "dataSource"))

    @data_source.setter
    def data_source(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__34de44d6e93a4019e3a925671326436b780d391ede396f2dd08d3606252f2383)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "dataSource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9f3b25c8f1e1b78327ad911c87c0b1664ad6b90f13360e314bb8a68e70bb54e1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "name", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="query")
    def query(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "query"))

    @query.setter
    def query(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c7879fbe739ad281890fd15d3f5dffef8c31cf2485295fd82169f127e65b70a2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "query", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetHeatmapDefinitionRequestQueryMetricQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetHeatmapDefinitionRequestQueryMetricQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetHeatmapDefinitionRequestQueryMetricQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__db0eb86c027dea1b4c7ce07c3197f7f2766b2ddeec990dd99cc75aa1756731d4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetHeatmapDefinitionRequestQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionRequestQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9784668d921bbb667d3cf0bb10052273d034386047821c35a59f4381ad0e793e)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putApmDependencyStatsQuery")
    def put_apm_dependency_stats_query(
        self,
        *,
        data_source: builtins.str,
        env: builtins.str,
        name: builtins.str,
        operation_name: builtins.str,
        resource_name: builtins.str,
        service: builtins.str,
        stat: builtins.str,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        is_upstream: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        primary_tag_name: typing.Optional[builtins.str] = None,
        primary_tag_value: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param data_source: The data source for APM Dependency Stats queries. Valid values are ``apm_dependency_stats``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param env: APM environment. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#env Powerpack#env}
        :param name: The name of query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param operation_name: Name of operation on service. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#operation_name Powerpack#operation_name}
        :param resource_name: APM resource. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#resource_name Powerpack#resource_name}
        :param service: APM service. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#service Powerpack#service}
        :param stat: APM statistic. Valid values are ``avg_duration``, ``avg_root_duration``, ``avg_spans_per_trace``, ``error_rate``, ``pct_exec_time``, ``pct_of_traces``, ``total_traces_count``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#stat Powerpack#stat}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param is_upstream: Determines whether stats for upstream or downstream dependencies should be queried. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#is_upstream Powerpack#is_upstream}
        :param primary_tag_name: The name of the second primary tag used within APM; required when ``primary_tag_value`` is specified. See https://docs.datadoghq.com/tracing/guide/setting_primary_tags_to_scope/#add-a-second-primary-tag-in-datadog. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_name Powerpack#primary_tag_name}
        :param primary_tag_value: Filter APM data by the second primary tag. ``primary_tag_name`` must also be specified. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_value Powerpack#primary_tag_value}
        '''
        value = PowerpackWidgetHeatmapDefinitionRequestQueryApmDependencyStatsQuery(
            data_source=data_source,
            env=env,
            name=name,
            operation_name=operation_name,
            resource_name=resource_name,
            service=service,
            stat=stat,
            cross_org_uuids=cross_org_uuids,
            is_upstream=is_upstream,
            primary_tag_name=primary_tag_name,
            primary_tag_value=primary_tag_value,
        )

        return typing.cast(None, jsii.invoke(self, "putApmDependencyStatsQuery", [value]))

    @jsii.member(jsii_name="putApmResourceStatsQuery")
    def put_apm_resource_stats_query(
        self,
        *,
        data_source: builtins.str,
        env: builtins.str,
        name: builtins.str,
        service: builtins.str,
        stat: builtins.str,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        group_by: typing.Optional[typing.Sequence[builtins.str]] = None,
        operation_name: typing.Optional[builtins.str] = None,
        primary_tag_name: typing.Optional[builtins.str] = None,
        primary_tag_value: typing.Optional[builtins.str] = None,
        resource_name: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param data_source: The data source for APM Resource Stats queries. Valid values are ``apm_resource_stats``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param env: APM environment. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#env Powerpack#env}
        :param name: The name of query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param service: APM service. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#service Powerpack#service}
        :param stat: APM statistic. Valid values are ``errors``, ``error_rate``, ``hits``, ``latency_avg``, ``latency_distribution``, ``latency_max``, ``latency_p50``, ``latency_p75``, ``latency_p90``, ``latency_p95``, ``latency_p99``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#stat Powerpack#stat}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param group_by: Array of fields to group results by. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param operation_name: Name of operation on service. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#operation_name Powerpack#operation_name}
        :param primary_tag_name: The name of the second primary tag used within APM; required when ``primary_tag_value`` is specified. See https://docs.datadoghq.com/tracing/guide/setting_primary_tags_to_scope/#add-a-second-primary-tag-in-datadog. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_name Powerpack#primary_tag_name}
        :param primary_tag_value: Filter APM data by the second primary tag. ``primary_tag_name`` must also be specified. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_value Powerpack#primary_tag_value}
        :param resource_name: APM resource. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#resource_name Powerpack#resource_name}
        '''
        value = PowerpackWidgetHeatmapDefinitionRequestQueryApmResourceStatsQuery(
            data_source=data_source,
            env=env,
            name=name,
            service=service,
            stat=stat,
            cross_org_uuids=cross_org_uuids,
            group_by=group_by,
            operation_name=operation_name,
            primary_tag_name=primary_tag_name,
            primary_tag_value=primary_tag_value,
            resource_name=resource_name,
        )

        return typing.cast(None, jsii.invoke(self, "putApmResourceStatsQuery", [value]))

    @jsii.member(jsii_name="putCloudCostQuery")
    def put_cloud_cost_query(
        self,
        *,
        data_source: builtins.str,
        name: builtins.str,
        query: builtins.str,
        aggregator: typing.Optional[builtins.str] = None,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
    ) -> None:
        '''
        :param data_source: The data source for cloud cost queries. Valid values are ``cloud_cost``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param name: The name of the query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param query: The cloud cost query definition. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        :param aggregator: The aggregation methods available for cloud cost queries. Valid values are ``avg``, ``last``, ``max``, ``min``, ``sum``, ``percentile``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregator Powerpack#aggregator}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        '''
        value = PowerpackWidgetHeatmapDefinitionRequestQueryCloudCostQuery(
            data_source=data_source,
            name=name,
            query=query,
            aggregator=aggregator,
            cross_org_uuids=cross_org_uuids,
        )

        return typing.cast(None, jsii.invoke(self, "putCloudCostQuery", [value]))

    @jsii.member(jsii_name="putEventQuery")
    def put_event_query(
        self,
        *,
        compute: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHeatmapDefinitionRequestQueryEventQueryCompute, typing.Dict[builtins.str, typing.Any]]]],
        data_source: builtins.str,
        name: builtins.str,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHeatmapDefinitionRequestQueryEventQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
        indexes: typing.Optional[typing.Sequence[builtins.str]] = None,
        search: typing.Optional[typing.Union[PowerpackWidgetHeatmapDefinitionRequestQueryEventQuerySearch, typing.Dict[builtins.str, typing.Any]]] = None,
        storage: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param compute: compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute Powerpack#compute}
        :param data_source: The data source for event platform-based queries. Valid values are ``logs``, ``spans``, ``network``, ``rum``, ``security_signals``, ``profiles``, ``audit``, ``events``, ``ci_tests``, ``ci_pipelines``, ``incident_analytics``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param name: The name of query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param indexes: An array of index names to query in the stream. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#indexes Powerpack#indexes}
        :param search: search block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search Powerpack#search}
        :param storage: Storage location (private beta). Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#storage Powerpack#storage}
        '''
        value = PowerpackWidgetHeatmapDefinitionRequestQueryEventQuery(
            compute=compute,
            data_source=data_source,
            name=name,
            cross_org_uuids=cross_org_uuids,
            group_by=group_by,
            indexes=indexes,
            search=search,
            storage=storage,
        )

        return typing.cast(None, jsii.invoke(self, "putEventQuery", [value]))

    @jsii.member(jsii_name="putMetricQuery")
    def put_metric_query(
        self,
        *,
        name: builtins.str,
        query: builtins.str,
        aggregator: typing.Optional[builtins.str] = None,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        data_source: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param name: The name of the query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param query: The metrics query definition. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        :param aggregator: The aggregation methods available for metrics queries. Valid values are ``avg``, ``min``, ``max``, ``sum``, ``last``, ``area``, ``l2norm``, ``percentile``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregator Powerpack#aggregator}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param data_source: The data source for metrics queries. Defaults to ``"metrics"``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        '''
        value = PowerpackWidgetHeatmapDefinitionRequestQueryMetricQuery(
            name=name,
            query=query,
            aggregator=aggregator,
            cross_org_uuids=cross_org_uuids,
            data_source=data_source,
        )

        return typing.cast(None, jsii.invoke(self, "putMetricQuery", [value]))

    @jsii.member(jsii_name="putProcessQuery")
    def put_process_query(
        self,
        *,
        data_source: builtins.str,
        metric: builtins.str,
        name: builtins.str,
        aggregator: typing.Optional[builtins.str] = None,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        is_normalized_cpu: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        limit: typing.Optional[jsii.Number] = None,
        sort: typing.Optional[builtins.str] = None,
        tag_filters: typing.Optional[typing.Sequence[builtins.str]] = None,
        text_filter: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param data_source: The data source for process queries. Valid values are ``process``, ``container``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param metric: The process metric name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        :param name: The name of query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param aggregator: The aggregation methods available for metrics queries. Valid values are ``avg``, ``min``, ``max``, ``sum``, ``last``, ``area``, ``l2norm``, ``percentile``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregator Powerpack#aggregator}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param is_normalized_cpu: Whether to normalize the CPU percentages. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#is_normalized_cpu Powerpack#is_normalized_cpu}
        :param limit: The number of hits to return. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param sort: The direction of the sort. Valid values are ``asc``, ``desc``. Defaults to ``"desc"``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort Powerpack#sort}
        :param tag_filters: An array of tags to filter by. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#tag_filters Powerpack#tag_filters}
        :param text_filter: The text to use as a filter. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#text_filter Powerpack#text_filter}
        '''
        value = PowerpackWidgetHeatmapDefinitionRequestQueryProcessQuery(
            data_source=data_source,
            metric=metric,
            name=name,
            aggregator=aggregator,
            cross_org_uuids=cross_org_uuids,
            is_normalized_cpu=is_normalized_cpu,
            limit=limit,
            sort=sort,
            tag_filters=tag_filters,
            text_filter=text_filter,
        )

        return typing.cast(None, jsii.invoke(self, "putProcessQuery", [value]))

    @jsii.member(jsii_name="putSloQuery")
    def put_slo_query(
        self,
        *,
        data_source: builtins.str,
        measure: builtins.str,
        slo_id: builtins.str,
        additional_query_filters: typing.Optional[builtins.str] = None,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        group_mode: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
        slo_query_type: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param data_source: The data source for SLO queries. Valid values are ``slo``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param measure: SLO measures queries. Valid values are ``good_events``, ``bad_events``, ``good_minutes``, ``bad_minutes``, ``slo_status``, ``error_budget_remaining``, ``burn_rate``, ``error_budget_burndown``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#measure Powerpack#measure}
        :param slo_id: ID of an SLO to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#slo_id Powerpack#slo_id}
        :param additional_query_filters: Additional filters applied to the SLO query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#additional_query_filters Powerpack#additional_query_filters}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param group_mode: Group mode to query measures. Valid values are ``overall``, ``components``. Defaults to ``"overall"``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_mode Powerpack#group_mode}
        :param name: The name of query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param slo_query_type: type of the SLO to query. Valid values are ``metric``, ``monitor``, ``time_slice``. Defaults to ``"metric"``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#slo_query_type Powerpack#slo_query_type}
        '''
        value = PowerpackWidgetHeatmapDefinitionRequestQuerySloQuery(
            data_source=data_source,
            measure=measure,
            slo_id=slo_id,
            additional_query_filters=additional_query_filters,
            cross_org_uuids=cross_org_uuids,
            group_mode=group_mode,
            name=name,
            slo_query_type=slo_query_type,
        )

        return typing.cast(None, jsii.invoke(self, "putSloQuery", [value]))

    @jsii.member(jsii_name="resetApmDependencyStatsQuery")
    def reset_apm_dependency_stats_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetApmDependencyStatsQuery", []))

    @jsii.member(jsii_name="resetApmResourceStatsQuery")
    def reset_apm_resource_stats_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetApmResourceStatsQuery", []))

    @jsii.member(jsii_name="resetCloudCostQuery")
    def reset_cloud_cost_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCloudCostQuery", []))

    @jsii.member(jsii_name="resetEventQuery")
    def reset_event_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetEventQuery", []))

    @jsii.member(jsii_name="resetMetricQuery")
    def reset_metric_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMetricQuery", []))

    @jsii.member(jsii_name="resetProcessQuery")
    def reset_process_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetProcessQuery", []))

    @jsii.member(jsii_name="resetSloQuery")
    def reset_slo_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSloQuery", []))

    @builtins.property
    @jsii.member(jsii_name="apmDependencyStatsQuery")
    def apm_dependency_stats_query(
        self,
    ) -> PowerpackWidgetHeatmapDefinitionRequestQueryApmDependencyStatsQueryOutputReference:
        return typing.cast(PowerpackWidgetHeatmapDefinitionRequestQueryApmDependencyStatsQueryOutputReference, jsii.get(self, "apmDependencyStatsQuery"))

    @builtins.property
    @jsii.member(jsii_name="apmResourceStatsQuery")
    def apm_resource_stats_query(
        self,
    ) -> PowerpackWidgetHeatmapDefinitionRequestQueryApmResourceStatsQueryOutputReference:
        return typing.cast(PowerpackWidgetHeatmapDefinitionRequestQueryApmResourceStatsQueryOutputReference, jsii.get(self, "apmResourceStatsQuery"))

    @builtins.property
    @jsii.member(jsii_name="cloudCostQuery")
    def cloud_cost_query(
        self,
    ) -> PowerpackWidgetHeatmapDefinitionRequestQueryCloudCostQueryOutputReference:
        return typing.cast(PowerpackWidgetHeatmapDefinitionRequestQueryCloudCostQueryOutputReference, jsii.get(self, "cloudCostQuery"))

    @builtins.property
    @jsii.member(jsii_name="eventQuery")
    def event_query(
        self,
    ) -> PowerpackWidgetHeatmapDefinitionRequestQueryEventQueryOutputReference:
        return typing.cast(PowerpackWidgetHeatmapDefinitionRequestQueryEventQueryOutputReference, jsii.get(self, "eventQuery"))

    @builtins.property
    @jsii.member(jsii_name="metricQuery")
    def metric_query(
        self,
    ) -> PowerpackWidgetHeatmapDefinitionRequestQueryMetricQueryOutputReference:
        return typing.cast(PowerpackWidgetHeatmapDefinitionRequestQueryMetricQueryOutputReference, jsii.get(self, "metricQuery"))

    @builtins.property
    @jsii.member(jsii_name="processQuery")
    def process_query(
        self,
    ) -> "PowerpackWidgetHeatmapDefinitionRequestQueryProcessQueryOutputReference":
        return typing.cast("PowerpackWidgetHeatmapDefinitionRequestQueryProcessQueryOutputReference", jsii.get(self, "processQuery"))

    @builtins.property
    @jsii.member(jsii_name="sloQuery")
    def slo_query(
        self,
    ) -> "PowerpackWidgetHeatmapDefinitionRequestQuerySloQueryOutputReference":
        return typing.cast("PowerpackWidgetHeatmapDefinitionRequestQuerySloQueryOutputReference", jsii.get(self, "sloQuery"))

    @builtins.property
    @jsii.member(jsii_name="apmDependencyStatsQueryInput")
    def apm_dependency_stats_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetHeatmapDefinitionRequestQueryApmDependencyStatsQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetHeatmapDefinitionRequestQueryApmDependencyStatsQuery], jsii.get(self, "apmDependencyStatsQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="apmResourceStatsQueryInput")
    def apm_resource_stats_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetHeatmapDefinitionRequestQueryApmResourceStatsQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetHeatmapDefinitionRequestQueryApmResourceStatsQuery], jsii.get(self, "apmResourceStatsQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="cloudCostQueryInput")
    def cloud_cost_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetHeatmapDefinitionRequestQueryCloudCostQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetHeatmapDefinitionRequestQueryCloudCostQuery], jsii.get(self, "cloudCostQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="eventQueryInput")
    def event_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetHeatmapDefinitionRequestQueryEventQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetHeatmapDefinitionRequestQueryEventQuery], jsii.get(self, "eventQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="metricQueryInput")
    def metric_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetHeatmapDefinitionRequestQueryMetricQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetHeatmapDefinitionRequestQueryMetricQuery], jsii.get(self, "metricQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="processQueryInput")
    def process_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetHeatmapDefinitionRequestQueryProcessQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetHeatmapDefinitionRequestQueryProcessQuery"], jsii.get(self, "processQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="sloQueryInput")
    def slo_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetHeatmapDefinitionRequestQuerySloQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetHeatmapDefinitionRequestQuerySloQuery"], jsii.get(self, "sloQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHeatmapDefinitionRequestQuery]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHeatmapDefinitionRequestQuery]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHeatmapDefinitionRequestQuery]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6937615aa9b6c53a0aa00530ccd7f17a8757bf9905b9d998ef84fa009edbf930)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionRequestQueryProcessQuery",
    jsii_struct_bases=[],
    name_mapping={
        "data_source": "dataSource",
        "metric": "metric",
        "name": "name",
        "aggregator": "aggregator",
        "cross_org_uuids": "crossOrgUuids",
        "is_normalized_cpu": "isNormalizedCpu",
        "limit": "limit",
        "sort": "sort",
        "tag_filters": "tagFilters",
        "text_filter": "textFilter",
    },
)
class PowerpackWidgetHeatmapDefinitionRequestQueryProcessQuery:
    def __init__(
        self,
        *,
        data_source: builtins.str,
        metric: builtins.str,
        name: builtins.str,
        aggregator: typing.Optional[builtins.str] = None,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        is_normalized_cpu: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        limit: typing.Optional[jsii.Number] = None,
        sort: typing.Optional[builtins.str] = None,
        tag_filters: typing.Optional[typing.Sequence[builtins.str]] = None,
        text_filter: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param data_source: The data source for process queries. Valid values are ``process``, ``container``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param metric: The process metric name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        :param name: The name of query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param aggregator: The aggregation methods available for metrics queries. Valid values are ``avg``, ``min``, ``max``, ``sum``, ``last``, ``area``, ``l2norm``, ``percentile``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregator Powerpack#aggregator}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param is_normalized_cpu: Whether to normalize the CPU percentages. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#is_normalized_cpu Powerpack#is_normalized_cpu}
        :param limit: The number of hits to return. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param sort: The direction of the sort. Valid values are ``asc``, ``desc``. Defaults to ``"desc"``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort Powerpack#sort}
        :param tag_filters: An array of tags to filter by. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#tag_filters Powerpack#tag_filters}
        :param text_filter: The text to use as a filter. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#text_filter Powerpack#text_filter}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9e376f017dcab994ed4f15c52a7441827a5f310708f820ba0d21653453551641)
            check_type(argname="argument data_source", value=data_source, expected_type=type_hints["data_source"])
            check_type(argname="argument metric", value=metric, expected_type=type_hints["metric"])
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument aggregator", value=aggregator, expected_type=type_hints["aggregator"])
            check_type(argname="argument cross_org_uuids", value=cross_org_uuids, expected_type=type_hints["cross_org_uuids"])
            check_type(argname="argument is_normalized_cpu", value=is_normalized_cpu, expected_type=type_hints["is_normalized_cpu"])
            check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
            check_type(argname="argument sort", value=sort, expected_type=type_hints["sort"])
            check_type(argname="argument tag_filters", value=tag_filters, expected_type=type_hints["tag_filters"])
            check_type(argname="argument text_filter", value=text_filter, expected_type=type_hints["text_filter"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "data_source": data_source,
            "metric": metric,
            "name": name,
        }
        if aggregator is not None:
            self._values["aggregator"] = aggregator
        if cross_org_uuids is not None:
            self._values["cross_org_uuids"] = cross_org_uuids
        if is_normalized_cpu is not None:
            self._values["is_normalized_cpu"] = is_normalized_cpu
        if limit is not None:
            self._values["limit"] = limit
        if sort is not None:
            self._values["sort"] = sort
        if tag_filters is not None:
            self._values["tag_filters"] = tag_filters
        if text_filter is not None:
            self._values["text_filter"] = text_filter

    @builtins.property
    def data_source(self) -> builtins.str:
        '''The data source for process queries. Valid values are ``process``, ``container``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        '''
        result = self._values.get("data_source")
        assert result is not None, "Required property 'data_source' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def metric(self) -> builtins.str:
        '''The process metric name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        '''
        result = self._values.get("metric")
        assert result is not None, "Required property 'metric' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def name(self) -> builtins.str:
        '''The name of query for use in formulas.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        '''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def aggregator(self) -> typing.Optional[builtins.str]:
        '''The aggregation methods available for metrics queries. Valid values are ``avg``, ``min``, ``max``, ``sum``, ``last``, ``area``, ``l2norm``, ``percentile``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregator Powerpack#aggregator}
        '''
        result = self._values.get("aggregator")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def cross_org_uuids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''The source organization UUID for cross organization queries. Feature in Private Beta.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        '''
        result = self._values.get("cross_org_uuids")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def is_normalized_cpu(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        '''Whether to normalize the CPU percentages.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#is_normalized_cpu Powerpack#is_normalized_cpu}
        '''
        result = self._values.get("is_normalized_cpu")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)

    @builtins.property
    def limit(self) -> typing.Optional[jsii.Number]:
        '''The number of hits to return.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        '''
        result = self._values.get("limit")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def sort(self) -> typing.Optional[builtins.str]:
        '''The direction of the sort. Valid values are ``asc``, ``desc``. Defaults to ``"desc"``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort Powerpack#sort}
        '''
        result = self._values.get("sort")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def tag_filters(self) -> typing.Optional[typing.List[builtins.str]]:
        '''An array of tags to filter by.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#tag_filters Powerpack#tag_filters}
        '''
        result = self._values.get("tag_filters")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def text_filter(self) -> typing.Optional[builtins.str]:
        '''The text to use as a filter.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#text_filter Powerpack#text_filter}
        '''
        result = self._values.get("text_filter")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetHeatmapDefinitionRequestQueryProcessQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetHeatmapDefinitionRequestQueryProcessQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionRequestQueryProcessQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__50e29e0aa453fa546bd0d5ad473dd154800de68652bcc94dad93c588a08781cd)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetAggregator")
    def reset_aggregator(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAggregator", []))

    @jsii.member(jsii_name="resetCrossOrgUuids")
    def reset_cross_org_uuids(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCrossOrgUuids", []))

    @jsii.member(jsii_name="resetIsNormalizedCpu")
    def reset_is_normalized_cpu(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetIsNormalizedCpu", []))

    @jsii.member(jsii_name="resetLimit")
    def reset_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLimit", []))

    @jsii.member(jsii_name="resetSort")
    def reset_sort(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSort", []))

    @jsii.member(jsii_name="resetTagFilters")
    def reset_tag_filters(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTagFilters", []))

    @jsii.member(jsii_name="resetTextFilter")
    def reset_text_filter(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTextFilter", []))

    @builtins.property
    @jsii.member(jsii_name="aggregatorInput")
    def aggregator_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregatorInput"))

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuidsInput")
    def cross_org_uuids_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "crossOrgUuidsInput"))

    @builtins.property
    @jsii.member(jsii_name="dataSourceInput")
    def data_source_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "dataSourceInput"))

    @builtins.property
    @jsii.member(jsii_name="isNormalizedCpuInput")
    def is_normalized_cpu_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "isNormalizedCpuInput"))

    @builtins.property
    @jsii.member(jsii_name="limitInput")
    def limit_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "limitInput"))

    @builtins.property
    @jsii.member(jsii_name="metricInput")
    def metric_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "metricInput"))

    @builtins.property
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property
    @jsii.member(jsii_name="sortInput")
    def sort_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "sortInput"))

    @builtins.property
    @jsii.member(jsii_name="tagFiltersInput")
    def tag_filters_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "tagFiltersInput"))

    @builtins.property
    @jsii.member(jsii_name="textFilterInput")
    def text_filter_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "textFilterInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregator")
    def aggregator(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregator"))

    @aggregator.setter
    def aggregator(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fca177f2f6e9685dc0f31478da6d175ffbb08188b81ba6b7b5f13380c918bb90)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregator", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuids")
    def cross_org_uuids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "crossOrgUuids"))

    @cross_org_uuids.setter
    def cross_org_uuids(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2584ac66363eeccd7db2fd6b855cde197c9b1d56e0ff714d33c7b0da753056e8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "crossOrgUuids", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="dataSource")
    def data_source(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "dataSource"))

    @data_source.setter
    def data_source(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c3a07202b08cafded7d8a857b17523bd438bda0983d7d6234c8141153bc66458)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "dataSource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="isNormalizedCpu")
    def is_normalized_cpu(
        self,
    ) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "isNormalizedCpu"))

    @is_normalized_cpu.setter
    def is_normalized_cpu(
        self,
        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4354eb8763d5af3a6d31b7d28be5db0e12e1685a67c3f6651eb23615841e743f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "isNormalizedCpu", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="limit")
    def limit(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "limit"))

    @limit.setter
    def limit(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__62d35d7a988a1d3a860543c2a814dfa6674a814bb08374edfd77386ee3dadb98)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "limit", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="metric")
    def metric(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "metric"))

    @metric.setter
    def metric(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8b83652e6b80e773314d9e2605ecbb1d873f447cda7908883ac69b469bc795dc)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "metric", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f190d65eac4e8a8a13f23be87c228789adf8a1e2020ffed2bd1963b5d59b463c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "name", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="sort")
    def sort(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "sort"))

    @sort.setter
    def sort(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__95da463081621cdf3ac84af49879f19432a2a1ef16e5c21641b46f9c966a36db)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "sort", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="tagFilters")
    def tag_filters(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "tagFilters"))

    @tag_filters.setter
    def tag_filters(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d43d84ebb78dac53ce469596474bec02498018072d7756e5369a45282c8be356)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "tagFilters", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="textFilter")
    def text_filter(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "textFilter"))

    @text_filter.setter
    def text_filter(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2499ade14057327cda4bb87d09a87dbbd7679c352601bc7eaa93edf39ba6d4d7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "textFilter", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetHeatmapDefinitionRequestQueryProcessQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetHeatmapDefinitionRequestQueryProcessQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetHeatmapDefinitionRequestQueryProcessQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dbe1b3df79aeb264f320deac85b2d7135794bbfbf4e06be21f1e23d6a9b69d4e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionRequestQuerySloQuery",
    jsii_struct_bases=[],
    name_mapping={
        "data_source": "dataSource",
        "measure": "measure",
        "slo_id": "sloId",
        "additional_query_filters": "additionalQueryFilters",
        "cross_org_uuids": "crossOrgUuids",
        "group_mode": "groupMode",
        "name": "name",
        "slo_query_type": "sloQueryType",
    },
)
class PowerpackWidgetHeatmapDefinitionRequestQuerySloQuery:
    def __init__(
        self,
        *,
        data_source: builtins.str,
        measure: builtins.str,
        slo_id: builtins.str,
        additional_query_filters: typing.Optional[builtins.str] = None,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        group_mode: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
        slo_query_type: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param data_source: The data source for SLO queries. Valid values are ``slo``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param measure: SLO measures queries. Valid values are ``good_events``, ``bad_events``, ``good_minutes``, ``bad_minutes``, ``slo_status``, ``error_budget_remaining``, ``burn_rate``, ``error_budget_burndown``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#measure Powerpack#measure}
        :param slo_id: ID of an SLO to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#slo_id Powerpack#slo_id}
        :param additional_query_filters: Additional filters applied to the SLO query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#additional_query_filters Powerpack#additional_query_filters}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param group_mode: Group mode to query measures. Valid values are ``overall``, ``components``. Defaults to ``"overall"``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_mode Powerpack#group_mode}
        :param name: The name of query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param slo_query_type: type of the SLO to query. Valid values are ``metric``, ``monitor``, ``time_slice``. Defaults to ``"metric"``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#slo_query_type Powerpack#slo_query_type}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__daa8c3c5f451ef2d03aa7647bbc178603a60daa59990a6f5287fc614fc59f1b1)
            check_type(argname="argument data_source", value=data_source, expected_type=type_hints["data_source"])
            check_type(argname="argument measure", value=measure, expected_type=type_hints["measure"])
            check_type(argname="argument slo_id", value=slo_id, expected_type=type_hints["slo_id"])
            check_type(argname="argument additional_query_filters", value=additional_query_filters, expected_type=type_hints["additional_query_filters"])
            check_type(argname="argument cross_org_uuids", value=cross_org_uuids, expected_type=type_hints["cross_org_uuids"])
            check_type(argname="argument group_mode", value=group_mode, expected_type=type_hints["group_mode"])
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument slo_query_type", value=slo_query_type, expected_type=type_hints["slo_query_type"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "data_source": data_source,
            "measure": measure,
            "slo_id": slo_id,
        }
        if additional_query_filters is not None:
            self._values["additional_query_filters"] = additional_query_filters
        if cross_org_uuids is not None:
            self._values["cross_org_uuids"] = cross_org_uuids
        if group_mode is not None:
            self._values["group_mode"] = group_mode
        if name is not None:
            self._values["name"] = name
        if slo_query_type is not None:
            self._values["slo_query_type"] = slo_query_type

    @builtins.property
    def data_source(self) -> builtins.str:
        '''The data source for SLO queries. Valid values are ``slo``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        '''
        result = self._values.get("data_source")
        assert result is not None, "Required property 'data_source' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def measure(self) -> builtins.str:
        '''SLO measures queries. Valid values are ``good_events``, ``bad_events``, ``good_minutes``, ``bad_minutes``, ``slo_status``, ``error_budget_remaining``, ``burn_rate``, ``error_budget_burndown``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#measure Powerpack#measure}
        '''
        result = self._values.get("measure")
        assert result is not None, "Required property 'measure' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def slo_id(self) -> builtins.str:
        '''ID of an SLO to query.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#slo_id Powerpack#slo_id}
        '''
        result = self._values.get("slo_id")
        assert result is not None, "Required property 'slo_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def additional_query_filters(self) -> typing.Optional[builtins.str]:
        '''Additional filters applied to the SLO query.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#additional_query_filters Powerpack#additional_query_filters}
        '''
        result = self._values.get("additional_query_filters")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def cross_org_uuids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''The source organization UUID for cross organization queries. Feature in Private Beta.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        '''
        result = self._values.get("cross_org_uuids")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def group_mode(self) -> typing.Optional[builtins.str]:
        '''Group mode to query measures. Valid values are ``overall``, ``components``. Defaults to ``"overall"``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_mode Powerpack#group_mode}
        '''
        result = self._values.get("group_mode")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''The name of query for use in formulas.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        '''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def slo_query_type(self) -> typing.Optional[builtins.str]:
        '''type of the SLO to query. Valid values are ``metric``, ``monitor``, ``time_slice``. Defaults to ``"metric"``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#slo_query_type Powerpack#slo_query_type}
        '''
        result = self._values.get("slo_query_type")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetHeatmapDefinitionRequestQuerySloQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetHeatmapDefinitionRequestQuerySloQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionRequestQuerySloQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__48c3539dd0dad5a96fb5be29902dac40655c9c332a08c9c2f2a06b6baee937d4)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetAdditionalQueryFilters")
    def reset_additional_query_filters(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAdditionalQueryFilters", []))

    @jsii.member(jsii_name="resetCrossOrgUuids")
    def reset_cross_org_uuids(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCrossOrgUuids", []))

    @jsii.member(jsii_name="resetGroupMode")
    def reset_group_mode(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGroupMode", []))

    @jsii.member(jsii_name="resetName")
    def reset_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetName", []))

    @jsii.member(jsii_name="resetSloQueryType")
    def reset_slo_query_type(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSloQueryType", []))

    @builtins.property
    @jsii.member(jsii_name="additionalQueryFiltersInput")
    def additional_query_filters_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "additionalQueryFiltersInput"))

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuidsInput")
    def cross_org_uuids_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "crossOrgUuidsInput"))

    @builtins.property
    @jsii.member(jsii_name="dataSourceInput")
    def data_source_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "dataSourceInput"))

    @builtins.property
    @jsii.member(jsii_name="groupModeInput")
    def group_mode_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "groupModeInput"))

    @builtins.property
    @jsii.member(jsii_name="measureInput")
    def measure_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "measureInput"))

    @builtins.property
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property
    @jsii.member(jsii_name="sloIdInput")
    def slo_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "sloIdInput"))

    @builtins.property
    @jsii.member(jsii_name="sloQueryTypeInput")
    def slo_query_type_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "sloQueryTypeInput"))

    @builtins.property
    @jsii.member(jsii_name="additionalQueryFilters")
    def additional_query_filters(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "additionalQueryFilters"))

    @additional_query_filters.setter
    def additional_query_filters(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__87ad2e3dc2975d7ff35da4963b8c032c3b452fb6d3d3edc810ccb9ff5d8be1b0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "additionalQueryFilters", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuids")
    def cross_org_uuids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "crossOrgUuids"))

    @cross_org_uuids.setter
    def cross_org_uuids(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6c708dc437f3de9eced59014ab55ca285fc89a417bc7cbb91c559bc419199e0f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "crossOrgUuids", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="dataSource")
    def data_source(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "dataSource"))

    @data_source.setter
    def data_source(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8701e09de96a32793a9ea2bf3f8eccaca4d86c933a90e1751e658df7c79b649f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "dataSource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="groupMode")
    def group_mode(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "groupMode"))

    @group_mode.setter
    def group_mode(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__834ad9656832cbb924d75c7e84055900ed5860838c064799d9c06444344e96c2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "groupMode", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="measure")
    def measure(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "measure"))

    @measure.setter
    def measure(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cbcd553938e84a8bd3d690083917a8c79993e1ed6bd1a333d6a85dc6de393b47)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "measure", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9ab47b3d7c46ae1596d6c8431e86d0fda69294c1c126588fdde09687cdb66bbd)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "name", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="sloId")
    def slo_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "sloId"))

    @slo_id.setter
    def slo_id(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__af52610e165650f7b25eb86278ec2876a6e2e2da45c29c7be6082613c47e8d2b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "sloId", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="sloQueryType")
    def slo_query_type(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "sloQueryType"))

    @slo_query_type.setter
    def slo_query_type(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__73a6aad4480417208be7438c510133b39a8cb48d99ab682affcd488c6edffbae)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "sloQueryType", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetHeatmapDefinitionRequestQuerySloQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetHeatmapDefinitionRequestQuerySloQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetHeatmapDefinitionRequestQuerySloQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__92d69f587629221c22226d6066c7eb182bfa6f55d5e93896a1491efcbe43b1b9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionRequestRumQuery",
    jsii_struct_bases=[],
    name_mapping={
        "index": "index",
        "compute_query": "computeQuery",
        "group_by": "groupBy",
        "multi_compute": "multiCompute",
        "search_query": "searchQuery",
    },
)
class PowerpackWidgetHeatmapDefinitionRequestRumQuery:
    def __init__(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union["PowerpackWidgetHeatmapDefinitionRequestRumQueryComputeQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetHeatmapDefinitionRequestRumQueryGroupBy", typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetHeatmapDefinitionRequestRumQueryMultiCompute", typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        if isinstance(compute_query, dict):
            compute_query = PowerpackWidgetHeatmapDefinitionRequestRumQueryComputeQuery(**compute_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__271e34a6b8ae0f1d200ad36f07bda4402a9c9221044988d8e541e28ea2494f3b)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
            check_type(argname="argument compute_query", value=compute_query, expected_type=type_hints["compute_query"])
            check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
            check_type(argname="argument multi_compute", value=multi_compute, expected_type=type_hints["multi_compute"])
            check_type(argname="argument search_query", value=search_query, expected_type=type_hints["search_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "index": index,
        }
        if compute_query is not None:
            self._values["compute_query"] = compute_query
        if group_by is not None:
            self._values["group_by"] = group_by
        if multi_compute is not None:
            self._values["multi_compute"] = multi_compute
        if search_query is not None:
            self._values["search_query"] = search_query

    @builtins.property
    def index(self) -> builtins.str:
        '''The name of the index to query.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        '''
        result = self._values.get("index")
        assert result is not None, "Required property 'index' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def compute_query(
        self,
    ) -> typing.Optional["PowerpackWidgetHeatmapDefinitionRequestRumQueryComputeQuery"]:
        '''compute_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        '''
        result = self._values.get("compute_query")
        return typing.cast(typing.Optional["PowerpackWidgetHeatmapDefinitionRequestRumQueryComputeQuery"], result)

    @builtins.property
    def group_by(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetHeatmapDefinitionRequestRumQueryGroupBy"]]]:
        '''group_by block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        '''
        result = self._values.get("group_by")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetHeatmapDefinitionRequestRumQueryGroupBy"]]], result)

    @builtins.property
    def multi_compute(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetHeatmapDefinitionRequestRumQueryMultiCompute"]]]:
        '''multi_compute block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        '''
        result = self._values.get("multi_compute")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetHeatmapDefinitionRequestRumQueryMultiCompute"]]], result)

    @builtins.property
    def search_query(self) -> typing.Optional[builtins.str]:
        '''The search query to use.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        result = self._values.get("search_query")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetHeatmapDefinitionRequestRumQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionRequestRumQueryComputeQuery",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetHeatmapDefinitionRequestRumQueryComputeQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f7fe9ec3e0529303d5e24aa156b65aafe192e5605c8938261e077cff43b54711)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetHeatmapDefinitionRequestRumQueryComputeQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetHeatmapDefinitionRequestRumQueryComputeQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionRequestRumQueryComputeQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5a7375190e70b195a5e0632b24174dfd393c82d1642c1320ab997eb829ad7b50)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1c131c0b757e08fa422e58ae812369a90a13c0adc4e9e3ce5acde9653b3e0971)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d3c44791ef70ab8fef51eb6da0b19af1a7e40e316c1c93c178f53e22fca1fe2c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a71bd6e5500ad8d48466aceb77597147d6594b6a2d4fe80f96de0153c42824be)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetHeatmapDefinitionRequestRumQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetHeatmapDefinitionRequestRumQueryComputeQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetHeatmapDefinitionRequestRumQueryComputeQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a8445533b5d19e381f98833cc336b339f016b09b150c6f086a75ac3aa078bf60)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionRequestRumQueryGroupBy",
    jsii_struct_bases=[],
    name_mapping={"facet": "facet", "limit": "limit", "sort_query": "sortQuery"},
)
class PowerpackWidgetHeatmapDefinitionRequestRumQueryGroupBy:
    def __init__(
        self,
        *,
        facet: typing.Optional[builtins.str] = None,
        limit: typing.Optional[jsii.Number] = None,
        sort_query: typing.Optional[typing.Union["PowerpackWidgetHeatmapDefinitionRequestRumQueryGroupBySortQuery", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param limit: The maximum number of items in the group. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param sort_query: sort_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        if isinstance(sort_query, dict):
            sort_query = PowerpackWidgetHeatmapDefinitionRequestRumQueryGroupBySortQuery(**sort_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a43e56956dbbcfcae3ea02e3c1d9d334835f4f0897f34bd5c2c17db0b4618876)
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
            check_type(argname="argument sort_query", value=sort_query, expected_type=type_hints["sort_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if facet is not None:
            self._values["facet"] = facet
        if limit is not None:
            self._values["limit"] = limit
        if sort_query is not None:
            self._values["sort_query"] = sort_query

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def limit(self) -> typing.Optional[jsii.Number]:
        '''The maximum number of items in the group.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        '''
        result = self._values.get("limit")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def sort_query(
        self,
    ) -> typing.Optional["PowerpackWidgetHeatmapDefinitionRequestRumQueryGroupBySortQuery"]:
        '''sort_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        result = self._values.get("sort_query")
        return typing.cast(typing.Optional["PowerpackWidgetHeatmapDefinitionRequestRumQueryGroupBySortQuery"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetHeatmapDefinitionRequestRumQueryGroupBy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetHeatmapDefinitionRequestRumQueryGroupByList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionRequestRumQueryGroupByList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__362fe3394fab902e6c7ded5a15355511ffe04cc958590a771ae24ab85135ad57)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetHeatmapDefinitionRequestRumQueryGroupByOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6ba913c4d6f0139f77237ff1deb1cb04e5e5881a474f886586814379495af2b8)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetHeatmapDefinitionRequestRumQueryGroupByOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__446b358177cc2549ecb4eadba18f6d088932ff2f27c2802c6b888ef8ea08a8a7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__008cdadc526ba0bb0fbcef98a33b9a959b186d8505f1cc2e6e70a0ae4c3c8390)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5061789deea63f61706694c1a98e4766dcf341db11b97e593ac419e55d7365cd)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHeatmapDefinitionRequestRumQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHeatmapDefinitionRequestRumQueryGroupBy]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHeatmapDefinitionRequestRumQueryGroupBy]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0270a50b8d79d8fccdbb588823856a6e296a6cbb33498bed9bdd4a0b28755173)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetHeatmapDefinitionRequestRumQueryGroupByOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionRequestRumQueryGroupByOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__659ad72429216e2252d40a852d7562e9897631bb9f1514cd85f0787b6b508235)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putSortQuery")
    def put_sort_query(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        value = PowerpackWidgetHeatmapDefinitionRequestRumQueryGroupBySortQuery(
            aggregation=aggregation, order=order, facet=facet
        )

        return typing.cast(None, jsii.invoke(self, "putSortQuery", [value]))

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetLimit")
    def reset_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLimit", []))

    @jsii.member(jsii_name="resetSortQuery")
    def reset_sort_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSortQuery", []))

    @builtins.property
    @jsii.member(jsii_name="sortQuery")
    def sort_query(
        self,
    ) -> "PowerpackWidgetHeatmapDefinitionRequestRumQueryGroupBySortQueryOutputReference":
        return typing.cast("PowerpackWidgetHeatmapDefinitionRequestRumQueryGroupBySortQueryOutputReference", jsii.get(self, "sortQuery"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="limitInput")
    def limit_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "limitInput"))

    @builtins.property
    @jsii.member(jsii_name="sortQueryInput")
    def sort_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetHeatmapDefinitionRequestRumQueryGroupBySortQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetHeatmapDefinitionRequestRumQueryGroupBySortQuery"], jsii.get(self, "sortQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__80619c6adddd58de491940dc8eecc29f0573d8bd113258949ba03895b4392b51)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="limit")
    def limit(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "limit"))

    @limit.setter
    def limit(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0062edd465606333bfd661c75fb7a33170a15430882f6da8dfbf748829d6e5f4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "limit", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHeatmapDefinitionRequestRumQueryGroupBy]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHeatmapDefinitionRequestRumQueryGroupBy]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHeatmapDefinitionRequestRumQueryGroupBy]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__be9ed37c47a939a877314970fddb40d3266ddea0b08d60de2e24d1c918c24cd5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionRequestRumQueryGroupBySortQuery",
    jsii_struct_bases=[],
    name_mapping={"aggregation": "aggregation", "order": "order", "facet": "facet"},
)
class PowerpackWidgetHeatmapDefinitionRequestRumQueryGroupBySortQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__638422331b48fd4c9520281dce777e9d96923dd16da9b2fe251ff987ce96891e)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument order", value=order, expected_type=type_hints["order"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
            "order": order,
        }
        if facet is not None:
            self._values["facet"] = facet

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def order(self) -> builtins.str:
        '''Widget sorting methods. Valid values are ``asc``, ``desc``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        result = self._values.get("order")
        assert result is not None, "Required property 'order' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetHeatmapDefinitionRequestRumQueryGroupBySortQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetHeatmapDefinitionRequestRumQueryGroupBySortQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionRequestRumQueryGroupBySortQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3aeafc44dc7dc0196e0a868c267a8a9609d71f4895b07e5b865e61bdf27de6d9)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="orderInput")
    def order_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "orderInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a4bf20aa804fa4a01ab7863f3928091f466e246c3c054939002f2d4318b0d5f7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fc19685b7b4c73b3a5d77390f59c03d44a2d877495d0e4178be2c104ecdaa1c9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="order")
    def order(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "order"))

    @order.setter
    def order(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e68e53b71883a4e211c48e5728c27540ab070f47ae3db133bc95d272590dc38c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "order", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetHeatmapDefinitionRequestRumQueryGroupBySortQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetHeatmapDefinitionRequestRumQueryGroupBySortQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetHeatmapDefinitionRequestRumQueryGroupBySortQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__910e7cc7c91ce257a90cae6350ab428738def240bc18d2f00fef7ffc3079deb9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionRequestRumQueryMultiCompute",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetHeatmapDefinitionRequestRumQueryMultiCompute:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b624fb89e1c2cea4950861b458935c21e9080ef807587c66e2dcac0430a79c02)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetHeatmapDefinitionRequestRumQueryMultiCompute(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetHeatmapDefinitionRequestRumQueryMultiComputeList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionRequestRumQueryMultiComputeList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4a7184877d5683bf1f47690b134524a4d7f0bffbc88d47085226dfbfe5dc0eb0)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetHeatmapDefinitionRequestRumQueryMultiComputeOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__93cb129987309f1708a9690582a60fc4caf28b822fdc7c3b90d8855e9eba6135)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetHeatmapDefinitionRequestRumQueryMultiComputeOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f384d5e793b598701f59ea4c7b0d16be7e21344158e93fb8323f018a05143d07)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__96afe5aabb102902375cfcbfc03af9a316a038c9ab6218899c1ecab0809ba90b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1f23d5e08680371c40e0640767e8139d60032bb95cf89480aa6a3b8f5edb357c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHeatmapDefinitionRequestRumQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHeatmapDefinitionRequestRumQueryMultiCompute]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHeatmapDefinitionRequestRumQueryMultiCompute]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7f5c7439fc61b0e30089b613d085b491602d88d6d33aa654c7904584a8f96f00)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetHeatmapDefinitionRequestRumQueryMultiComputeOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionRequestRumQueryMultiComputeOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9f4c5194abf95c02179c363cf3f1af963d29987c36cf54a15bdad1166af8b7bf)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4882bb36054cb8651d2167cdb2c7195f6a6f4a7e72854b1c5622a355c24831ff)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__76ebd9a235c83895c47752728f9d3839c911664a5f722a777a3e9ccf71a05918)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__74d581cd7356ea89dce62f27e4bbf7e74f64bfbd17e4f16073b3684c0372c3cf)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHeatmapDefinitionRequestRumQueryMultiCompute]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHeatmapDefinitionRequestRumQueryMultiCompute]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHeatmapDefinitionRequestRumQueryMultiCompute]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1d373d02ef6d16956ed4fdb03127241caa71a2b1c3bd760d73ff75bc44a1146c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetHeatmapDefinitionRequestRumQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionRequestRumQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7f7865c00e4871d5e819caf9e3f02ad35cf724c2e4b754d4bf80a7fcd291fde4)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putComputeQuery")
    def put_compute_query(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        value = PowerpackWidgetHeatmapDefinitionRequestRumQueryComputeQuery(
            aggregation=aggregation, facet=facet, interval=interval
        )

        return typing.cast(None, jsii.invoke(self, "putComputeQuery", [value]))

    @jsii.member(jsii_name="putGroupBy")
    def put_group_by(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHeatmapDefinitionRequestRumQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__15d50e1ecdfc58849929c6480053be8076df68b486a0b298f4c836c8424b81b3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putGroupBy", [value]))

    @jsii.member(jsii_name="putMultiCompute")
    def put_multi_compute(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHeatmapDefinitionRequestRumQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0878c1197727d54a681f3d205f2d644864bcbd66995cfbe8cbef766b501ade3b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putMultiCompute", [value]))

    @jsii.member(jsii_name="resetComputeQuery")
    def reset_compute_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetComputeQuery", []))

    @jsii.member(jsii_name="resetGroupBy")
    def reset_group_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGroupBy", []))

    @jsii.member(jsii_name="resetMultiCompute")
    def reset_multi_compute(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMultiCompute", []))

    @jsii.member(jsii_name="resetSearchQuery")
    def reset_search_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSearchQuery", []))

    @builtins.property
    @jsii.member(jsii_name="computeQuery")
    def compute_query(
        self,
    ) -> PowerpackWidgetHeatmapDefinitionRequestRumQueryComputeQueryOutputReference:
        return typing.cast(PowerpackWidgetHeatmapDefinitionRequestRumQueryComputeQueryOutputReference, jsii.get(self, "computeQuery"))

    @builtins.property
    @jsii.member(jsii_name="groupBy")
    def group_by(self) -> PowerpackWidgetHeatmapDefinitionRequestRumQueryGroupByList:
        return typing.cast(PowerpackWidgetHeatmapDefinitionRequestRumQueryGroupByList, jsii.get(self, "groupBy"))

    @builtins.property
    @jsii.member(jsii_name="multiCompute")
    def multi_compute(
        self,
    ) -> PowerpackWidgetHeatmapDefinitionRequestRumQueryMultiComputeList:
        return typing.cast(PowerpackWidgetHeatmapDefinitionRequestRumQueryMultiComputeList, jsii.get(self, "multiCompute"))

    @builtins.property
    @jsii.member(jsii_name="computeQueryInput")
    def compute_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetHeatmapDefinitionRequestRumQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetHeatmapDefinitionRequestRumQueryComputeQuery], jsii.get(self, "computeQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="groupByInput")
    def group_by_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHeatmapDefinitionRequestRumQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHeatmapDefinitionRequestRumQueryGroupBy]]], jsii.get(self, "groupByInput"))

    @builtins.property
    @jsii.member(jsii_name="indexInput")
    def index_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "indexInput"))

    @builtins.property
    @jsii.member(jsii_name="multiComputeInput")
    def multi_compute_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHeatmapDefinitionRequestRumQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHeatmapDefinitionRequestRumQueryMultiCompute]]], jsii.get(self, "multiComputeInput"))

    @builtins.property
    @jsii.member(jsii_name="searchQueryInput")
    def search_query_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "searchQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="index")
    def index(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "index"))

    @index.setter
    def index(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__08d4defddbd965ebfd9de7892c75e1ceaf8ac34b633806a1010fd6f0b34b4a65)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "index", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="searchQuery")
    def search_query(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "searchQuery"))

    @search_query.setter
    def search_query(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9ed0e24146dc6e6ef6caf562229bc489c128fe2525c86224fb9faf0e14438300)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "searchQuery", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetHeatmapDefinitionRequestRumQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetHeatmapDefinitionRequestRumQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetHeatmapDefinitionRequestRumQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8d2b4e43f5f63c0f6682f27c37f62f00f13c881c267b01e9425fbb575d0e8acb)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionRequestSecurityQuery",
    jsii_struct_bases=[],
    name_mapping={
        "index": "index",
        "compute_query": "computeQuery",
        "group_by": "groupBy",
        "multi_compute": "multiCompute",
        "search_query": "searchQuery",
    },
)
class PowerpackWidgetHeatmapDefinitionRequestSecurityQuery:
    def __init__(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union["PowerpackWidgetHeatmapDefinitionRequestSecurityQueryComputeQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetHeatmapDefinitionRequestSecurityQueryGroupBy", typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetHeatmapDefinitionRequestSecurityQueryMultiCompute", typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        if isinstance(compute_query, dict):
            compute_query = PowerpackWidgetHeatmapDefinitionRequestSecurityQueryComputeQuery(**compute_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__60abf27a1c4abe214e6e8701faa7281ffb281019336676949f8073bd9c56e63c)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
            check_type(argname="argument compute_query", value=compute_query, expected_type=type_hints["compute_query"])
            check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
            check_type(argname="argument multi_compute", value=multi_compute, expected_type=type_hints["multi_compute"])
            check_type(argname="argument search_query", value=search_query, expected_type=type_hints["search_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "index": index,
        }
        if compute_query is not None:
            self._values["compute_query"] = compute_query
        if group_by is not None:
            self._values["group_by"] = group_by
        if multi_compute is not None:
            self._values["multi_compute"] = multi_compute
        if search_query is not None:
            self._values["search_query"] = search_query

    @builtins.property
    def index(self) -> builtins.str:
        '''The name of the index to query.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        '''
        result = self._values.get("index")
        assert result is not None, "Required property 'index' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def compute_query(
        self,
    ) -> typing.Optional["PowerpackWidgetHeatmapDefinitionRequestSecurityQueryComputeQuery"]:
        '''compute_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        '''
        result = self._values.get("compute_query")
        return typing.cast(typing.Optional["PowerpackWidgetHeatmapDefinitionRequestSecurityQueryComputeQuery"], result)

    @builtins.property
    def group_by(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetHeatmapDefinitionRequestSecurityQueryGroupBy"]]]:
        '''group_by block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        '''
        result = self._values.get("group_by")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetHeatmapDefinitionRequestSecurityQueryGroupBy"]]], result)

    @builtins.property
    def multi_compute(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetHeatmapDefinitionRequestSecurityQueryMultiCompute"]]]:
        '''multi_compute block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        '''
        result = self._values.get("multi_compute")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetHeatmapDefinitionRequestSecurityQueryMultiCompute"]]], result)

    @builtins.property
    def search_query(self) -> typing.Optional[builtins.str]:
        '''The search query to use.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        result = self._values.get("search_query")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetHeatmapDefinitionRequestSecurityQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionRequestSecurityQueryComputeQuery",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetHeatmapDefinitionRequestSecurityQueryComputeQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__69ee706458403a4c824e59fe1ee6921b34e877cc7a2d1070f2b5cf6be57bdb7d)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetHeatmapDefinitionRequestSecurityQueryComputeQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetHeatmapDefinitionRequestSecurityQueryComputeQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionRequestSecurityQueryComputeQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__90726409b23064f4719bf46b5314a0921f90d3b79c8f705652bfa2e7c72092f7)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b256f572931382ebd2aa26cbddd79ef91489d5e659b2de3cae963fa0c447a842)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__eb240f5be20743357bfadd707c9b93c96b6198ad83a5015648bd97b49c33f1c2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__79738cbdb3cdbc6ea1fb7afb080d9c5c9ebfc96938e228f96a41c4457ab1923c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetHeatmapDefinitionRequestSecurityQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetHeatmapDefinitionRequestSecurityQueryComputeQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetHeatmapDefinitionRequestSecurityQueryComputeQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2f4406bf4c0939d410a671f58974e7e20a6fb4b8fba71e2b22a0b10d77ea9d8b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionRequestSecurityQueryGroupBy",
    jsii_struct_bases=[],
    name_mapping={"facet": "facet", "limit": "limit", "sort_query": "sortQuery"},
)
class PowerpackWidgetHeatmapDefinitionRequestSecurityQueryGroupBy:
    def __init__(
        self,
        *,
        facet: typing.Optional[builtins.str] = None,
        limit: typing.Optional[jsii.Number] = None,
        sort_query: typing.Optional[typing.Union["PowerpackWidgetHeatmapDefinitionRequestSecurityQueryGroupBySortQuery", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param limit: The maximum number of items in the group. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param sort_query: sort_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        if isinstance(sort_query, dict):
            sort_query = PowerpackWidgetHeatmapDefinitionRequestSecurityQueryGroupBySortQuery(**sort_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ddf60d45c7230a1305d6dcfeb1412c33a77f62fb5192181921719e5904b2c00b)
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
            check_type(argname="argument sort_query", value=sort_query, expected_type=type_hints["sort_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if facet is not None:
            self._values["facet"] = facet
        if limit is not None:
            self._values["limit"] = limit
        if sort_query is not None:
            self._values["sort_query"] = sort_query

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def limit(self) -> typing.Optional[jsii.Number]:
        '''The maximum number of items in the group.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        '''
        result = self._values.get("limit")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def sort_query(
        self,
    ) -> typing.Optional["PowerpackWidgetHeatmapDefinitionRequestSecurityQueryGroupBySortQuery"]:
        '''sort_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        result = self._values.get("sort_query")
        return typing.cast(typing.Optional["PowerpackWidgetHeatmapDefinitionRequestSecurityQueryGroupBySortQuery"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetHeatmapDefinitionRequestSecurityQueryGroupBy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetHeatmapDefinitionRequestSecurityQueryGroupByList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionRequestSecurityQueryGroupByList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8eedca56c0ad62e0b0d5403029af526a9903a5d807a9819449e8e8a0128f2a62)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetHeatmapDefinitionRequestSecurityQueryGroupByOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__961b4e2c1ba6106ab27dfc9a3887cb99e498d96164c0cce211289cfb37ff77a5)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetHeatmapDefinitionRequestSecurityQueryGroupByOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8b7ef5d7a47e2c6ba43e16c83e9b07f3017eab1a106e196c857399afb43f2ffe)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4daf88cc47fb5c05318c2f6776263ba41deaa66b6c939e64a35aba27f454f07e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e21a9a666d862b9b0883a2e73fa8c35f86fd10844940566d5cdfce2d1e62c977)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHeatmapDefinitionRequestSecurityQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHeatmapDefinitionRequestSecurityQueryGroupBy]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHeatmapDefinitionRequestSecurityQueryGroupBy]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c4c427935f32e859052b9631bddac0e38254cee5d3adb44f6b4f980f57136c26)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetHeatmapDefinitionRequestSecurityQueryGroupByOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionRequestSecurityQueryGroupByOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8b66af30599222d4cedcb1e4e0fb513f2c187b32ea0031f63f81792d83c13e67)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putSortQuery")
    def put_sort_query(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        value = PowerpackWidgetHeatmapDefinitionRequestSecurityQueryGroupBySortQuery(
            aggregation=aggregation, order=order, facet=facet
        )

        return typing.cast(None, jsii.invoke(self, "putSortQuery", [value]))

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetLimit")
    def reset_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLimit", []))

    @jsii.member(jsii_name="resetSortQuery")
    def reset_sort_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSortQuery", []))

    @builtins.property
    @jsii.member(jsii_name="sortQuery")
    def sort_query(
        self,
    ) -> "PowerpackWidgetHeatmapDefinitionRequestSecurityQueryGroupBySortQueryOutputReference":
        return typing.cast("PowerpackWidgetHeatmapDefinitionRequestSecurityQueryGroupBySortQueryOutputReference", jsii.get(self, "sortQuery"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="limitInput")
    def limit_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "limitInput"))

    @builtins.property
    @jsii.member(jsii_name="sortQueryInput")
    def sort_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetHeatmapDefinitionRequestSecurityQueryGroupBySortQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetHeatmapDefinitionRequestSecurityQueryGroupBySortQuery"], jsii.get(self, "sortQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__298f9f9bdffe9c37be4d4fc1a2bd56c1a52db3e7a5d4b180faf31a3d90f75f6e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="limit")
    def limit(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "limit"))

    @limit.setter
    def limit(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f5fe19f6373f3a42601cf46673c29092c528e6af0a49cca7f0c03b92ebffeb36)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "limit", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHeatmapDefinitionRequestSecurityQueryGroupBy]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHeatmapDefinitionRequestSecurityQueryGroupBy]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHeatmapDefinitionRequestSecurityQueryGroupBy]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__31dfa147c6632ecd2e02668524cd466c76eeb564854d8a76e893a39f4411d0bd)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionRequestSecurityQueryGroupBySortQuery",
    jsii_struct_bases=[],
    name_mapping={"aggregation": "aggregation", "order": "order", "facet": "facet"},
)
class PowerpackWidgetHeatmapDefinitionRequestSecurityQueryGroupBySortQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1e333ad0baf239d011ca3cb3bdeb310b73ff98786835f3c7779056d35e8d1871)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument order", value=order, expected_type=type_hints["order"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
            "order": order,
        }
        if facet is not None:
            self._values["facet"] = facet

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def order(self) -> builtins.str:
        '''Widget sorting methods. Valid values are ``asc``, ``desc``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        result = self._values.get("order")
        assert result is not None, "Required property 'order' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetHeatmapDefinitionRequestSecurityQueryGroupBySortQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetHeatmapDefinitionRequestSecurityQueryGroupBySortQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionRequestSecurityQueryGroupBySortQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9449a06e9a462abb9bc95d549e697c93274a9c330962ba2d882872a9334af2c8)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="orderInput")
    def order_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "orderInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5bf4be18d6990fbfa628a3a9f18cd31ab759126c70214849136b229b11221f90)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__99323aa32f71fef730cb7812b6228069ec4753e129935ed935ef2ac57b4fda71)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="order")
    def order(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "order"))

    @order.setter
    def order(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__619148263c3636756891c816c2ae426ad279ad18a01eccea9930ca592a941b0b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "order", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetHeatmapDefinitionRequestSecurityQueryGroupBySortQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetHeatmapDefinitionRequestSecurityQueryGroupBySortQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetHeatmapDefinitionRequestSecurityQueryGroupBySortQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c819ac0c0e9dcc0a525af97968f531336d45bb612c903c3f7226c5d6ea637934)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionRequestSecurityQueryMultiCompute",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetHeatmapDefinitionRequestSecurityQueryMultiCompute:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6d06d2a22a6b0c486d90a7eb86e68072844f8cb404c5b5a38ac724977d8ab5ba)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetHeatmapDefinitionRequestSecurityQueryMultiCompute(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetHeatmapDefinitionRequestSecurityQueryMultiComputeList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionRequestSecurityQueryMultiComputeList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3a47326f029dd2ddcaa5b244fe4a0191890cd341ae5dbd37df4e351a990803da)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetHeatmapDefinitionRequestSecurityQueryMultiComputeOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9e9b82410c219e292737eb96391a05ea45482bec5e11a07646718109eeedde4e)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetHeatmapDefinitionRequestSecurityQueryMultiComputeOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4473b78c1cf9f2058afaa10d2a72a753a3349a73ddacd9f84984145b7b027b82)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__92997c93b64261b1318ace7303546c24b7fa7103669e6501a5964f0304c0ca20)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3649b1fcb4255e9cddb0bee9c8e70f75b046c9f3740adb4c690fb4cc676ea884)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHeatmapDefinitionRequestSecurityQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHeatmapDefinitionRequestSecurityQueryMultiCompute]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHeatmapDefinitionRequestSecurityQueryMultiCompute]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__aa907f5c45e6c545fd7aa80c66f8336fedfb11f450fbee31857e88c5d6853877)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetHeatmapDefinitionRequestSecurityQueryMultiComputeOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionRequestSecurityQueryMultiComputeOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5eea41214ad981fb0186d82ba9c35704b122feb41e6969423627c8914921a105)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ef74dec2379c147e6f332db9a43d2358b069a739da7cf58ed2adaf3dfc42ca22)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__38fbded4f8670eb24a9ba9a7d96040ad895046740f1ac7d43dfa84640d64d819)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f6c371a1b29a35e95e37c07254c0a32ecd4b5402e234b75e2f20486c2b7113e3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHeatmapDefinitionRequestSecurityQueryMultiCompute]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHeatmapDefinitionRequestSecurityQueryMultiCompute]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHeatmapDefinitionRequestSecurityQueryMultiCompute]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a59550f4a25da86dba5768b05bd5c376d72402b99ca36d24895552437143dc06)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetHeatmapDefinitionRequestSecurityQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionRequestSecurityQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7f027f4e9e4a69ea4a2452701968a49cc4e4b859c7dd31653afa331ac9bbb4e9)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putComputeQuery")
    def put_compute_query(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        value = PowerpackWidgetHeatmapDefinitionRequestSecurityQueryComputeQuery(
            aggregation=aggregation, facet=facet, interval=interval
        )

        return typing.cast(None, jsii.invoke(self, "putComputeQuery", [value]))

    @jsii.member(jsii_name="putGroupBy")
    def put_group_by(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHeatmapDefinitionRequestSecurityQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cbbca7c71f2aefc6be3e2b4e8806aafe660849ea0105593d6499e8a6fdf96206)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putGroupBy", [value]))

    @jsii.member(jsii_name="putMultiCompute")
    def put_multi_compute(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHeatmapDefinitionRequestSecurityQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__726491647a588675a7747f06fb8677dbb17fbf2c5b40f7d93d8603b3901fa2db)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putMultiCompute", [value]))

    @jsii.member(jsii_name="resetComputeQuery")
    def reset_compute_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetComputeQuery", []))

    @jsii.member(jsii_name="resetGroupBy")
    def reset_group_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGroupBy", []))

    @jsii.member(jsii_name="resetMultiCompute")
    def reset_multi_compute(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMultiCompute", []))

    @jsii.member(jsii_name="resetSearchQuery")
    def reset_search_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSearchQuery", []))

    @builtins.property
    @jsii.member(jsii_name="computeQuery")
    def compute_query(
        self,
    ) -> PowerpackWidgetHeatmapDefinitionRequestSecurityQueryComputeQueryOutputReference:
        return typing.cast(PowerpackWidgetHeatmapDefinitionRequestSecurityQueryComputeQueryOutputReference, jsii.get(self, "computeQuery"))

    @builtins.property
    @jsii.member(jsii_name="groupBy")
    def group_by(
        self,
    ) -> PowerpackWidgetHeatmapDefinitionRequestSecurityQueryGroupByList:
        return typing.cast(PowerpackWidgetHeatmapDefinitionRequestSecurityQueryGroupByList, jsii.get(self, "groupBy"))

    @builtins.property
    @jsii.member(jsii_name="multiCompute")
    def multi_compute(
        self,
    ) -> PowerpackWidgetHeatmapDefinitionRequestSecurityQueryMultiComputeList:
        return typing.cast(PowerpackWidgetHeatmapDefinitionRequestSecurityQueryMultiComputeList, jsii.get(self, "multiCompute"))

    @builtins.property
    @jsii.member(jsii_name="computeQueryInput")
    def compute_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetHeatmapDefinitionRequestSecurityQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetHeatmapDefinitionRequestSecurityQueryComputeQuery], jsii.get(self, "computeQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="groupByInput")
    def group_by_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHeatmapDefinitionRequestSecurityQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHeatmapDefinitionRequestSecurityQueryGroupBy]]], jsii.get(self, "groupByInput"))

    @builtins.property
    @jsii.member(jsii_name="indexInput")
    def index_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "indexInput"))

    @builtins.property
    @jsii.member(jsii_name="multiComputeInput")
    def multi_compute_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHeatmapDefinitionRequestSecurityQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHeatmapDefinitionRequestSecurityQueryMultiCompute]]], jsii.get(self, "multiComputeInput"))

    @builtins.property
    @jsii.member(jsii_name="searchQueryInput")
    def search_query_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "searchQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="index")
    def index(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "index"))

    @index.setter
    def index(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ee7285b3d29900b5dd3e71860fff69f011c2a468db1b3d2bb3f535739139ab05)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "index", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="searchQuery")
    def search_query(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "searchQuery"))

    @search_query.setter
    def search_query(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5a7cd37a7cfe6156d0d92e6404092a5fb1c48d38a85a08026af7752bc5ce04dc)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "searchQuery", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetHeatmapDefinitionRequestSecurityQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetHeatmapDefinitionRequestSecurityQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetHeatmapDefinitionRequestSecurityQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__98e3f3091628c94d5f51641b430395940379c0e17f8315865643fb69aeb64cc1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionRequestStyle",
    jsii_struct_bases=[],
    name_mapping={"palette": "palette"},
)
class PowerpackWidgetHeatmapDefinitionRequestStyle:
    def __init__(self, *, palette: typing.Optional[builtins.str] = None) -> None:
        '''
        :param palette: A color palette to apply to the widget. The available options are available at: https://docs.datadoghq.com/dashboards/widgets/timeseries/#appearance. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette Powerpack#palette}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__94e530ed242174b3fa02e6be8aa963138243ccd9950e8af4fd810b1c87b1f934)
            check_type(argname="argument palette", value=palette, expected_type=type_hints["palette"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if palette is not None:
            self._values["palette"] = palette

    @builtins.property
    def palette(self) -> typing.Optional[builtins.str]:
        '''A color palette to apply to the widget. The available options are available at: https://docs.datadoghq.com/dashboards/widgets/timeseries/#appearance.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette Powerpack#palette}
        '''
        result = self._values.get("palette")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetHeatmapDefinitionRequestStyle(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetHeatmapDefinitionRequestStyleOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionRequestStyleOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d349302271f10d025a2a71c0fdc2e4a9da9c3acb8a005d344e3621e44bdbbda7)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetPalette")
    def reset_palette(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPalette", []))

    @builtins.property
    @jsii.member(jsii_name="paletteInput")
    def palette_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "paletteInput"))

    @builtins.property
    @jsii.member(jsii_name="palette")
    def palette(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "palette"))

    @palette.setter
    def palette(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d1f4d7c985eb6e1708f4e307678d010148492b75f4766dc8b6a56d8cf4d54c9c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "palette", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetHeatmapDefinitionRequestStyle]:
        return typing.cast(typing.Optional[PowerpackWidgetHeatmapDefinitionRequestStyle], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetHeatmapDefinitionRequestStyle],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b00ef504bdae25c228d55bf931808bd5e9da4ffa464f8cfa51ed06c074458ae4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionYaxis",
    jsii_struct_bases=[],
    name_mapping={
        "include_zero": "includeZero",
        "label": "label",
        "max": "max",
        "min": "min",
        "scale": "scale",
    },
)
class PowerpackWidgetHeatmapDefinitionYaxis:
    def __init__(
        self,
        *,
        include_zero: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        label: typing.Optional[builtins.str] = None,
        max: typing.Optional[builtins.str] = None,
        min: typing.Optional[builtins.str] = None,
        scale: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param include_zero: Always include zero or fit the axis to the data range. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#include_zero Powerpack#include_zero}
        :param label: The label of the axis to display on the graph. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#label Powerpack#label}
        :param max: Specify the maximum value to show on the Y-axis. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#max Powerpack#max}
        :param min: Specify the minimum value to show on the Y-axis. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#min Powerpack#min}
        :param scale: Specify the scale type, options: ``linear``, ``log``, ``pow``, ``sqrt``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#scale Powerpack#scale}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4c2c395e5f7219919007129fc1b7403b3b5b134f75064c9121297fd978553cdd)
            check_type(argname="argument include_zero", value=include_zero, expected_type=type_hints["include_zero"])
            check_type(argname="argument label", value=label, expected_type=type_hints["label"])
            check_type(argname="argument max", value=max, expected_type=type_hints["max"])
            check_type(argname="argument min", value=min, expected_type=type_hints["min"])
            check_type(argname="argument scale", value=scale, expected_type=type_hints["scale"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if include_zero is not None:
            self._values["include_zero"] = include_zero
        if label is not None:
            self._values["label"] = label
        if max is not None:
            self._values["max"] = max
        if min is not None:
            self._values["min"] = min
        if scale is not None:
            self._values["scale"] = scale

    @builtins.property
    def include_zero(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        '''Always include zero or fit the axis to the data range.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#include_zero Powerpack#include_zero}
        '''
        result = self._values.get("include_zero")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)

    @builtins.property
    def label(self) -> typing.Optional[builtins.str]:
        '''The label of the axis to display on the graph.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#label Powerpack#label}
        '''
        result = self._values.get("label")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def max(self) -> typing.Optional[builtins.str]:
        '''Specify the maximum value to show on the Y-axis.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#max Powerpack#max}
        '''
        result = self._values.get("max")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def min(self) -> typing.Optional[builtins.str]:
        '''Specify the minimum value to show on the Y-axis.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#min Powerpack#min}
        '''
        result = self._values.get("min")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def scale(self) -> typing.Optional[builtins.str]:
        '''Specify the scale type, options: ``linear``, ``log``, ``pow``, ``sqrt``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#scale Powerpack#scale}
        '''
        result = self._values.get("scale")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetHeatmapDefinitionYaxis(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetHeatmapDefinitionYaxisOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHeatmapDefinitionYaxisOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__924430423807041992382c94d492584cebc797bfa8e2d647d27a850b035cd071)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetIncludeZero")
    def reset_include_zero(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetIncludeZero", []))

    @jsii.member(jsii_name="resetLabel")
    def reset_label(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLabel", []))

    @jsii.member(jsii_name="resetMax")
    def reset_max(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMax", []))

    @jsii.member(jsii_name="resetMin")
    def reset_min(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMin", []))

    @jsii.member(jsii_name="resetScale")
    def reset_scale(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetScale", []))

    @builtins.property
    @jsii.member(jsii_name="includeZeroInput")
    def include_zero_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "includeZeroInput"))

    @builtins.property
    @jsii.member(jsii_name="labelInput")
    def label_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "labelInput"))

    @builtins.property
    @jsii.member(jsii_name="maxInput")
    def max_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "maxInput"))

    @builtins.property
    @jsii.member(jsii_name="minInput")
    def min_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "minInput"))

    @builtins.property
    @jsii.member(jsii_name="scaleInput")
    def scale_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "scaleInput"))

    @builtins.property
    @jsii.member(jsii_name="includeZero")
    def include_zero(self) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "includeZero"))

    @include_zero.setter
    def include_zero(
        self,
        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c89bd24c171ad2abf1fb696da15d8b77909925d142e647579fa67a5c8a9265d7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "includeZero", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="label")
    def label(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "label"))

    @label.setter
    def label(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__aee66e7bc39518b756b04d7e2c40639287552ce34e0071b62283207d704be305)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "label", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="max")
    def max(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "max"))

    @max.setter
    def max(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__acc9612e20adbb44379f216c706bab36870181508355165e8779fb4028865a63)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "max", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="min")
    def min(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "min"))

    @min.setter
    def min(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c8328e59ee3550f349207297fb9cbcdc15dc7b66819f7d06fd73aab751d5c6fa)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "min", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="scale")
    def scale(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "scale"))

    @scale.setter
    def scale(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a4051a86571a1e653c2bac840af092fd2b8733fa7e9dc904ea90af146b65dedb)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "scale", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[PowerpackWidgetHeatmapDefinitionYaxis]:
        return typing.cast(typing.Optional[PowerpackWidgetHeatmapDefinitionYaxis], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetHeatmapDefinitionYaxis],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__25e58053a3212eb1dc90b18598c2d555aa4ae0e5b9f9ed2e5aa0532e48d90d4d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinition",
    jsii_struct_bases=[],
    name_mapping={
        "custom_link": "customLink",
        "group": "group",
        "node_type": "nodeType",
        "no_group_hosts": "noGroupHosts",
        "no_metric_hosts": "noMetricHosts",
        "request": "request",
        "scope": "scope",
        "style": "style",
        "title": "title",
        "title_align": "titleAlign",
        "title_size": "titleSize",
    },
)
class PowerpackWidgetHostmapDefinition:
    def __init__(
        self,
        *,
        custom_link: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetHostmapDefinitionCustomLink", typing.Dict[builtins.str, typing.Any]]]]] = None,
        group: typing.Optional[typing.Sequence[builtins.str]] = None,
        node_type: typing.Optional[builtins.str] = None,
        no_group_hosts: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        no_metric_hosts: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        request: typing.Optional[typing.Union["PowerpackWidgetHostmapDefinitionRequest", typing.Dict[builtins.str, typing.Any]]] = None,
        scope: typing.Optional[typing.Sequence[builtins.str]] = None,
        style: typing.Optional[typing.Union["PowerpackWidgetHostmapDefinitionStyle", typing.Dict[builtins.str, typing.Any]]] = None,
        title: typing.Optional[builtins.str] = None,
        title_align: typing.Optional[builtins.str] = None,
        title_size: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param custom_link: custom_link block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom_link Powerpack#custom_link}
        :param group: The list of tags to group nodes by. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group Powerpack#group}
        :param node_type: The type of node used. Valid values are ``host``, ``container``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#node_type Powerpack#node_type}
        :param no_group_hosts: A Boolean indicating whether to show ungrouped nodes. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#no_group_hosts Powerpack#no_group_hosts}
        :param no_metric_hosts: A Boolean indicating whether to show nodes with no metrics. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#no_metric_hosts Powerpack#no_metric_hosts}
        :param request: request block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#request Powerpack#request}
        :param scope: The list of tags to filter nodes by. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#scope Powerpack#scope}
        :param style: style block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#style Powerpack#style}
        :param title: The title of the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title Powerpack#title}
        :param title_align: The alignment of the widget's title. Valid values are ``center``, ``left``, ``right``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_align Powerpack#title_align}
        :param title_size: The size of the widget's title (defaults to 16). Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_size Powerpack#title_size}
        '''
        if isinstance(request, dict):
            request = PowerpackWidgetHostmapDefinitionRequest(**request)
        if isinstance(style, dict):
            style = PowerpackWidgetHostmapDefinitionStyle(**style)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4ffcdc694d1b4b6be6d5c719bf6dc44efa78c8d5e72e8a80fb19c342bdcbfd64)
            check_type(argname="argument custom_link", value=custom_link, expected_type=type_hints["custom_link"])
            check_type(argname="argument group", value=group, expected_type=type_hints["group"])
            check_type(argname="argument node_type", value=node_type, expected_type=type_hints["node_type"])
            check_type(argname="argument no_group_hosts", value=no_group_hosts, expected_type=type_hints["no_group_hosts"])
            check_type(argname="argument no_metric_hosts", value=no_metric_hosts, expected_type=type_hints["no_metric_hosts"])
            check_type(argname="argument request", value=request, expected_type=type_hints["request"])
            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
            check_type(argname="argument style", value=style, expected_type=type_hints["style"])
            check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            check_type(argname="argument title_align", value=title_align, expected_type=type_hints["title_align"])
            check_type(argname="argument title_size", value=title_size, expected_type=type_hints["title_size"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if custom_link is not None:
            self._values["custom_link"] = custom_link
        if group is not None:
            self._values["group"] = group
        if node_type is not None:
            self._values["node_type"] = node_type
        if no_group_hosts is not None:
            self._values["no_group_hosts"] = no_group_hosts
        if no_metric_hosts is not None:
            self._values["no_metric_hosts"] = no_metric_hosts
        if request is not None:
            self._values["request"] = request
        if scope is not None:
            self._values["scope"] = scope
        if style is not None:
            self._values["style"] = style
        if title is not None:
            self._values["title"] = title
        if title_align is not None:
            self._values["title_align"] = title_align
        if title_size is not None:
            self._values["title_size"] = title_size

    @builtins.property
    def custom_link(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetHostmapDefinitionCustomLink"]]]:
        '''custom_link block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom_link Powerpack#custom_link}
        '''
        result = self._values.get("custom_link")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetHostmapDefinitionCustomLink"]]], result)

    @builtins.property
    def group(self) -> typing.Optional[typing.List[builtins.str]]:
        '''The list of tags to group nodes by.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group Powerpack#group}
        '''
        result = self._values.get("group")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def node_type(self) -> typing.Optional[builtins.str]:
        '''The type of node used. Valid values are ``host``, ``container``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#node_type Powerpack#node_type}
        '''
        result = self._values.get("node_type")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def no_group_hosts(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        '''A Boolean indicating whether to show ungrouped nodes.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#no_group_hosts Powerpack#no_group_hosts}
        '''
        result = self._values.get("no_group_hosts")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)

    @builtins.property
    def no_metric_hosts(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        '''A Boolean indicating whether to show nodes with no metrics.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#no_metric_hosts Powerpack#no_metric_hosts}
        '''
        result = self._values.get("no_metric_hosts")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)

    @builtins.property
    def request(self) -> typing.Optional["PowerpackWidgetHostmapDefinitionRequest"]:
        '''request block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#request Powerpack#request}
        '''
        result = self._values.get("request")
        return typing.cast(typing.Optional["PowerpackWidgetHostmapDefinitionRequest"], result)

    @builtins.property
    def scope(self) -> typing.Optional[typing.List[builtins.str]]:
        '''The list of tags to filter nodes by.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#scope Powerpack#scope}
        '''
        result = self._values.get("scope")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def style(self) -> typing.Optional["PowerpackWidgetHostmapDefinitionStyle"]:
        '''style block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#style Powerpack#style}
        '''
        result = self._values.get("style")
        return typing.cast(typing.Optional["PowerpackWidgetHostmapDefinitionStyle"], result)

    @builtins.property
    def title(self) -> typing.Optional[builtins.str]:
        '''The title of the widget.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title Powerpack#title}
        '''
        result = self._values.get("title")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def title_align(self) -> typing.Optional[builtins.str]:
        '''The alignment of the widget's title. Valid values are ``center``, ``left``, ``right``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_align Powerpack#title_align}
        '''
        result = self._values.get("title_align")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def title_size(self) -> typing.Optional[builtins.str]:
        '''The size of the widget's title (defaults to 16).

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_size Powerpack#title_size}
        '''
        result = self._values.get("title_size")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetHostmapDefinition(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionCustomLink",
    jsii_struct_bases=[],
    name_mapping={
        "is_hidden": "isHidden",
        "label": "label",
        "link": "link",
        "override_label": "overrideLabel",
    },
)
class PowerpackWidgetHostmapDefinitionCustomLink:
    def __init__(
        self,
        *,
        is_hidden: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        label: typing.Optional[builtins.str] = None,
        link: typing.Optional[builtins.str] = None,
        override_label: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param is_hidden: The flag for toggling context menu link visibility. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#is_hidden Powerpack#is_hidden}
        :param label: The label for the custom link URL. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#label Powerpack#label}
        :param link: The URL of the custom link. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#link Powerpack#link}
        :param override_label: The label ID that refers to a context menu link item. When ``override_label`` is provided, the client request omits the label field. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#override_label Powerpack#override_label}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__da178905759cb5230fb0092e435290834440740c579647e5555fb2abd3abe399)
            check_type(argname="argument is_hidden", value=is_hidden, expected_type=type_hints["is_hidden"])
            check_type(argname="argument label", value=label, expected_type=type_hints["label"])
            check_type(argname="argument link", value=link, expected_type=type_hints["link"])
            check_type(argname="argument override_label", value=override_label, expected_type=type_hints["override_label"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if is_hidden is not None:
            self._values["is_hidden"] = is_hidden
        if label is not None:
            self._values["label"] = label
        if link is not None:
            self._values["link"] = link
        if override_label is not None:
            self._values["override_label"] = override_label

    @builtins.property
    def is_hidden(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        '''The flag for toggling context menu link visibility.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#is_hidden Powerpack#is_hidden}
        '''
        result = self._values.get("is_hidden")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)

    @builtins.property
    def label(self) -> typing.Optional[builtins.str]:
        '''The label for the custom link URL.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#label Powerpack#label}
        '''
        result = self._values.get("label")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def link(self) -> typing.Optional[builtins.str]:
        '''The URL of the custom link.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#link Powerpack#link}
        '''
        result = self._values.get("link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def override_label(self) -> typing.Optional[builtins.str]:
        '''The label ID that refers to a context menu link item.

        When ``override_label`` is provided, the client request omits the label field.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#override_label Powerpack#override_label}
        '''
        result = self._values.get("override_label")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetHostmapDefinitionCustomLink(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetHostmapDefinitionCustomLinkList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionCustomLinkList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__70df2fdf5b7087b5f55b9fcdf33d4470d6c7830ceb2bf23ffe2e57254c512aad)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetHostmapDefinitionCustomLinkOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ecae0354eb7e262295ef87e2f6efe5604586d1b9797a1f3674e4e9e46ae65d82)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetHostmapDefinitionCustomLinkOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fd91e3b9e9e696f2712227827071c0fd9df6574632bec35dd2599b128610583e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b33836ddae020800fe648301afc5ef5458ba0e4eae10175daf4447d6eda9948f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__61510da9811ac43ffda8aa163d1b1bf684638a58fd7529f48cc079ca878203d7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionCustomLink]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionCustomLink]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionCustomLink]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4227f2c976a5f5108d6049b084d553ce5619758254a73f5a7147cbd8d13f2ef6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetHostmapDefinitionCustomLinkOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionCustomLinkOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7e502cdebed239b509fa21ccc2bccb956d402ab82076e83b39d1449650862448)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetIsHidden")
    def reset_is_hidden(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetIsHidden", []))

    @jsii.member(jsii_name="resetLabel")
    def reset_label(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLabel", []))

    @jsii.member(jsii_name="resetLink")
    def reset_link(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLink", []))

    @jsii.member(jsii_name="resetOverrideLabel")
    def reset_override_label(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetOverrideLabel", []))

    @builtins.property
    @jsii.member(jsii_name="isHiddenInput")
    def is_hidden_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "isHiddenInput"))

    @builtins.property
    @jsii.member(jsii_name="labelInput")
    def label_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "labelInput"))

    @builtins.property
    @jsii.member(jsii_name="linkInput")
    def link_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "linkInput"))

    @builtins.property
    @jsii.member(jsii_name="overrideLabelInput")
    def override_label_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "overrideLabelInput"))

    @builtins.property
    @jsii.member(jsii_name="isHidden")
    def is_hidden(self) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "isHidden"))

    @is_hidden.setter
    def is_hidden(
        self,
        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5ab148fed33dc86236b343fe889a9152b926f2f4c93154a034a511eb0db1b43b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "isHidden", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="label")
    def label(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "label"))

    @label.setter
    def label(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3f69b7e0bc17297c76bdc2e0c047c6f6c67679ec0cf5cd9756c991fe38cac33e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "label", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="link")
    def link(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "link"))

    @link.setter
    def link(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__29e299791d5a817b167b75216d457e6893e0b58a6ca03246c8aee37262e41af3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "link", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="overrideLabel")
    def override_label(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "overrideLabel"))

    @override_label.setter
    def override_label(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dcdd38087223586c27fecd733e132a9a7df3671a87365a7954bb90e7cf1053ee)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "overrideLabel", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHostmapDefinitionCustomLink]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHostmapDefinitionCustomLink]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHostmapDefinitionCustomLink]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9e2f096ebc21d429399c2bef077561f7c3c646bdec0ad24bcf3968f47c950632)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetHostmapDefinitionOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__aa9acd695b04ab7a37e35ba496e35755a8160ce4c01d3864aaa41b0ac187a7e7)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putCustomLink")
    def put_custom_link(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHostmapDefinitionCustomLink, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__00a61caad7cd72fed7b8111c0e30f06e0fff5cc6c04cfe737285bf8597b8c1c1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putCustomLink", [value]))

    @jsii.member(jsii_name="putRequest")
    def put_request(
        self,
        *,
        fill: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetHostmapDefinitionRequestFill", typing.Dict[builtins.str, typing.Any]]]]] = None,
        size: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetHostmapDefinitionRequestSize", typing.Dict[builtins.str, typing.Any]]]]] = None,
    ) -> None:
        '''
        :param fill: fill block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#fill Powerpack#fill}
        :param size: size block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#size Powerpack#size}
        '''
        value = PowerpackWidgetHostmapDefinitionRequest(fill=fill, size=size)

        return typing.cast(None, jsii.invoke(self, "putRequest", [value]))

    @jsii.member(jsii_name="putStyle")
    def put_style(
        self,
        *,
        fill_max: typing.Optional[builtins.str] = None,
        fill_min: typing.Optional[builtins.str] = None,
        palette: typing.Optional[builtins.str] = None,
        palette_flip: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
    ) -> None:
        '''
        :param fill_max: The max value to use to color the map. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#fill_max Powerpack#fill_max}
        :param fill_min: The min value to use to color the map. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#fill_min Powerpack#fill_min}
        :param palette: A color palette to apply to the widget. The available options are available at: https://docs.datadoghq.com/dashboards/widgets/timeseries/#appearance. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette Powerpack#palette}
        :param palette_flip: A Boolean indicating whether to flip the palette tones. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette_flip Powerpack#palette_flip}
        '''
        value = PowerpackWidgetHostmapDefinitionStyle(
            fill_max=fill_max,
            fill_min=fill_min,
            palette=palette,
            palette_flip=palette_flip,
        )

        return typing.cast(None, jsii.invoke(self, "putStyle", [value]))

    @jsii.member(jsii_name="resetCustomLink")
    def reset_custom_link(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCustomLink", []))

    @jsii.member(jsii_name="resetGroup")
    def reset_group(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGroup", []))

    @jsii.member(jsii_name="resetNodeType")
    def reset_node_type(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetNodeType", []))

    @jsii.member(jsii_name="resetNoGroupHosts")
    def reset_no_group_hosts(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetNoGroupHosts", []))

    @jsii.member(jsii_name="resetNoMetricHosts")
    def reset_no_metric_hosts(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetNoMetricHosts", []))

    @jsii.member(jsii_name="resetRequest")
    def reset_request(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetRequest", []))

    @jsii.member(jsii_name="resetScope")
    def reset_scope(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetScope", []))

    @jsii.member(jsii_name="resetStyle")
    def reset_style(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetStyle", []))

    @jsii.member(jsii_name="resetTitle")
    def reset_title(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTitle", []))

    @jsii.member(jsii_name="resetTitleAlign")
    def reset_title_align(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTitleAlign", []))

    @jsii.member(jsii_name="resetTitleSize")
    def reset_title_size(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTitleSize", []))

    @builtins.property
    @jsii.member(jsii_name="customLink")
    def custom_link(self) -> PowerpackWidgetHostmapDefinitionCustomLinkList:
        return typing.cast(PowerpackWidgetHostmapDefinitionCustomLinkList, jsii.get(self, "customLink"))

    @builtins.property
    @jsii.member(jsii_name="request")
    def request(self) -> "PowerpackWidgetHostmapDefinitionRequestOutputReference":
        return typing.cast("PowerpackWidgetHostmapDefinitionRequestOutputReference", jsii.get(self, "request"))

    @builtins.property
    @jsii.member(jsii_name="style")
    def style(self) -> "PowerpackWidgetHostmapDefinitionStyleOutputReference":
        return typing.cast("PowerpackWidgetHostmapDefinitionStyleOutputReference", jsii.get(self, "style"))

    @builtins.property
    @jsii.member(jsii_name="customLinkInput")
    def custom_link_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionCustomLink]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionCustomLink]]], jsii.get(self, "customLinkInput"))

    @builtins.property
    @jsii.member(jsii_name="groupInput")
    def group_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "groupInput"))

    @builtins.property
    @jsii.member(jsii_name="nodeTypeInput")
    def node_type_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nodeTypeInput"))

    @builtins.property
    @jsii.member(jsii_name="noGroupHostsInput")
    def no_group_hosts_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "noGroupHostsInput"))

    @builtins.property
    @jsii.member(jsii_name="noMetricHostsInput")
    def no_metric_hosts_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "noMetricHostsInput"))

    @builtins.property
    @jsii.member(jsii_name="requestInput")
    def request_input(
        self,
    ) -> typing.Optional["PowerpackWidgetHostmapDefinitionRequest"]:
        return typing.cast(typing.Optional["PowerpackWidgetHostmapDefinitionRequest"], jsii.get(self, "requestInput"))

    @builtins.property
    @jsii.member(jsii_name="scopeInput")
    def scope_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "scopeInput"))

    @builtins.property
    @jsii.member(jsii_name="styleInput")
    def style_input(self) -> typing.Optional["PowerpackWidgetHostmapDefinitionStyle"]:
        return typing.cast(typing.Optional["PowerpackWidgetHostmapDefinitionStyle"], jsii.get(self, "styleInput"))

    @builtins.property
    @jsii.member(jsii_name="titleAlignInput")
    def title_align_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "titleAlignInput"))

    @builtins.property
    @jsii.member(jsii_name="titleInput")
    def title_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "titleInput"))

    @builtins.property
    @jsii.member(jsii_name="titleSizeInput")
    def title_size_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "titleSizeInput"))

    @builtins.property
    @jsii.member(jsii_name="group")
    def group(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "group"))

    @group.setter
    def group(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e41b223302901141d9bdfb64966cbebe91799e284d8babb175766112d23d32a7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "group", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="nodeType")
    def node_type(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "nodeType"))

    @node_type.setter
    def node_type(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5b1955ee9931732cbc78ed246cbac6c1c444b5ae5fad2de200fc6cf554aedf63)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "nodeType", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="noGroupHosts")
    def no_group_hosts(
        self,
    ) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "noGroupHosts"))

    @no_group_hosts.setter
    def no_group_hosts(
        self,
        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__577fc28e1f9a878ae0b0f0c1b8c50471f3d3b40e0b91317f48dc62b60e6de48f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "noGroupHosts", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="noMetricHosts")
    def no_metric_hosts(
        self,
    ) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "noMetricHosts"))

    @no_metric_hosts.setter
    def no_metric_hosts(
        self,
        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c7617373783df85881308c4b924c69cec2f2ef0ba6dc9f4e735cb2c56a640892)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "noMetricHosts", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="scope")
    def scope(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "scope"))

    @scope.setter
    def scope(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4e58887f027ed58f17f0d988fa2baf81454ac7aaf156d9fb36535fcb215f1dd6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "scope", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="title")
    def title(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "title"))

    @title.setter
    def title(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0278a60fd04aaa45747f2d593acca763cf89fa422b0667c4311952a58f87b481)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "title", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="titleAlign")
    def title_align(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "titleAlign"))

    @title_align.setter
    def title_align(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__08bf9282fd2c67d412867e6bb8557d2af9804afe5edfea9bd64fdf8d42636126)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "titleAlign", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="titleSize")
    def title_size(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "titleSize"))

    @title_size.setter
    def title_size(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ffa504432b54ac2b0ca9b7a56986aabb776a2fb84205b9b3c8eb8dce8e136798)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "titleSize", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[PowerpackWidgetHostmapDefinition]:
        return typing.cast(typing.Optional[PowerpackWidgetHostmapDefinition], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetHostmapDefinition],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__87ae5bdbfc6d996bf778a1302a1671685525928ab2c19dcc1460ddde6ec5fe94)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequest",
    jsii_struct_bases=[],
    name_mapping={"fill": "fill", "size": "size"},
)
class PowerpackWidgetHostmapDefinitionRequest:
    def __init__(
        self,
        *,
        fill: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetHostmapDefinitionRequestFill", typing.Dict[builtins.str, typing.Any]]]]] = None,
        size: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetHostmapDefinitionRequestSize", typing.Dict[builtins.str, typing.Any]]]]] = None,
    ) -> None:
        '''
        :param fill: fill block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#fill Powerpack#fill}
        :param size: size block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#size Powerpack#size}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e31b561284805d8a11bcaf17250f240898d56cc055229e05ccb122f111789507)
            check_type(argname="argument fill", value=fill, expected_type=type_hints["fill"])
            check_type(argname="argument size", value=size, expected_type=type_hints["size"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if fill is not None:
            self._values["fill"] = fill
        if size is not None:
            self._values["size"] = size

    @builtins.property
    def fill(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetHostmapDefinitionRequestFill"]]]:
        '''fill block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#fill Powerpack#fill}
        '''
        result = self._values.get("fill")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetHostmapDefinitionRequestFill"]]], result)

    @builtins.property
    def size(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetHostmapDefinitionRequestSize"]]]:
        '''size block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#size Powerpack#size}
        '''
        result = self._values.get("size")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetHostmapDefinitionRequestSize"]]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetHostmapDefinitionRequest(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestFill",
    jsii_struct_bases=[],
    name_mapping={
        "apm_query": "apmQuery",
        "log_query": "logQuery",
        "process_query": "processQuery",
        "q": "q",
        "rum_query": "rumQuery",
        "security_query": "securityQuery",
    },
)
class PowerpackWidgetHostmapDefinitionRequestFill:
    def __init__(
        self,
        *,
        apm_query: typing.Optional[typing.Union["PowerpackWidgetHostmapDefinitionRequestFillApmQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        log_query: typing.Optional[typing.Union["PowerpackWidgetHostmapDefinitionRequestFillLogQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        process_query: typing.Optional[typing.Union["PowerpackWidgetHostmapDefinitionRequestFillProcessQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        q: typing.Optional[builtins.str] = None,
        rum_query: typing.Optional[typing.Union["PowerpackWidgetHostmapDefinitionRequestFillRumQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        security_query: typing.Optional[typing.Union["PowerpackWidgetHostmapDefinitionRequestFillSecurityQuery", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param apm_query: apm_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#apm_query Powerpack#apm_query}
        :param log_query: log_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#log_query Powerpack#log_query}
        :param process_query: process_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#process_query Powerpack#process_query}
        :param q: The metric query to use for this widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#q Powerpack#q}
        :param rum_query: rum_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#rum_query Powerpack#rum_query}
        :param security_query: security_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#security_query Powerpack#security_query}
        '''
        if isinstance(apm_query, dict):
            apm_query = PowerpackWidgetHostmapDefinitionRequestFillApmQuery(**apm_query)
        if isinstance(log_query, dict):
            log_query = PowerpackWidgetHostmapDefinitionRequestFillLogQuery(**log_query)
        if isinstance(process_query, dict):
            process_query = PowerpackWidgetHostmapDefinitionRequestFillProcessQuery(**process_query)
        if isinstance(rum_query, dict):
            rum_query = PowerpackWidgetHostmapDefinitionRequestFillRumQuery(**rum_query)
        if isinstance(security_query, dict):
            security_query = PowerpackWidgetHostmapDefinitionRequestFillSecurityQuery(**security_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f36ab04019b875b38031e67ba55606b576dffd3ff1c4e2d1fa0ac09d6a2ecfd6)
            check_type(argname="argument apm_query", value=apm_query, expected_type=type_hints["apm_query"])
            check_type(argname="argument log_query", value=log_query, expected_type=type_hints["log_query"])
            check_type(argname="argument process_query", value=process_query, expected_type=type_hints["process_query"])
            check_type(argname="argument q", value=q, expected_type=type_hints["q"])
            check_type(argname="argument rum_query", value=rum_query, expected_type=type_hints["rum_query"])
            check_type(argname="argument security_query", value=security_query, expected_type=type_hints["security_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if apm_query is not None:
            self._values["apm_query"] = apm_query
        if log_query is not None:
            self._values["log_query"] = log_query
        if process_query is not None:
            self._values["process_query"] = process_query
        if q is not None:
            self._values["q"] = q
        if rum_query is not None:
            self._values["rum_query"] = rum_query
        if security_query is not None:
            self._values["security_query"] = security_query

    @builtins.property
    def apm_query(
        self,
    ) -> typing.Optional["PowerpackWidgetHostmapDefinitionRequestFillApmQuery"]:
        '''apm_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#apm_query Powerpack#apm_query}
        '''
        result = self._values.get("apm_query")
        return typing.cast(typing.Optional["PowerpackWidgetHostmapDefinitionRequestFillApmQuery"], result)

    @builtins.property
    def log_query(
        self,
    ) -> typing.Optional["PowerpackWidgetHostmapDefinitionRequestFillLogQuery"]:
        '''log_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#log_query Powerpack#log_query}
        '''
        result = self._values.get("log_query")
        return typing.cast(typing.Optional["PowerpackWidgetHostmapDefinitionRequestFillLogQuery"], result)

    @builtins.property
    def process_query(
        self,
    ) -> typing.Optional["PowerpackWidgetHostmapDefinitionRequestFillProcessQuery"]:
        '''process_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#process_query Powerpack#process_query}
        '''
        result = self._values.get("process_query")
        return typing.cast(typing.Optional["PowerpackWidgetHostmapDefinitionRequestFillProcessQuery"], result)

    @builtins.property
    def q(self) -> typing.Optional[builtins.str]:
        '''The metric query to use for this widget.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#q Powerpack#q}
        '''
        result = self._values.get("q")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def rum_query(
        self,
    ) -> typing.Optional["PowerpackWidgetHostmapDefinitionRequestFillRumQuery"]:
        '''rum_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#rum_query Powerpack#rum_query}
        '''
        result = self._values.get("rum_query")
        return typing.cast(typing.Optional["PowerpackWidgetHostmapDefinitionRequestFillRumQuery"], result)

    @builtins.property
    def security_query(
        self,
    ) -> typing.Optional["PowerpackWidgetHostmapDefinitionRequestFillSecurityQuery"]:
        '''security_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#security_query Powerpack#security_query}
        '''
        result = self._values.get("security_query")
        return typing.cast(typing.Optional["PowerpackWidgetHostmapDefinitionRequestFillSecurityQuery"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetHostmapDefinitionRequestFill(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestFillApmQuery",
    jsii_struct_bases=[],
    name_mapping={
        "index": "index",
        "compute_query": "computeQuery",
        "group_by": "groupBy",
        "multi_compute": "multiCompute",
        "search_query": "searchQuery",
    },
)
class PowerpackWidgetHostmapDefinitionRequestFillApmQuery:
    def __init__(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union["PowerpackWidgetHostmapDefinitionRequestFillApmQueryComputeQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetHostmapDefinitionRequestFillApmQueryGroupBy", typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetHostmapDefinitionRequestFillApmQueryMultiCompute", typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        if isinstance(compute_query, dict):
            compute_query = PowerpackWidgetHostmapDefinitionRequestFillApmQueryComputeQuery(**compute_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__371fad1e34de2733160d9bd5b19d61486822a8f8837fe1ce39fd3f2e0b16c3a1)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
            check_type(argname="argument compute_query", value=compute_query, expected_type=type_hints["compute_query"])
            check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
            check_type(argname="argument multi_compute", value=multi_compute, expected_type=type_hints["multi_compute"])
            check_type(argname="argument search_query", value=search_query, expected_type=type_hints["search_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "index": index,
        }
        if compute_query is not None:
            self._values["compute_query"] = compute_query
        if group_by is not None:
            self._values["group_by"] = group_by
        if multi_compute is not None:
            self._values["multi_compute"] = multi_compute
        if search_query is not None:
            self._values["search_query"] = search_query

    @builtins.property
    def index(self) -> builtins.str:
        '''The name of the index to query.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        '''
        result = self._values.get("index")
        assert result is not None, "Required property 'index' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def compute_query(
        self,
    ) -> typing.Optional["PowerpackWidgetHostmapDefinitionRequestFillApmQueryComputeQuery"]:
        '''compute_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        '''
        result = self._values.get("compute_query")
        return typing.cast(typing.Optional["PowerpackWidgetHostmapDefinitionRequestFillApmQueryComputeQuery"], result)

    @builtins.property
    def group_by(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetHostmapDefinitionRequestFillApmQueryGroupBy"]]]:
        '''group_by block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        '''
        result = self._values.get("group_by")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetHostmapDefinitionRequestFillApmQueryGroupBy"]]], result)

    @builtins.property
    def multi_compute(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetHostmapDefinitionRequestFillApmQueryMultiCompute"]]]:
        '''multi_compute block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        '''
        result = self._values.get("multi_compute")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetHostmapDefinitionRequestFillApmQueryMultiCompute"]]], result)

    @builtins.property
    def search_query(self) -> typing.Optional[builtins.str]:
        '''The search query to use.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        result = self._values.get("search_query")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetHostmapDefinitionRequestFillApmQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestFillApmQueryComputeQuery",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetHostmapDefinitionRequestFillApmQueryComputeQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e7656e2bdca41524d492e6eb5691c9767dbe32eda69d53d47aa0cb955c4e289c)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetHostmapDefinitionRequestFillApmQueryComputeQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetHostmapDefinitionRequestFillApmQueryComputeQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestFillApmQueryComputeQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8b4bbf0a29c430517959df9f471e58d79a76f3f248c624f620668c8600b36572)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a2f84f6bd0ac01821f9928cac74fcce025cc7c49b08a41ba5101658cf4831b17)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__20b65852b15a83b0f0d36b8edd6f8cedbd96670916b37cff7b288b15603cbd90)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__40bfac7fb7b550869d6a52d31ef573e5297b2ec2507f56d05ea8dab6629d15aa)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetHostmapDefinitionRequestFillApmQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetHostmapDefinitionRequestFillApmQueryComputeQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetHostmapDefinitionRequestFillApmQueryComputeQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__49c3f6d22e43b41414100e746deaaaecda264d839898a1dc047ff9aa0458a0c9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestFillApmQueryGroupBy",
    jsii_struct_bases=[],
    name_mapping={"facet": "facet", "limit": "limit", "sort_query": "sortQuery"},
)
class PowerpackWidgetHostmapDefinitionRequestFillApmQueryGroupBy:
    def __init__(
        self,
        *,
        facet: typing.Optional[builtins.str] = None,
        limit: typing.Optional[jsii.Number] = None,
        sort_query: typing.Optional[typing.Union["PowerpackWidgetHostmapDefinitionRequestFillApmQueryGroupBySortQuery", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param limit: The maximum number of items in the group. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param sort_query: sort_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        if isinstance(sort_query, dict):
            sort_query = PowerpackWidgetHostmapDefinitionRequestFillApmQueryGroupBySortQuery(**sort_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2b3b70c1588cec081e4e457bba014d6393e91bbc415eead0536828daddb0cdf4)
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
            check_type(argname="argument sort_query", value=sort_query, expected_type=type_hints["sort_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if facet is not None:
            self._values["facet"] = facet
        if limit is not None:
            self._values["limit"] = limit
        if sort_query is not None:
            self._values["sort_query"] = sort_query

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def limit(self) -> typing.Optional[jsii.Number]:
        '''The maximum number of items in the group.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        '''
        result = self._values.get("limit")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def sort_query(
        self,
    ) -> typing.Optional["PowerpackWidgetHostmapDefinitionRequestFillApmQueryGroupBySortQuery"]:
        '''sort_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        result = self._values.get("sort_query")
        return typing.cast(typing.Optional["PowerpackWidgetHostmapDefinitionRequestFillApmQueryGroupBySortQuery"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetHostmapDefinitionRequestFillApmQueryGroupBy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetHostmapDefinitionRequestFillApmQueryGroupByList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestFillApmQueryGroupByList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__06fea99295731caa48826eebe76a2f99a2b3a4cb373c79dbe2ce4ff0cd3e126e)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetHostmapDefinitionRequestFillApmQueryGroupByOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5582d8784065cb64aebd3a848ddda3a79c21cf500e7c4668c8a2b3b36e2b0616)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetHostmapDefinitionRequestFillApmQueryGroupByOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7b2bccf735a2427e89a8dd8d1f11542c3faf3d2291f3130dce12efb3423ace8e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__de97645544a1a339231ca81bf6edf408fc7fef0d48726fc2d6b05f2567389c72)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2ea7304cb2c1bc4733b2c24a986b34b987e72103727a22a274284bd62b81c890)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestFillApmQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestFillApmQueryGroupBy]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestFillApmQueryGroupBy]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dc2babecef6dc6254543dbdb983d2bbab81b4e05d8b89466a1ddecfc01184fcf)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetHostmapDefinitionRequestFillApmQueryGroupByOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestFillApmQueryGroupByOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2f36a46347fbc842cebb2cac3f432d4fa7bb5c327e2af08df374788ec7fb5033)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putSortQuery")
    def put_sort_query(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        value = PowerpackWidgetHostmapDefinitionRequestFillApmQueryGroupBySortQuery(
            aggregation=aggregation, order=order, facet=facet
        )

        return typing.cast(None, jsii.invoke(self, "putSortQuery", [value]))

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetLimit")
    def reset_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLimit", []))

    @jsii.member(jsii_name="resetSortQuery")
    def reset_sort_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSortQuery", []))

    @builtins.property
    @jsii.member(jsii_name="sortQuery")
    def sort_query(
        self,
    ) -> "PowerpackWidgetHostmapDefinitionRequestFillApmQueryGroupBySortQueryOutputReference":
        return typing.cast("PowerpackWidgetHostmapDefinitionRequestFillApmQueryGroupBySortQueryOutputReference", jsii.get(self, "sortQuery"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="limitInput")
    def limit_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "limitInput"))

    @builtins.property
    @jsii.member(jsii_name="sortQueryInput")
    def sort_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetHostmapDefinitionRequestFillApmQueryGroupBySortQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetHostmapDefinitionRequestFillApmQueryGroupBySortQuery"], jsii.get(self, "sortQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1781cb9137be78a8c997ea72cc6fb1da324acb72bcc9e799ba1584a848b4c7e4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="limit")
    def limit(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "limit"))

    @limit.setter
    def limit(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4c9c5f1a134e64f30548cb0d46b760a5365079d2ae6444127ed6dc5426880763)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "limit", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHostmapDefinitionRequestFillApmQueryGroupBy]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHostmapDefinitionRequestFillApmQueryGroupBy]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHostmapDefinitionRequestFillApmQueryGroupBy]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0c89803b06a7513fdc6135190bef5e3c7b5170b868ec6691b35d1d2b78a8b1a9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestFillApmQueryGroupBySortQuery",
    jsii_struct_bases=[],
    name_mapping={"aggregation": "aggregation", "order": "order", "facet": "facet"},
)
class PowerpackWidgetHostmapDefinitionRequestFillApmQueryGroupBySortQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__80071386eac19d7fe3a2988251fe5c8e4cf1b915d620c2e863d9a62704d13c90)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument order", value=order, expected_type=type_hints["order"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
            "order": order,
        }
        if facet is not None:
            self._values["facet"] = facet

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def order(self) -> builtins.str:
        '''Widget sorting methods. Valid values are ``asc``, ``desc``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        result = self._values.get("order")
        assert result is not None, "Required property 'order' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetHostmapDefinitionRequestFillApmQueryGroupBySortQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetHostmapDefinitionRequestFillApmQueryGroupBySortQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestFillApmQueryGroupBySortQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e1e11af5673718e380f7489b4eda33cbb621a12afbdbb3a53163dd28f0f2d230)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="orderInput")
    def order_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "orderInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7e13b548e04930e7e6a633f86997764a3b8c604aac5001828a2b5542275e1cf9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__27216ee1bcd57ed34941f0722183408e9e328ed7197c71a20e3900104a8f5186)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="order")
    def order(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "order"))

    @order.setter
    def order(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a9ffae64475bb04b89d15b3e2db5311a8d5e75be6741654710947ceb51e35251)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "order", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetHostmapDefinitionRequestFillApmQueryGroupBySortQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetHostmapDefinitionRequestFillApmQueryGroupBySortQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetHostmapDefinitionRequestFillApmQueryGroupBySortQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__afc16cdf937876decb94bacea526cf5599d3820f815ac8ea5610ee0f2ad3f490)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestFillApmQueryMultiCompute",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetHostmapDefinitionRequestFillApmQueryMultiCompute:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5352a825a95a51ac3243483dfb6d8afe98f0a7616ffa72206fff066b6ba6e290)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetHostmapDefinitionRequestFillApmQueryMultiCompute(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetHostmapDefinitionRequestFillApmQueryMultiComputeList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestFillApmQueryMultiComputeList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f5086915a1756c7e824327073bcf60acca9d908b0b15c92e78b4209dd387f6d3)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetHostmapDefinitionRequestFillApmQueryMultiComputeOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a1176a7cec3b788b9268ee011789829e856d220b89273fe009ade976363475c9)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetHostmapDefinitionRequestFillApmQueryMultiComputeOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e1097da010b6179a2c5f1114df37e5b67e009e7580b5b7257a7ed71329c1786c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f264cc5351375480f5ad7f17ae1e5b7d401a4215dc0c55f71ece557db208d714)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0ccbb000d66622362521aa8e629ccaa5c4a3e7afd2892d9bdd52972bf81b9973)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestFillApmQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestFillApmQueryMultiCompute]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestFillApmQueryMultiCompute]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2e86bd1811d6a8409fc8e2bbcdd6a51ec03733fe621e2528f3a91daf6ac54662)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetHostmapDefinitionRequestFillApmQueryMultiComputeOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestFillApmQueryMultiComputeOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cc9e0f115bfb5fc4e15ea9e7298808ccff3a2c04d749988ed5d82a580b8ac637)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__025393ae60d9da1906a5648bb5cce3bb8be84cfa107149cb880ebf6fc69705ea)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9e90faccd75a57a821ec8afe7699f87729133d204c271f7d0321ee82163226ae)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__88aa8825fbe95bdd69eb99df6721c5a31f9e90933d891bae208063482dee0ffe)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHostmapDefinitionRequestFillApmQueryMultiCompute]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHostmapDefinitionRequestFillApmQueryMultiCompute]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHostmapDefinitionRequestFillApmQueryMultiCompute]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8591d15dc6fd69c58b0f2d5eb39b184fdd30607a70b150f71dc3c0db56d8a3ee)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetHostmapDefinitionRequestFillApmQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestFillApmQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__787605443151948553e163a3244d5faa8d6d1bce7b8933feb56e5258b26bdf3d)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putComputeQuery")
    def put_compute_query(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        value = PowerpackWidgetHostmapDefinitionRequestFillApmQueryComputeQuery(
            aggregation=aggregation, facet=facet, interval=interval
        )

        return typing.cast(None, jsii.invoke(self, "putComputeQuery", [value]))

    @jsii.member(jsii_name="putGroupBy")
    def put_group_by(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHostmapDefinitionRequestFillApmQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2e6fb2a8eb87b3e3eeafb4585a2cd45b244be0671da6677561ac290767dd465d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putGroupBy", [value]))

    @jsii.member(jsii_name="putMultiCompute")
    def put_multi_compute(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHostmapDefinitionRequestFillApmQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a75d7d05a4e28ff75e4bcfaa4764526106ed50dcf24dc596ba3577e6ec797549)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putMultiCompute", [value]))

    @jsii.member(jsii_name="resetComputeQuery")
    def reset_compute_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetComputeQuery", []))

    @jsii.member(jsii_name="resetGroupBy")
    def reset_group_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGroupBy", []))

    @jsii.member(jsii_name="resetMultiCompute")
    def reset_multi_compute(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMultiCompute", []))

    @jsii.member(jsii_name="resetSearchQuery")
    def reset_search_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSearchQuery", []))

    @builtins.property
    @jsii.member(jsii_name="computeQuery")
    def compute_query(
        self,
    ) -> PowerpackWidgetHostmapDefinitionRequestFillApmQueryComputeQueryOutputReference:
        return typing.cast(PowerpackWidgetHostmapDefinitionRequestFillApmQueryComputeQueryOutputReference, jsii.get(self, "computeQuery"))

    @builtins.property
    @jsii.member(jsii_name="groupBy")
    def group_by(
        self,
    ) -> PowerpackWidgetHostmapDefinitionRequestFillApmQueryGroupByList:
        return typing.cast(PowerpackWidgetHostmapDefinitionRequestFillApmQueryGroupByList, jsii.get(self, "groupBy"))

    @builtins.property
    @jsii.member(jsii_name="multiCompute")
    def multi_compute(
        self,
    ) -> PowerpackWidgetHostmapDefinitionRequestFillApmQueryMultiComputeList:
        return typing.cast(PowerpackWidgetHostmapDefinitionRequestFillApmQueryMultiComputeList, jsii.get(self, "multiCompute"))

    @builtins.property
    @jsii.member(jsii_name="computeQueryInput")
    def compute_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetHostmapDefinitionRequestFillApmQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetHostmapDefinitionRequestFillApmQueryComputeQuery], jsii.get(self, "computeQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="groupByInput")
    def group_by_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestFillApmQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestFillApmQueryGroupBy]]], jsii.get(self, "groupByInput"))

    @builtins.property
    @jsii.member(jsii_name="indexInput")
    def index_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "indexInput"))

    @builtins.property
    @jsii.member(jsii_name="multiComputeInput")
    def multi_compute_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestFillApmQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestFillApmQueryMultiCompute]]], jsii.get(self, "multiComputeInput"))

    @builtins.property
    @jsii.member(jsii_name="searchQueryInput")
    def search_query_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "searchQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="index")
    def index(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "index"))

    @index.setter
    def index(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__68d6231444f0d94b2900002c90afebf63c7d0e7da07adc353df0a68f899a8321)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "index", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="searchQuery")
    def search_query(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "searchQuery"))

    @search_query.setter
    def search_query(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7400c6589fae05f6d93e08cfc208b7c03484daa86f37d147ea64b2e8a456ca23)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "searchQuery", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetHostmapDefinitionRequestFillApmQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetHostmapDefinitionRequestFillApmQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetHostmapDefinitionRequestFillApmQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__544cadd31a97c5523e04c94a5a4a7a6c184e74088ee739f63a84a70fa5fec804)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetHostmapDefinitionRequestFillList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestFillList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d882fd37a6a307411125d65b08d16cfa72300274438072db2db2548562f9af8e)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetHostmapDefinitionRequestFillOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b41ff3a06c154fc64138cdab776df19a85a4651eae80b425fe35a63e236532e9)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetHostmapDefinitionRequestFillOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c6977203821076795bd0c179400dbb02ce48fcb82812d2711d826e70d3162a1d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0f6af6b187e205368c53e50458e47a012db54bc862282d286dddb1f0e0921b68)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a8f9bc721f0e4b0b23407e400db858299d7239fe51a804c1b9d6758cc2d17909)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestFill]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestFill]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestFill]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__03958fe80e50ddb907d08ea6b4fb8a99029c701d6841706de22c44ef355b7a25)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestFillLogQuery",
    jsii_struct_bases=[],
    name_mapping={
        "index": "index",
        "compute_query": "computeQuery",
        "group_by": "groupBy",
        "multi_compute": "multiCompute",
        "search_query": "searchQuery",
    },
)
class PowerpackWidgetHostmapDefinitionRequestFillLogQuery:
    def __init__(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union["PowerpackWidgetHostmapDefinitionRequestFillLogQueryComputeQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetHostmapDefinitionRequestFillLogQueryGroupBy", typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetHostmapDefinitionRequestFillLogQueryMultiCompute", typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        if isinstance(compute_query, dict):
            compute_query = PowerpackWidgetHostmapDefinitionRequestFillLogQueryComputeQuery(**compute_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fb65d41bf0eab8847607bcc0bbcbc50de971f9c6b6edfa1686761810c3e63442)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
            check_type(argname="argument compute_query", value=compute_query, expected_type=type_hints["compute_query"])
            check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
            check_type(argname="argument multi_compute", value=multi_compute, expected_type=type_hints["multi_compute"])
            check_type(argname="argument search_query", value=search_query, expected_type=type_hints["search_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "index": index,
        }
        if compute_query is not None:
            self._values["compute_query"] = compute_query
        if group_by is not None:
            self._values["group_by"] = group_by
        if multi_compute is not None:
            self._values["multi_compute"] = multi_compute
        if search_query is not None:
            self._values["search_query"] = search_query

    @builtins.property
    def index(self) -> builtins.str:
        '''The name of the index to query.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        '''
        result = self._values.get("index")
        assert result is not None, "Required property 'index' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def compute_query(
        self,
    ) -> typing.Optional["PowerpackWidgetHostmapDefinitionRequestFillLogQueryComputeQuery"]:
        '''compute_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        '''
        result = self._values.get("compute_query")
        return typing.cast(typing.Optional["PowerpackWidgetHostmapDefinitionRequestFillLogQueryComputeQuery"], result)

    @builtins.property
    def group_by(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetHostmapDefinitionRequestFillLogQueryGroupBy"]]]:
        '''group_by block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        '''
        result = self._values.get("group_by")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetHostmapDefinitionRequestFillLogQueryGroupBy"]]], result)

    @builtins.property
    def multi_compute(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetHostmapDefinitionRequestFillLogQueryMultiCompute"]]]:
        '''multi_compute block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        '''
        result = self._values.get("multi_compute")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetHostmapDefinitionRequestFillLogQueryMultiCompute"]]], result)

    @builtins.property
    def search_query(self) -> typing.Optional[builtins.str]:
        '''The search query to use.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        result = self._values.get("search_query")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetHostmapDefinitionRequestFillLogQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestFillLogQueryComputeQuery",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetHostmapDefinitionRequestFillLogQueryComputeQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__eb761ebddb044f5209379549267d7be6c0cbe573242348c5d7e81ad52256879d)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetHostmapDefinitionRequestFillLogQueryComputeQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetHostmapDefinitionRequestFillLogQueryComputeQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestFillLogQueryComputeQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c69061cdd612807acf0ed7a93002e4981baf3ae1e12f252fb05a2fe83b15bb41)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bda80db04f17a09b982f2a7306e585cb19de080f20910a86b10d084ade982cb1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__00fa7c66b92b5248b22b96167a56de1119f146ce12b548133a722c7e492feea0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ab71b779af262f63331f95edd3199ff727d872f72382bcf90e921b9a5089f130)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetHostmapDefinitionRequestFillLogQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetHostmapDefinitionRequestFillLogQueryComputeQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetHostmapDefinitionRequestFillLogQueryComputeQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__acfc3880fa8533e81fe1d38ec021e44708b10b2497a2fcf599619ee26efe8461)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestFillLogQueryGroupBy",
    jsii_struct_bases=[],
    name_mapping={"facet": "facet", "limit": "limit", "sort_query": "sortQuery"},
)
class PowerpackWidgetHostmapDefinitionRequestFillLogQueryGroupBy:
    def __init__(
        self,
        *,
        facet: typing.Optional[builtins.str] = None,
        limit: typing.Optional[jsii.Number] = None,
        sort_query: typing.Optional[typing.Union["PowerpackWidgetHostmapDefinitionRequestFillLogQueryGroupBySortQuery", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param limit: The maximum number of items in the group. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param sort_query: sort_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        if isinstance(sort_query, dict):
            sort_query = PowerpackWidgetHostmapDefinitionRequestFillLogQueryGroupBySortQuery(**sort_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dcf3f388c5ba1ace6aa529277dda2a24d50b091b1850d6e532379793904c8812)
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
            check_type(argname="argument sort_query", value=sort_query, expected_type=type_hints["sort_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if facet is not None:
            self._values["facet"] = facet
        if limit is not None:
            self._values["limit"] = limit
        if sort_query is not None:
            self._values["sort_query"] = sort_query

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def limit(self) -> typing.Optional[jsii.Number]:
        '''The maximum number of items in the group.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        '''
        result = self._values.get("limit")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def sort_query(
        self,
    ) -> typing.Optional["PowerpackWidgetHostmapDefinitionRequestFillLogQueryGroupBySortQuery"]:
        '''sort_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        result = self._values.get("sort_query")
        return typing.cast(typing.Optional["PowerpackWidgetHostmapDefinitionRequestFillLogQueryGroupBySortQuery"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetHostmapDefinitionRequestFillLogQueryGroupBy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetHostmapDefinitionRequestFillLogQueryGroupByList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestFillLogQueryGroupByList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f7dbb9e078f0f160065e9aed084e96e5daec118643825d29c78d4b904de97955)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetHostmapDefinitionRequestFillLogQueryGroupByOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a127fa13c2fcec57df975fbfdd366deb0a912ae94b11fc82b268a1bc1d093227)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetHostmapDefinitionRequestFillLogQueryGroupByOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__824ae013bc5fa93ef693ea60f41c87a5e67c30b88fbf7518e6e4cfccb4593046)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a8b1886227f638db7da21eaca3a0ab8e201cf6e33d88a10d9d518b3ca3d1116b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__30a0df30d4399d170f631f6e92939f4930fa339a862335c1b5d14d8de8334ba9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestFillLogQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestFillLogQueryGroupBy]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestFillLogQueryGroupBy]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7cd9b5f3ce28fc1123dd5b542b3fc05c0204d01da03da4a13358e35ee90526a1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetHostmapDefinitionRequestFillLogQueryGroupByOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestFillLogQueryGroupByOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8126be4e1a69627af41fe51852bb74bc4623a44310ca3387a9863162e3b25b78)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putSortQuery")
    def put_sort_query(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        value = PowerpackWidgetHostmapDefinitionRequestFillLogQueryGroupBySortQuery(
            aggregation=aggregation, order=order, facet=facet
        )

        return typing.cast(None, jsii.invoke(self, "putSortQuery", [value]))

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetLimit")
    def reset_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLimit", []))

    @jsii.member(jsii_name="resetSortQuery")
    def reset_sort_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSortQuery", []))

    @builtins.property
    @jsii.member(jsii_name="sortQuery")
    def sort_query(
        self,
    ) -> "PowerpackWidgetHostmapDefinitionRequestFillLogQueryGroupBySortQueryOutputReference":
        return typing.cast("PowerpackWidgetHostmapDefinitionRequestFillLogQueryGroupBySortQueryOutputReference", jsii.get(self, "sortQuery"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="limitInput")
    def limit_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "limitInput"))

    @builtins.property
    @jsii.member(jsii_name="sortQueryInput")
    def sort_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetHostmapDefinitionRequestFillLogQueryGroupBySortQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetHostmapDefinitionRequestFillLogQueryGroupBySortQuery"], jsii.get(self, "sortQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dc9b32a30fedbbb13306f55c4e9b9f315f99796109ef81cd8364084b42c3026f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="limit")
    def limit(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "limit"))

    @limit.setter
    def limit(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4f3aca12fb2d0f4281e75194a46a43c2aaf299a2c5054414d138a4d8f6fb89b8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "limit", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHostmapDefinitionRequestFillLogQueryGroupBy]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHostmapDefinitionRequestFillLogQueryGroupBy]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHostmapDefinitionRequestFillLogQueryGroupBy]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__570f8813fbd7def51f9cca90f34484674bc454db576bfe87c02b838777853f5c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestFillLogQueryGroupBySortQuery",
    jsii_struct_bases=[],
    name_mapping={"aggregation": "aggregation", "order": "order", "facet": "facet"},
)
class PowerpackWidgetHostmapDefinitionRequestFillLogQueryGroupBySortQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__609eec2ea09a550812d63049ea9bb789f253c4096523e64d68b123b0393e5dbc)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument order", value=order, expected_type=type_hints["order"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
            "order": order,
        }
        if facet is not None:
            self._values["facet"] = facet

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def order(self) -> builtins.str:
        '''Widget sorting methods. Valid values are ``asc``, ``desc``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        result = self._values.get("order")
        assert result is not None, "Required property 'order' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetHostmapDefinitionRequestFillLogQueryGroupBySortQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetHostmapDefinitionRequestFillLogQueryGroupBySortQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestFillLogQueryGroupBySortQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c09605abdf4fea32af18f93535bc698a17b1406b53557e9ead131599c9801dde)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="orderInput")
    def order_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "orderInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dd9a3e0321b3a17a6aa62145ff5d2658df224c9a0ca006902ad6b7eb178361d3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__39666e2cb29d520f961f4c8a7ffd75383938956992eb84cd1143ec34d8d8497b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="order")
    def order(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "order"))

    @order.setter
    def order(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__576356724fd46e36b8a015947e8ea4c509f79eeee7813906328b7a8b5a03bc33)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "order", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetHostmapDefinitionRequestFillLogQueryGroupBySortQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetHostmapDefinitionRequestFillLogQueryGroupBySortQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetHostmapDefinitionRequestFillLogQueryGroupBySortQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1a8c84c518878a14aa4adcc60677c1cfac799806c069124c4510ac6a2f000bee)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestFillLogQueryMultiCompute",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetHostmapDefinitionRequestFillLogQueryMultiCompute:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4c470b1d25781f1b907f880060aa51114ef27a23f590260a4be511103d532590)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetHostmapDefinitionRequestFillLogQueryMultiCompute(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetHostmapDefinitionRequestFillLogQueryMultiComputeList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestFillLogQueryMultiComputeList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__26215740528ec1c055d402593bbc628c79cab4f01c261ab5f71a8cee9fc983ae)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetHostmapDefinitionRequestFillLogQueryMultiComputeOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d23b2ae0909700e72d02b4c6a5e79510bfa5c68a45f90eba1a6c78ea9fbd6414)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetHostmapDefinitionRequestFillLogQueryMultiComputeOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c7fb6a0fbe068405acc65502f5d5fe1c7830e21693076705f70b03e18ad5f000)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f87397b828d29d5a519b975d9d39d04080be36a9304ed10c6a05e459be33d947)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__745ec349e43b70dcc1ab3a1fe3bd28890857a982b0709095ce08b6f25dd34d89)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestFillLogQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestFillLogQueryMultiCompute]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestFillLogQueryMultiCompute]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8b932f520772a43364fce7009866e36e0ed3f0e19f989938b0cd837b7c4c2ee1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetHostmapDefinitionRequestFillLogQueryMultiComputeOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestFillLogQueryMultiComputeOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__669df4d26835feb9d5c5c936921a76031c11c2c5b1c15a5daf627c574d4b70be)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d529f6cbd35426e8309dfca3a1226bc628f66c213c1ca6289f74c807ba0ee3b2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9d4750dbd549102b2b0fdb25b519f865fe82d6852ceb0e8933407dcaf88fc0a1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__37c8a621f830f675a29a5d54d899a1d08fb893521302501cf8ac9ed7dfa1856d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHostmapDefinitionRequestFillLogQueryMultiCompute]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHostmapDefinitionRequestFillLogQueryMultiCompute]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHostmapDefinitionRequestFillLogQueryMultiCompute]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5b12dae4e03bde333a5bbc5d0e335638b8b8086d1c0d4f21b2a9cfd41e149ed8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetHostmapDefinitionRequestFillLogQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestFillLogQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3f4342ace258b5aea0e583782058c6703f5957ad775d17a7842aea344ca2712e)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putComputeQuery")
    def put_compute_query(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        value = PowerpackWidgetHostmapDefinitionRequestFillLogQueryComputeQuery(
            aggregation=aggregation, facet=facet, interval=interval
        )

        return typing.cast(None, jsii.invoke(self, "putComputeQuery", [value]))

    @jsii.member(jsii_name="putGroupBy")
    def put_group_by(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHostmapDefinitionRequestFillLogQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__509eaf6d4b319c1e7a91184412291c8a4f871e37f78c0b1d6ae3f5ec6c210a35)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putGroupBy", [value]))

    @jsii.member(jsii_name="putMultiCompute")
    def put_multi_compute(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHostmapDefinitionRequestFillLogQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6ee5aea20ca2d24e694c384e8a3d507dd1942c0b9edf669b4203c1519e208307)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putMultiCompute", [value]))

    @jsii.member(jsii_name="resetComputeQuery")
    def reset_compute_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetComputeQuery", []))

    @jsii.member(jsii_name="resetGroupBy")
    def reset_group_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGroupBy", []))

    @jsii.member(jsii_name="resetMultiCompute")
    def reset_multi_compute(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMultiCompute", []))

    @jsii.member(jsii_name="resetSearchQuery")
    def reset_search_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSearchQuery", []))

    @builtins.property
    @jsii.member(jsii_name="computeQuery")
    def compute_query(
        self,
    ) -> PowerpackWidgetHostmapDefinitionRequestFillLogQueryComputeQueryOutputReference:
        return typing.cast(PowerpackWidgetHostmapDefinitionRequestFillLogQueryComputeQueryOutputReference, jsii.get(self, "computeQuery"))

    @builtins.property
    @jsii.member(jsii_name="groupBy")
    def group_by(
        self,
    ) -> PowerpackWidgetHostmapDefinitionRequestFillLogQueryGroupByList:
        return typing.cast(PowerpackWidgetHostmapDefinitionRequestFillLogQueryGroupByList, jsii.get(self, "groupBy"))

    @builtins.property
    @jsii.member(jsii_name="multiCompute")
    def multi_compute(
        self,
    ) -> PowerpackWidgetHostmapDefinitionRequestFillLogQueryMultiComputeList:
        return typing.cast(PowerpackWidgetHostmapDefinitionRequestFillLogQueryMultiComputeList, jsii.get(self, "multiCompute"))

    @builtins.property
    @jsii.member(jsii_name="computeQueryInput")
    def compute_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetHostmapDefinitionRequestFillLogQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetHostmapDefinitionRequestFillLogQueryComputeQuery], jsii.get(self, "computeQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="groupByInput")
    def group_by_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestFillLogQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestFillLogQueryGroupBy]]], jsii.get(self, "groupByInput"))

    @builtins.property
    @jsii.member(jsii_name="indexInput")
    def index_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "indexInput"))

    @builtins.property
    @jsii.member(jsii_name="multiComputeInput")
    def multi_compute_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestFillLogQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestFillLogQueryMultiCompute]]], jsii.get(self, "multiComputeInput"))

    @builtins.property
    @jsii.member(jsii_name="searchQueryInput")
    def search_query_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "searchQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="index")
    def index(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "index"))

    @index.setter
    def index(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1475bb6525f9d19b68ef3f41ce565c90a2dfa788d9428ed9268f2c89464422fa)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "index", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="searchQuery")
    def search_query(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "searchQuery"))

    @search_query.setter
    def search_query(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__acba247e74e15331f1c1255928440dd8404fc1036df58195be98ba544ae1f532)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "searchQuery", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetHostmapDefinitionRequestFillLogQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetHostmapDefinitionRequestFillLogQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetHostmapDefinitionRequestFillLogQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__681581ea7b39abb7b8040e76c3b61cbeba4f4f744fa58e8b7d38eea30a4e25da)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetHostmapDefinitionRequestFillOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestFillOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__717bd26e2cea7d318778cf43234395fa20b59d018e7bf1efea6b783cf06ed396)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putApmQuery")
    def put_apm_query(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union[PowerpackWidgetHostmapDefinitionRequestFillApmQueryComputeQuery, typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHostmapDefinitionRequestFillApmQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHostmapDefinitionRequestFillApmQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        value = PowerpackWidgetHostmapDefinitionRequestFillApmQuery(
            index=index,
            compute_query=compute_query,
            group_by=group_by,
            multi_compute=multi_compute,
            search_query=search_query,
        )

        return typing.cast(None, jsii.invoke(self, "putApmQuery", [value]))

    @jsii.member(jsii_name="putLogQuery")
    def put_log_query(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union[PowerpackWidgetHostmapDefinitionRequestFillLogQueryComputeQuery, typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHostmapDefinitionRequestFillLogQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHostmapDefinitionRequestFillLogQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        value = PowerpackWidgetHostmapDefinitionRequestFillLogQuery(
            index=index,
            compute_query=compute_query,
            group_by=group_by,
            multi_compute=multi_compute,
            search_query=search_query,
        )

        return typing.cast(None, jsii.invoke(self, "putLogQuery", [value]))

    @jsii.member(jsii_name="putProcessQuery")
    def put_process_query(
        self,
        *,
        metric: builtins.str,
        filter_by: typing.Optional[typing.Sequence[builtins.str]] = None,
        limit: typing.Optional[jsii.Number] = None,
        search_by: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param metric: Your chosen metric. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        :param filter_by: A list of processes. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#filter_by Powerpack#filter_by}
        :param limit: The max number of items in the filter list. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param search_by: Your chosen search term. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_by Powerpack#search_by}
        '''
        value = PowerpackWidgetHostmapDefinitionRequestFillProcessQuery(
            metric=metric, filter_by=filter_by, limit=limit, search_by=search_by
        )

        return typing.cast(None, jsii.invoke(self, "putProcessQuery", [value]))

    @jsii.member(jsii_name="putRumQuery")
    def put_rum_query(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union["PowerpackWidgetHostmapDefinitionRequestFillRumQueryComputeQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetHostmapDefinitionRequestFillRumQueryGroupBy", typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetHostmapDefinitionRequestFillRumQueryMultiCompute", typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        value = PowerpackWidgetHostmapDefinitionRequestFillRumQuery(
            index=index,
            compute_query=compute_query,
            group_by=group_by,
            multi_compute=multi_compute,
            search_query=search_query,
        )

        return typing.cast(None, jsii.invoke(self, "putRumQuery", [value]))

    @jsii.member(jsii_name="putSecurityQuery")
    def put_security_query(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union["PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryComputeQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryGroupBy", typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryMultiCompute", typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        value = PowerpackWidgetHostmapDefinitionRequestFillSecurityQuery(
            index=index,
            compute_query=compute_query,
            group_by=group_by,
            multi_compute=multi_compute,
            search_query=search_query,
        )

        return typing.cast(None, jsii.invoke(self, "putSecurityQuery", [value]))

    @jsii.member(jsii_name="resetApmQuery")
    def reset_apm_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetApmQuery", []))

    @jsii.member(jsii_name="resetLogQuery")
    def reset_log_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLogQuery", []))

    @jsii.member(jsii_name="resetProcessQuery")
    def reset_process_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetProcessQuery", []))

    @jsii.member(jsii_name="resetQ")
    def reset_q(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetQ", []))

    @jsii.member(jsii_name="resetRumQuery")
    def reset_rum_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetRumQuery", []))

    @jsii.member(jsii_name="resetSecurityQuery")
    def reset_security_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSecurityQuery", []))

    @builtins.property
    @jsii.member(jsii_name="apmQuery")
    def apm_query(
        self,
    ) -> PowerpackWidgetHostmapDefinitionRequestFillApmQueryOutputReference:
        return typing.cast(PowerpackWidgetHostmapDefinitionRequestFillApmQueryOutputReference, jsii.get(self, "apmQuery"))

    @builtins.property
    @jsii.member(jsii_name="logQuery")
    def log_query(
        self,
    ) -> PowerpackWidgetHostmapDefinitionRequestFillLogQueryOutputReference:
        return typing.cast(PowerpackWidgetHostmapDefinitionRequestFillLogQueryOutputReference, jsii.get(self, "logQuery"))

    @builtins.property
    @jsii.member(jsii_name="processQuery")
    def process_query(
        self,
    ) -> "PowerpackWidgetHostmapDefinitionRequestFillProcessQueryOutputReference":
        return typing.cast("PowerpackWidgetHostmapDefinitionRequestFillProcessQueryOutputReference", jsii.get(self, "processQuery"))

    @builtins.property
    @jsii.member(jsii_name="rumQuery")
    def rum_query(
        self,
    ) -> "PowerpackWidgetHostmapDefinitionRequestFillRumQueryOutputReference":
        return typing.cast("PowerpackWidgetHostmapDefinitionRequestFillRumQueryOutputReference", jsii.get(self, "rumQuery"))

    @builtins.property
    @jsii.member(jsii_name="securityQuery")
    def security_query(
        self,
    ) -> "PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryOutputReference":
        return typing.cast("PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryOutputReference", jsii.get(self, "securityQuery"))

    @builtins.property
    @jsii.member(jsii_name="apmQueryInput")
    def apm_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetHostmapDefinitionRequestFillApmQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetHostmapDefinitionRequestFillApmQuery], jsii.get(self, "apmQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="logQueryInput")
    def log_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetHostmapDefinitionRequestFillLogQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetHostmapDefinitionRequestFillLogQuery], jsii.get(self, "logQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="processQueryInput")
    def process_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetHostmapDefinitionRequestFillProcessQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetHostmapDefinitionRequestFillProcessQuery"], jsii.get(self, "processQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="qInput")
    def q_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "qInput"))

    @builtins.property
    @jsii.member(jsii_name="rumQueryInput")
    def rum_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetHostmapDefinitionRequestFillRumQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetHostmapDefinitionRequestFillRumQuery"], jsii.get(self, "rumQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="securityQueryInput")
    def security_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetHostmapDefinitionRequestFillSecurityQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetHostmapDefinitionRequestFillSecurityQuery"], jsii.get(self, "securityQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="q")
    def q(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "q"))

    @q.setter
    def q(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1e14f849f248ea0641aeeb874e1a834c4552b1a804f2fe5a9fb7ca8c195e74d9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "q", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHostmapDefinitionRequestFill]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHostmapDefinitionRequestFill]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHostmapDefinitionRequestFill]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__591fa03e3359fd5e6c288bd133b8bde36100b630693963f92f037e426a6ca84b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestFillProcessQuery",
    jsii_struct_bases=[],
    name_mapping={
        "metric": "metric",
        "filter_by": "filterBy",
        "limit": "limit",
        "search_by": "searchBy",
    },
)
class PowerpackWidgetHostmapDefinitionRequestFillProcessQuery:
    def __init__(
        self,
        *,
        metric: builtins.str,
        filter_by: typing.Optional[typing.Sequence[builtins.str]] = None,
        limit: typing.Optional[jsii.Number] = None,
        search_by: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param metric: Your chosen metric. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        :param filter_by: A list of processes. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#filter_by Powerpack#filter_by}
        :param limit: The max number of items in the filter list. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param search_by: Your chosen search term. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_by Powerpack#search_by}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8169d3d5c24ef5ee9cf6ceb518b7f5642c2fa7d4ed52f45a512c12535946f5e7)
            check_type(argname="argument metric", value=metric, expected_type=type_hints["metric"])
            check_type(argname="argument filter_by", value=filter_by, expected_type=type_hints["filter_by"])
            check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
            check_type(argname="argument search_by", value=search_by, expected_type=type_hints["search_by"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "metric": metric,
        }
        if filter_by is not None:
            self._values["filter_by"] = filter_by
        if limit is not None:
            self._values["limit"] = limit
        if search_by is not None:
            self._values["search_by"] = search_by

    @builtins.property
    def metric(self) -> builtins.str:
        '''Your chosen metric.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        '''
        result = self._values.get("metric")
        assert result is not None, "Required property 'metric' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def filter_by(self) -> typing.Optional[typing.List[builtins.str]]:
        '''A list of processes.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#filter_by Powerpack#filter_by}
        '''
        result = self._values.get("filter_by")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def limit(self) -> typing.Optional[jsii.Number]:
        '''The max number of items in the filter list.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        '''
        result = self._values.get("limit")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def search_by(self) -> typing.Optional[builtins.str]:
        '''Your chosen search term.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_by Powerpack#search_by}
        '''
        result = self._values.get("search_by")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetHostmapDefinitionRequestFillProcessQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetHostmapDefinitionRequestFillProcessQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestFillProcessQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bc0722b3b8172d454a78042c49b0173a011ed709337c48e9be716ce988fbeefe)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFilterBy")
    def reset_filter_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFilterBy", []))

    @jsii.member(jsii_name="resetLimit")
    def reset_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLimit", []))

    @jsii.member(jsii_name="resetSearchBy")
    def reset_search_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSearchBy", []))

    @builtins.property
    @jsii.member(jsii_name="filterByInput")
    def filter_by_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "filterByInput"))

    @builtins.property
    @jsii.member(jsii_name="limitInput")
    def limit_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "limitInput"))

    @builtins.property
    @jsii.member(jsii_name="metricInput")
    def metric_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "metricInput"))

    @builtins.property
    @jsii.member(jsii_name="searchByInput")
    def search_by_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "searchByInput"))

    @builtins.property
    @jsii.member(jsii_name="filterBy")
    def filter_by(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "filterBy"))

    @filter_by.setter
    def filter_by(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b037af6c9496bbb4e4c9577d0433d45ae29a0abc8d91b2b2130d0e956347795d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "filterBy", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="limit")
    def limit(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "limit"))

    @limit.setter
    def limit(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8966636ec8090e53a23e891234b86f6f40dae33ad6019da203f980b193009246)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "limit", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="metric")
    def metric(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "metric"))

    @metric.setter
    def metric(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__eddb35e9bafcf44d95952d9dbe001aa792128726e109849d3ff373e8bea9f5d7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "metric", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="searchBy")
    def search_by(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "searchBy"))

    @search_by.setter
    def search_by(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7c2324ec43344d1695c5aefbd3923fa038ee64fc946466a89eaaa47273d7e0b4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "searchBy", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetHostmapDefinitionRequestFillProcessQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetHostmapDefinitionRequestFillProcessQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetHostmapDefinitionRequestFillProcessQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__040d783e6561995fc62f1856fc26b82f27376d3ed5062f41755dc002c5338978)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestFillRumQuery",
    jsii_struct_bases=[],
    name_mapping={
        "index": "index",
        "compute_query": "computeQuery",
        "group_by": "groupBy",
        "multi_compute": "multiCompute",
        "search_query": "searchQuery",
    },
)
class PowerpackWidgetHostmapDefinitionRequestFillRumQuery:
    def __init__(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union["PowerpackWidgetHostmapDefinitionRequestFillRumQueryComputeQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetHostmapDefinitionRequestFillRumQueryGroupBy", typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetHostmapDefinitionRequestFillRumQueryMultiCompute", typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        if isinstance(compute_query, dict):
            compute_query = PowerpackWidgetHostmapDefinitionRequestFillRumQueryComputeQuery(**compute_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__81366e5aefbd7bf48b6e069935106fcee879588e4a5ad611faf46dcb1deb4d85)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
            check_type(argname="argument compute_query", value=compute_query, expected_type=type_hints["compute_query"])
            check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
            check_type(argname="argument multi_compute", value=multi_compute, expected_type=type_hints["multi_compute"])
            check_type(argname="argument search_query", value=search_query, expected_type=type_hints["search_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "index": index,
        }
        if compute_query is not None:
            self._values["compute_query"] = compute_query
        if group_by is not None:
            self._values["group_by"] = group_by
        if multi_compute is not None:
            self._values["multi_compute"] = multi_compute
        if search_query is not None:
            self._values["search_query"] = search_query

    @builtins.property
    def index(self) -> builtins.str:
        '''The name of the index to query.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        '''
        result = self._values.get("index")
        assert result is not None, "Required property 'index' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def compute_query(
        self,
    ) -> typing.Optional["PowerpackWidgetHostmapDefinitionRequestFillRumQueryComputeQuery"]:
        '''compute_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        '''
        result = self._values.get("compute_query")
        return typing.cast(typing.Optional["PowerpackWidgetHostmapDefinitionRequestFillRumQueryComputeQuery"], result)

    @builtins.property
    def group_by(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetHostmapDefinitionRequestFillRumQueryGroupBy"]]]:
        '''group_by block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        '''
        result = self._values.get("group_by")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetHostmapDefinitionRequestFillRumQueryGroupBy"]]], result)

    @builtins.property
    def multi_compute(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetHostmapDefinitionRequestFillRumQueryMultiCompute"]]]:
        '''multi_compute block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        '''
        result = self._values.get("multi_compute")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetHostmapDefinitionRequestFillRumQueryMultiCompute"]]], result)

    @builtins.property
    def search_query(self) -> typing.Optional[builtins.str]:
        '''The search query to use.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        result = self._values.get("search_query")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetHostmapDefinitionRequestFillRumQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestFillRumQueryComputeQuery",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetHostmapDefinitionRequestFillRumQueryComputeQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5945af29cbf4710cc63c82a12db89d9ef0cd6b133a0f11eb4a3a77f987bada7b)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetHostmapDefinitionRequestFillRumQueryComputeQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetHostmapDefinitionRequestFillRumQueryComputeQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestFillRumQueryComputeQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1db23e21898b8b58e8113d81129954c72847db3bc95a456cfb13db453b74cb09)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2c30c761108b5f9308686e24d2c1a4c683bda1649dd34583b45dbfa65f67e804)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9f2fcc940a6a7e6ca701f089bd56007b0f90f7a3c11c22d9b8ab2a5d2ae29bb6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__eb541e8e7f9f1bb4020933ee3abf09b01f0d9f3825251679863da0db208dd90b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetHostmapDefinitionRequestFillRumQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetHostmapDefinitionRequestFillRumQueryComputeQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetHostmapDefinitionRequestFillRumQueryComputeQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b03a7f7552390e62d12d7865f4cfb45c6445496fb8c7691aee405ea68dd6f1f1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestFillRumQueryGroupBy",
    jsii_struct_bases=[],
    name_mapping={"facet": "facet", "limit": "limit", "sort_query": "sortQuery"},
)
class PowerpackWidgetHostmapDefinitionRequestFillRumQueryGroupBy:
    def __init__(
        self,
        *,
        facet: typing.Optional[builtins.str] = None,
        limit: typing.Optional[jsii.Number] = None,
        sort_query: typing.Optional[typing.Union["PowerpackWidgetHostmapDefinitionRequestFillRumQueryGroupBySortQuery", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param limit: The maximum number of items in the group. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param sort_query: sort_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        if isinstance(sort_query, dict):
            sort_query = PowerpackWidgetHostmapDefinitionRequestFillRumQueryGroupBySortQuery(**sort_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1e74ad9de40702945a6ca7bcd07d2bd3af013a3c9b26a92cda42c055fe5c1f42)
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
            check_type(argname="argument sort_query", value=sort_query, expected_type=type_hints["sort_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if facet is not None:
            self._values["facet"] = facet
        if limit is not None:
            self._values["limit"] = limit
        if sort_query is not None:
            self._values["sort_query"] = sort_query

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def limit(self) -> typing.Optional[jsii.Number]:
        '''The maximum number of items in the group.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        '''
        result = self._values.get("limit")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def sort_query(
        self,
    ) -> typing.Optional["PowerpackWidgetHostmapDefinitionRequestFillRumQueryGroupBySortQuery"]:
        '''sort_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        result = self._values.get("sort_query")
        return typing.cast(typing.Optional["PowerpackWidgetHostmapDefinitionRequestFillRumQueryGroupBySortQuery"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetHostmapDefinitionRequestFillRumQueryGroupBy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetHostmapDefinitionRequestFillRumQueryGroupByList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestFillRumQueryGroupByList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__972bffc5767b6ce1ac93ec1f1093c059f5bad9139338d4c4ec159252d554a2a0)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetHostmapDefinitionRequestFillRumQueryGroupByOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ea7989fb609929c65e76c1c64800fb0cdba3caa5deda242345a5b669df4514e8)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetHostmapDefinitionRequestFillRumQueryGroupByOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__342c9bc55e383f2f2a093e95f9eb645caae7945a6ba95cd988cc5bfedc6cb8e5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a4d30095425c031e3cc90f4a3a8657beb7843fc4eaf38ea3508b9f3bc9243776)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b60e4686fceb7ab1535e1ee03305d439043def0ad085fe50b510f5d6d1e264a3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestFillRumQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestFillRumQueryGroupBy]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestFillRumQueryGroupBy]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b3d99ead1d82b81b24827958baa2f480b1bece1fbdb865ca9be2baffeb2ad8e2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetHostmapDefinitionRequestFillRumQueryGroupByOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestFillRumQueryGroupByOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f76aa1f5ee1ac23f5fe5c76984d6da07e6cf6fdc237b7afd298fa81a5527d94c)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putSortQuery")
    def put_sort_query(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        value = PowerpackWidgetHostmapDefinitionRequestFillRumQueryGroupBySortQuery(
            aggregation=aggregation, order=order, facet=facet
        )

        return typing.cast(None, jsii.invoke(self, "putSortQuery", [value]))

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetLimit")
    def reset_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLimit", []))

    @jsii.member(jsii_name="resetSortQuery")
    def reset_sort_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSortQuery", []))

    @builtins.property
    @jsii.member(jsii_name="sortQuery")
    def sort_query(
        self,
    ) -> "PowerpackWidgetHostmapDefinitionRequestFillRumQueryGroupBySortQueryOutputReference":
        return typing.cast("PowerpackWidgetHostmapDefinitionRequestFillRumQueryGroupBySortQueryOutputReference", jsii.get(self, "sortQuery"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="limitInput")
    def limit_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "limitInput"))

    @builtins.property
    @jsii.member(jsii_name="sortQueryInput")
    def sort_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetHostmapDefinitionRequestFillRumQueryGroupBySortQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetHostmapDefinitionRequestFillRumQueryGroupBySortQuery"], jsii.get(self, "sortQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9093069a3e68dfdc9776bb6a22d0f6160d98fb7c8f71fe173b74eb03c2a96065)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="limit")
    def limit(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "limit"))

    @limit.setter
    def limit(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4b8277385abf223f19d61ca0b3c75643f7228b1b16181e5f64143a47d6fc8614)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "limit", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHostmapDefinitionRequestFillRumQueryGroupBy]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHostmapDefinitionRequestFillRumQueryGroupBy]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHostmapDefinitionRequestFillRumQueryGroupBy]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d2b2bc769645dda32b0a8654adb7b96024e8c506936a4365617d7c61524883f6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestFillRumQueryGroupBySortQuery",
    jsii_struct_bases=[],
    name_mapping={"aggregation": "aggregation", "order": "order", "facet": "facet"},
)
class PowerpackWidgetHostmapDefinitionRequestFillRumQueryGroupBySortQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bdc368fea38af0fb1ac97abfba902e0eb5d06e22c214d589cdc64da3f4296a03)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument order", value=order, expected_type=type_hints["order"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
            "order": order,
        }
        if facet is not None:
            self._values["facet"] = facet

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def order(self) -> builtins.str:
        '''Widget sorting methods. Valid values are ``asc``, ``desc``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        result = self._values.get("order")
        assert result is not None, "Required property 'order' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetHostmapDefinitionRequestFillRumQueryGroupBySortQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetHostmapDefinitionRequestFillRumQueryGroupBySortQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestFillRumQueryGroupBySortQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6f17a7f16005ea6f1a37aad5dba234ac3316662bfcc7c1cae44418086277d41a)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="orderInput")
    def order_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "orderInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d410a47c1a0240fe236ec5bfdbaa7151e99f74c778433fd5ffa4b18776479bce)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__64f6019ab5349e3e6b69727260c558def1161abac191568e9e0379ffcb0e73c7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="order")
    def order(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "order"))

    @order.setter
    def order(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__64d28d921d297fb3fcba6a02ad815cd817228afd82b20b0fe20f764774c1fff5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "order", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetHostmapDefinitionRequestFillRumQueryGroupBySortQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetHostmapDefinitionRequestFillRumQueryGroupBySortQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetHostmapDefinitionRequestFillRumQueryGroupBySortQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__929b1805014dc096a24c8a36ae130147484fee87702780cc296779867b456d49)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestFillRumQueryMultiCompute",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetHostmapDefinitionRequestFillRumQueryMultiCompute:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__44bdddb1abd2020c62991ade8265db8f84057fda6edade92d7bfcb0cad937ce8)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetHostmapDefinitionRequestFillRumQueryMultiCompute(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetHostmapDefinitionRequestFillRumQueryMultiComputeList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestFillRumQueryMultiComputeList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__17c0cc5f0aac89ed54242ba2b30a96e8df50d9a2971ef8cc3ca80984c7c33fc7)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetHostmapDefinitionRequestFillRumQueryMultiComputeOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2771fa41ad4a9988634bc2d76a2153d33499028fc2cba9726bcbc5edcde9d737)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetHostmapDefinitionRequestFillRumQueryMultiComputeOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__78c4c131f8f34c738b58812bf354a04b8569f465e1cee7317590c082716de277)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__494effcccafd546b3130ee3b11efbe07306a9ed6a9ae8749bb0fc5609349106e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__96e045cca7210325fc53df4b2f60cad03b7e0619cbc4a959085e897f8c5d2b6e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestFillRumQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestFillRumQueryMultiCompute]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestFillRumQueryMultiCompute]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d20451e30eda5b91073de16979d84bdd21c872585d6099beea7987222ae4370b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetHostmapDefinitionRequestFillRumQueryMultiComputeOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestFillRumQueryMultiComputeOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__62c9ae30d72249b777c323b8d46fa4e91c0baa8446748e6010fa699504f6602d)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e92bc0535908cb527ed273ec9588521b89f16d80c31667f24b41730ed7c388de)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dee396142abcaf780506d71c4c6f898c700a175dfb1f54d5001099b26e2ff757)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a2d2781a291525226251b06508b7c866e2cb5567421fe80197855b325fafed4a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHostmapDefinitionRequestFillRumQueryMultiCompute]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHostmapDefinitionRequestFillRumQueryMultiCompute]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHostmapDefinitionRequestFillRumQueryMultiCompute]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__46786a9ba01c5f73e0bf5b1689da800808a19cdfad2c79c9a74e5dd8cebbab16)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetHostmapDefinitionRequestFillRumQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestFillRumQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d82a714663490a512922e07fdd1497452f2a32ce4ca29847ecf5ae620db4c1c8)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putComputeQuery")
    def put_compute_query(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        value = PowerpackWidgetHostmapDefinitionRequestFillRumQueryComputeQuery(
            aggregation=aggregation, facet=facet, interval=interval
        )

        return typing.cast(None, jsii.invoke(self, "putComputeQuery", [value]))

    @jsii.member(jsii_name="putGroupBy")
    def put_group_by(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHostmapDefinitionRequestFillRumQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__716da044d748e5d2ac0741f4e2c40b66d8aab2602542fbcb2706c191e7baa031)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putGroupBy", [value]))

    @jsii.member(jsii_name="putMultiCompute")
    def put_multi_compute(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHostmapDefinitionRequestFillRumQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4de97775d236e5d19fe5c24208db8fe1673b0d427758a34cc3ed7a798e2fe914)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putMultiCompute", [value]))

    @jsii.member(jsii_name="resetComputeQuery")
    def reset_compute_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetComputeQuery", []))

    @jsii.member(jsii_name="resetGroupBy")
    def reset_group_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGroupBy", []))

    @jsii.member(jsii_name="resetMultiCompute")
    def reset_multi_compute(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMultiCompute", []))

    @jsii.member(jsii_name="resetSearchQuery")
    def reset_search_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSearchQuery", []))

    @builtins.property
    @jsii.member(jsii_name="computeQuery")
    def compute_query(
        self,
    ) -> PowerpackWidgetHostmapDefinitionRequestFillRumQueryComputeQueryOutputReference:
        return typing.cast(PowerpackWidgetHostmapDefinitionRequestFillRumQueryComputeQueryOutputReference, jsii.get(self, "computeQuery"))

    @builtins.property
    @jsii.member(jsii_name="groupBy")
    def group_by(
        self,
    ) -> PowerpackWidgetHostmapDefinitionRequestFillRumQueryGroupByList:
        return typing.cast(PowerpackWidgetHostmapDefinitionRequestFillRumQueryGroupByList, jsii.get(self, "groupBy"))

    @builtins.property
    @jsii.member(jsii_name="multiCompute")
    def multi_compute(
        self,
    ) -> PowerpackWidgetHostmapDefinitionRequestFillRumQueryMultiComputeList:
        return typing.cast(PowerpackWidgetHostmapDefinitionRequestFillRumQueryMultiComputeList, jsii.get(self, "multiCompute"))

    @builtins.property
    @jsii.member(jsii_name="computeQueryInput")
    def compute_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetHostmapDefinitionRequestFillRumQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetHostmapDefinitionRequestFillRumQueryComputeQuery], jsii.get(self, "computeQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="groupByInput")
    def group_by_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestFillRumQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestFillRumQueryGroupBy]]], jsii.get(self, "groupByInput"))

    @builtins.property
    @jsii.member(jsii_name="indexInput")
    def index_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "indexInput"))

    @builtins.property
    @jsii.member(jsii_name="multiComputeInput")
    def multi_compute_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestFillRumQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestFillRumQueryMultiCompute]]], jsii.get(self, "multiComputeInput"))

    @builtins.property
    @jsii.member(jsii_name="searchQueryInput")
    def search_query_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "searchQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="index")
    def index(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "index"))

    @index.setter
    def index(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7d8aa57f85e2fb71063f8f416529addda0a49e5294d15bbb50849034c0ca8cc0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "index", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="searchQuery")
    def search_query(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "searchQuery"))

    @search_query.setter
    def search_query(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d1ab1110be3788073f20b19c4c99a94d544e6514762786af0b8e7d89b8e6dc97)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "searchQuery", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetHostmapDefinitionRequestFillRumQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetHostmapDefinitionRequestFillRumQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetHostmapDefinitionRequestFillRumQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ae68fd5c5d0e43d483d039c9a37bc5d2f354b4a73527f3736ac6c8cd012e1955)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestFillSecurityQuery",
    jsii_struct_bases=[],
    name_mapping={
        "index": "index",
        "compute_query": "computeQuery",
        "group_by": "groupBy",
        "multi_compute": "multiCompute",
        "search_query": "searchQuery",
    },
)
class PowerpackWidgetHostmapDefinitionRequestFillSecurityQuery:
    def __init__(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union["PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryComputeQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryGroupBy", typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryMultiCompute", typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        if isinstance(compute_query, dict):
            compute_query = PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryComputeQuery(**compute_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0393d09c939789f442079f4d1ced404b91d299ebcbd05d514131601b80698a46)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
            check_type(argname="argument compute_query", value=compute_query, expected_type=type_hints["compute_query"])
            check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
            check_type(argname="argument multi_compute", value=multi_compute, expected_type=type_hints["multi_compute"])
            check_type(argname="argument search_query", value=search_query, expected_type=type_hints["search_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "index": index,
        }
        if compute_query is not None:
            self._values["compute_query"] = compute_query
        if group_by is not None:
            self._values["group_by"] = group_by
        if multi_compute is not None:
            self._values["multi_compute"] = multi_compute
        if search_query is not None:
            self._values["search_query"] = search_query

    @builtins.property
    def index(self) -> builtins.str:
        '''The name of the index to query.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        '''
        result = self._values.get("index")
        assert result is not None, "Required property 'index' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def compute_query(
        self,
    ) -> typing.Optional["PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryComputeQuery"]:
        '''compute_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        '''
        result = self._values.get("compute_query")
        return typing.cast(typing.Optional["PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryComputeQuery"], result)

    @builtins.property
    def group_by(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryGroupBy"]]]:
        '''group_by block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        '''
        result = self._values.get("group_by")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryGroupBy"]]], result)

    @builtins.property
    def multi_compute(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryMultiCompute"]]]:
        '''multi_compute block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        '''
        result = self._values.get("multi_compute")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryMultiCompute"]]], result)

    @builtins.property
    def search_query(self) -> typing.Optional[builtins.str]:
        '''The search query to use.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        result = self._values.get("search_query")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetHostmapDefinitionRequestFillSecurityQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryComputeQuery",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryComputeQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__18ce7cf28d7ec03926c0c86acabb9d3ffcc7e4803adda54be0023aa81d53d375)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryComputeQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryComputeQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryComputeQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6d05c08c4732edd4d3efa77426a88c842a181b26e8e0d70bdb5bbaefe36c7176)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0da8d30831e8f0f04172b93fdc2bbf70c15fc9ee8db953602f187ecd85ff27d8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__93a6b5c1c5a046fd86503254cf7eae6356b49bef2d7cdeaf7c47dd3afb8121ec)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0eeb94867905e34fd192f2be8eb2f4a3a20c5e919fabd45dd85156e759e55830)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryComputeQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryComputeQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a611500346f930725bf8f9708ac9c4f9e3555691ee31c5d58f66dc31e9a0a710)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryGroupBy",
    jsii_struct_bases=[],
    name_mapping={"facet": "facet", "limit": "limit", "sort_query": "sortQuery"},
)
class PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryGroupBy:
    def __init__(
        self,
        *,
        facet: typing.Optional[builtins.str] = None,
        limit: typing.Optional[jsii.Number] = None,
        sort_query: typing.Optional[typing.Union["PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryGroupBySortQuery", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param limit: The maximum number of items in the group. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param sort_query: sort_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        if isinstance(sort_query, dict):
            sort_query = PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryGroupBySortQuery(**sort_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__50664a0f193bf766da8870e98600916d8a166221d36081d9606ad5f9b3f53a79)
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
            check_type(argname="argument sort_query", value=sort_query, expected_type=type_hints["sort_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if facet is not None:
            self._values["facet"] = facet
        if limit is not None:
            self._values["limit"] = limit
        if sort_query is not None:
            self._values["sort_query"] = sort_query

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def limit(self) -> typing.Optional[jsii.Number]:
        '''The maximum number of items in the group.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        '''
        result = self._values.get("limit")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def sort_query(
        self,
    ) -> typing.Optional["PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryGroupBySortQuery"]:
        '''sort_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        result = self._values.get("sort_query")
        return typing.cast(typing.Optional["PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryGroupBySortQuery"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryGroupBy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryGroupByList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryGroupByList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__060ff07c872f28f92d2b8d591c3dad9baea7e03ef5d458bdc61cdb6d8dd3fad3)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryGroupByOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f1388994e77976b3683973bf29a083bd7bde9e3cd86163f05c936c5c15094c41)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryGroupByOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__95a7d5f33f6571fe36db403af7e440c1ae4e167ce4ccaaff554689d4e4676897)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6b49f415609f9f2daf5e6a12fc852954a51dd4173622cffb8fbe31c09af4c297)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__170b1265c0c6377ce37736b6dfa3c3a20053a7734c0cc47fbbe6890914df5540)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryGroupBy]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryGroupBy]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__078ae5a7beb946e253480897f157b85fb2dd96a935d9eee36cd206aedd4af5e0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryGroupByOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryGroupByOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__09070f5e8946ba29a184168fe77483e96b1eb920195af3bf1cdbf4fa1e40720d)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putSortQuery")
    def put_sort_query(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        value = PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryGroupBySortQuery(
            aggregation=aggregation, order=order, facet=facet
        )

        return typing.cast(None, jsii.invoke(self, "putSortQuery", [value]))

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetLimit")
    def reset_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLimit", []))

    @jsii.member(jsii_name="resetSortQuery")
    def reset_sort_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSortQuery", []))

    @builtins.property
    @jsii.member(jsii_name="sortQuery")
    def sort_query(
        self,
    ) -> "PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryGroupBySortQueryOutputReference":
        return typing.cast("PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryGroupBySortQueryOutputReference", jsii.get(self, "sortQuery"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="limitInput")
    def limit_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "limitInput"))

    @builtins.property
    @jsii.member(jsii_name="sortQueryInput")
    def sort_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryGroupBySortQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryGroupBySortQuery"], jsii.get(self, "sortQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4dc7dd5e103417823ea793060ac34f170dcfbd9ea941a865cec4b19d19d211c7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="limit")
    def limit(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "limit"))

    @limit.setter
    def limit(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5995b646650a1b96fdfa3c0d37f5b5d49b13d36623207873fae6fb4a23d906ab)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "limit", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryGroupBy]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryGroupBy]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryGroupBy]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__be537967b7ef5963133e74ef0df7490e18414629ef796b9a24ba4d9269976581)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryGroupBySortQuery",
    jsii_struct_bases=[],
    name_mapping={"aggregation": "aggregation", "order": "order", "facet": "facet"},
)
class PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryGroupBySortQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3ae386bd8386fa641e7df89a5de6538e0d88add836310f7bca54ddc4ab0f437c)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument order", value=order, expected_type=type_hints["order"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
            "order": order,
        }
        if facet is not None:
            self._values["facet"] = facet

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def order(self) -> builtins.str:
        '''Widget sorting methods. Valid values are ``asc``, ``desc``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        result = self._values.get("order")
        assert result is not None, "Required property 'order' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryGroupBySortQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryGroupBySortQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryGroupBySortQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c68778a9ea457dd078b2e3f39fe495044de9ee81cafc4e188ece02e0ac1455d6)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="orderInput")
    def order_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "orderInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__901e672c171c15690703986b681a3d4d3566b404fd3408edd4f2f4280f8ead75)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7b9128023f325d8283db6e6e52596a9d2c733a7b331d30d1e8470a8e2cc6232c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="order")
    def order(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "order"))

    @order.setter
    def order(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__01a53007c12f49f95a38c070352905a7dcd6924e71decaed549ff3a1b886d59c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "order", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryGroupBySortQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryGroupBySortQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryGroupBySortQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e4f1f09c30023721b0c7955d3b0f02746875d4265d367e14cf5d6c728dc81914)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryMultiCompute",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryMultiCompute:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b0594908a176ed770bf2420457f46af5fbeeffa26c54f965321c565f723a77b5)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryMultiCompute(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryMultiComputeList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryMultiComputeList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__aaaee644869782536c2e0dba8da09e504e2911b73bfe7c3b0e2543e638f32da0)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryMultiComputeOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dcb7d1ec78c4902599f02982c1cb937eaea0209d07f879de7ea5aadd6d93f657)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryMultiComputeOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__113f6187b8da135ca98fe47e7c5ccba91c96709ee9a11cc5cf5932e250ee351e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b7d6ff3e2837b4ad6188323b61ffdefbab897ff5b5fc571cd51b70a9abfbf114)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8f9d25f3035f661ee6f25dcc6847c066d9da48a18b686268f9609d9948515ebc)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryMultiCompute]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryMultiCompute]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1ba683f00d5d1e39977614a3b13f4583b6de5cba18b2cb9b695ba5fbad164d00)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryMultiComputeOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryMultiComputeOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__eb42257ecb6a8fba7a2c60bdf554450667b2fae960c2983322f6007015e57b5e)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f91d69181c3d251d94723b1bdb034e2d9e72898b4e6bbf7600646c70d8e0914d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__923d664dae3879f99a9e940bfb97d1010c227fcd1de704a0571da0fa60cb4a97)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c262e8c7f83e68813ea144e92e9e84011b59d777794710ba296e7072ee604e1a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryMultiCompute]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryMultiCompute]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryMultiCompute]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3f246d29341922789577b61b713ecbbfaa2d4c1a4e9ef255f7c24dfdd3d9c8bc)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__59d6d8fb920ea993e63e9eae9cfe0cc27b7b04c2f051eb0829ac96b71ff8dc57)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putComputeQuery")
    def put_compute_query(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        value = PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryComputeQuery(
            aggregation=aggregation, facet=facet, interval=interval
        )

        return typing.cast(None, jsii.invoke(self, "putComputeQuery", [value]))

    @jsii.member(jsii_name="putGroupBy")
    def put_group_by(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__aae15b80ca22ef5c11589ca4d909f2d2369c7575ec0f17f01eb184a9c0b244b1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putGroupBy", [value]))

    @jsii.member(jsii_name="putMultiCompute")
    def put_multi_compute(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ebbc20f3874aa0c089fb3af344ea024b57f3fc0f447a6d5f298419221ffbca57)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putMultiCompute", [value]))

    @jsii.member(jsii_name="resetComputeQuery")
    def reset_compute_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetComputeQuery", []))

    @jsii.member(jsii_name="resetGroupBy")
    def reset_group_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGroupBy", []))

    @jsii.member(jsii_name="resetMultiCompute")
    def reset_multi_compute(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMultiCompute", []))

    @jsii.member(jsii_name="resetSearchQuery")
    def reset_search_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSearchQuery", []))

    @builtins.property
    @jsii.member(jsii_name="computeQuery")
    def compute_query(
        self,
    ) -> PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryComputeQueryOutputReference:
        return typing.cast(PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryComputeQueryOutputReference, jsii.get(self, "computeQuery"))

    @builtins.property
    @jsii.member(jsii_name="groupBy")
    def group_by(
        self,
    ) -> PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryGroupByList:
        return typing.cast(PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryGroupByList, jsii.get(self, "groupBy"))

    @builtins.property
    @jsii.member(jsii_name="multiCompute")
    def multi_compute(
        self,
    ) -> PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryMultiComputeList:
        return typing.cast(PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryMultiComputeList, jsii.get(self, "multiCompute"))

    @builtins.property
    @jsii.member(jsii_name="computeQueryInput")
    def compute_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryComputeQuery], jsii.get(self, "computeQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="groupByInput")
    def group_by_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryGroupBy]]], jsii.get(self, "groupByInput"))

    @builtins.property
    @jsii.member(jsii_name="indexInput")
    def index_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "indexInput"))

    @builtins.property
    @jsii.member(jsii_name="multiComputeInput")
    def multi_compute_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryMultiCompute]]], jsii.get(self, "multiComputeInput"))

    @builtins.property
    @jsii.member(jsii_name="searchQueryInput")
    def search_query_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "searchQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="index")
    def index(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "index"))

    @index.setter
    def index(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__45922bf09c97655f5b8a4408177fcb3b21834409858dd180fafdba69559ec854)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "index", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="searchQuery")
    def search_query(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "searchQuery"))

    @search_query.setter
    def search_query(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fc3888ef2cd31d88530fba77d12c3c32211ecdc6d378b24ab4bb7464e14a65f1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "searchQuery", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetHostmapDefinitionRequestFillSecurityQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetHostmapDefinitionRequestFillSecurityQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetHostmapDefinitionRequestFillSecurityQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2a87644968baef047518413ce4cfa44f5ef9eff1a9cb9025054c313d987e2382)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetHostmapDefinitionRequestOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__395a75e3c1a635a8a775b2b3b768d44ce546bbb5eabca94cda63d41167b89914)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putFill")
    def put_fill(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHostmapDefinitionRequestFill, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5ca6f5d47437845ad65a225bda378d3d84a8e1bbf1c8f1504a416b0c0f3b4668)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putFill", [value]))

    @jsii.member(jsii_name="putSize")
    def put_size(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetHostmapDefinitionRequestSize", typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__63218cc50fcb6e1cdbd87dd2815e52b4721ddf85fd7eb6369b76a5a83010a3b1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putSize", [value]))

    @jsii.member(jsii_name="resetFill")
    def reset_fill(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFill", []))

    @jsii.member(jsii_name="resetSize")
    def reset_size(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSize", []))

    @builtins.property
    @jsii.member(jsii_name="fill")
    def fill(self) -> PowerpackWidgetHostmapDefinitionRequestFillList:
        return typing.cast(PowerpackWidgetHostmapDefinitionRequestFillList, jsii.get(self, "fill"))

    @builtins.property
    @jsii.member(jsii_name="size")
    def size(self) -> "PowerpackWidgetHostmapDefinitionRequestSizeList":
        return typing.cast("PowerpackWidgetHostmapDefinitionRequestSizeList", jsii.get(self, "size"))

    @builtins.property
    @jsii.member(jsii_name="fillInput")
    def fill_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestFill]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestFill]]], jsii.get(self, "fillInput"))

    @builtins.property
    @jsii.member(jsii_name="sizeInput")
    def size_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetHostmapDefinitionRequestSize"]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetHostmapDefinitionRequestSize"]]], jsii.get(self, "sizeInput"))

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetHostmapDefinitionRequest]:
        return typing.cast(typing.Optional[PowerpackWidgetHostmapDefinitionRequest], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetHostmapDefinitionRequest],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dbde4e761e1f22c3fb80903c82722213864571f175e2477f885670f79316b83d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestSize",
    jsii_struct_bases=[],
    name_mapping={
        "apm_query": "apmQuery",
        "log_query": "logQuery",
        "process_query": "processQuery",
        "q": "q",
        "rum_query": "rumQuery",
        "security_query": "securityQuery",
    },
)
class PowerpackWidgetHostmapDefinitionRequestSize:
    def __init__(
        self,
        *,
        apm_query: typing.Optional[typing.Union["PowerpackWidgetHostmapDefinitionRequestSizeApmQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        log_query: typing.Optional[typing.Union["PowerpackWidgetHostmapDefinitionRequestSizeLogQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        process_query: typing.Optional[typing.Union["PowerpackWidgetHostmapDefinitionRequestSizeProcessQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        q: typing.Optional[builtins.str] = None,
        rum_query: typing.Optional[typing.Union["PowerpackWidgetHostmapDefinitionRequestSizeRumQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        security_query: typing.Optional[typing.Union["PowerpackWidgetHostmapDefinitionRequestSizeSecurityQuery", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param apm_query: apm_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#apm_query Powerpack#apm_query}
        :param log_query: log_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#log_query Powerpack#log_query}
        :param process_query: process_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#process_query Powerpack#process_query}
        :param q: The metric query to use for this widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#q Powerpack#q}
        :param rum_query: rum_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#rum_query Powerpack#rum_query}
        :param security_query: security_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#security_query Powerpack#security_query}
        '''
        if isinstance(apm_query, dict):
            apm_query = PowerpackWidgetHostmapDefinitionRequestSizeApmQuery(**apm_query)
        if isinstance(log_query, dict):
            log_query = PowerpackWidgetHostmapDefinitionRequestSizeLogQuery(**log_query)
        if isinstance(process_query, dict):
            process_query = PowerpackWidgetHostmapDefinitionRequestSizeProcessQuery(**process_query)
        if isinstance(rum_query, dict):
            rum_query = PowerpackWidgetHostmapDefinitionRequestSizeRumQuery(**rum_query)
        if isinstance(security_query, dict):
            security_query = PowerpackWidgetHostmapDefinitionRequestSizeSecurityQuery(**security_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1c0ca097871328734c1b54bf50aa03dfb4ede09ce66b9cfcb21de560827ff14b)
            check_type(argname="argument apm_query", value=apm_query, expected_type=type_hints["apm_query"])
            check_type(argname="argument log_query", value=log_query, expected_type=type_hints["log_query"])
            check_type(argname="argument process_query", value=process_query, expected_type=type_hints["process_query"])
            check_type(argname="argument q", value=q, expected_type=type_hints["q"])
            check_type(argname="argument rum_query", value=rum_query, expected_type=type_hints["rum_query"])
            check_type(argname="argument security_query", value=security_query, expected_type=type_hints["security_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if apm_query is not None:
            self._values["apm_query"] = apm_query
        if log_query is not None:
            self._values["log_query"] = log_query
        if process_query is not None:
            self._values["process_query"] = process_query
        if q is not None:
            self._values["q"] = q
        if rum_query is not None:
            self._values["rum_query"] = rum_query
        if security_query is not None:
            self._values["security_query"] = security_query

    @builtins.property
    def apm_query(
        self,
    ) -> typing.Optional["PowerpackWidgetHostmapDefinitionRequestSizeApmQuery"]:
        '''apm_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#apm_query Powerpack#apm_query}
        '''
        result = self._values.get("apm_query")
        return typing.cast(typing.Optional["PowerpackWidgetHostmapDefinitionRequestSizeApmQuery"], result)

    @builtins.property
    def log_query(
        self,
    ) -> typing.Optional["PowerpackWidgetHostmapDefinitionRequestSizeLogQuery"]:
        '''log_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#log_query Powerpack#log_query}
        '''
        result = self._values.get("log_query")
        return typing.cast(typing.Optional["PowerpackWidgetHostmapDefinitionRequestSizeLogQuery"], result)

    @builtins.property
    def process_query(
        self,
    ) -> typing.Optional["PowerpackWidgetHostmapDefinitionRequestSizeProcessQuery"]:
        '''process_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#process_query Powerpack#process_query}
        '''
        result = self._values.get("process_query")
        return typing.cast(typing.Optional["PowerpackWidgetHostmapDefinitionRequestSizeProcessQuery"], result)

    @builtins.property
    def q(self) -> typing.Optional[builtins.str]:
        '''The metric query to use for this widget.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#q Powerpack#q}
        '''
        result = self._values.get("q")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def rum_query(
        self,
    ) -> typing.Optional["PowerpackWidgetHostmapDefinitionRequestSizeRumQuery"]:
        '''rum_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#rum_query Powerpack#rum_query}
        '''
        result = self._values.get("rum_query")
        return typing.cast(typing.Optional["PowerpackWidgetHostmapDefinitionRequestSizeRumQuery"], result)

    @builtins.property
    def security_query(
        self,
    ) -> typing.Optional["PowerpackWidgetHostmapDefinitionRequestSizeSecurityQuery"]:
        '''security_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#security_query Powerpack#security_query}
        '''
        result = self._values.get("security_query")
        return typing.cast(typing.Optional["PowerpackWidgetHostmapDefinitionRequestSizeSecurityQuery"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetHostmapDefinitionRequestSize(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestSizeApmQuery",
    jsii_struct_bases=[],
    name_mapping={
        "index": "index",
        "compute_query": "computeQuery",
        "group_by": "groupBy",
        "multi_compute": "multiCompute",
        "search_query": "searchQuery",
    },
)
class PowerpackWidgetHostmapDefinitionRequestSizeApmQuery:
    def __init__(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union["PowerpackWidgetHostmapDefinitionRequestSizeApmQueryComputeQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetHostmapDefinitionRequestSizeApmQueryGroupBy", typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetHostmapDefinitionRequestSizeApmQueryMultiCompute", typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        if isinstance(compute_query, dict):
            compute_query = PowerpackWidgetHostmapDefinitionRequestSizeApmQueryComputeQuery(**compute_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6b42df22a2feb224155e2d3dc72fb11b11ea23a88d489fbada3c58e053d7df69)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
            check_type(argname="argument compute_query", value=compute_query, expected_type=type_hints["compute_query"])
            check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
            check_type(argname="argument multi_compute", value=multi_compute, expected_type=type_hints["multi_compute"])
            check_type(argname="argument search_query", value=search_query, expected_type=type_hints["search_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "index": index,
        }
        if compute_query is not None:
            self._values["compute_query"] = compute_query
        if group_by is not None:
            self._values["group_by"] = group_by
        if multi_compute is not None:
            self._values["multi_compute"] = multi_compute
        if search_query is not None:
            self._values["search_query"] = search_query

    @builtins.property
    def index(self) -> builtins.str:
        '''The name of the index to query.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        '''
        result = self._values.get("index")
        assert result is not None, "Required property 'index' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def compute_query(
        self,
    ) -> typing.Optional["PowerpackWidgetHostmapDefinitionRequestSizeApmQueryComputeQuery"]:
        '''compute_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        '''
        result = self._values.get("compute_query")
        return typing.cast(typing.Optional["PowerpackWidgetHostmapDefinitionRequestSizeApmQueryComputeQuery"], result)

    @builtins.property
    def group_by(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetHostmapDefinitionRequestSizeApmQueryGroupBy"]]]:
        '''group_by block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        '''
        result = self._values.get("group_by")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetHostmapDefinitionRequestSizeApmQueryGroupBy"]]], result)

    @builtins.property
    def multi_compute(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetHostmapDefinitionRequestSizeApmQueryMultiCompute"]]]:
        '''multi_compute block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        '''
        result = self._values.get("multi_compute")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetHostmapDefinitionRequestSizeApmQueryMultiCompute"]]], result)

    @builtins.property
    def search_query(self) -> typing.Optional[builtins.str]:
        '''The search query to use.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        result = self._values.get("search_query")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetHostmapDefinitionRequestSizeApmQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestSizeApmQueryComputeQuery",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetHostmapDefinitionRequestSizeApmQueryComputeQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__524eebcab771d84833df2d471b8145f6bc4624313051224281592954887355de)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetHostmapDefinitionRequestSizeApmQueryComputeQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetHostmapDefinitionRequestSizeApmQueryComputeQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestSizeApmQueryComputeQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bd532e3601268d071e64edbd281318ecaf0b02b439e2625b29775dadbedef7a4)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f3ac0a1a3d67d5825c63d49a579b5991426f5526fa7fc6af120429377e04a664)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d0f9e0d532555940122fa2f5afb2e36b6263b73745bc8266162ecbe5167aaf60)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f779097ff52197dfcfb0039897fe4f10c689c84aa3b69e78cb518d7f8f10945d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetHostmapDefinitionRequestSizeApmQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetHostmapDefinitionRequestSizeApmQueryComputeQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetHostmapDefinitionRequestSizeApmQueryComputeQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__072362508eb6103af2a866e024699e958aac9dd4244c63d79be5e5373bfceb84)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestSizeApmQueryGroupBy",
    jsii_struct_bases=[],
    name_mapping={"facet": "facet", "limit": "limit", "sort_query": "sortQuery"},
)
class PowerpackWidgetHostmapDefinitionRequestSizeApmQueryGroupBy:
    def __init__(
        self,
        *,
        facet: typing.Optional[builtins.str] = None,
        limit: typing.Optional[jsii.Number] = None,
        sort_query: typing.Optional[typing.Union["PowerpackWidgetHostmapDefinitionRequestSizeApmQueryGroupBySortQuery", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param limit: The maximum number of items in the group. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param sort_query: sort_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        if isinstance(sort_query, dict):
            sort_query = PowerpackWidgetHostmapDefinitionRequestSizeApmQueryGroupBySortQuery(**sort_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__427740761c2e681f2fd99d4def736c3b3b462acd077f99311da0053f5bf2becc)
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
            check_type(argname="argument sort_query", value=sort_query, expected_type=type_hints["sort_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if facet is not None:
            self._values["facet"] = facet
        if limit is not None:
            self._values["limit"] = limit
        if sort_query is not None:
            self._values["sort_query"] = sort_query

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def limit(self) -> typing.Optional[jsii.Number]:
        '''The maximum number of items in the group.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        '''
        result = self._values.get("limit")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def sort_query(
        self,
    ) -> typing.Optional["PowerpackWidgetHostmapDefinitionRequestSizeApmQueryGroupBySortQuery"]:
        '''sort_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        result = self._values.get("sort_query")
        return typing.cast(typing.Optional["PowerpackWidgetHostmapDefinitionRequestSizeApmQueryGroupBySortQuery"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetHostmapDefinitionRequestSizeApmQueryGroupBy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetHostmapDefinitionRequestSizeApmQueryGroupByList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestSizeApmQueryGroupByList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9bb67b97ff073db89ca65c376ed948c2e07f3fb91f5d8a1ff96c598bdf858012)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetHostmapDefinitionRequestSizeApmQueryGroupByOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d7986569ae261379ff80f73ec49c2e84521219f87e91e73f1992687fe1e8ec11)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetHostmapDefinitionRequestSizeApmQueryGroupByOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__63163e64ec812fccbe24fa887f218d519f5414907b665db93f8678fd276b9db0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b73105f36f58f534db6b8723fa318acaf59fb3ebd149e844f6dff45b8173e4b2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5bebc86e5fe7d575bb109f5cffc329ab802d577782c298b43f1190cdb92025bd)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestSizeApmQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestSizeApmQueryGroupBy]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestSizeApmQueryGroupBy]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9fb394f64d47df84152f5f424e8cb17ac4e998f76e0b0717e41806433addea67)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetHostmapDefinitionRequestSizeApmQueryGroupByOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestSizeApmQueryGroupByOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8caa0182ea37271d858419046fbe5f27c4a4930b02691e2037e3ba1737f5f56e)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putSortQuery")
    def put_sort_query(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        value = PowerpackWidgetHostmapDefinitionRequestSizeApmQueryGroupBySortQuery(
            aggregation=aggregation, order=order, facet=facet
        )

        return typing.cast(None, jsii.invoke(self, "putSortQuery", [value]))

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetLimit")
    def reset_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLimit", []))

    @jsii.member(jsii_name="resetSortQuery")
    def reset_sort_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSortQuery", []))

    @builtins.property
    @jsii.member(jsii_name="sortQuery")
    def sort_query(
        self,
    ) -> "PowerpackWidgetHostmapDefinitionRequestSizeApmQueryGroupBySortQueryOutputReference":
        return typing.cast("PowerpackWidgetHostmapDefinitionRequestSizeApmQueryGroupBySortQueryOutputReference", jsii.get(self, "sortQuery"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="limitInput")
    def limit_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "limitInput"))

    @builtins.property
    @jsii.member(jsii_name="sortQueryInput")
    def sort_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetHostmapDefinitionRequestSizeApmQueryGroupBySortQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetHostmapDefinitionRequestSizeApmQueryGroupBySortQuery"], jsii.get(self, "sortQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f0ba4248fb55dfc65bea6f053fe32dabe2527a371f2c9699492ac87f103f815f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="limit")
    def limit(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "limit"))

    @limit.setter
    def limit(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1b541450fedba4e74f4fa5cc56156ef7bad2d5eca11ec714801c6ecb195fca13)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "limit", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHostmapDefinitionRequestSizeApmQueryGroupBy]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHostmapDefinitionRequestSizeApmQueryGroupBy]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHostmapDefinitionRequestSizeApmQueryGroupBy]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__48c7de265fc8806840d2dfb672039dca1a38964583112ac06e4241b24c564768)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestSizeApmQueryGroupBySortQuery",
    jsii_struct_bases=[],
    name_mapping={"aggregation": "aggregation", "order": "order", "facet": "facet"},
)
class PowerpackWidgetHostmapDefinitionRequestSizeApmQueryGroupBySortQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__37d99a696204444b0d81e98a706f5fcb5edf31b497d5c0d03ce45b26a13a283a)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument order", value=order, expected_type=type_hints["order"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
            "order": order,
        }
        if facet is not None:
            self._values["facet"] = facet

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def order(self) -> builtins.str:
        '''Widget sorting methods. Valid values are ``asc``, ``desc``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        result = self._values.get("order")
        assert result is not None, "Required property 'order' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetHostmapDefinitionRequestSizeApmQueryGroupBySortQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetHostmapDefinitionRequestSizeApmQueryGroupBySortQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestSizeApmQueryGroupBySortQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cf2d723673d90e2a765f2d0f8efa6895985c643d3d13a9226eb1492b7941d845)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="orderInput")
    def order_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "orderInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f06e411e8e57c32a15495daffda726f95f76261e8a53ba93330d391b7539b327)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4f574ccaa58592391137b0673e39fd4732919cb568fe96eb81c582768c0c37d4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="order")
    def order(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "order"))

    @order.setter
    def order(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d6374c6702d5bef3e6dc74594c95619cb8b02408c0c46ff0de01ad6d10b02f19)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "order", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetHostmapDefinitionRequestSizeApmQueryGroupBySortQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetHostmapDefinitionRequestSizeApmQueryGroupBySortQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetHostmapDefinitionRequestSizeApmQueryGroupBySortQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4727b8fe76c546819b967af261578be6a69120669322140d49580b2276737134)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestSizeApmQueryMultiCompute",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetHostmapDefinitionRequestSizeApmQueryMultiCompute:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__00f37894d346b5292821ada27e73d6a2a5d48a161ec6f5a057b28d6c99f9277e)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetHostmapDefinitionRequestSizeApmQueryMultiCompute(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetHostmapDefinitionRequestSizeApmQueryMultiComputeList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestSizeApmQueryMultiComputeList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ec15829640e025bed8f7f05bf2fde7b08dbe4ea5195746405a49ab7750607610)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetHostmapDefinitionRequestSizeApmQueryMultiComputeOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8fd4ef50ebbc37ee8996f1456aad83239a449fb586459340ae3cf19eb2f8de73)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetHostmapDefinitionRequestSizeApmQueryMultiComputeOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__273315ebdff4636278763c5693c4cfc31a8421a4b90199fbfaa1ecefecbcadb8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6cb4523b3f5f72669ec2b0cc862690bd666e777be40c9796863ec21655a1a581)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b7dd983afe7d6a4d11ec99ee55d45f3a237bfc3660190ae2959b806f6a99f817)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestSizeApmQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestSizeApmQueryMultiCompute]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestSizeApmQueryMultiCompute]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7ad0173f4044c7dbf37c469db0734eb64a924957c58269ea7c0f9777684242c9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetHostmapDefinitionRequestSizeApmQueryMultiComputeOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestSizeApmQueryMultiComputeOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__305283374406d57d9c19ec6f3c92282bcea51ca14d0c1fd5b65c4814ab383526)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0d4b8e093f1c7fffd5e0a4f632c5ec595c7c2378f9599d00d3c48a504aa53687)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a41a5eec32038b1e43a007e7e314868c2a526a9ef5376faaa0027508fc0d388f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9bb69b200e3d7b42e294938076543b62586556bf539b00b264479bdced964d64)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHostmapDefinitionRequestSizeApmQueryMultiCompute]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHostmapDefinitionRequestSizeApmQueryMultiCompute]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHostmapDefinitionRequestSizeApmQueryMultiCompute]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__10a822a96fd1afe47d4a4c19291ff3cbd2a346d594cdf7ae4a84a0e9c038d26d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetHostmapDefinitionRequestSizeApmQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestSizeApmQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__01556d2c1acf7dc25440a805f05dd56dd3e67397960e76e2e77aa559770694ce)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putComputeQuery")
    def put_compute_query(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        value = PowerpackWidgetHostmapDefinitionRequestSizeApmQueryComputeQuery(
            aggregation=aggregation, facet=facet, interval=interval
        )

        return typing.cast(None, jsii.invoke(self, "putComputeQuery", [value]))

    @jsii.member(jsii_name="putGroupBy")
    def put_group_by(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHostmapDefinitionRequestSizeApmQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cd06e28ed91b2e51c0134c5f91e6e85badb6b01e543b757d1765e7ecbc0048c2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putGroupBy", [value]))

    @jsii.member(jsii_name="putMultiCompute")
    def put_multi_compute(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHostmapDefinitionRequestSizeApmQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a32c3507475c57b4bea80a3acbb4f5ed9895b857bb852db9734e805a72ef8b21)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putMultiCompute", [value]))

    @jsii.member(jsii_name="resetComputeQuery")
    def reset_compute_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetComputeQuery", []))

    @jsii.member(jsii_name="resetGroupBy")
    def reset_group_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGroupBy", []))

    @jsii.member(jsii_name="resetMultiCompute")
    def reset_multi_compute(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMultiCompute", []))

    @jsii.member(jsii_name="resetSearchQuery")
    def reset_search_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSearchQuery", []))

    @builtins.property
    @jsii.member(jsii_name="computeQuery")
    def compute_query(
        self,
    ) -> PowerpackWidgetHostmapDefinitionRequestSizeApmQueryComputeQueryOutputReference:
        return typing.cast(PowerpackWidgetHostmapDefinitionRequestSizeApmQueryComputeQueryOutputReference, jsii.get(self, "computeQuery"))

    @builtins.property
    @jsii.member(jsii_name="groupBy")
    def group_by(
        self,
    ) -> PowerpackWidgetHostmapDefinitionRequestSizeApmQueryGroupByList:
        return typing.cast(PowerpackWidgetHostmapDefinitionRequestSizeApmQueryGroupByList, jsii.get(self, "groupBy"))

    @builtins.property
    @jsii.member(jsii_name="multiCompute")
    def multi_compute(
        self,
    ) -> PowerpackWidgetHostmapDefinitionRequestSizeApmQueryMultiComputeList:
        return typing.cast(PowerpackWidgetHostmapDefinitionRequestSizeApmQueryMultiComputeList, jsii.get(self, "multiCompute"))

    @builtins.property
    @jsii.member(jsii_name="computeQueryInput")
    def compute_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetHostmapDefinitionRequestSizeApmQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetHostmapDefinitionRequestSizeApmQueryComputeQuery], jsii.get(self, "computeQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="groupByInput")
    def group_by_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestSizeApmQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestSizeApmQueryGroupBy]]], jsii.get(self, "groupByInput"))

    @builtins.property
    @jsii.member(jsii_name="indexInput")
    def index_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "indexInput"))

    @builtins.property
    @jsii.member(jsii_name="multiComputeInput")
    def multi_compute_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestSizeApmQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestSizeApmQueryMultiCompute]]], jsii.get(self, "multiComputeInput"))

    @builtins.property
    @jsii.member(jsii_name="searchQueryInput")
    def search_query_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "searchQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="index")
    def index(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "index"))

    @index.setter
    def index(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b0e397220d56bd0275355b58f69071aab5c9ed1e2cb1da15947b635df921ff16)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "index", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="searchQuery")
    def search_query(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "searchQuery"))

    @search_query.setter
    def search_query(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e5d61de392381a5ab597d36f5696cb82bac75d690c93bd969f63042c3aa7ab68)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "searchQuery", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetHostmapDefinitionRequestSizeApmQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetHostmapDefinitionRequestSizeApmQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetHostmapDefinitionRequestSizeApmQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__24025524a0070463aeebaed39d343931aef92d66d82f40372471ca5e3598f6a2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetHostmapDefinitionRequestSizeList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestSizeList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f4c732da51fd060153e1bf1e6007de82704d990caee858b47867c3c3156188ef)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetHostmapDefinitionRequestSizeOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ae43da53eb31aa5b30f9f8ed70276ca8e6e4bf7f2fc5b50252a65fc2e3d27775)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetHostmapDefinitionRequestSizeOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__012bf6372c938cb7cca98b93198b368a862d83b5fffb00480982d75454fa950f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1c070294f6adf48728f314ee3e6e85cb9fe4390f54073cb83ff33e266cbc2b82)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2fa9101eab04ddc78e851d240f44288798397b71f26d585cfd27ce5e3a26475c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestSize]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestSize]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestSize]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ad5706fcfa737224dd96d065243366077f68d78a6bd72a373b24739bc46d2d0f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestSizeLogQuery",
    jsii_struct_bases=[],
    name_mapping={
        "index": "index",
        "compute_query": "computeQuery",
        "group_by": "groupBy",
        "multi_compute": "multiCompute",
        "search_query": "searchQuery",
    },
)
class PowerpackWidgetHostmapDefinitionRequestSizeLogQuery:
    def __init__(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union["PowerpackWidgetHostmapDefinitionRequestSizeLogQueryComputeQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetHostmapDefinitionRequestSizeLogQueryGroupBy", typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetHostmapDefinitionRequestSizeLogQueryMultiCompute", typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        if isinstance(compute_query, dict):
            compute_query = PowerpackWidgetHostmapDefinitionRequestSizeLogQueryComputeQuery(**compute_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f60d6dec0b5c62001d1fd76e8812e8ad1e9e6cc261cf290de732b25b3a606e3e)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
            check_type(argname="argument compute_query", value=compute_query, expected_type=type_hints["compute_query"])
            check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
            check_type(argname="argument multi_compute", value=multi_compute, expected_type=type_hints["multi_compute"])
            check_type(argname="argument search_query", value=search_query, expected_type=type_hints["search_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "index": index,
        }
        if compute_query is not None:
            self._values["compute_query"] = compute_query
        if group_by is not None:
            self._values["group_by"] = group_by
        if multi_compute is not None:
            self._values["multi_compute"] = multi_compute
        if search_query is not None:
            self._values["search_query"] = search_query

    @builtins.property
    def index(self) -> builtins.str:
        '''The name of the index to query.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        '''
        result = self._values.get("index")
        assert result is not None, "Required property 'index' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def compute_query(
        self,
    ) -> typing.Optional["PowerpackWidgetHostmapDefinitionRequestSizeLogQueryComputeQuery"]:
        '''compute_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        '''
        result = self._values.get("compute_query")
        return typing.cast(typing.Optional["PowerpackWidgetHostmapDefinitionRequestSizeLogQueryComputeQuery"], result)

    @builtins.property
    def group_by(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetHostmapDefinitionRequestSizeLogQueryGroupBy"]]]:
        '''group_by block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        '''
        result = self._values.get("group_by")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetHostmapDefinitionRequestSizeLogQueryGroupBy"]]], result)

    @builtins.property
    def multi_compute(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetHostmapDefinitionRequestSizeLogQueryMultiCompute"]]]:
        '''multi_compute block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        '''
        result = self._values.get("multi_compute")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetHostmapDefinitionRequestSizeLogQueryMultiCompute"]]], result)

    @builtins.property
    def search_query(self) -> typing.Optional[builtins.str]:
        '''The search query to use.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        result = self._values.get("search_query")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetHostmapDefinitionRequestSizeLogQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestSizeLogQueryComputeQuery",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetHostmapDefinitionRequestSizeLogQueryComputeQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__baecd524f805cc893e0640a3c223a4603c9594f4ab1bca1b550ca8612e27f410)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetHostmapDefinitionRequestSizeLogQueryComputeQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetHostmapDefinitionRequestSizeLogQueryComputeQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestSizeLogQueryComputeQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__35730ac08e1b973ccdadb1c5de4c24fed1e9aa28488a45bd48b44deb16f0ac09)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a34c88ed10f7509e27ac0081fdefc5aff1d16c687740d179a77ee07ce5f08ed6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__577de92b50d151ff4b2be3754cf13e70b60f68e208c974c0592a186fc500b8cb)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__da469cba3bda36534aae39766d37e5da30506e0fb4d729b494df179b2805ceb0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetHostmapDefinitionRequestSizeLogQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetHostmapDefinitionRequestSizeLogQueryComputeQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetHostmapDefinitionRequestSizeLogQueryComputeQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f85b1aa928c9aa3bf41153881f40171c2bf46b1d5bd0e27e14901f78c9a6f4e3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestSizeLogQueryGroupBy",
    jsii_struct_bases=[],
    name_mapping={"facet": "facet", "limit": "limit", "sort_query": "sortQuery"},
)
class PowerpackWidgetHostmapDefinitionRequestSizeLogQueryGroupBy:
    def __init__(
        self,
        *,
        facet: typing.Optional[builtins.str] = None,
        limit: typing.Optional[jsii.Number] = None,
        sort_query: typing.Optional[typing.Union["PowerpackWidgetHostmapDefinitionRequestSizeLogQueryGroupBySortQuery", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param limit: The maximum number of items in the group. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param sort_query: sort_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        if isinstance(sort_query, dict):
            sort_query = PowerpackWidgetHostmapDefinitionRequestSizeLogQueryGroupBySortQuery(**sort_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9df1ec37a5405d80ac556bc25a93c13cec7783233c9fd24537a627f11be07b66)
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
            check_type(argname="argument sort_query", value=sort_query, expected_type=type_hints["sort_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if facet is not None:
            self._values["facet"] = facet
        if limit is not None:
            self._values["limit"] = limit
        if sort_query is not None:
            self._values["sort_query"] = sort_query

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def limit(self) -> typing.Optional[jsii.Number]:
        '''The maximum number of items in the group.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        '''
        result = self._values.get("limit")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def sort_query(
        self,
    ) -> typing.Optional["PowerpackWidgetHostmapDefinitionRequestSizeLogQueryGroupBySortQuery"]:
        '''sort_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        result = self._values.get("sort_query")
        return typing.cast(typing.Optional["PowerpackWidgetHostmapDefinitionRequestSizeLogQueryGroupBySortQuery"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetHostmapDefinitionRequestSizeLogQueryGroupBy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetHostmapDefinitionRequestSizeLogQueryGroupByList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestSizeLogQueryGroupByList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a8f245a0868ac91d3a1ff27cc92fca074f80f814332f68adab2b4c3fe34c5341)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetHostmapDefinitionRequestSizeLogQueryGroupByOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__605ef55b80ae69d6321a9dc13b46536ea516db323bdc8113e09df18e404d986f)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetHostmapDefinitionRequestSizeLogQueryGroupByOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e8ff7cf9ab76e8d67fcba9a121238d61bc8ff3a1a7e737679db2c1654ac39b80)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3b2963d60e91d188d8d689feaf31569672009a241d1b54e812ebc87a32045637)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__785edef4715e0c95f6201b0c89b1b47cde785f8c46e23385609607dd06a690d6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestSizeLogQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestSizeLogQueryGroupBy]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestSizeLogQueryGroupBy]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b0ea91adbfcb449ea694c36c9fa08dda3e0e91d2f42bb27c91b8742c5e7d240d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetHostmapDefinitionRequestSizeLogQueryGroupByOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestSizeLogQueryGroupByOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5e1ecc86babeae4ebab14c50c754d003389b26e36a1a909e9b03a2aac9d18a66)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putSortQuery")
    def put_sort_query(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        value = PowerpackWidgetHostmapDefinitionRequestSizeLogQueryGroupBySortQuery(
            aggregation=aggregation, order=order, facet=facet
        )

        return typing.cast(None, jsii.invoke(self, "putSortQuery", [value]))

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetLimit")
    def reset_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLimit", []))

    @jsii.member(jsii_name="resetSortQuery")
    def reset_sort_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSortQuery", []))

    @builtins.property
    @jsii.member(jsii_name="sortQuery")
    def sort_query(
        self,
    ) -> "PowerpackWidgetHostmapDefinitionRequestSizeLogQueryGroupBySortQueryOutputReference":
        return typing.cast("PowerpackWidgetHostmapDefinitionRequestSizeLogQueryGroupBySortQueryOutputReference", jsii.get(self, "sortQuery"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="limitInput")
    def limit_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "limitInput"))

    @builtins.property
    @jsii.member(jsii_name="sortQueryInput")
    def sort_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetHostmapDefinitionRequestSizeLogQueryGroupBySortQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetHostmapDefinitionRequestSizeLogQueryGroupBySortQuery"], jsii.get(self, "sortQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9a5eeea3e8aaf684bb39147d31b78fa941e71cd9b2c659bfb627515dcb0ba8e8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="limit")
    def limit(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "limit"))

    @limit.setter
    def limit(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__86038e2e346d596c15f36a1bab4e64c8d4176942c63373cd5a5cb659c156719b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "limit", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHostmapDefinitionRequestSizeLogQueryGroupBy]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHostmapDefinitionRequestSizeLogQueryGroupBy]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHostmapDefinitionRequestSizeLogQueryGroupBy]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a494d0ad94ec497546b3c8057344b00bce334d204ec177a56dfb6221ce91b71c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestSizeLogQueryGroupBySortQuery",
    jsii_struct_bases=[],
    name_mapping={"aggregation": "aggregation", "order": "order", "facet": "facet"},
)
class PowerpackWidgetHostmapDefinitionRequestSizeLogQueryGroupBySortQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__75c1659906629331f45df6ac5cb6bb7cb66e38827905a33e656dce50a21e2677)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument order", value=order, expected_type=type_hints["order"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
            "order": order,
        }
        if facet is not None:
            self._values["facet"] = facet

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def order(self) -> builtins.str:
        '''Widget sorting methods. Valid values are ``asc``, ``desc``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        result = self._values.get("order")
        assert result is not None, "Required property 'order' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetHostmapDefinitionRequestSizeLogQueryGroupBySortQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetHostmapDefinitionRequestSizeLogQueryGroupBySortQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestSizeLogQueryGroupBySortQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7e7a73aacbffb638810da2f79e149e38dcf0cb3d6681718457a774be504deb6b)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="orderInput")
    def order_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "orderInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__211ce7e9f0469b7beace57e3390da57b74cbd0904e62d7321d4953711960b6fe)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c5e33ab238f08b0a11d7b904d55bf3f94eb8582ed54bea7d2695fdab9086da52)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="order")
    def order(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "order"))

    @order.setter
    def order(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e410ef15c7926731fcdfa4fbad9aab696efd6e9e704d646e65fc8e26e80890ba)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "order", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetHostmapDefinitionRequestSizeLogQueryGroupBySortQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetHostmapDefinitionRequestSizeLogQueryGroupBySortQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetHostmapDefinitionRequestSizeLogQueryGroupBySortQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ed597722d3631e5f48d6cc68eb17272407c284d16df9fc21842aa8055ddfd01d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestSizeLogQueryMultiCompute",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetHostmapDefinitionRequestSizeLogQueryMultiCompute:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c1281dff731e7dca75f6f37cd9cca8be442b671259a7a589356b0d37f788a08e)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetHostmapDefinitionRequestSizeLogQueryMultiCompute(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetHostmapDefinitionRequestSizeLogQueryMultiComputeList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestSizeLogQueryMultiComputeList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__afa2a1998ec5b10e57fa18c71633f6cd05b08be825774fba8a324b73686b66b5)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetHostmapDefinitionRequestSizeLogQueryMultiComputeOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ee29e19a4a86bc6385f850f5e040b5c80ec53c83013bc1702904238e225bf387)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetHostmapDefinitionRequestSizeLogQueryMultiComputeOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1e466e2c1626d85b2cb75b9c5a31887d521cba4aec34880fa96ffd1d91fda6c2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8e8e71f5a96d16e74b7929b0c1c9bd08f4947c95fa6afe016f1949e81268f21b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__98db761634b3ef60ee3dcc75eb1b65cded41a4d660f2d32c2ccdc81aefe9dfb8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestSizeLogQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestSizeLogQueryMultiCompute]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestSizeLogQueryMultiCompute]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__98287e9a388e6ea02ebe47e500226a81e4f847a2d17c4e2ffedc7becc765c0d2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetHostmapDefinitionRequestSizeLogQueryMultiComputeOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestSizeLogQueryMultiComputeOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3d6fa6aae4b1f223ab262c0820313286262873eeca6cdd41a97962450a92031c)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__391383a241a0cbb589355019ae33fc06c62bdbcbc0e06a9ec6e9a63c48275567)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6565785689e23449b346ffef73990e258fe8cf8fba2e8b1f23e8cd0217cd5eaa)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d66aac08f7bd63d572b6ed7c5ed8dc730c289af3f54b3178cd7a0fd3fa68de7f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHostmapDefinitionRequestSizeLogQueryMultiCompute]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHostmapDefinitionRequestSizeLogQueryMultiCompute]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHostmapDefinitionRequestSizeLogQueryMultiCompute]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bffc4e03ca89e18b72d396b95b33c5c074969437bc210d1d42b0b6543a212d81)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetHostmapDefinitionRequestSizeLogQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestSizeLogQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0fe08c52533c81d766a9a8b1211abbd129903670ce7b035e3997d7c059a7a6c4)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putComputeQuery")
    def put_compute_query(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        value = PowerpackWidgetHostmapDefinitionRequestSizeLogQueryComputeQuery(
            aggregation=aggregation, facet=facet, interval=interval
        )

        return typing.cast(None, jsii.invoke(self, "putComputeQuery", [value]))

    @jsii.member(jsii_name="putGroupBy")
    def put_group_by(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHostmapDefinitionRequestSizeLogQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ed041b58672c2e401c2f1d34f9f6f93c6ee5e81216f9013c3f83f457f328e66b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putGroupBy", [value]))

    @jsii.member(jsii_name="putMultiCompute")
    def put_multi_compute(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHostmapDefinitionRequestSizeLogQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__230e66242e2c647682082da5575889a82f746d9d18c25cff2d85c8528b798e68)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putMultiCompute", [value]))

    @jsii.member(jsii_name="resetComputeQuery")
    def reset_compute_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetComputeQuery", []))

    @jsii.member(jsii_name="resetGroupBy")
    def reset_group_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGroupBy", []))

    @jsii.member(jsii_name="resetMultiCompute")
    def reset_multi_compute(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMultiCompute", []))

    @jsii.member(jsii_name="resetSearchQuery")
    def reset_search_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSearchQuery", []))

    @builtins.property
    @jsii.member(jsii_name="computeQuery")
    def compute_query(
        self,
    ) -> PowerpackWidgetHostmapDefinitionRequestSizeLogQueryComputeQueryOutputReference:
        return typing.cast(PowerpackWidgetHostmapDefinitionRequestSizeLogQueryComputeQueryOutputReference, jsii.get(self, "computeQuery"))

    @builtins.property
    @jsii.member(jsii_name="groupBy")
    def group_by(
        self,
    ) -> PowerpackWidgetHostmapDefinitionRequestSizeLogQueryGroupByList:
        return typing.cast(PowerpackWidgetHostmapDefinitionRequestSizeLogQueryGroupByList, jsii.get(self, "groupBy"))

    @builtins.property
    @jsii.member(jsii_name="multiCompute")
    def multi_compute(
        self,
    ) -> PowerpackWidgetHostmapDefinitionRequestSizeLogQueryMultiComputeList:
        return typing.cast(PowerpackWidgetHostmapDefinitionRequestSizeLogQueryMultiComputeList, jsii.get(self, "multiCompute"))

    @builtins.property
    @jsii.member(jsii_name="computeQueryInput")
    def compute_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetHostmapDefinitionRequestSizeLogQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetHostmapDefinitionRequestSizeLogQueryComputeQuery], jsii.get(self, "computeQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="groupByInput")
    def group_by_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestSizeLogQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestSizeLogQueryGroupBy]]], jsii.get(self, "groupByInput"))

    @builtins.property
    @jsii.member(jsii_name="indexInput")
    def index_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "indexInput"))

    @builtins.property
    @jsii.member(jsii_name="multiComputeInput")
    def multi_compute_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestSizeLogQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestSizeLogQueryMultiCompute]]], jsii.get(self, "multiComputeInput"))

    @builtins.property
    @jsii.member(jsii_name="searchQueryInput")
    def search_query_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "searchQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="index")
    def index(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "index"))

    @index.setter
    def index(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__696380f9de2057b2c8bb4a2018587e2c9fc5ef3417c32165a25989faed5c59ee)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "index", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="searchQuery")
    def search_query(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "searchQuery"))

    @search_query.setter
    def search_query(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6b6b843cd55e28e24fff5f74646778fc889e1e76187691373deeeb0fb2ac0959)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "searchQuery", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetHostmapDefinitionRequestSizeLogQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetHostmapDefinitionRequestSizeLogQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetHostmapDefinitionRequestSizeLogQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5497567d465b10de40037d445453613a6df1cf1d3e0c420e72d1a6866f2967e9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetHostmapDefinitionRequestSizeOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestSizeOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__764c340426ee5c26f6f4b4a335a2625d34cfb2df69ec10645cbaf8d96734fecc)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putApmQuery")
    def put_apm_query(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union[PowerpackWidgetHostmapDefinitionRequestSizeApmQueryComputeQuery, typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHostmapDefinitionRequestSizeApmQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHostmapDefinitionRequestSizeApmQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        value = PowerpackWidgetHostmapDefinitionRequestSizeApmQuery(
            index=index,
            compute_query=compute_query,
            group_by=group_by,
            multi_compute=multi_compute,
            search_query=search_query,
        )

        return typing.cast(None, jsii.invoke(self, "putApmQuery", [value]))

    @jsii.member(jsii_name="putLogQuery")
    def put_log_query(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union[PowerpackWidgetHostmapDefinitionRequestSizeLogQueryComputeQuery, typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHostmapDefinitionRequestSizeLogQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHostmapDefinitionRequestSizeLogQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        value = PowerpackWidgetHostmapDefinitionRequestSizeLogQuery(
            index=index,
            compute_query=compute_query,
            group_by=group_by,
            multi_compute=multi_compute,
            search_query=search_query,
        )

        return typing.cast(None, jsii.invoke(self, "putLogQuery", [value]))

    @jsii.member(jsii_name="putProcessQuery")
    def put_process_query(
        self,
        *,
        metric: builtins.str,
        filter_by: typing.Optional[typing.Sequence[builtins.str]] = None,
        limit: typing.Optional[jsii.Number] = None,
        search_by: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param metric: Your chosen metric. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        :param filter_by: A list of processes. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#filter_by Powerpack#filter_by}
        :param limit: The max number of items in the filter list. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param search_by: Your chosen search term. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_by Powerpack#search_by}
        '''
        value = PowerpackWidgetHostmapDefinitionRequestSizeProcessQuery(
            metric=metric, filter_by=filter_by, limit=limit, search_by=search_by
        )

        return typing.cast(None, jsii.invoke(self, "putProcessQuery", [value]))

    @jsii.member(jsii_name="putRumQuery")
    def put_rum_query(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union["PowerpackWidgetHostmapDefinitionRequestSizeRumQueryComputeQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetHostmapDefinitionRequestSizeRumQueryGroupBy", typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetHostmapDefinitionRequestSizeRumQueryMultiCompute", typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        value = PowerpackWidgetHostmapDefinitionRequestSizeRumQuery(
            index=index,
            compute_query=compute_query,
            group_by=group_by,
            multi_compute=multi_compute,
            search_query=search_query,
        )

        return typing.cast(None, jsii.invoke(self, "putRumQuery", [value]))

    @jsii.member(jsii_name="putSecurityQuery")
    def put_security_query(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union["PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryComputeQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryGroupBy", typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryMultiCompute", typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        value = PowerpackWidgetHostmapDefinitionRequestSizeSecurityQuery(
            index=index,
            compute_query=compute_query,
            group_by=group_by,
            multi_compute=multi_compute,
            search_query=search_query,
        )

        return typing.cast(None, jsii.invoke(self, "putSecurityQuery", [value]))

    @jsii.member(jsii_name="resetApmQuery")
    def reset_apm_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetApmQuery", []))

    @jsii.member(jsii_name="resetLogQuery")
    def reset_log_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLogQuery", []))

    @jsii.member(jsii_name="resetProcessQuery")
    def reset_process_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetProcessQuery", []))

    @jsii.member(jsii_name="resetQ")
    def reset_q(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetQ", []))

    @jsii.member(jsii_name="resetRumQuery")
    def reset_rum_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetRumQuery", []))

    @jsii.member(jsii_name="resetSecurityQuery")
    def reset_security_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSecurityQuery", []))

    @builtins.property
    @jsii.member(jsii_name="apmQuery")
    def apm_query(
        self,
    ) -> PowerpackWidgetHostmapDefinitionRequestSizeApmQueryOutputReference:
        return typing.cast(PowerpackWidgetHostmapDefinitionRequestSizeApmQueryOutputReference, jsii.get(self, "apmQuery"))

    @builtins.property
    @jsii.member(jsii_name="logQuery")
    def log_query(
        self,
    ) -> PowerpackWidgetHostmapDefinitionRequestSizeLogQueryOutputReference:
        return typing.cast(PowerpackWidgetHostmapDefinitionRequestSizeLogQueryOutputReference, jsii.get(self, "logQuery"))

    @builtins.property
    @jsii.member(jsii_name="processQuery")
    def process_query(
        self,
    ) -> "PowerpackWidgetHostmapDefinitionRequestSizeProcessQueryOutputReference":
        return typing.cast("PowerpackWidgetHostmapDefinitionRequestSizeProcessQueryOutputReference", jsii.get(self, "processQuery"))

    @builtins.property
    @jsii.member(jsii_name="rumQuery")
    def rum_query(
        self,
    ) -> "PowerpackWidgetHostmapDefinitionRequestSizeRumQueryOutputReference":
        return typing.cast("PowerpackWidgetHostmapDefinitionRequestSizeRumQueryOutputReference", jsii.get(self, "rumQuery"))

    @builtins.property
    @jsii.member(jsii_name="securityQuery")
    def security_query(
        self,
    ) -> "PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryOutputReference":
        return typing.cast("PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryOutputReference", jsii.get(self, "securityQuery"))

    @builtins.property
    @jsii.member(jsii_name="apmQueryInput")
    def apm_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetHostmapDefinitionRequestSizeApmQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetHostmapDefinitionRequestSizeApmQuery], jsii.get(self, "apmQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="logQueryInput")
    def log_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetHostmapDefinitionRequestSizeLogQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetHostmapDefinitionRequestSizeLogQuery], jsii.get(self, "logQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="processQueryInput")
    def process_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetHostmapDefinitionRequestSizeProcessQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetHostmapDefinitionRequestSizeProcessQuery"], jsii.get(self, "processQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="qInput")
    def q_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "qInput"))

    @builtins.property
    @jsii.member(jsii_name="rumQueryInput")
    def rum_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetHostmapDefinitionRequestSizeRumQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetHostmapDefinitionRequestSizeRumQuery"], jsii.get(self, "rumQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="securityQueryInput")
    def security_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetHostmapDefinitionRequestSizeSecurityQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetHostmapDefinitionRequestSizeSecurityQuery"], jsii.get(self, "securityQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="q")
    def q(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "q"))

    @q.setter
    def q(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__39e260c3fe1591af0d5434ecfd3ed1adab74fb13525a418024935765b7260aac)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "q", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHostmapDefinitionRequestSize]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHostmapDefinitionRequestSize]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHostmapDefinitionRequestSize]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a1a8336d1e30a1f455db05b79680df740454282bbcdd46a4f0ee8a53df0feade)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestSizeProcessQuery",
    jsii_struct_bases=[],
    name_mapping={
        "metric": "metric",
        "filter_by": "filterBy",
        "limit": "limit",
        "search_by": "searchBy",
    },
)
class PowerpackWidgetHostmapDefinitionRequestSizeProcessQuery:
    def __init__(
        self,
        *,
        metric: builtins.str,
        filter_by: typing.Optional[typing.Sequence[builtins.str]] = None,
        limit: typing.Optional[jsii.Number] = None,
        search_by: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param metric: Your chosen metric. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        :param filter_by: A list of processes. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#filter_by Powerpack#filter_by}
        :param limit: The max number of items in the filter list. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param search_by: Your chosen search term. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_by Powerpack#search_by}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b042ee62256dee91e1766f1b5f267118ae9196016061b604c5b1e25e3670ed0c)
            check_type(argname="argument metric", value=metric, expected_type=type_hints["metric"])
            check_type(argname="argument filter_by", value=filter_by, expected_type=type_hints["filter_by"])
            check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
            check_type(argname="argument search_by", value=search_by, expected_type=type_hints["search_by"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "metric": metric,
        }
        if filter_by is not None:
            self._values["filter_by"] = filter_by
        if limit is not None:
            self._values["limit"] = limit
        if search_by is not None:
            self._values["search_by"] = search_by

    @builtins.property
    def metric(self) -> builtins.str:
        '''Your chosen metric.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        '''
        result = self._values.get("metric")
        assert result is not None, "Required property 'metric' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def filter_by(self) -> typing.Optional[typing.List[builtins.str]]:
        '''A list of processes.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#filter_by Powerpack#filter_by}
        '''
        result = self._values.get("filter_by")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def limit(self) -> typing.Optional[jsii.Number]:
        '''The max number of items in the filter list.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        '''
        result = self._values.get("limit")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def search_by(self) -> typing.Optional[builtins.str]:
        '''Your chosen search term.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_by Powerpack#search_by}
        '''
        result = self._values.get("search_by")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetHostmapDefinitionRequestSizeProcessQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetHostmapDefinitionRequestSizeProcessQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestSizeProcessQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__54fab8907dbadca8c989c794754ccc38a4e3ad67795995d0e24d7b61d75e962e)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFilterBy")
    def reset_filter_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFilterBy", []))

    @jsii.member(jsii_name="resetLimit")
    def reset_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLimit", []))

    @jsii.member(jsii_name="resetSearchBy")
    def reset_search_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSearchBy", []))

    @builtins.property
    @jsii.member(jsii_name="filterByInput")
    def filter_by_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "filterByInput"))

    @builtins.property
    @jsii.member(jsii_name="limitInput")
    def limit_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "limitInput"))

    @builtins.property
    @jsii.member(jsii_name="metricInput")
    def metric_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "metricInput"))

    @builtins.property
    @jsii.member(jsii_name="searchByInput")
    def search_by_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "searchByInput"))

    @builtins.property
    @jsii.member(jsii_name="filterBy")
    def filter_by(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "filterBy"))

    @filter_by.setter
    def filter_by(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1e37dae4cb349ed56f6c1c9f60cf3ca477085c2c3a35112c3b3c1683fc14a10b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "filterBy", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="limit")
    def limit(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "limit"))

    @limit.setter
    def limit(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6864878d6f2166736e8c51f72e3b29b7186f2ddb906f61b44ee05fb792b21792)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "limit", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="metric")
    def metric(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "metric"))

    @metric.setter
    def metric(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e2f0bf6fa52faeecd0be0d1f5726c6dd64949646ee64d120187aea7d29d390ac)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "metric", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="searchBy")
    def search_by(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "searchBy"))

    @search_by.setter
    def search_by(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ed30faaf214c7ac2f469d6fde2df9b493589b40185856ccf26afd6b7be37c205)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "searchBy", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetHostmapDefinitionRequestSizeProcessQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetHostmapDefinitionRequestSizeProcessQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetHostmapDefinitionRequestSizeProcessQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5d09df00e67da1113ecd7d427fc79f96db3361c9e840d2c6f155dd029a4bdd66)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestSizeRumQuery",
    jsii_struct_bases=[],
    name_mapping={
        "index": "index",
        "compute_query": "computeQuery",
        "group_by": "groupBy",
        "multi_compute": "multiCompute",
        "search_query": "searchQuery",
    },
)
class PowerpackWidgetHostmapDefinitionRequestSizeRumQuery:
    def __init__(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union["PowerpackWidgetHostmapDefinitionRequestSizeRumQueryComputeQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetHostmapDefinitionRequestSizeRumQueryGroupBy", typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetHostmapDefinitionRequestSizeRumQueryMultiCompute", typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        if isinstance(compute_query, dict):
            compute_query = PowerpackWidgetHostmapDefinitionRequestSizeRumQueryComputeQuery(**compute_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__696a841f0def415fa8b7b590deaf42c16e60d7c8ac44c7798e440250bac51328)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
            check_type(argname="argument compute_query", value=compute_query, expected_type=type_hints["compute_query"])
            check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
            check_type(argname="argument multi_compute", value=multi_compute, expected_type=type_hints["multi_compute"])
            check_type(argname="argument search_query", value=search_query, expected_type=type_hints["search_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "index": index,
        }
        if compute_query is not None:
            self._values["compute_query"] = compute_query
        if group_by is not None:
            self._values["group_by"] = group_by
        if multi_compute is not None:
            self._values["multi_compute"] = multi_compute
        if search_query is not None:
            self._values["search_query"] = search_query

    @builtins.property
    def index(self) -> builtins.str:
        '''The name of the index to query.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        '''
        result = self._values.get("index")
        assert result is not None, "Required property 'index' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def compute_query(
        self,
    ) -> typing.Optional["PowerpackWidgetHostmapDefinitionRequestSizeRumQueryComputeQuery"]:
        '''compute_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        '''
        result = self._values.get("compute_query")
        return typing.cast(typing.Optional["PowerpackWidgetHostmapDefinitionRequestSizeRumQueryComputeQuery"], result)

    @builtins.property
    def group_by(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetHostmapDefinitionRequestSizeRumQueryGroupBy"]]]:
        '''group_by block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        '''
        result = self._values.get("group_by")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetHostmapDefinitionRequestSizeRumQueryGroupBy"]]], result)

    @builtins.property
    def multi_compute(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetHostmapDefinitionRequestSizeRumQueryMultiCompute"]]]:
        '''multi_compute block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        '''
        result = self._values.get("multi_compute")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetHostmapDefinitionRequestSizeRumQueryMultiCompute"]]], result)

    @builtins.property
    def search_query(self) -> typing.Optional[builtins.str]:
        '''The search query to use.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        result = self._values.get("search_query")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetHostmapDefinitionRequestSizeRumQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestSizeRumQueryComputeQuery",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetHostmapDefinitionRequestSizeRumQueryComputeQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3ced772bcf88008b8b7943c3056e6ec89c6388a40caabef0916f02370c61360f)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetHostmapDefinitionRequestSizeRumQueryComputeQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetHostmapDefinitionRequestSizeRumQueryComputeQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestSizeRumQueryComputeQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__98b3973122128b84bf1650363c82a7a47923ac750563134e3ca441b1631f1350)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5289b0d70a3eea96a04df10b607a3cf0b0e69e4a296da77dd0263a477ac803e7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__98ef4ff7221a2fdd685cc9c0ba22bf799c3098977f71b431384670584d9bf827)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__796d87a81015261cfa84a30222bcd7d33f2275d8ee62f0d41bd1dc123e722a7d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetHostmapDefinitionRequestSizeRumQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetHostmapDefinitionRequestSizeRumQueryComputeQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetHostmapDefinitionRequestSizeRumQueryComputeQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9715574f15e40a25b0ce18ed193ddb8e4599078bbd75a6a5dc48b410e2ab5c5c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestSizeRumQueryGroupBy",
    jsii_struct_bases=[],
    name_mapping={"facet": "facet", "limit": "limit", "sort_query": "sortQuery"},
)
class PowerpackWidgetHostmapDefinitionRequestSizeRumQueryGroupBy:
    def __init__(
        self,
        *,
        facet: typing.Optional[builtins.str] = None,
        limit: typing.Optional[jsii.Number] = None,
        sort_query: typing.Optional[typing.Union["PowerpackWidgetHostmapDefinitionRequestSizeRumQueryGroupBySortQuery", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param limit: The maximum number of items in the group. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param sort_query: sort_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        if isinstance(sort_query, dict):
            sort_query = PowerpackWidgetHostmapDefinitionRequestSizeRumQueryGroupBySortQuery(**sort_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c424fa0806ea31835a4464e232f830df486dff70b67599761e7f7657eeb1f90d)
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
            check_type(argname="argument sort_query", value=sort_query, expected_type=type_hints["sort_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if facet is not None:
            self._values["facet"] = facet
        if limit is not None:
            self._values["limit"] = limit
        if sort_query is not None:
            self._values["sort_query"] = sort_query

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def limit(self) -> typing.Optional[jsii.Number]:
        '''The maximum number of items in the group.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        '''
        result = self._values.get("limit")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def sort_query(
        self,
    ) -> typing.Optional["PowerpackWidgetHostmapDefinitionRequestSizeRumQueryGroupBySortQuery"]:
        '''sort_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        result = self._values.get("sort_query")
        return typing.cast(typing.Optional["PowerpackWidgetHostmapDefinitionRequestSizeRumQueryGroupBySortQuery"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetHostmapDefinitionRequestSizeRumQueryGroupBy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetHostmapDefinitionRequestSizeRumQueryGroupByList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestSizeRumQueryGroupByList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ef770337113598fe3149ad1f73392f2ad403470534c009f5ba5e1d07fb743e66)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetHostmapDefinitionRequestSizeRumQueryGroupByOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0b8d799757768945f7c6d52a670a2361cec7ad43c99b351acdd89bae7be30158)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetHostmapDefinitionRequestSizeRumQueryGroupByOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2b148b1c4993cc8adc5c23f69fca17fb96bc196f3f7c31e74af0f97c47bc6db4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1735d05851fdd9b3ad532e1f90fe4d1cf1b2e9e5f0e907ea7b7292d0e94db9d8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ba4f37b82aa159c58ac016224d919f16b9b065bfa27797c138e196428c6859e1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestSizeRumQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestSizeRumQueryGroupBy]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestSizeRumQueryGroupBy]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ff8023dc64d76372ad5d4d8c3a948c64f01860bc0c5cf2e49b4dfb4217987f10)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetHostmapDefinitionRequestSizeRumQueryGroupByOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestSizeRumQueryGroupByOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cac435aa930beb397bccae82adf47dd47459d09e13ec944941f7a57c0b5dcac2)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putSortQuery")
    def put_sort_query(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        value = PowerpackWidgetHostmapDefinitionRequestSizeRumQueryGroupBySortQuery(
            aggregation=aggregation, order=order, facet=facet
        )

        return typing.cast(None, jsii.invoke(self, "putSortQuery", [value]))

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetLimit")
    def reset_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLimit", []))

    @jsii.member(jsii_name="resetSortQuery")
    def reset_sort_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSortQuery", []))

    @builtins.property
    @jsii.member(jsii_name="sortQuery")
    def sort_query(
        self,
    ) -> "PowerpackWidgetHostmapDefinitionRequestSizeRumQueryGroupBySortQueryOutputReference":
        return typing.cast("PowerpackWidgetHostmapDefinitionRequestSizeRumQueryGroupBySortQueryOutputReference", jsii.get(self, "sortQuery"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="limitInput")
    def limit_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "limitInput"))

    @builtins.property
    @jsii.member(jsii_name="sortQueryInput")
    def sort_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetHostmapDefinitionRequestSizeRumQueryGroupBySortQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetHostmapDefinitionRequestSizeRumQueryGroupBySortQuery"], jsii.get(self, "sortQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0807e29d65c1467b9fba0ae7b4394aedf016ec3d80d22914919bb2856dd9d0e0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="limit")
    def limit(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "limit"))

    @limit.setter
    def limit(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0e5dfc28c2c064a5c57b3c75f7e154c242c1a26139229c3607f7a67f5f67622b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "limit", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHostmapDefinitionRequestSizeRumQueryGroupBy]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHostmapDefinitionRequestSizeRumQueryGroupBy]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHostmapDefinitionRequestSizeRumQueryGroupBy]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__874a52533e9f8eaa3a1b68846a611e6770d3b9c864712bfbe80bba06ab95752c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestSizeRumQueryGroupBySortQuery",
    jsii_struct_bases=[],
    name_mapping={"aggregation": "aggregation", "order": "order", "facet": "facet"},
)
class PowerpackWidgetHostmapDefinitionRequestSizeRumQueryGroupBySortQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7382ee3eda4497512e06d87d4efa3352c4d2473cc30b6f68cf4817aeca9076d8)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument order", value=order, expected_type=type_hints["order"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
            "order": order,
        }
        if facet is not None:
            self._values["facet"] = facet

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def order(self) -> builtins.str:
        '''Widget sorting methods. Valid values are ``asc``, ``desc``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        result = self._values.get("order")
        assert result is not None, "Required property 'order' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetHostmapDefinitionRequestSizeRumQueryGroupBySortQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetHostmapDefinitionRequestSizeRumQueryGroupBySortQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestSizeRumQueryGroupBySortQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__14acb95c6169212d9d2a496de44aef20fc296e26d54d937cfe7416af93d00c10)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="orderInput")
    def order_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "orderInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f03f00f431dd3d30053d8fa69b02fe9486af367e8a90093abd2fa8a26c29125b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1ebb5566ff211a9d1c32b6cb6482e68f38c4c21291fc8e456c9dd8cec0e83932)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="order")
    def order(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "order"))

    @order.setter
    def order(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8b502da157149a8c7c743d7bf38689796507b10ed328fc9469097311908641f3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "order", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetHostmapDefinitionRequestSizeRumQueryGroupBySortQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetHostmapDefinitionRequestSizeRumQueryGroupBySortQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetHostmapDefinitionRequestSizeRumQueryGroupBySortQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3c926e080296ada8ce3d3c1cfd8021b1948bd60d24c161decbc2da074c1d7f05)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestSizeRumQueryMultiCompute",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetHostmapDefinitionRequestSizeRumQueryMultiCompute:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7240361676408ca4ebd63375c6cb7a3a371b68d04eb4c9e8cc8e48f6c4f57746)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetHostmapDefinitionRequestSizeRumQueryMultiCompute(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetHostmapDefinitionRequestSizeRumQueryMultiComputeList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestSizeRumQueryMultiComputeList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d02da6637008517771b3b255ac733d7e33d3192f48db654d93ed557a5c822ff6)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetHostmapDefinitionRequestSizeRumQueryMultiComputeOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f2470afe92fdf3ddf7145122a7e80eddb7c5f98a365f488e79da22009fbefdff)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetHostmapDefinitionRequestSizeRumQueryMultiComputeOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__302f719ba6c8962a07a873fc91089d74efc40aa15a4d8c8d5f111b0a5a12db65)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e60e63cd7a1f34eabf9aa7e7b2a9103fe06591325ce9f0d8a33af6a600c40897)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c5decd7939a98d7ace7e6ab2111aa43fd3f36a62a01df93b4c895bdde807da88)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestSizeRumQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestSizeRumQueryMultiCompute]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestSizeRumQueryMultiCompute]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bc86a089e522b658957a1a032fa8d78e8d1785218fe6b6e28acc95c069ada163)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetHostmapDefinitionRequestSizeRumQueryMultiComputeOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestSizeRumQueryMultiComputeOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fbe14098fb383f004491492386356b655fe0bbb8a59e23b6a3f1879d5b411a0c)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0e1559899a519cde1df99505bda95fa9e461b4a925ccf12e550100c77f2b8944)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ec2066619512066564666b7448831d36ffeac6e7899280646c2e17211f66df80)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5a1932d005ba69224afc679c5360066bd397b78da7d7d6b9da98d21dae8974b5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHostmapDefinitionRequestSizeRumQueryMultiCompute]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHostmapDefinitionRequestSizeRumQueryMultiCompute]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHostmapDefinitionRequestSizeRumQueryMultiCompute]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9e57cd54f2520e8327d7e73bea001ed1a53406d1274ff80d11d95b419cfbd420)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetHostmapDefinitionRequestSizeRumQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestSizeRumQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__26b2a8a2cf65d7bfac2202ba7e60fb73306eb2bc375c3d44ae9035f07dda0737)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putComputeQuery")
    def put_compute_query(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        value = PowerpackWidgetHostmapDefinitionRequestSizeRumQueryComputeQuery(
            aggregation=aggregation, facet=facet, interval=interval
        )

        return typing.cast(None, jsii.invoke(self, "putComputeQuery", [value]))

    @jsii.member(jsii_name="putGroupBy")
    def put_group_by(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHostmapDefinitionRequestSizeRumQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7763121c9defcaf1fff248a60f0db291ea794b31efd02ccb4e5909418d1da0f6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putGroupBy", [value]))

    @jsii.member(jsii_name="putMultiCompute")
    def put_multi_compute(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHostmapDefinitionRequestSizeRumQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__443073d189a5d13fe461714c8695213d0133019a155e4fa4510c8a9089352ce7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putMultiCompute", [value]))

    @jsii.member(jsii_name="resetComputeQuery")
    def reset_compute_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetComputeQuery", []))

    @jsii.member(jsii_name="resetGroupBy")
    def reset_group_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGroupBy", []))

    @jsii.member(jsii_name="resetMultiCompute")
    def reset_multi_compute(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMultiCompute", []))

    @jsii.member(jsii_name="resetSearchQuery")
    def reset_search_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSearchQuery", []))

    @builtins.property
    @jsii.member(jsii_name="computeQuery")
    def compute_query(
        self,
    ) -> PowerpackWidgetHostmapDefinitionRequestSizeRumQueryComputeQueryOutputReference:
        return typing.cast(PowerpackWidgetHostmapDefinitionRequestSizeRumQueryComputeQueryOutputReference, jsii.get(self, "computeQuery"))

    @builtins.property
    @jsii.member(jsii_name="groupBy")
    def group_by(
        self,
    ) -> PowerpackWidgetHostmapDefinitionRequestSizeRumQueryGroupByList:
        return typing.cast(PowerpackWidgetHostmapDefinitionRequestSizeRumQueryGroupByList, jsii.get(self, "groupBy"))

    @builtins.property
    @jsii.member(jsii_name="multiCompute")
    def multi_compute(
        self,
    ) -> PowerpackWidgetHostmapDefinitionRequestSizeRumQueryMultiComputeList:
        return typing.cast(PowerpackWidgetHostmapDefinitionRequestSizeRumQueryMultiComputeList, jsii.get(self, "multiCompute"))

    @builtins.property
    @jsii.member(jsii_name="computeQueryInput")
    def compute_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetHostmapDefinitionRequestSizeRumQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetHostmapDefinitionRequestSizeRumQueryComputeQuery], jsii.get(self, "computeQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="groupByInput")
    def group_by_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestSizeRumQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestSizeRumQueryGroupBy]]], jsii.get(self, "groupByInput"))

    @builtins.property
    @jsii.member(jsii_name="indexInput")
    def index_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "indexInput"))

    @builtins.property
    @jsii.member(jsii_name="multiComputeInput")
    def multi_compute_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestSizeRumQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestSizeRumQueryMultiCompute]]], jsii.get(self, "multiComputeInput"))

    @builtins.property
    @jsii.member(jsii_name="searchQueryInput")
    def search_query_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "searchQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="index")
    def index(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "index"))

    @index.setter
    def index(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4fbace557b3d757816cf81960643c83d3d241902cc602dd3ab9372b52dfd20a1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "index", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="searchQuery")
    def search_query(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "searchQuery"))

    @search_query.setter
    def search_query(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2aeb9fbb7ebabfa671e46e7c3d4bc148fe1cd6991502b59c8c77c511626b0c3a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "searchQuery", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetHostmapDefinitionRequestSizeRumQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetHostmapDefinitionRequestSizeRumQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetHostmapDefinitionRequestSizeRumQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__01bd41d0b67efa7870924971bd58aa029768e1d45257b98f541ba4ab0a308886)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestSizeSecurityQuery",
    jsii_struct_bases=[],
    name_mapping={
        "index": "index",
        "compute_query": "computeQuery",
        "group_by": "groupBy",
        "multi_compute": "multiCompute",
        "search_query": "searchQuery",
    },
)
class PowerpackWidgetHostmapDefinitionRequestSizeSecurityQuery:
    def __init__(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union["PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryComputeQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryGroupBy", typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryMultiCompute", typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        if isinstance(compute_query, dict):
            compute_query = PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryComputeQuery(**compute_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b9da5a6b20fdbccd4118084fbf48c855b6782973b09080361cef539e3f187fe3)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
            check_type(argname="argument compute_query", value=compute_query, expected_type=type_hints["compute_query"])
            check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
            check_type(argname="argument multi_compute", value=multi_compute, expected_type=type_hints["multi_compute"])
            check_type(argname="argument search_query", value=search_query, expected_type=type_hints["search_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "index": index,
        }
        if compute_query is not None:
            self._values["compute_query"] = compute_query
        if group_by is not None:
            self._values["group_by"] = group_by
        if multi_compute is not None:
            self._values["multi_compute"] = multi_compute
        if search_query is not None:
            self._values["search_query"] = search_query

    @builtins.property
    def index(self) -> builtins.str:
        '''The name of the index to query.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        '''
        result = self._values.get("index")
        assert result is not None, "Required property 'index' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def compute_query(
        self,
    ) -> typing.Optional["PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryComputeQuery"]:
        '''compute_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        '''
        result = self._values.get("compute_query")
        return typing.cast(typing.Optional["PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryComputeQuery"], result)

    @builtins.property
    def group_by(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryGroupBy"]]]:
        '''group_by block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        '''
        result = self._values.get("group_by")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryGroupBy"]]], result)

    @builtins.property
    def multi_compute(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryMultiCompute"]]]:
        '''multi_compute block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        '''
        result = self._values.get("multi_compute")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryMultiCompute"]]], result)

    @builtins.property
    def search_query(self) -> typing.Optional[builtins.str]:
        '''The search query to use.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        result = self._values.get("search_query")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetHostmapDefinitionRequestSizeSecurityQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryComputeQuery",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryComputeQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a14dd5df330ca36bfd0764095258e06fde751350dd144af2c30c51bcfe621a7a)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryComputeQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryComputeQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryComputeQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4ba5705faafc24a407ae11cd8c20c3cf3af192af41ca71f34e3b3362889152c6)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e1eb5c0409ce0014228383d4a821903ff703d568c976db3c38d102e551e1be71)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cf8e3b0481c0c7eca30f5ef9939a9dcb25417a2970ff98e2cb1c2df38d120dad)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e2286e516bd4e4be5ca0650813ea4d90644e4dc3fde6d4005abf8dc877d5f68f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryComputeQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryComputeQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__375995f3bfb4fcace4a68481b7009462f7e0ba8934b74d446ad748f5cfc72571)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryGroupBy",
    jsii_struct_bases=[],
    name_mapping={"facet": "facet", "limit": "limit", "sort_query": "sortQuery"},
)
class PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryGroupBy:
    def __init__(
        self,
        *,
        facet: typing.Optional[builtins.str] = None,
        limit: typing.Optional[jsii.Number] = None,
        sort_query: typing.Optional[typing.Union["PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryGroupBySortQuery", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param limit: The maximum number of items in the group. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param sort_query: sort_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        if isinstance(sort_query, dict):
            sort_query = PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryGroupBySortQuery(**sort_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b1a14fbe1457f4604cea4a83d511f6cb02a8ade569d015e95ae3dc89d5874740)
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
            check_type(argname="argument sort_query", value=sort_query, expected_type=type_hints["sort_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if facet is not None:
            self._values["facet"] = facet
        if limit is not None:
            self._values["limit"] = limit
        if sort_query is not None:
            self._values["sort_query"] = sort_query

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def limit(self) -> typing.Optional[jsii.Number]:
        '''The maximum number of items in the group.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        '''
        result = self._values.get("limit")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def sort_query(
        self,
    ) -> typing.Optional["PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryGroupBySortQuery"]:
        '''sort_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        result = self._values.get("sort_query")
        return typing.cast(typing.Optional["PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryGroupBySortQuery"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryGroupBy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryGroupByList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryGroupByList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__99c68b11ef0b549bb5a3730289c74847b3d68ab3337e7cfd5f7ee4208ad6632c)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryGroupByOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__03cbf05803c6c44372283e3e687ed252e3149989e7a84f794644ea270a7871b6)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryGroupByOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__365ff2cc386cfc683c2c96413b6a72ed58cae01d5bae82ffb1cb4655ad99f2a4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c27f3d1c7b815d387708dcfadaf0e3b3d0b88fcbab350421c86a624503d53090)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7fd04307d9a67f3b7421da4414a730896c0babb9efb5e019ef9cf7c5749bb255)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryGroupBy]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryGroupBy]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__00d538bdb6e606c95f67b41769000c68748bb4798e7ed2e743ffd38113ec3bf7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryGroupByOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryGroupByOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b6f5c07a5e3447f1f6fea8c6f2d4134e0829e61e5f1a597caee089a8f645c698)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putSortQuery")
    def put_sort_query(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        value = PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryGroupBySortQuery(
            aggregation=aggregation, order=order, facet=facet
        )

        return typing.cast(None, jsii.invoke(self, "putSortQuery", [value]))

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetLimit")
    def reset_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLimit", []))

    @jsii.member(jsii_name="resetSortQuery")
    def reset_sort_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSortQuery", []))

    @builtins.property
    @jsii.member(jsii_name="sortQuery")
    def sort_query(
        self,
    ) -> "PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryGroupBySortQueryOutputReference":
        return typing.cast("PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryGroupBySortQueryOutputReference", jsii.get(self, "sortQuery"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="limitInput")
    def limit_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "limitInput"))

    @builtins.property
    @jsii.member(jsii_name="sortQueryInput")
    def sort_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryGroupBySortQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryGroupBySortQuery"], jsii.get(self, "sortQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__604f8f0b7369dc810f7135d79d73c405d31c991a03f6f93b2c3d8d9dbf11bb59)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="limit")
    def limit(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "limit"))

    @limit.setter
    def limit(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1fd7abcc44ac33d8f5c6fe758fccb79ac850070836f092d9c6c8e1c081754a77)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "limit", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryGroupBy]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryGroupBy]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryGroupBy]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1224d8e4a884cf53d39055e929097b6d285b77d7f7f1b95ca729f0c19f064465)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryGroupBySortQuery",
    jsii_struct_bases=[],
    name_mapping={"aggregation": "aggregation", "order": "order", "facet": "facet"},
)
class PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryGroupBySortQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__87e499c146295b29bf1e7dd09731e994ebba700f6c8d1f0521a6bbdee7d0367e)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument order", value=order, expected_type=type_hints["order"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
            "order": order,
        }
        if facet is not None:
            self._values["facet"] = facet

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def order(self) -> builtins.str:
        '''Widget sorting methods. Valid values are ``asc``, ``desc``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        result = self._values.get("order")
        assert result is not None, "Required property 'order' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryGroupBySortQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryGroupBySortQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryGroupBySortQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__99b7d32b863b92794e0b7d02904ad12284f79c3978440263bd72962d343522e1)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="orderInput")
    def order_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "orderInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__63540abbd16443898a976006b8f8ebe900b93b547cf5412119b76a1ea47c5803)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cb52f20cc65f352021ac40363af40284091f2b677da6d3e3ef13dd36182ffe93)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="order")
    def order(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "order"))

    @order.setter
    def order(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2b8f21e45f0405b5bc0949ddac4bf59b6b7cbc819a28c337e65f65a3b1e14990)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "order", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryGroupBySortQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryGroupBySortQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryGroupBySortQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7a55f42a77afc4abbc843e070f2f143e762535303f86ce08d7e53027e25392f6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryMultiCompute",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryMultiCompute:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f1ae1d63f6c1d3c389a009aaf23cd25583ec42b715d29ea4e0a10e0db13d381c)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryMultiCompute(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryMultiComputeList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryMultiComputeList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__523295f0032b5cd813fac0a68274f56aea2b38cc236a67da35ba4a7a53b5e203)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryMultiComputeOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d3bda3fa4f04ce0ab2786760429fa164d687fb66f6f622a03513548015819a9b)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryMultiComputeOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__310e99ab85e86eb116cf575991dcd86fdda0b25c9548358b55d50147d08ca5a9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__640b64279aba93e22444b01efb03001854558151862df4ae963e6b13175f038c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c01a2c11076328b4174d661d2459baf09fbf1a33b0061b9cd84953873dd4f6fd)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryMultiCompute]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryMultiCompute]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5f58d645ad7b04bf300cb2b4b59c9af2165b132a2f45849e5d63cd9279f05d81)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryMultiComputeOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryMultiComputeOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f4c2a28cd1fd97950227243675c2c5294c4ab9488d0a8a1064496b80445f7657)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__eea7cf82ece21b51a23063e1490b9e72c9d246abd8613900aba3d9cfda3b35ce)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6372b07565b9cbcc9458823d930c9c9e8a1ed96e81931355649c7dd6481a8d90)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2769769c3bc612abf44a7603085d0eb372459616a850c35e5b6b5cc798dd8aee)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryMultiCompute]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryMultiCompute]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryMultiCompute]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f47a5cffcfa55dc014e594130861f9190934ec70a058ef13ba7b51ff8a5266f7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9655089e5dd0029f748e0b5c5118aa702a7b8670145e3f4eb120dce135ca8914)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putComputeQuery")
    def put_compute_query(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        value = PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryComputeQuery(
            aggregation=aggregation, facet=facet, interval=interval
        )

        return typing.cast(None, jsii.invoke(self, "putComputeQuery", [value]))

    @jsii.member(jsii_name="putGroupBy")
    def put_group_by(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2d3fafa4f822dd9a73e550eef71c2e3ac57056300e65e77dc83b9b0a09611633)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putGroupBy", [value]))

    @jsii.member(jsii_name="putMultiCompute")
    def put_multi_compute(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f3e73503d230afb6787d7532afc07966358bb342dc437eb65d4afaa37f9b4434)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putMultiCompute", [value]))

    @jsii.member(jsii_name="resetComputeQuery")
    def reset_compute_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetComputeQuery", []))

    @jsii.member(jsii_name="resetGroupBy")
    def reset_group_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGroupBy", []))

    @jsii.member(jsii_name="resetMultiCompute")
    def reset_multi_compute(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMultiCompute", []))

    @jsii.member(jsii_name="resetSearchQuery")
    def reset_search_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSearchQuery", []))

    @builtins.property
    @jsii.member(jsii_name="computeQuery")
    def compute_query(
        self,
    ) -> PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryComputeQueryOutputReference:
        return typing.cast(PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryComputeQueryOutputReference, jsii.get(self, "computeQuery"))

    @builtins.property
    @jsii.member(jsii_name="groupBy")
    def group_by(
        self,
    ) -> PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryGroupByList:
        return typing.cast(PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryGroupByList, jsii.get(self, "groupBy"))

    @builtins.property
    @jsii.member(jsii_name="multiCompute")
    def multi_compute(
        self,
    ) -> PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryMultiComputeList:
        return typing.cast(PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryMultiComputeList, jsii.get(self, "multiCompute"))

    @builtins.property
    @jsii.member(jsii_name="computeQueryInput")
    def compute_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryComputeQuery], jsii.get(self, "computeQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="groupByInput")
    def group_by_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryGroupBy]]], jsii.get(self, "groupByInput"))

    @builtins.property
    @jsii.member(jsii_name="indexInput")
    def index_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "indexInput"))

    @builtins.property
    @jsii.member(jsii_name="multiComputeInput")
    def multi_compute_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryMultiCompute]]], jsii.get(self, "multiComputeInput"))

    @builtins.property
    @jsii.member(jsii_name="searchQueryInput")
    def search_query_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "searchQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="index")
    def index(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "index"))

    @index.setter
    def index(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__92382277665d4b5f2ceff1fee9920864a903685846c9d9a9d15ac60953b9b7a7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "index", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="searchQuery")
    def search_query(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "searchQuery"))

    @search_query.setter
    def search_query(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4e82aa4469ef78bd1d15950832fa994618c0882d9a7035f28b6ed3383d56e4e0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "searchQuery", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetHostmapDefinitionRequestSizeSecurityQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetHostmapDefinitionRequestSizeSecurityQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetHostmapDefinitionRequestSizeSecurityQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a3f7119071690b2b4a46622795d46a98264a3c311c66d642ed2901b6e4e3015b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionStyle",
    jsii_struct_bases=[],
    name_mapping={
        "fill_max": "fillMax",
        "fill_min": "fillMin",
        "palette": "palette",
        "palette_flip": "paletteFlip",
    },
)
class PowerpackWidgetHostmapDefinitionStyle:
    def __init__(
        self,
        *,
        fill_max: typing.Optional[builtins.str] = None,
        fill_min: typing.Optional[builtins.str] = None,
        palette: typing.Optional[builtins.str] = None,
        palette_flip: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
    ) -> None:
        '''
        :param fill_max: The max value to use to color the map. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#fill_max Powerpack#fill_max}
        :param fill_min: The min value to use to color the map. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#fill_min Powerpack#fill_min}
        :param palette: A color palette to apply to the widget. The available options are available at: https://docs.datadoghq.com/dashboards/widgets/timeseries/#appearance. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette Powerpack#palette}
        :param palette_flip: A Boolean indicating whether to flip the palette tones. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette_flip Powerpack#palette_flip}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1eb7f505b0285db8eb95ea33ffdd2bd22ca7296124019b3bbe97705ed1134f32)
            check_type(argname="argument fill_max", value=fill_max, expected_type=type_hints["fill_max"])
            check_type(argname="argument fill_min", value=fill_min, expected_type=type_hints["fill_min"])
            check_type(argname="argument palette", value=palette, expected_type=type_hints["palette"])
            check_type(argname="argument palette_flip", value=palette_flip, expected_type=type_hints["palette_flip"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if fill_max is not None:
            self._values["fill_max"] = fill_max
        if fill_min is not None:
            self._values["fill_min"] = fill_min
        if palette is not None:
            self._values["palette"] = palette
        if palette_flip is not None:
            self._values["palette_flip"] = palette_flip

    @builtins.property
    def fill_max(self) -> typing.Optional[builtins.str]:
        '''The max value to use to color the map.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#fill_max Powerpack#fill_max}
        '''
        result = self._values.get("fill_max")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def fill_min(self) -> typing.Optional[builtins.str]:
        '''The min value to use to color the map.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#fill_min Powerpack#fill_min}
        '''
        result = self._values.get("fill_min")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def palette(self) -> typing.Optional[builtins.str]:
        '''A color palette to apply to the widget. The available options are available at: https://docs.datadoghq.com/dashboards/widgets/timeseries/#appearance.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette Powerpack#palette}
        '''
        result = self._values.get("palette")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def palette_flip(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        '''A Boolean indicating whether to flip the palette tones.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette_flip Powerpack#palette_flip}
        '''
        result = self._values.get("palette_flip")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetHostmapDefinitionStyle(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetHostmapDefinitionStyleOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetHostmapDefinitionStyleOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__11e34c2d061175fbec649089d276731dcb21a27a060995f22b1875fff3634dce)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFillMax")
    def reset_fill_max(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFillMax", []))

    @jsii.member(jsii_name="resetFillMin")
    def reset_fill_min(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFillMin", []))

    @jsii.member(jsii_name="resetPalette")
    def reset_palette(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPalette", []))

    @jsii.member(jsii_name="resetPaletteFlip")
    def reset_palette_flip(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPaletteFlip", []))

    @builtins.property
    @jsii.member(jsii_name="fillMaxInput")
    def fill_max_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "fillMaxInput"))

    @builtins.property
    @jsii.member(jsii_name="fillMinInput")
    def fill_min_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "fillMinInput"))

    @builtins.property
    @jsii.member(jsii_name="paletteFlipInput")
    def palette_flip_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "paletteFlipInput"))

    @builtins.property
    @jsii.member(jsii_name="paletteInput")
    def palette_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "paletteInput"))

    @builtins.property
    @jsii.member(jsii_name="fillMax")
    def fill_max(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "fillMax"))

    @fill_max.setter
    def fill_max(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__74f1bd84e71355431703985fac3a11795872b925de1682f4aba4e6a5c945af96)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "fillMax", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="fillMin")
    def fill_min(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "fillMin"))

    @fill_min.setter
    def fill_min(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4ae1aa6b25189f9d23d7519737e4b8edf2d390467b2239cc0984aca9ce8e5d79)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "fillMin", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="palette")
    def palette(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "palette"))

    @palette.setter
    def palette(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__655e7043016b802357d4670a54e1872c3a064ac34c8a60c952b58f7618df7f6a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "palette", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="paletteFlip")
    def palette_flip(self) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "paletteFlip"))

    @palette_flip.setter
    def palette_flip(
        self,
        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cd057ca686a7b323dccc6a256b9f84883365047e60ae7736231dc80e6d95d7e7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "paletteFlip", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[PowerpackWidgetHostmapDefinitionStyle]:
        return typing.cast(typing.Optional[PowerpackWidgetHostmapDefinitionStyle], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetHostmapDefinitionStyle],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4cbdafd35badb65c723bfd93c44370cd155b8513be553d80b063090633418a2a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetIframeDefinition",
    jsii_struct_bases=[],
    name_mapping={"url": "url"},
)
class PowerpackWidgetIframeDefinition:
    def __init__(self, *, url: builtins.str) -> None:
        '''
        :param url: The URL to use as a data source for the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#url Powerpack#url}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4c1f252e38b2f48faa4b7b87a41137c807924e33600237d7dedce097e9ee78a1)
            check_type(argname="argument url", value=url, expected_type=type_hints["url"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "url": url,
        }

    @builtins.property
    def url(self) -> builtins.str:
        '''The URL to use as a data source for the widget.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#url Powerpack#url}
        '''
        result = self._values.get("url")
        assert result is not None, "Required property 'url' is missing"
        return typing.cast(builtins.str, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetIframeDefinition(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetIframeDefinitionOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetIframeDefinitionOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4bc8f5284b50a5e391a8c7e87da1d86fc94fafe75c4f08387c1d1ee7f8414733)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @builtins.property
    @jsii.member(jsii_name="urlInput")
    def url_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "urlInput"))

    @builtins.property
    @jsii.member(jsii_name="url")
    def url(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "url"))

    @url.setter
    def url(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5546535a977bc7853db444d267c93d80320b1ec2ed0efb5079012f26e65df190)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "url", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[PowerpackWidgetIframeDefinition]:
        return typing.cast(typing.Optional[PowerpackWidgetIframeDefinition], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetIframeDefinition],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7aaee0701846a06a13dfa700cc69a7d278b3ac36789873584f98fd2927765c85)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetImageDefinition",
    jsii_struct_bases=[],
    name_mapping={
        "url": "url",
        "has_background": "hasBackground",
        "has_border": "hasBorder",
        "horizontal_align": "horizontalAlign",
        "margin": "margin",
        "sizing": "sizing",
        "url_dark_theme": "urlDarkTheme",
        "vertical_align": "verticalAlign",
    },
)
class PowerpackWidgetImageDefinition:
    def __init__(
        self,
        *,
        url: builtins.str,
        has_background: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        has_border: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        horizontal_align: typing.Optional[builtins.str] = None,
        margin: typing.Optional[builtins.str] = None,
        sizing: typing.Optional[builtins.str] = None,
        url_dark_theme: typing.Optional[builtins.str] = None,
        vertical_align: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param url: The URL to use as a data source for the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#url Powerpack#url}
        :param has_background: Whether to display a background or not. Defaults to ``true``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#has_background Powerpack#has_background}
        :param has_border: Whether to display a border or not. Defaults to ``true``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#has_border Powerpack#has_border}
        :param horizontal_align: The horizontal alignment for the widget. Valid values are ``center``, ``left``, ``right``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#horizontal_align Powerpack#horizontal_align}
        :param margin: The margins to use around the image. Note: ``small`` and ``large`` values are deprecated. Valid values are ``sm``, ``md``, ``lg``, ``small``, ``large``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#margin Powerpack#margin}
        :param sizing: The preferred method to adapt the dimensions of the image. The values are based on the image ``object-fit`` CSS properties. Note: ``zoom``, ``fit`` and ``center`` values are deprecated. Valid values are ``fill``, ``contain``, ``cover``, ``none``, ``scale-down``, ``zoom``, ``fit``, ``center``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sizing Powerpack#sizing}
        :param url_dark_theme: The URL in dark mode to use as a data source for the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#url_dark_theme Powerpack#url_dark_theme}
        :param vertical_align: The vertical alignment for the widget. Valid values are ``center``, ``top``, ``bottom``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#vertical_align Powerpack#vertical_align}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0d3a8e594c7f889680501a7ed91ca553dd3a7b65136e395a6b48b44abad824f6)
            check_type(argname="argument url", value=url, expected_type=type_hints["url"])
            check_type(argname="argument has_background", value=has_background, expected_type=type_hints["has_background"])
            check_type(argname="argument has_border", value=has_border, expected_type=type_hints["has_border"])
            check_type(argname="argument horizontal_align", value=horizontal_align, expected_type=type_hints["horizontal_align"])
            check_type(argname="argument margin", value=margin, expected_type=type_hints["margin"])
            check_type(argname="argument sizing", value=sizing, expected_type=type_hints["sizing"])
            check_type(argname="argument url_dark_theme", value=url_dark_theme, expected_type=type_hints["url_dark_theme"])
            check_type(argname="argument vertical_align", value=vertical_align, expected_type=type_hints["vertical_align"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "url": url,
        }
        if has_background is not None:
            self._values["has_background"] = has_background
        if has_border is not None:
            self._values["has_border"] = has_border
        if horizontal_align is not None:
            self._values["horizontal_align"] = horizontal_align
        if margin is not None:
            self._values["margin"] = margin
        if sizing is not None:
            self._values["sizing"] = sizing
        if url_dark_theme is not None:
            self._values["url_dark_theme"] = url_dark_theme
        if vertical_align is not None:
            self._values["vertical_align"] = vertical_align

    @builtins.property
    def url(self) -> builtins.str:
        '''The URL to use as a data source for the widget.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#url Powerpack#url}
        '''
        result = self._values.get("url")
        assert result is not None, "Required property 'url' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def has_background(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        '''Whether to display a background or not. Defaults to ``true``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#has_background Powerpack#has_background}
        '''
        result = self._values.get("has_background")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)

    @builtins.property
    def has_border(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        '''Whether to display a border or not. Defaults to ``true``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#has_border Powerpack#has_border}
        '''
        result = self._values.get("has_border")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)

    @builtins.property
    def horizontal_align(self) -> typing.Optional[builtins.str]:
        '''The horizontal alignment for the widget. Valid values are ``center``, ``left``, ``right``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#horizontal_align Powerpack#horizontal_align}
        '''
        result = self._values.get("horizontal_align")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def margin(self) -> typing.Optional[builtins.str]:
        '''The margins to use around the image.

        Note: ``small`` and ``large`` values are deprecated. Valid values are ``sm``, ``md``, ``lg``, ``small``, ``large``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#margin Powerpack#margin}
        '''
        result = self._values.get("margin")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def sizing(self) -> typing.Optional[builtins.str]:
        '''The preferred method to adapt the dimensions of the image.

        The values are based on the image ``object-fit`` CSS properties. Note: ``zoom``, ``fit`` and ``center`` values are deprecated. Valid values are ``fill``, ``contain``, ``cover``, ``none``, ``scale-down``, ``zoom``, ``fit``, ``center``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sizing Powerpack#sizing}
        '''
        result = self._values.get("sizing")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def url_dark_theme(self) -> typing.Optional[builtins.str]:
        '''The URL in dark mode to use as a data source for the widget.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#url_dark_theme Powerpack#url_dark_theme}
        '''
        result = self._values.get("url_dark_theme")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def vertical_align(self) -> typing.Optional[builtins.str]:
        '''The vertical alignment for the widget. Valid values are ``center``, ``top``, ``bottom``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#vertical_align Powerpack#vertical_align}
        '''
        result = self._values.get("vertical_align")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetImageDefinition(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetImageDefinitionOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetImageDefinitionOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b800633df8937fbea0df0f8a8ab251064fc003270f72fec9334998eb129255ec)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetHasBackground")
    def reset_has_background(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHasBackground", []))

    @jsii.member(jsii_name="resetHasBorder")
    def reset_has_border(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHasBorder", []))

    @jsii.member(jsii_name="resetHorizontalAlign")
    def reset_horizontal_align(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHorizontalAlign", []))

    @jsii.member(jsii_name="resetMargin")
    def reset_margin(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMargin", []))

    @jsii.member(jsii_name="resetSizing")
    def reset_sizing(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSizing", []))

    @jsii.member(jsii_name="resetUrlDarkTheme")
    def reset_url_dark_theme(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetUrlDarkTheme", []))

    @jsii.member(jsii_name="resetVerticalAlign")
    def reset_vertical_align(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetVerticalAlign", []))

    @builtins.property
    @jsii.member(jsii_name="hasBackgroundInput")
    def has_background_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "hasBackgroundInput"))

    @builtins.property
    @jsii.member(jsii_name="hasBorderInput")
    def has_border_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "hasBorderInput"))

    @builtins.property
    @jsii.member(jsii_name="horizontalAlignInput")
    def horizontal_align_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "horizontalAlignInput"))

    @builtins.property
    @jsii.member(jsii_name="marginInput")
    def margin_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "marginInput"))

    @builtins.property
    @jsii.member(jsii_name="sizingInput")
    def sizing_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "sizingInput"))

    @builtins.property
    @jsii.member(jsii_name="urlDarkThemeInput")
    def url_dark_theme_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "urlDarkThemeInput"))

    @builtins.property
    @jsii.member(jsii_name="urlInput")
    def url_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "urlInput"))

    @builtins.property
    @jsii.member(jsii_name="verticalAlignInput")
    def vertical_align_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "verticalAlignInput"))

    @builtins.property
    @jsii.member(jsii_name="hasBackground")
    def has_background(
        self,
    ) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "hasBackground"))

    @has_background.setter
    def has_background(
        self,
        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6aa5136f7b2d557b02d82b955f8623b4bc4985ecceaddd1f8882135834a172ba)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "hasBackground", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="hasBorder")
    def has_border(self) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "hasBorder"))

    @has_border.setter
    def has_border(
        self,
        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d34d107c85f182c3b1ba1444c2843f9a65e52df45310ba335ed719ce781bb890)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "hasBorder", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="horizontalAlign")
    def horizontal_align(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "horizontalAlign"))

    @horizontal_align.setter
    def horizontal_align(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__465d96e7fa4f3f01258b3fdeed05941ef53dc8bd89b2331324cbb46a780d0438)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "horizontalAlign", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="margin")
    def margin(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "margin"))

    @margin.setter
    def margin(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0fd54931d916daa4850b246c3c0a8244d8a2424b09cc371e7ff927899a9aaf67)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "margin", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="sizing")
    def sizing(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "sizing"))

    @sizing.setter
    def sizing(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4970a594f0707d1524e4e88c50e2873ed1e9f1df7681bac7809f7d1f41495b0b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "sizing", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="url")
    def url(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "url"))

    @url.setter
    def url(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__46410917e739ded6c31f3c1bbec5ba589519313b12a093f6fce489dd8806366d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "url", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="urlDarkTheme")
    def url_dark_theme(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "urlDarkTheme"))

    @url_dark_theme.setter
    def url_dark_theme(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e3015ce24945c09c0d5ffd8a09029c08ea926fff0ca2c5ec4768ac0dfc62c772)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "urlDarkTheme", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="verticalAlign")
    def vertical_align(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "verticalAlign"))

    @vertical_align.setter
    def vertical_align(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b47c400bfa33cd85ba0882f1ee858b9ec627060a3399fabf3ec0be63b89a2466)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "verticalAlign", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[PowerpackWidgetImageDefinition]:
        return typing.cast(typing.Optional[PowerpackWidgetImageDefinition], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetImageDefinition],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fea9304089e00eba46103a7173ab222ba2f165fa6272374a3bf99cada7604949)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__965a963fb2f3c0458dbf95f722d2255f68e3db4d62ffc832baf4a7c62959d473)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(self, index: jsii.Number) -> "PowerpackWidgetOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__11a21d92fc6666e13bd356f096ceaa995ba4388ccded7b43eedbd6f8c4676b93)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1a71afcf316c80ebf24c53b126f8a969b34e2550f434d2f2500e9eec46edaac6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__af765e02d275969fd877e6d529bb9a3936eef8b12b09056ff14dcea9983ead66)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__30eb9ff6c2feac2d2705d94ce0c6a1d21b69a8368f32a0ba70b6ddea02305d64)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidget]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidget]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidget]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__67f43daca88f94707a4627823bf473235401db2d5aa1cd3046104311201fadb4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetListStreamDefinition",
    jsii_struct_bases=[],
    name_mapping={
        "request": "request",
        "title": "title",
        "title_align": "titleAlign",
        "title_size": "titleSize",
    },
)
class PowerpackWidgetListStreamDefinition:
    def __init__(
        self,
        *,
        request: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetListStreamDefinitionRequest", typing.Dict[builtins.str, typing.Any]]]],
        title: typing.Optional[builtins.str] = None,
        title_align: typing.Optional[builtins.str] = None,
        title_size: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param request: request block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#request Powerpack#request}
        :param title: The title of the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title Powerpack#title}
        :param title_align: The alignment of the widget's title. Valid values are ``center``, ``left``, ``right``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_align Powerpack#title_align}
        :param title_size: The size of the widget's title. Default is 16. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_size Powerpack#title_size}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ac199788e84f6263bfa343f3da4aaea8840973bb53d1ea5c815eb86de5f6c917)
            check_type(argname="argument request", value=request, expected_type=type_hints["request"])
            check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            check_type(argname="argument title_align", value=title_align, expected_type=type_hints["title_align"])
            check_type(argname="argument title_size", value=title_size, expected_type=type_hints["title_size"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "request": request,
        }
        if title is not None:
            self._values["title"] = title
        if title_align is not None:
            self._values["title_align"] = title_align
        if title_size is not None:
            self._values["title_size"] = title_size

    @builtins.property
    def request(
        self,
    ) -> typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetListStreamDefinitionRequest"]]:
        '''request block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#request Powerpack#request}
        '''
        result = self._values.get("request")
        assert result is not None, "Required property 'request' is missing"
        return typing.cast(typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetListStreamDefinitionRequest"]], result)

    @builtins.property
    def title(self) -> typing.Optional[builtins.str]:
        '''The title of the widget.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title Powerpack#title}
        '''
        result = self._values.get("title")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def title_align(self) -> typing.Optional[builtins.str]:
        '''The alignment of the widget's title. Valid values are ``center``, ``left``, ``right``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_align Powerpack#title_align}
        '''
        result = self._values.get("title_align")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def title_size(self) -> typing.Optional[builtins.str]:
        '''The size of the widget's title. Default is 16.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_size Powerpack#title_size}
        '''
        result = self._values.get("title_size")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetListStreamDefinition(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetListStreamDefinitionOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetListStreamDefinitionOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bcc5bd0bd3e09a81ff98bd58e91ec74209c1163141f0692562b63794a694ae4f)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putRequest")
    def put_request(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetListStreamDefinitionRequest", typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5ebf09be36319a406f544c69a9ce76a680ec27f719593f44dda84adab9e24dbf)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putRequest", [value]))

    @jsii.member(jsii_name="resetTitle")
    def reset_title(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTitle", []))

    @jsii.member(jsii_name="resetTitleAlign")
    def reset_title_align(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTitleAlign", []))

    @jsii.member(jsii_name="resetTitleSize")
    def reset_title_size(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTitleSize", []))

    @builtins.property
    @jsii.member(jsii_name="request")
    def request(self) -> "PowerpackWidgetListStreamDefinitionRequestList":
        return typing.cast("PowerpackWidgetListStreamDefinitionRequestList", jsii.get(self, "request"))

    @builtins.property
    @jsii.member(jsii_name="requestInput")
    def request_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetListStreamDefinitionRequest"]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetListStreamDefinitionRequest"]]], jsii.get(self, "requestInput"))

    @builtins.property
    @jsii.member(jsii_name="titleAlignInput")
    def title_align_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "titleAlignInput"))

    @builtins.property
    @jsii.member(jsii_name="titleInput")
    def title_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "titleInput"))

    @builtins.property
    @jsii.member(jsii_name="titleSizeInput")
    def title_size_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "titleSizeInput"))

    @builtins.property
    @jsii.member(jsii_name="title")
    def title(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "title"))

    @title.setter
    def title(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__951da5ca87bb71febc98128db5d31ed0953a7d19c1715876cd90971bcef4295b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "title", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="titleAlign")
    def title_align(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "titleAlign"))

    @title_align.setter
    def title_align(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__71e2831ad188ce45bc48ae1a96b106fc30eff5d996ec9480b9f117f86dd7de77)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "titleAlign", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="titleSize")
    def title_size(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "titleSize"))

    @title_size.setter
    def title_size(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__53c475192a763c3a2a61682e11dc09bb6aeeb930c9cf824e79b377f64a36ccc2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "titleSize", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[PowerpackWidgetListStreamDefinition]:
        return typing.cast(typing.Optional[PowerpackWidgetListStreamDefinition], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetListStreamDefinition],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2c40e9855b3f4502e15577e53cfc2e39d45a6a24d9448630d15e2e4112ff7019)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetListStreamDefinitionRequest",
    jsii_struct_bases=[],
    name_mapping={
        "columns": "columns",
        "query": "query",
        "response_format": "responseFormat",
    },
)
class PowerpackWidgetListStreamDefinitionRequest:
    def __init__(
        self,
        *,
        columns: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetListStreamDefinitionRequestColumns", typing.Dict[builtins.str, typing.Any]]]],
        query: typing.Union["PowerpackWidgetListStreamDefinitionRequestQuery", typing.Dict[builtins.str, typing.Any]],
        response_format: builtins.str,
    ) -> None:
        '''
        :param columns: columns block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#columns Powerpack#columns}
        :param query: query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        :param response_format: Widget response format. Valid values are ``event_list``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#response_format Powerpack#response_format}
        '''
        if isinstance(query, dict):
            query = PowerpackWidgetListStreamDefinitionRequestQuery(**query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ba70f75d3b12fea7db875660e928abb1da2e9887cf9733c5ca95b3c081ee9ae3)
            check_type(argname="argument columns", value=columns, expected_type=type_hints["columns"])
            check_type(argname="argument query", value=query, expected_type=type_hints["query"])
            check_type(argname="argument response_format", value=response_format, expected_type=type_hints["response_format"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "columns": columns,
            "query": query,
            "response_format": response_format,
        }

    @builtins.property
    def columns(
        self,
    ) -> typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetListStreamDefinitionRequestColumns"]]:
        '''columns block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#columns Powerpack#columns}
        '''
        result = self._values.get("columns")
        assert result is not None, "Required property 'columns' is missing"
        return typing.cast(typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetListStreamDefinitionRequestColumns"]], result)

    @builtins.property
    def query(self) -> "PowerpackWidgetListStreamDefinitionRequestQuery":
        '''query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        '''
        result = self._values.get("query")
        assert result is not None, "Required property 'query' is missing"
        return typing.cast("PowerpackWidgetListStreamDefinitionRequestQuery", result)

    @builtins.property
    def response_format(self) -> builtins.str:
        '''Widget response format. Valid values are ``event_list``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#response_format Powerpack#response_format}
        '''
        result = self._values.get("response_format")
        assert result is not None, "Required property 'response_format' is missing"
        return typing.cast(builtins.str, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetListStreamDefinitionRequest(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetListStreamDefinitionRequestColumns",
    jsii_struct_bases=[],
    name_mapping={"field": "field", "width": "width"},
)
class PowerpackWidgetListStreamDefinitionRequestColumns:
    def __init__(
        self,
        *,
        field: typing.Optional[builtins.str] = None,
        width: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param field: Widget column field. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#field Powerpack#field}
        :param width: Widget column width. Valid values are ``auto``, ``compact``, ``full``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#width Powerpack#width}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ca54d788d9888832b16e2589e817637ae9c7c6cf3f83d1383e1bfe8f03efcc74)
            check_type(argname="argument field", value=field, expected_type=type_hints["field"])
            check_type(argname="argument width", value=width, expected_type=type_hints["width"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if field is not None:
            self._values["field"] = field
        if width is not None:
            self._values["width"] = width

    @builtins.property
    def field(self) -> typing.Optional[builtins.str]:
        '''Widget column field.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#field Powerpack#field}
        '''
        result = self._values.get("field")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def width(self) -> typing.Optional[builtins.str]:
        '''Widget column width. Valid values are ``auto``, ``compact``, ``full``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#width Powerpack#width}
        '''
        result = self._values.get("width")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetListStreamDefinitionRequestColumns(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetListStreamDefinitionRequestColumnsList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetListStreamDefinitionRequestColumnsList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5a238d78347d1fb498001ddf97de253be19a442f56cbd38aa5992a90e8c69c54)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetListStreamDefinitionRequestColumnsOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f0ebd3491e67d93f8c75870d295616081c1a6e67d18f9db83207676a94ea65ba)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetListStreamDefinitionRequestColumnsOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__02c42df9d529ce0e20ea39345882bf2b316527ab77f1a53998bf19d444fd3ea5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d644d4322bb7a7d8cccb56e2a2b4f526a785ef21909ad9370f0debb52b157aaf)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__15685faa990e2fd42d9cb0f5336cdac02f65998c398ceeaedb54d09617401928)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetListStreamDefinitionRequestColumns]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetListStreamDefinitionRequestColumns]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetListStreamDefinitionRequestColumns]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a74465ecc3ec654b6572578062d8f40465e657ed7ce49df6f61348e1d96371a1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetListStreamDefinitionRequestColumnsOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetListStreamDefinitionRequestColumnsOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__db7bc3ce8e3025fccee669af45b05ea52d4885f78431cce6bb1ef14ebe1088f0)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetField")
    def reset_field(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetField", []))

    @jsii.member(jsii_name="resetWidth")
    def reset_width(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetWidth", []))

    @builtins.property
    @jsii.member(jsii_name="fieldInput")
    def field_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "fieldInput"))

    @builtins.property
    @jsii.member(jsii_name="widthInput")
    def width_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "widthInput"))

    @builtins.property
    @jsii.member(jsii_name="field")
    def field(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "field"))

    @field.setter
    def field(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__93cd9e028cc155b909e25af3d76029a1b92003d2318a35897e2d6057f00f44da)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "field", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="width")
    def width(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "width"))

    @width.setter
    def width(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cac831adb6c300270df2116e3b0acbb98579e42dc67f385078182b80589bab1d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "width", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetListStreamDefinitionRequestColumns]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetListStreamDefinitionRequestColumns]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetListStreamDefinitionRequestColumns]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__95c67f954061e1c9012ce872df1138d188a01c288d8ca9b91da0da8b2c77dd89)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetListStreamDefinitionRequestList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetListStreamDefinitionRequestList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__51ae49d37e0c0f17e0e8e73ab61533352bd24a0a33657a0d8d2f9d601fdcc27c)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetListStreamDefinitionRequestOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2c3a3de436a777c7f0a7080f924b6949f5de92bb5c343f8b7ee3a2cd053664c7)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetListStreamDefinitionRequestOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f9ae762303f8bedcaba22ecfd68919f140065079bff918174601b616e79e267f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9c90a05b69ef18387d18238dbe0aa74ff99a490b1c1928103f60a35b907c77df)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4a8a42a2b2739d2ce7ec523742f4915f3b040a5ea77d86ef081725fef366825d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetListStreamDefinitionRequest]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetListStreamDefinitionRequest]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetListStreamDefinitionRequest]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4eaafad551bb7cdb4bce0e08c6630aacada310bcf4d4f194db04be93581de3f7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetListStreamDefinitionRequestOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetListStreamDefinitionRequestOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9cbcc997d7ba7d7454ae997f2c23b1884c2776b3f7c5828f15e1e820035e2dae)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putColumns")
    def put_columns(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetListStreamDefinitionRequestColumns, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1a169398da1be6a6a9857c3234c680905db5adf02506c7746953831f2ed8a4b1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putColumns", [value]))

    @jsii.member(jsii_name="putQuery")
    def put_query(
        self,
        *,
        data_source: builtins.str,
        clustering_pattern_field_path: typing.Optional[builtins.str] = None,
        event_size: typing.Optional[builtins.str] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetListStreamDefinitionRequestQueryGroupBy", typing.Dict[builtins.str, typing.Any]]]]] = None,
        indexes: typing.Optional[typing.Sequence[builtins.str]] = None,
        query_string: typing.Optional[builtins.str] = None,
        sort: typing.Optional[typing.Union["PowerpackWidgetListStreamDefinitionRequestQuerySort", typing.Dict[builtins.str, typing.Any]]] = None,
        storage: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param data_source: Source from which to query items to display in the stream. Valid values are ``logs_stream``, ``audit_stream``, ``ci_pipeline_stream``, ``ci_test_stream``, ``rum_issue_stream``, ``apm_issue_stream``, ``trace_stream``, ``logs_issue_stream``, ``logs_pattern_stream``, ``logs_transaction_stream``, ``event_stream``, ``rum_stream``, ``llm_observability_stream``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param clustering_pattern_field_path: Specifies the field for logs pattern clustering. Can only be used with ``logs_pattern_stream``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#clustering_pattern_field_path Powerpack#clustering_pattern_field_path}
        :param event_size: Size of events displayed in widget. Required if ``data_source`` is ``event_stream``. Valid values are ``s``, ``l``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#event_size Powerpack#event_size}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param indexes: List of indexes. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#indexes Powerpack#indexes}
        :param query_string: Widget query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query_string Powerpack#query_string}
        :param sort: sort block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort Powerpack#sort}
        :param storage: Storage location (private beta). Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#storage Powerpack#storage}
        '''
        value = PowerpackWidgetListStreamDefinitionRequestQuery(
            data_source=data_source,
            clustering_pattern_field_path=clustering_pattern_field_path,
            event_size=event_size,
            group_by=group_by,
            indexes=indexes,
            query_string=query_string,
            sort=sort,
            storage=storage,
        )

        return typing.cast(None, jsii.invoke(self, "putQuery", [value]))

    @builtins.property
    @jsii.member(jsii_name="columns")
    def columns(self) -> PowerpackWidgetListStreamDefinitionRequestColumnsList:
        return typing.cast(PowerpackWidgetListStreamDefinitionRequestColumnsList, jsii.get(self, "columns"))

    @builtins.property
    @jsii.member(jsii_name="query")
    def query(self) -> "PowerpackWidgetListStreamDefinitionRequestQueryOutputReference":
        return typing.cast("PowerpackWidgetListStreamDefinitionRequestQueryOutputReference", jsii.get(self, "query"))

    @builtins.property
    @jsii.member(jsii_name="columnsInput")
    def columns_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetListStreamDefinitionRequestColumns]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetListStreamDefinitionRequestColumns]]], jsii.get(self, "columnsInput"))

    @builtins.property
    @jsii.member(jsii_name="queryInput")
    def query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetListStreamDefinitionRequestQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetListStreamDefinitionRequestQuery"], jsii.get(self, "queryInput"))

    @builtins.property
    @jsii.member(jsii_name="responseFormatInput")
    def response_format_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "responseFormatInput"))

    @builtins.property
    @jsii.member(jsii_name="responseFormat")
    def response_format(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "responseFormat"))

    @response_format.setter
    def response_format(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4741d4b7940152694b52a86a786729908423d030eafe23084f34987d4589044c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "responseFormat", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetListStreamDefinitionRequest]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetListStreamDefinitionRequest]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetListStreamDefinitionRequest]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__434aefc9a99f9102aedf2d3697257b742bba095ddcacdb0774e40c3ab0ecd151)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetListStreamDefinitionRequestQuery",
    jsii_struct_bases=[],
    name_mapping={
        "data_source": "dataSource",
        "clustering_pattern_field_path": "clusteringPatternFieldPath",
        "event_size": "eventSize",
        "group_by": "groupBy",
        "indexes": "indexes",
        "query_string": "queryString",
        "sort": "sort",
        "storage": "storage",
    },
)
class PowerpackWidgetListStreamDefinitionRequestQuery:
    def __init__(
        self,
        *,
        data_source: builtins.str,
        clustering_pattern_field_path: typing.Optional[builtins.str] = None,
        event_size: typing.Optional[builtins.str] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetListStreamDefinitionRequestQueryGroupBy", typing.Dict[builtins.str, typing.Any]]]]] = None,
        indexes: typing.Optional[typing.Sequence[builtins.str]] = None,
        query_string: typing.Optional[builtins.str] = None,
        sort: typing.Optional[typing.Union["PowerpackWidgetListStreamDefinitionRequestQuerySort", typing.Dict[builtins.str, typing.Any]]] = None,
        storage: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param data_source: Source from which to query items to display in the stream. Valid values are ``logs_stream``, ``audit_stream``, ``ci_pipeline_stream``, ``ci_test_stream``, ``rum_issue_stream``, ``apm_issue_stream``, ``trace_stream``, ``logs_issue_stream``, ``logs_pattern_stream``, ``logs_transaction_stream``, ``event_stream``, ``rum_stream``, ``llm_observability_stream``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param clustering_pattern_field_path: Specifies the field for logs pattern clustering. Can only be used with ``logs_pattern_stream``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#clustering_pattern_field_path Powerpack#clustering_pattern_field_path}
        :param event_size: Size of events displayed in widget. Required if ``data_source`` is ``event_stream``. Valid values are ``s``, ``l``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#event_size Powerpack#event_size}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param indexes: List of indexes. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#indexes Powerpack#indexes}
        :param query_string: Widget query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query_string Powerpack#query_string}
        :param sort: sort block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort Powerpack#sort}
        :param storage: Storage location (private beta). Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#storage Powerpack#storage}
        '''
        if isinstance(sort, dict):
            sort = PowerpackWidgetListStreamDefinitionRequestQuerySort(**sort)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ad55f558a3f9c7d98424ced9e7d9e3dfc88b3f66eaceb9795ff88a4bf2cb79ef)
            check_type(argname="argument data_source", value=data_source, expected_type=type_hints["data_source"])
            check_type(argname="argument clustering_pattern_field_path", value=clustering_pattern_field_path, expected_type=type_hints["clustering_pattern_field_path"])
            check_type(argname="argument event_size", value=event_size, expected_type=type_hints["event_size"])
            check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
            check_type(argname="argument indexes", value=indexes, expected_type=type_hints["indexes"])
            check_type(argname="argument query_string", value=query_string, expected_type=type_hints["query_string"])
            check_type(argname="argument sort", value=sort, expected_type=type_hints["sort"])
            check_type(argname="argument storage", value=storage, expected_type=type_hints["storage"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "data_source": data_source,
        }
        if clustering_pattern_field_path is not None:
            self._values["clustering_pattern_field_path"] = clustering_pattern_field_path
        if event_size is not None:
            self._values["event_size"] = event_size
        if group_by is not None:
            self._values["group_by"] = group_by
        if indexes is not None:
            self._values["indexes"] = indexes
        if query_string is not None:
            self._values["query_string"] = query_string
        if sort is not None:
            self._values["sort"] = sort
        if storage is not None:
            self._values["storage"] = storage

    @builtins.property
    def data_source(self) -> builtins.str:
        '''Source from which to query items to display in the stream.

        Valid values are ``logs_stream``, ``audit_stream``, ``ci_pipeline_stream``, ``ci_test_stream``, ``rum_issue_stream``, ``apm_issue_stream``, ``trace_stream``, ``logs_issue_stream``, ``logs_pattern_stream``, ``logs_transaction_stream``, ``event_stream``, ``rum_stream``, ``llm_observability_stream``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        '''
        result = self._values.get("data_source")
        assert result is not None, "Required property 'data_source' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def clustering_pattern_field_path(self) -> typing.Optional[builtins.str]:
        '''Specifies the field for logs pattern clustering. Can only be used with ``logs_pattern_stream``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#clustering_pattern_field_path Powerpack#clustering_pattern_field_path}
        '''
        result = self._values.get("clustering_pattern_field_path")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def event_size(self) -> typing.Optional[builtins.str]:
        '''Size of events displayed in widget. Required if ``data_source`` is ``event_stream``. Valid values are ``s``, ``l``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#event_size Powerpack#event_size}
        '''
        result = self._values.get("event_size")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def group_by(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetListStreamDefinitionRequestQueryGroupBy"]]]:
        '''group_by block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        '''
        result = self._values.get("group_by")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetListStreamDefinitionRequestQueryGroupBy"]]], result)

    @builtins.property
    def indexes(self) -> typing.Optional[typing.List[builtins.str]]:
        '''List of indexes.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#indexes Powerpack#indexes}
        '''
        result = self._values.get("indexes")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def query_string(self) -> typing.Optional[builtins.str]:
        '''Widget query.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query_string Powerpack#query_string}
        '''
        result = self._values.get("query_string")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def sort(
        self,
    ) -> typing.Optional["PowerpackWidgetListStreamDefinitionRequestQuerySort"]:
        '''sort block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort Powerpack#sort}
        '''
        result = self._values.get("sort")
        return typing.cast(typing.Optional["PowerpackWidgetListStreamDefinitionRequestQuerySort"], result)

    @builtins.property
    def storage(self) -> typing.Optional[builtins.str]:
        '''Storage location (private beta).

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#storage Powerpack#storage}
        '''
        result = self._values.get("storage")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetListStreamDefinitionRequestQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetListStreamDefinitionRequestQueryGroupBy",
    jsii_struct_bases=[],
    name_mapping={"facet": "facet"},
)
class PowerpackWidgetListStreamDefinitionRequestQueryGroupBy:
    def __init__(self, *, facet: builtins.str) -> None:
        '''
        :param facet: Facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__36e1a4bea414fda02b5c5f57c53b25d6fe6e39bf4c05a0601d0102d5c3fe836e)
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "facet": facet,
        }

    @builtins.property
    def facet(self) -> builtins.str:
        '''Facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        assert result is not None, "Required property 'facet' is missing"
        return typing.cast(builtins.str, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetListStreamDefinitionRequestQueryGroupBy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetListStreamDefinitionRequestQueryGroupByList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetListStreamDefinitionRequestQueryGroupByList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bfcd71a6efb46a61dee9d5baa27539786b523a86ec9a48735fc8212a02d9e07d)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetListStreamDefinitionRequestQueryGroupByOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a6ef9d3cc72f565273d77ff0d9b22318e56c81482119a2e9cae430323fea9a63)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetListStreamDefinitionRequestQueryGroupByOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0cafdc2a50fddd55c737d8c0477741c27cd02541c09d9f7d8667f421d1594c03)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6d63268013c4c94edbc070fb7e9f5af9e85bb4660d3803c8243264869ef8ac2a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__11f87d0249f0f22a97ba3032a9f66889a340cf1b2b77a6bd7d3b7e16b8625b01)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetListStreamDefinitionRequestQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetListStreamDefinitionRequestQueryGroupBy]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetListStreamDefinitionRequestQueryGroupBy]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__146b586248e56fee363cf695d40721de77f07a6504035257fd4de2f807bec357)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetListStreamDefinitionRequestQueryGroupByOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetListStreamDefinitionRequestQueryGroupByOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__192ccd58cdf5e4bfc8cb8254001f6341c77c955ff57609275c5397af219e9055)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a0272eea5c178a96cdfa5035f860ab177c1f9509cd15e13191d2bba42535087c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetListStreamDefinitionRequestQueryGroupBy]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetListStreamDefinitionRequestQueryGroupBy]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetListStreamDefinitionRequestQueryGroupBy]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a030b195494c7d33408cbdbb9d5b0c1281d61ff8ac75a6847a33c734c3ea8bd2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetListStreamDefinitionRequestQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetListStreamDefinitionRequestQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b5e941f40fb96c63f593fe56eb4888e6ed0747ad244a5618e585eeb9a1a63b7f)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putGroupBy")
    def put_group_by(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetListStreamDefinitionRequestQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__94e369493424c00dcdaea964521ee2a56ccaa18cdeb7b292e7e42ad507cc19a0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putGroupBy", [value]))

    @jsii.member(jsii_name="putSort")
    def put_sort(self, *, column: builtins.str, order: builtins.str) -> None:
        '''
        :param column: The facet path for the column. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#column Powerpack#column}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        value = PowerpackWidgetListStreamDefinitionRequestQuerySort(
            column=column, order=order
        )

        return typing.cast(None, jsii.invoke(self, "putSort", [value]))

    @jsii.member(jsii_name="resetClusteringPatternFieldPath")
    def reset_clustering_pattern_field_path(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetClusteringPatternFieldPath", []))

    @jsii.member(jsii_name="resetEventSize")
    def reset_event_size(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetEventSize", []))

    @jsii.member(jsii_name="resetGroupBy")
    def reset_group_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGroupBy", []))

    @jsii.member(jsii_name="resetIndexes")
    def reset_indexes(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetIndexes", []))

    @jsii.member(jsii_name="resetQueryString")
    def reset_query_string(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetQueryString", []))

    @jsii.member(jsii_name="resetSort")
    def reset_sort(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSort", []))

    @jsii.member(jsii_name="resetStorage")
    def reset_storage(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetStorage", []))

    @builtins.property
    @jsii.member(jsii_name="groupBy")
    def group_by(self) -> PowerpackWidgetListStreamDefinitionRequestQueryGroupByList:
        return typing.cast(PowerpackWidgetListStreamDefinitionRequestQueryGroupByList, jsii.get(self, "groupBy"))

    @builtins.property
    @jsii.member(jsii_name="sort")
    def sort(
        self,
    ) -> "PowerpackWidgetListStreamDefinitionRequestQuerySortOutputReference":
        return typing.cast("PowerpackWidgetListStreamDefinitionRequestQuerySortOutputReference", jsii.get(self, "sort"))

    @builtins.property
    @jsii.member(jsii_name="clusteringPatternFieldPathInput")
    def clustering_pattern_field_path_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "clusteringPatternFieldPathInput"))

    @builtins.property
    @jsii.member(jsii_name="dataSourceInput")
    def data_source_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "dataSourceInput"))

    @builtins.property
    @jsii.member(jsii_name="eventSizeInput")
    def event_size_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "eventSizeInput"))

    @builtins.property
    @jsii.member(jsii_name="groupByInput")
    def group_by_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetListStreamDefinitionRequestQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetListStreamDefinitionRequestQueryGroupBy]]], jsii.get(self, "groupByInput"))

    @builtins.property
    @jsii.member(jsii_name="indexesInput")
    def indexes_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "indexesInput"))

    @builtins.property
    @jsii.member(jsii_name="queryStringInput")
    def query_string_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "queryStringInput"))

    @builtins.property
    @jsii.member(jsii_name="sortInput")
    def sort_input(
        self,
    ) -> typing.Optional["PowerpackWidgetListStreamDefinitionRequestQuerySort"]:
        return typing.cast(typing.Optional["PowerpackWidgetListStreamDefinitionRequestQuerySort"], jsii.get(self, "sortInput"))

    @builtins.property
    @jsii.member(jsii_name="storageInput")
    def storage_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "storageInput"))

    @builtins.property
    @jsii.member(jsii_name="clusteringPatternFieldPath")
    def clustering_pattern_field_path(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "clusteringPatternFieldPath"))

    @clustering_pattern_field_path.setter
    def clustering_pattern_field_path(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1be90d555c163dbfb58ea4e461fc3e62aec517e9accd13093ac078d34c8db430)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "clusteringPatternFieldPath", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="dataSource")
    def data_source(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "dataSource"))

    @data_source.setter
    def data_source(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6704dfffd1d965025e12bd5c250ad268024aeb0a860bdfa9214bbb86ce1af0b7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "dataSource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="eventSize")
    def event_size(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "eventSize"))

    @event_size.setter
    def event_size(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__051a2d94d6540888db10f3358727543f32b126dada0eb0b02ddc7dfd3d57c15b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "eventSize", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="indexes")
    def indexes(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "indexes"))

    @indexes.setter
    def indexes(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a8770c2f0a1a649cc1a0eaa475bb05584f6ba143b04f7e579547924b8cbdeac6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "indexes", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="queryString")
    def query_string(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "queryString"))

    @query_string.setter
    def query_string(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f464e362ed76ed526960f65e879fd160d33fc5bde4f0fececefa4039a45b7621)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "queryString", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="storage")
    def storage(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "storage"))

    @storage.setter
    def storage(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9a1adf3093d2caeb5cae2166caa87d8d726933fea781d7ed12cc915086eb1778)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "storage", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetListStreamDefinitionRequestQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetListStreamDefinitionRequestQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetListStreamDefinitionRequestQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__02020b309a7efa4f3a9f2cb358c3260ba1ec2be75716e7b27d87134710b4f560)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetListStreamDefinitionRequestQuerySort",
    jsii_struct_bases=[],
    name_mapping={"column": "column", "order": "order"},
)
class PowerpackWidgetListStreamDefinitionRequestQuerySort:
    def __init__(self, *, column: builtins.str, order: builtins.str) -> None:
        '''
        :param column: The facet path for the column. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#column Powerpack#column}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0faafc630db6417605186ed17c8e320c46166828aa1a06155e6b006df0283b07)
            check_type(argname="argument column", value=column, expected_type=type_hints["column"])
            check_type(argname="argument order", value=order, expected_type=type_hints["order"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "column": column,
            "order": order,
        }

    @builtins.property
    def column(self) -> builtins.str:
        '''The facet path for the column.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#column Powerpack#column}
        '''
        result = self._values.get("column")
        assert result is not None, "Required property 'column' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def order(self) -> builtins.str:
        '''Widget sorting methods. Valid values are ``asc``, ``desc``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        result = self._values.get("order")
        assert result is not None, "Required property 'order' is missing"
        return typing.cast(builtins.str, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetListStreamDefinitionRequestQuerySort(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetListStreamDefinitionRequestQuerySortOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetListStreamDefinitionRequestQuerySortOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f7bc382d7040db6308f48ec351c3967f03a50197c4f58e74902f72829c60cccf)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @builtins.property
    @jsii.member(jsii_name="columnInput")
    def column_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "columnInput"))

    @builtins.property
    @jsii.member(jsii_name="orderInput")
    def order_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "orderInput"))

    @builtins.property
    @jsii.member(jsii_name="column")
    def column(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "column"))

    @column.setter
    def column(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ef658ba55900026440ee1832f386617cd34a79c3e9bba3e7da0eaf97d36d0b0a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "column", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="order")
    def order(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "order"))

    @order.setter
    def order(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__628d059b6fa92a6549c3a538ade0d78c532e945dc0de24bb06df2c3fa3a2f83b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "order", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetListStreamDefinitionRequestQuerySort]:
        return typing.cast(typing.Optional[PowerpackWidgetListStreamDefinitionRequestQuerySort], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetListStreamDefinitionRequestQuerySort],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1f561a4cf037e2c5b4be8ae2fe6fe84103d31c9faa066697d4e56bfe562e4ee2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetLogStreamDefinition",
    jsii_struct_bases=[],
    name_mapping={
        "columns": "columns",
        "indexes": "indexes",
        "live_span": "liveSpan",
        "message_display": "messageDisplay",
        "query": "query",
        "show_date_column": "showDateColumn",
        "show_message_column": "showMessageColumn",
        "sort": "sort",
        "title": "title",
        "title_align": "titleAlign",
        "title_size": "titleSize",
    },
)
class PowerpackWidgetLogStreamDefinition:
    def __init__(
        self,
        *,
        columns: typing.Optional[typing.Sequence[builtins.str]] = None,
        indexes: typing.Optional[typing.Sequence[builtins.str]] = None,
        live_span: typing.Optional[builtins.str] = None,
        message_display: typing.Optional[builtins.str] = None,
        query: typing.Optional[builtins.str] = None,
        show_date_column: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        show_message_column: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        sort: typing.Optional[typing.Union["PowerpackWidgetLogStreamDefinitionSort", typing.Dict[builtins.str, typing.Any]]] = None,
        title: typing.Optional[builtins.str] = None,
        title_align: typing.Optional[builtins.str] = None,
        title_size: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param columns: Stringified list of columns to use, for example: ``["column1","column2","column3"]``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#columns Powerpack#columns}
        :param indexes: An array of index names to query in the stream. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#indexes Powerpack#indexes}
        :param live_span: The timeframe to use when displaying the widget. Valid values are ``1m``, ``5m``, ``10m``, ``15m``, ``30m``, ``1h``, ``4h``, ``1d``, ``2d``, ``1w``, ``1mo``, ``3mo``, ``6mo``, ``week_to_date``, ``month_to_date``, ``1y``, ``alert``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#live_span Powerpack#live_span}
        :param message_display: The number of log lines to display. Valid values are ``inline``, ``expanded-md``, ``expanded-lg``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#message_display Powerpack#message_display}
        :param query: The query to use in the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        :param show_date_column: If the date column should be displayed. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#show_date_column Powerpack#show_date_column}
        :param show_message_column: If the message column should be displayed. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#show_message_column Powerpack#show_message_column}
        :param sort: sort block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort Powerpack#sort}
        :param title: The title of the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title Powerpack#title}
        :param title_align: The alignment of the widget's title. Valid values are ``center``, ``left``, ``right``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_align Powerpack#title_align}
        :param title_size: The size of the widget's title (defaults to 16). Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_size Powerpack#title_size}
        '''
        if isinstance(sort, dict):
            sort = PowerpackWidgetLogStreamDefinitionSort(**sort)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6b81fe2da378a00f43cf367eaa3cdb448a3affa06fbe30fde171815d1e00baac)
            check_type(argname="argument columns", value=columns, expected_type=type_hints["columns"])
            check_type(argname="argument indexes", value=indexes, expected_type=type_hints["indexes"])
            check_type(argname="argument live_span", value=live_span, expected_type=type_hints["live_span"])
            check_type(argname="argument message_display", value=message_display, expected_type=type_hints["message_display"])
            check_type(argname="argument query", value=query, expected_type=type_hints["query"])
            check_type(argname="argument show_date_column", value=show_date_column, expected_type=type_hints["show_date_column"])
            check_type(argname="argument show_message_column", value=show_message_column, expected_type=type_hints["show_message_column"])
            check_type(argname="argument sort", value=sort, expected_type=type_hints["sort"])
            check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            check_type(argname="argument title_align", value=title_align, expected_type=type_hints["title_align"])
            check_type(argname="argument title_size", value=title_size, expected_type=type_hints["title_size"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if columns is not None:
            self._values["columns"] = columns
        if indexes is not None:
            self._values["indexes"] = indexes
        if live_span is not None:
            self._values["live_span"] = live_span
        if message_display is not None:
            self._values["message_display"] = message_display
        if query is not None:
            self._values["query"] = query
        if show_date_column is not None:
            self._values["show_date_column"] = show_date_column
        if show_message_column is not None:
            self._values["show_message_column"] = show_message_column
        if sort is not None:
            self._values["sort"] = sort
        if title is not None:
            self._values["title"] = title
        if title_align is not None:
            self._values["title_align"] = title_align
        if title_size is not None:
            self._values["title_size"] = title_size

    @builtins.property
    def columns(self) -> typing.Optional[typing.List[builtins.str]]:
        '''Stringified list of columns to use, for example: ``["column1","column2","column3"]``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#columns Powerpack#columns}
        '''
        result = self._values.get("columns")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def indexes(self) -> typing.Optional[typing.List[builtins.str]]:
        '''An array of index names to query in the stream.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#indexes Powerpack#indexes}
        '''
        result = self._values.get("indexes")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def live_span(self) -> typing.Optional[builtins.str]:
        '''The timeframe to use when displaying the widget.

        Valid values are ``1m``, ``5m``, ``10m``, ``15m``, ``30m``, ``1h``, ``4h``, ``1d``, ``2d``, ``1w``, ``1mo``, ``3mo``, ``6mo``, ``week_to_date``, ``month_to_date``, ``1y``, ``alert``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#live_span Powerpack#live_span}
        '''
        result = self._values.get("live_span")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def message_display(self) -> typing.Optional[builtins.str]:
        '''The number of log lines to display. Valid values are ``inline``, ``expanded-md``, ``expanded-lg``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#message_display Powerpack#message_display}
        '''
        result = self._values.get("message_display")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def query(self) -> typing.Optional[builtins.str]:
        '''The query to use in the widget.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        '''
        result = self._values.get("query")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def show_date_column(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        '''If the date column should be displayed.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#show_date_column Powerpack#show_date_column}
        '''
        result = self._values.get("show_date_column")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)

    @builtins.property
    def show_message_column(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        '''If the message column should be displayed.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#show_message_column Powerpack#show_message_column}
        '''
        result = self._values.get("show_message_column")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)

    @builtins.property
    def sort(self) -> typing.Optional["PowerpackWidgetLogStreamDefinitionSort"]:
        '''sort block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort Powerpack#sort}
        '''
        result = self._values.get("sort")
        return typing.cast(typing.Optional["PowerpackWidgetLogStreamDefinitionSort"], result)

    @builtins.property
    def title(self) -> typing.Optional[builtins.str]:
        '''The title of the widget.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title Powerpack#title}
        '''
        result = self._values.get("title")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def title_align(self) -> typing.Optional[builtins.str]:
        '''The alignment of the widget's title. Valid values are ``center``, ``left``, ``right``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_align Powerpack#title_align}
        '''
        result = self._values.get("title_align")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def title_size(self) -> typing.Optional[builtins.str]:
        '''The size of the widget's title (defaults to 16).

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_size Powerpack#title_size}
        '''
        result = self._values.get("title_size")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetLogStreamDefinition(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetLogStreamDefinitionOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetLogStreamDefinitionOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7c414186bc5bb8dea7fb1fbda57ad2f7daa240fe04c9738829b1b8b403f7c1d7)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putSort")
    def put_sort(self, *, column: builtins.str, order: builtins.str) -> None:
        '''
        :param column: The facet path for the column. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#column Powerpack#column}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        value = PowerpackWidgetLogStreamDefinitionSort(column=column, order=order)

        return typing.cast(None, jsii.invoke(self, "putSort", [value]))

    @jsii.member(jsii_name="resetColumns")
    def reset_columns(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetColumns", []))

    @jsii.member(jsii_name="resetIndexes")
    def reset_indexes(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetIndexes", []))

    @jsii.member(jsii_name="resetLiveSpan")
    def reset_live_span(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLiveSpan", []))

    @jsii.member(jsii_name="resetMessageDisplay")
    def reset_message_display(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMessageDisplay", []))

    @jsii.member(jsii_name="resetQuery")
    def reset_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetQuery", []))

    @jsii.member(jsii_name="resetShowDateColumn")
    def reset_show_date_column(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetShowDateColumn", []))

    @jsii.member(jsii_name="resetShowMessageColumn")
    def reset_show_message_column(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetShowMessageColumn", []))

    @jsii.member(jsii_name="resetSort")
    def reset_sort(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSort", []))

    @jsii.member(jsii_name="resetTitle")
    def reset_title(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTitle", []))

    @jsii.member(jsii_name="resetTitleAlign")
    def reset_title_align(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTitleAlign", []))

    @jsii.member(jsii_name="resetTitleSize")
    def reset_title_size(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTitleSize", []))

    @builtins.property
    @jsii.member(jsii_name="sort")
    def sort(self) -> "PowerpackWidgetLogStreamDefinitionSortOutputReference":
        return typing.cast("PowerpackWidgetLogStreamDefinitionSortOutputReference", jsii.get(self, "sort"))

    @builtins.property
    @jsii.member(jsii_name="columnsInput")
    def columns_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "columnsInput"))

    @builtins.property
    @jsii.member(jsii_name="indexesInput")
    def indexes_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "indexesInput"))

    @builtins.property
    @jsii.member(jsii_name="liveSpanInput")
    def live_span_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "liveSpanInput"))

    @builtins.property
    @jsii.member(jsii_name="messageDisplayInput")
    def message_display_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "messageDisplayInput"))

    @builtins.property
    @jsii.member(jsii_name="queryInput")
    def query_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "queryInput"))

    @builtins.property
    @jsii.member(jsii_name="showDateColumnInput")
    def show_date_column_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "showDateColumnInput"))

    @builtins.property
    @jsii.member(jsii_name="showMessageColumnInput")
    def show_message_column_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "showMessageColumnInput"))

    @builtins.property
    @jsii.member(jsii_name="sortInput")
    def sort_input(self) -> typing.Optional["PowerpackWidgetLogStreamDefinitionSort"]:
        return typing.cast(typing.Optional["PowerpackWidgetLogStreamDefinitionSort"], jsii.get(self, "sortInput"))

    @builtins.property
    @jsii.member(jsii_name="titleAlignInput")
    def title_align_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "titleAlignInput"))

    @builtins.property
    @jsii.member(jsii_name="titleInput")
    def title_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "titleInput"))

    @builtins.property
    @jsii.member(jsii_name="titleSizeInput")
    def title_size_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "titleSizeInput"))

    @builtins.property
    @jsii.member(jsii_name="columns")
    def columns(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "columns"))

    @columns.setter
    def columns(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__872f5c4e8e746692dd77737c2e4fd2d2192ebf64e047858b256782d94ee0b473)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "columns", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="indexes")
    def indexes(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "indexes"))

    @indexes.setter
    def indexes(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6621bb8d7127a5742c9c1518dcae3345431eda3541f06f5ea79c02473cd884fc)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "indexes", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="liveSpan")
    def live_span(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "liveSpan"))

    @live_span.setter
    def live_span(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e18a9712fe256c2735292f175e3f17dd5613e83cb83a712b409a1921c8bfbbbd)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "liveSpan", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="messageDisplay")
    def message_display(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "messageDisplay"))

    @message_display.setter
    def message_display(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__36dcc12645ecc1cce09db053a242814fca6e7bc1d935e17b9126a77d7306deed)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "messageDisplay", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="query")
    def query(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "query"))

    @query.setter
    def query(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__49e714216e5bf66a61537ff9bb33e571b2a1c9c137e3a21a60e65adaaa4704bd)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "query", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="showDateColumn")
    def show_date_column(
        self,
    ) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "showDateColumn"))

    @show_date_column.setter
    def show_date_column(
        self,
        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8aa1a1e88280a99f52ba24ab45215b6b4a8a571ef60c590b3798cb454fddc010)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "showDateColumn", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="showMessageColumn")
    def show_message_column(
        self,
    ) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "showMessageColumn"))

    @show_message_column.setter
    def show_message_column(
        self,
        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1d212e6d6bd597f59bbcf99c9b4b50e38c92352cee3df0f83480227a0d8e7121)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "showMessageColumn", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="title")
    def title(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "title"))

    @title.setter
    def title(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__72d6944c522b82f26c178b6c6f8ff6fae5e5e0562a99cb436d449689ef0260ee)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "title", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="titleAlign")
    def title_align(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "titleAlign"))

    @title_align.setter
    def title_align(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__34718ffdd151ad2e21854ad183701feade6073a5917fc6e467530d49690d4c57)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "titleAlign", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="titleSize")
    def title_size(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "titleSize"))

    @title_size.setter
    def title_size(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__61442f3ffafb55d5a9d80c35b66145d7c54fdf32e8073c178a37b8c56a7d364f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "titleSize", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[PowerpackWidgetLogStreamDefinition]:
        return typing.cast(typing.Optional[PowerpackWidgetLogStreamDefinition], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetLogStreamDefinition],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c22f4495346063f8a06728cf37036f0f971fbd48cd2dd2cf4c7b4c8ade72007f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetLogStreamDefinitionSort",
    jsii_struct_bases=[],
    name_mapping={"column": "column", "order": "order"},
)
class PowerpackWidgetLogStreamDefinitionSort:
    def __init__(self, *, column: builtins.str, order: builtins.str) -> None:
        '''
        :param column: The facet path for the column. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#column Powerpack#column}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6ef8b32f89891b90e00abe61c2ada54206dda3e31871c7536f8f4e0dfe07b478)
            check_type(argname="argument column", value=column, expected_type=type_hints["column"])
            check_type(argname="argument order", value=order, expected_type=type_hints["order"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "column": column,
            "order": order,
        }

    @builtins.property
    def column(self) -> builtins.str:
        '''The facet path for the column.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#column Powerpack#column}
        '''
        result = self._values.get("column")
        assert result is not None, "Required property 'column' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def order(self) -> builtins.str:
        '''Widget sorting methods. Valid values are ``asc``, ``desc``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        result = self._values.get("order")
        assert result is not None, "Required property 'order' is missing"
        return typing.cast(builtins.str, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetLogStreamDefinitionSort(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetLogStreamDefinitionSortOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetLogStreamDefinitionSortOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d02eca4311d3cac7d24bc97260d32f3719f7bf3789ef3ccbe4691b588dc189d4)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @builtins.property
    @jsii.member(jsii_name="columnInput")
    def column_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "columnInput"))

    @builtins.property
    @jsii.member(jsii_name="orderInput")
    def order_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "orderInput"))

    @builtins.property
    @jsii.member(jsii_name="column")
    def column(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "column"))

    @column.setter
    def column(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9a6f32b767fa2c2d35a1ae2138722ff64ae9bce12765f1b83390bc4115f7cd01)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "column", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="order")
    def order(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "order"))

    @order.setter
    def order(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1e501fe440126d5089689196002ee8e8e90866f3100b75258c3ec2376395e3c6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "order", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[PowerpackWidgetLogStreamDefinitionSort]:
        return typing.cast(typing.Optional[PowerpackWidgetLogStreamDefinitionSort], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetLogStreamDefinitionSort],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cafa46c3fc802fdf41599469e6acc52cf9d81b1865737111da9545ecbf43a38f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetManageStatusDefinition",
    jsii_struct_bases=[],
    name_mapping={
        "query": "query",
        "color_preference": "colorPreference",
        "display_format": "displayFormat",
        "hide_zero_counts": "hideZeroCounts",
        "show_last_triggered": "showLastTriggered",
        "show_priority": "showPriority",
        "sort": "sort",
        "summary_type": "summaryType",
        "title": "title",
        "title_align": "titleAlign",
        "title_size": "titleSize",
    },
)
class PowerpackWidgetManageStatusDefinition:
    def __init__(
        self,
        *,
        query: builtins.str,
        color_preference: typing.Optional[builtins.str] = None,
        display_format: typing.Optional[builtins.str] = None,
        hide_zero_counts: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        show_last_triggered: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        show_priority: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        sort: typing.Optional[builtins.str] = None,
        summary_type: typing.Optional[builtins.str] = None,
        title: typing.Optional[builtins.str] = None,
        title_align: typing.Optional[builtins.str] = None,
        title_size: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param query: The query to use in the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        :param color_preference: Whether to colorize text or background. Valid values are ``background``, ``text``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#color_preference Powerpack#color_preference}
        :param display_format: The display setting to use. Valid values are ``counts``, ``countsAndList``, ``list``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#display_format Powerpack#display_format}
        :param hide_zero_counts: A Boolean indicating whether to hide empty categories. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#hide_zero_counts Powerpack#hide_zero_counts}
        :param show_last_triggered: A Boolean indicating whether to show when monitors/groups last triggered. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#show_last_triggered Powerpack#show_last_triggered}
        :param show_priority: Whether to show the priorities column. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#show_priority Powerpack#show_priority}
        :param sort: The method to sort the monitors. Valid values are ``name``, ``group``, ``status``, ``tags``, ``triggered``, ``group,asc``, ``group,desc``, ``name,asc``, ``name,desc``, ``status,asc``, ``status,desc``, ``tags,asc``, ``tags,desc``, ``triggered,asc``, ``triggered,desc``, ``priority,asc``, ``priority,desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort Powerpack#sort}
        :param summary_type: The summary type to use. Valid values are ``monitors``, ``groups``, ``combined``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#summary_type Powerpack#summary_type}
        :param title: The title of the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title Powerpack#title}
        :param title_align: The alignment of the widget's title. Valid values are ``center``, ``left``, ``right``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_align Powerpack#title_align}
        :param title_size: The size of the widget's title (defaults to 16). Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_size Powerpack#title_size}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f2853d3277878db44a572e291222037556563e9a6aacd252b48d2c33ae01c5e6)
            check_type(argname="argument query", value=query, expected_type=type_hints["query"])
            check_type(argname="argument color_preference", value=color_preference, expected_type=type_hints["color_preference"])
            check_type(argname="argument display_format", value=display_format, expected_type=type_hints["display_format"])
            check_type(argname="argument hide_zero_counts", value=hide_zero_counts, expected_type=type_hints["hide_zero_counts"])
            check_type(argname="argument show_last_triggered", value=show_last_triggered, expected_type=type_hints["show_last_triggered"])
            check_type(argname="argument show_priority", value=show_priority, expected_type=type_hints["show_priority"])
            check_type(argname="argument sort", value=sort, expected_type=type_hints["sort"])
            check_type(argname="argument summary_type", value=summary_type, expected_type=type_hints["summary_type"])
            check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            check_type(argname="argument title_align", value=title_align, expected_type=type_hints["title_align"])
            check_type(argname="argument title_size", value=title_size, expected_type=type_hints["title_size"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "query": query,
        }
        if color_preference is not None:
            self._values["color_preference"] = color_preference
        if display_format is not None:
            self._values["display_format"] = display_format
        if hide_zero_counts is not None:
            self._values["hide_zero_counts"] = hide_zero_counts
        if show_last_triggered is not None:
            self._values["show_last_triggered"] = show_last_triggered
        if show_priority is not None:
            self._values["show_priority"] = show_priority
        if sort is not None:
            self._values["sort"] = sort
        if summary_type is not None:
            self._values["summary_type"] = summary_type
        if title is not None:
            self._values["title"] = title
        if title_align is not None:
            self._values["title_align"] = title_align
        if title_size is not None:
            self._values["title_size"] = title_size

    @builtins.property
    def query(self) -> builtins.str:
        '''The query to use in the widget.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        '''
        result = self._values.get("query")
        assert result is not None, "Required property 'query' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def color_preference(self) -> typing.Optional[builtins.str]:
        '''Whether to colorize text or background. Valid values are ``background``, ``text``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#color_preference Powerpack#color_preference}
        '''
        result = self._values.get("color_preference")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def display_format(self) -> typing.Optional[builtins.str]:
        '''The display setting to use. Valid values are ``counts``, ``countsAndList``, ``list``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#display_format Powerpack#display_format}
        '''
        result = self._values.get("display_format")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def hide_zero_counts(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        '''A Boolean indicating whether to hide empty categories.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#hide_zero_counts Powerpack#hide_zero_counts}
        '''
        result = self._values.get("hide_zero_counts")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)

    @builtins.property
    def show_last_triggered(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        '''A Boolean indicating whether to show when monitors/groups last triggered.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#show_last_triggered Powerpack#show_last_triggered}
        '''
        result = self._values.get("show_last_triggered")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)

    @builtins.property
    def show_priority(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        '''Whether to show the priorities column.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#show_priority Powerpack#show_priority}
        '''
        result = self._values.get("show_priority")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)

    @builtins.property
    def sort(self) -> typing.Optional[builtins.str]:
        '''The method to sort the monitors.

        Valid values are ``name``, ``group``, ``status``, ``tags``, ``triggered``, ``group,asc``, ``group,desc``, ``name,asc``, ``name,desc``, ``status,asc``, ``status,desc``, ``tags,asc``, ``tags,desc``, ``triggered,asc``, ``triggered,desc``, ``priority,asc``, ``priority,desc``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort Powerpack#sort}
        '''
        result = self._values.get("sort")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def summary_type(self) -> typing.Optional[builtins.str]:
        '''The summary type to use. Valid values are ``monitors``, ``groups``, ``combined``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#summary_type Powerpack#summary_type}
        '''
        result = self._values.get("summary_type")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def title(self) -> typing.Optional[builtins.str]:
        '''The title of the widget.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title Powerpack#title}
        '''
        result = self._values.get("title")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def title_align(self) -> typing.Optional[builtins.str]:
        '''The alignment of the widget's title. Valid values are ``center``, ``left``, ``right``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_align Powerpack#title_align}
        '''
        result = self._values.get("title_align")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def title_size(self) -> typing.Optional[builtins.str]:
        '''The size of the widget's title (defaults to 16).

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_size Powerpack#title_size}
        '''
        result = self._values.get("title_size")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetManageStatusDefinition(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetManageStatusDefinitionOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetManageStatusDefinitionOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__25f0c74cf1ad8ef8f78f4332baa391d088bd58d9bf5236ac5b2a164e95342fd8)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetColorPreference")
    def reset_color_preference(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetColorPreference", []))

    @jsii.member(jsii_name="resetDisplayFormat")
    def reset_display_format(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDisplayFormat", []))

    @jsii.member(jsii_name="resetHideZeroCounts")
    def reset_hide_zero_counts(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHideZeroCounts", []))

    @jsii.member(jsii_name="resetShowLastTriggered")
    def reset_show_last_triggered(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetShowLastTriggered", []))

    @jsii.member(jsii_name="resetShowPriority")
    def reset_show_priority(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetShowPriority", []))

    @jsii.member(jsii_name="resetSort")
    def reset_sort(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSort", []))

    @jsii.member(jsii_name="resetSummaryType")
    def reset_summary_type(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSummaryType", []))

    @jsii.member(jsii_name="resetTitle")
    def reset_title(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTitle", []))

    @jsii.member(jsii_name="resetTitleAlign")
    def reset_title_align(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTitleAlign", []))

    @jsii.member(jsii_name="resetTitleSize")
    def reset_title_size(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTitleSize", []))

    @builtins.property
    @jsii.member(jsii_name="colorPreferenceInput")
    def color_preference_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "colorPreferenceInput"))

    @builtins.property
    @jsii.member(jsii_name="displayFormatInput")
    def display_format_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "displayFormatInput"))

    @builtins.property
    @jsii.member(jsii_name="hideZeroCountsInput")
    def hide_zero_counts_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "hideZeroCountsInput"))

    @builtins.property
    @jsii.member(jsii_name="queryInput")
    def query_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "queryInput"))

    @builtins.property
    @jsii.member(jsii_name="showLastTriggeredInput")
    def show_last_triggered_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "showLastTriggeredInput"))

    @builtins.property
    @jsii.member(jsii_name="showPriorityInput")
    def show_priority_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "showPriorityInput"))

    @builtins.property
    @jsii.member(jsii_name="sortInput")
    def sort_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "sortInput"))

    @builtins.property
    @jsii.member(jsii_name="summaryTypeInput")
    def summary_type_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "summaryTypeInput"))

    @builtins.property
    @jsii.member(jsii_name="titleAlignInput")
    def title_align_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "titleAlignInput"))

    @builtins.property
    @jsii.member(jsii_name="titleInput")
    def title_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "titleInput"))

    @builtins.property
    @jsii.member(jsii_name="titleSizeInput")
    def title_size_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "titleSizeInput"))

    @builtins.property
    @jsii.member(jsii_name="colorPreference")
    def color_preference(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "colorPreference"))

    @color_preference.setter
    def color_preference(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b95b8bfba435737a11ef3db41b50037d1e6e089798a6091374594127a8207b04)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "colorPreference", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="displayFormat")
    def display_format(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "displayFormat"))

    @display_format.setter
    def display_format(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__10887afdacf2293d77d4898cbea39f4b53a2d47a5541344c93c3ad4326d4e4e3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "displayFormat", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="hideZeroCounts")
    def hide_zero_counts(
        self,
    ) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "hideZeroCounts"))

    @hide_zero_counts.setter
    def hide_zero_counts(
        self,
        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7aba4958fe10f27d59165cfe5e4246177949d253df93f9e687346df1534c17b9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "hideZeroCounts", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="query")
    def query(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "query"))

    @query.setter
    def query(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fc091bd1f9e051187b624ef685a27fecf51259d012f0d86422ac1f462bbad2c6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "query", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="showLastTriggered")
    def show_last_triggered(
        self,
    ) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "showLastTriggered"))

    @show_last_triggered.setter
    def show_last_triggered(
        self,
        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b13bab9acbf7781b2745f999ee6a91457af703a0c58b9cd2197aa32386f436ac)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "showLastTriggered", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="showPriority")
    def show_priority(self) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "showPriority"))

    @show_priority.setter
    def show_priority(
        self,
        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__688929ed746acbb110667f6603ee11015548226ec4fe028ffe26c3caa5c61bf1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "showPriority", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="sort")
    def sort(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "sort"))

    @sort.setter
    def sort(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3144bd8b0b8c5dd5c473926e3ed3775f7966c2abded15f9313402a3f368dffa2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "sort", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="summaryType")
    def summary_type(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "summaryType"))

    @summary_type.setter
    def summary_type(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5fbac87bec5e17ab8bc2c6fa3b663cf7fb779e1501661513835968ac057c9616)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "summaryType", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="title")
    def title(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "title"))

    @title.setter
    def title(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0302c9d66be8109b1fabad79b9a565cf8f49a7ee0568dee59f8e43c58da0e41d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "title", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="titleAlign")
    def title_align(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "titleAlign"))

    @title_align.setter
    def title_align(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4d05ebe9267617a81328de845a6470fc021e27ae5952694a2bbc42e3808e6852)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "titleAlign", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="titleSize")
    def title_size(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "titleSize"))

    @title_size.setter
    def title_size(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__edd8c302f2408d9ac801a807555846ab7b61c06e0fa1dfe4595e88d5d2da0eec)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "titleSize", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[PowerpackWidgetManageStatusDefinition]:
        return typing.cast(typing.Optional[PowerpackWidgetManageStatusDefinition], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetManageStatusDefinition],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__533bbeff3dd8ac3b3a27ed8163aaf3bc867a4d0d0960adc1da07ba146db4c5c9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetNoteDefinition",
    jsii_struct_bases=[],
    name_mapping={
        "content": "content",
        "background_color": "backgroundColor",
        "font_size": "fontSize",
        "has_padding": "hasPadding",
        "show_tick": "showTick",
        "text_align": "textAlign",
        "tick_edge": "tickEdge",
        "tick_pos": "tickPos",
        "vertical_align": "verticalAlign",
    },
)
class PowerpackWidgetNoteDefinition:
    def __init__(
        self,
        *,
        content: builtins.str,
        background_color: typing.Optional[builtins.str] = None,
        font_size: typing.Optional[builtins.str] = None,
        has_padding: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        show_tick: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        text_align: typing.Optional[builtins.str] = None,
        tick_edge: typing.Optional[builtins.str] = None,
        tick_pos: typing.Optional[builtins.str] = None,
        vertical_align: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param content: The content of the note. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#content Powerpack#content}
        :param background_color: The background color of the note. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#background_color Powerpack#background_color}
        :param font_size: The size of the text. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#font_size Powerpack#font_size}
        :param has_padding: Whether to add padding or not. Defaults to ``true``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#has_padding Powerpack#has_padding}
        :param show_tick: Whether to show a tick or not. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#show_tick Powerpack#show_tick}
        :param text_align: The alignment of the widget's text. Valid values are ``center``, ``left``, ``right``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#text_align Powerpack#text_align}
        :param tick_edge: When ``tick = true``, a string indicating on which side of the widget the tick should be displayed. Valid values are ``bottom``, ``left``, ``right``, ``top``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#tick_edge Powerpack#tick_edge}
        :param tick_pos: When ``tick = true``, a string with a percent sign indicating the position of the tick, for example: ``tick_pos = "50%"`` is centered alignment. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#tick_pos Powerpack#tick_pos}
        :param vertical_align: The vertical alignment for the widget. Valid values are ``center``, ``top``, ``bottom``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#vertical_align Powerpack#vertical_align}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c7303db97d1be881bb05d4f60ea78c03fc3388d353f5d5e3b7c89d47cb939edd)
            check_type(argname="argument content", value=content, expected_type=type_hints["content"])
            check_type(argname="argument background_color", value=background_color, expected_type=type_hints["background_color"])
            check_type(argname="argument font_size", value=font_size, expected_type=type_hints["font_size"])
            check_type(argname="argument has_padding", value=has_padding, expected_type=type_hints["has_padding"])
            check_type(argname="argument show_tick", value=show_tick, expected_type=type_hints["show_tick"])
            check_type(argname="argument text_align", value=text_align, expected_type=type_hints["text_align"])
            check_type(argname="argument tick_edge", value=tick_edge, expected_type=type_hints["tick_edge"])
            check_type(argname="argument tick_pos", value=tick_pos, expected_type=type_hints["tick_pos"])
            check_type(argname="argument vertical_align", value=vertical_align, expected_type=type_hints["vertical_align"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "content": content,
        }
        if background_color is not None:
            self._values["background_color"] = background_color
        if font_size is not None:
            self._values["font_size"] = font_size
        if has_padding is not None:
            self._values["has_padding"] = has_padding
        if show_tick is not None:
            self._values["show_tick"] = show_tick
        if text_align is not None:
            self._values["text_align"] = text_align
        if tick_edge is not None:
            self._values["tick_edge"] = tick_edge
        if tick_pos is not None:
            self._values["tick_pos"] = tick_pos
        if vertical_align is not None:
            self._values["vertical_align"] = vertical_align

    @builtins.property
    def content(self) -> builtins.str:
        '''The content of the note.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#content Powerpack#content}
        '''
        result = self._values.get("content")
        assert result is not None, "Required property 'content' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def background_color(self) -> typing.Optional[builtins.str]:
        '''The background color of the note.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#background_color Powerpack#background_color}
        '''
        result = self._values.get("background_color")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def font_size(self) -> typing.Optional[builtins.str]:
        '''The size of the text.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#font_size Powerpack#font_size}
        '''
        result = self._values.get("font_size")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def has_padding(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        '''Whether to add padding or not. Defaults to ``true``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#has_padding Powerpack#has_padding}
        '''
        result = self._values.get("has_padding")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)

    @builtins.property
    def show_tick(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        '''Whether to show a tick or not.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#show_tick Powerpack#show_tick}
        '''
        result = self._values.get("show_tick")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)

    @builtins.property
    def text_align(self) -> typing.Optional[builtins.str]:
        '''The alignment of the widget's text. Valid values are ``center``, ``left``, ``right``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#text_align Powerpack#text_align}
        '''
        result = self._values.get("text_align")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def tick_edge(self) -> typing.Optional[builtins.str]:
        '''When ``tick = true``, a string indicating on which side of the widget the tick should be displayed.

        Valid values are ``bottom``, ``left``, ``right``, ``top``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#tick_edge Powerpack#tick_edge}
        '''
        result = self._values.get("tick_edge")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def tick_pos(self) -> typing.Optional[builtins.str]:
        '''When ``tick = true``, a string with a percent sign indicating the position of the tick, for example: ``tick_pos = "50%"`` is centered alignment.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#tick_pos Powerpack#tick_pos}
        '''
        result = self._values.get("tick_pos")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def vertical_align(self) -> typing.Optional[builtins.str]:
        '''The vertical alignment for the widget. Valid values are ``center``, ``top``, ``bottom``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#vertical_align Powerpack#vertical_align}
        '''
        result = self._values.get("vertical_align")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetNoteDefinition(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetNoteDefinitionOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetNoteDefinitionOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__49f67fb10943a6fc02570281f6a284cf2dfcd0d3a1ce8a0928db7422786ec313)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetBackgroundColor")
    def reset_background_color(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetBackgroundColor", []))

    @jsii.member(jsii_name="resetFontSize")
    def reset_font_size(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFontSize", []))

    @jsii.member(jsii_name="resetHasPadding")
    def reset_has_padding(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHasPadding", []))

    @jsii.member(jsii_name="resetShowTick")
    def reset_show_tick(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetShowTick", []))

    @jsii.member(jsii_name="resetTextAlign")
    def reset_text_align(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTextAlign", []))

    @jsii.member(jsii_name="resetTickEdge")
    def reset_tick_edge(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTickEdge", []))

    @jsii.member(jsii_name="resetTickPos")
    def reset_tick_pos(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTickPos", []))

    @jsii.member(jsii_name="resetVerticalAlign")
    def reset_vertical_align(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetVerticalAlign", []))

    @builtins.property
    @jsii.member(jsii_name="backgroundColorInput")
    def background_color_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "backgroundColorInput"))

    @builtins.property
    @jsii.member(jsii_name="contentInput")
    def content_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "contentInput"))

    @builtins.property
    @jsii.member(jsii_name="fontSizeInput")
    def font_size_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "fontSizeInput"))

    @builtins.property
    @jsii.member(jsii_name="hasPaddingInput")
    def has_padding_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "hasPaddingInput"))

    @builtins.property
    @jsii.member(jsii_name="showTickInput")
    def show_tick_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "showTickInput"))

    @builtins.property
    @jsii.member(jsii_name="textAlignInput")
    def text_align_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "textAlignInput"))

    @builtins.property
    @jsii.member(jsii_name="tickEdgeInput")
    def tick_edge_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "tickEdgeInput"))

    @builtins.property
    @jsii.member(jsii_name="tickPosInput")
    def tick_pos_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "tickPosInput"))

    @builtins.property
    @jsii.member(jsii_name="verticalAlignInput")
    def vertical_align_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "verticalAlignInput"))

    @builtins.property
    @jsii.member(jsii_name="backgroundColor")
    def background_color(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "backgroundColor"))

    @background_color.setter
    def background_color(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a939fd05517e872ff8b35fac55a6b7b1144e27f657e1fd07e170b8170c9ff786)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "backgroundColor", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="content")
    def content(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "content"))

    @content.setter
    def content(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8c91d7585ad789cf546e24f8f26f2ab9c99a3d72231383e6b8cd02d1f3d20e7f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "content", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="fontSize")
    def font_size(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "fontSize"))

    @font_size.setter
    def font_size(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ee98c6cad88e04368f79f8ae268ea4c784543eb1018d647f92854b105332d37e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "fontSize", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="hasPadding")
    def has_padding(self) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "hasPadding"))

    @has_padding.setter
    def has_padding(
        self,
        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1857d14f6e9db396b1f152365c1640691382889363cf363a764cec239bbfffdb)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "hasPadding", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="showTick")
    def show_tick(self) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "showTick"))

    @show_tick.setter
    def show_tick(
        self,
        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__66f656ebe31ee9706684107383b4547c9a345884e7c9d6f1dc7a0475f199e5e3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "showTick", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="textAlign")
    def text_align(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "textAlign"))

    @text_align.setter
    def text_align(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bae039aa6712034c048263808308de3ca04290b0b48ac9ef712c095c3ece4c7e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "textAlign", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="tickEdge")
    def tick_edge(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "tickEdge"))

    @tick_edge.setter
    def tick_edge(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__82b33c8b4d2266f296d9a3101f5ebc5d1e2e8702896576d3e3a79fe24f68d3b0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "tickEdge", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="tickPos")
    def tick_pos(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "tickPos"))

    @tick_pos.setter
    def tick_pos(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d1a188bbfa32c9f3907443cea9f55017546f305c7e27ceff1492885c66a58120)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "tickPos", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="verticalAlign")
    def vertical_align(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "verticalAlign"))

    @vertical_align.setter
    def vertical_align(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b99f3453090a022b3f571985eecdc2c2eb8e486babb1445764501feac314f701)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "verticalAlign", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[PowerpackWidgetNoteDefinition]:
        return typing.cast(typing.Optional[PowerpackWidgetNoteDefinition], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetNoteDefinition],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7e2f770ea8e942ebecf11a4c4a15b6487559c70688c0bd7b12b9c08e61599088)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__90c47c37308ad37f1a1c7958548183fc41350a2b39dd9a8f3296896b502f2827)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putAlertGraphDefinition")
    def put_alert_graph_definition(
        self,
        *,
        alert_id: builtins.str,
        viz_type: builtins.str,
        live_span: typing.Optional[builtins.str] = None,
        title: typing.Optional[builtins.str] = None,
        title_align: typing.Optional[builtins.str] = None,
        title_size: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param alert_id: The ID of the monitor used by the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#alert_id Powerpack#alert_id}
        :param viz_type: Type of visualization to use when displaying the widget. Valid values are ``timeseries``, ``toplist``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#viz_type Powerpack#viz_type}
        :param live_span: The timeframe to use when displaying the widget. Valid values are ``1m``, ``5m``, ``10m``, ``15m``, ``30m``, ``1h``, ``4h``, ``1d``, ``2d``, ``1w``, ``1mo``, ``3mo``, ``6mo``, ``week_to_date``, ``month_to_date``, ``1y``, ``alert``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#live_span Powerpack#live_span}
        :param title: The title of the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title Powerpack#title}
        :param title_align: The alignment of the widget's title. Valid values are ``center``, ``left``, ``right``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_align Powerpack#title_align}
        :param title_size: The size of the widget's title (defaults to 16). Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_size Powerpack#title_size}
        '''
        value = PowerpackWidgetAlertGraphDefinition(
            alert_id=alert_id,
            viz_type=viz_type,
            live_span=live_span,
            title=title,
            title_align=title_align,
            title_size=title_size,
        )

        return typing.cast(None, jsii.invoke(self, "putAlertGraphDefinition", [value]))

    @jsii.member(jsii_name="putAlertValueDefinition")
    def put_alert_value_definition(
        self,
        *,
        alert_id: builtins.str,
        precision: typing.Optional[jsii.Number] = None,
        text_align: typing.Optional[builtins.str] = None,
        title: typing.Optional[builtins.str] = None,
        title_align: typing.Optional[builtins.str] = None,
        title_size: typing.Optional[builtins.str] = None,
        unit: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param alert_id: The ID of the monitor used by the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#alert_id Powerpack#alert_id}
        :param precision: The precision to use when displaying the value. Use ``*`` for maximum precision. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#precision Powerpack#precision}
        :param text_align: The alignment of the text in the widget. Valid values are ``center``, ``left``, ``right``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#text_align Powerpack#text_align}
        :param title: The title of the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title Powerpack#title}
        :param title_align: The alignment of the widget's title. Valid values are ``center``, ``left``, ``right``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_align Powerpack#title_align}
        :param title_size: The size of the widget's title (defaults to 16). Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_size Powerpack#title_size}
        :param unit: The unit for the value displayed in the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit Powerpack#unit}
        '''
        value = PowerpackWidgetAlertValueDefinition(
            alert_id=alert_id,
            precision=precision,
            text_align=text_align,
            title=title,
            title_align=title_align,
            title_size=title_size,
            unit=unit,
        )

        return typing.cast(None, jsii.invoke(self, "putAlertValueDefinition", [value]))

    @jsii.member(jsii_name="putChangeDefinition")
    def put_change_definition(
        self,
        *,
        custom_link: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetChangeDefinitionCustomLink, typing.Dict[builtins.str, typing.Any]]]]] = None,
        live_span: typing.Optional[builtins.str] = None,
        request: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetChangeDefinitionRequest, typing.Dict[builtins.str, typing.Any]]]]] = None,
        title: typing.Optional[builtins.str] = None,
        title_align: typing.Optional[builtins.str] = None,
        title_size: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param custom_link: custom_link block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom_link Powerpack#custom_link}
        :param live_span: The timeframe to use when displaying the widget. Valid values are ``1m``, ``5m``, ``10m``, ``15m``, ``30m``, ``1h``, ``4h``, ``1d``, ``2d``, ``1w``, ``1mo``, ``3mo``, ``6mo``, ``week_to_date``, ``month_to_date``, ``1y``, ``alert``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#live_span Powerpack#live_span}
        :param request: request block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#request Powerpack#request}
        :param title: The title of the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title Powerpack#title}
        :param title_align: The alignment of the widget's title. Valid values are ``center``, ``left``, ``right``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_align Powerpack#title_align}
        :param title_size: The size of the widget's title (defaults to 16). Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_size Powerpack#title_size}
        '''
        value = PowerpackWidgetChangeDefinition(
            custom_link=custom_link,
            live_span=live_span,
            request=request,
            title=title,
            title_align=title_align,
            title_size=title_size,
        )

        return typing.cast(None, jsii.invoke(self, "putChangeDefinition", [value]))

    @jsii.member(jsii_name="putCheckStatusDefinition")
    def put_check_status_definition(
        self,
        *,
        check: builtins.str,
        grouping: builtins.str,
        group: typing.Optional[builtins.str] = None,
        group_by: typing.Optional[typing.Sequence[builtins.str]] = None,
        live_span: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Sequence[builtins.str]] = None,
        title: typing.Optional[builtins.str] = None,
        title_align: typing.Optional[builtins.str] = None,
        title_size: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param check: The check to use in the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#check Powerpack#check}
        :param grouping: The kind of grouping to use. Valid values are ``check``, ``cluster``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#grouping Powerpack#grouping}
        :param group: The check group to use in the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group Powerpack#group}
        :param group_by: When ``grouping = "cluster"``, indicates a list of tags to use for grouping. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param live_span: The timeframe to use when displaying the widget. Valid values are ``1m``, ``5m``, ``10m``, ``15m``, ``30m``, ``1h``, ``4h``, ``1d``, ``2d``, ``1w``, ``1mo``, ``3mo``, ``6mo``, ``week_to_date``, ``month_to_date``, ``1y``, ``alert``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#live_span Powerpack#live_span}
        :param tags: A list of tags to use in the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#tags Powerpack#tags}
        :param title: The title of the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title Powerpack#title}
        :param title_align: The alignment of the widget's title. Valid values are ``center``, ``left``, ``right``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_align Powerpack#title_align}
        :param title_size: The size of the widget's title (defaults to 16). Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_size Powerpack#title_size}
        '''
        value = PowerpackWidgetCheckStatusDefinition(
            check=check,
            grouping=grouping,
            group=group,
            group_by=group_by,
            live_span=live_span,
            tags=tags,
            title=title,
            title_align=title_align,
            title_size=title_size,
        )

        return typing.cast(None, jsii.invoke(self, "putCheckStatusDefinition", [value]))

    @jsii.member(jsii_name="putDistributionDefinition")
    def put_distribution_definition(
        self,
        *,
        legend_size: typing.Optional[builtins.str] = None,
        live_span: typing.Optional[builtins.str] = None,
        request: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetDistributionDefinitionRequest, typing.Dict[builtins.str, typing.Any]]]]] = None,
        show_legend: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        title: typing.Optional[builtins.str] = None,
        title_align: typing.Optional[builtins.str] = None,
        title_size: typing.Optional[builtins.str] = None,
        xaxis: typing.Optional[typing.Union[PowerpackWidgetDistributionDefinitionXaxis, typing.Dict[builtins.str, typing.Any]]] = None,
        yaxis: typing.Optional[typing.Union[PowerpackWidgetDistributionDefinitionYaxis, typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param legend_size: The size of the legend displayed in the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#legend_size Powerpack#legend_size}
        :param live_span: The timeframe to use when displaying the widget. Valid values are ``1m``, ``5m``, ``10m``, ``15m``, ``30m``, ``1h``, ``4h``, ``1d``, ``2d``, ``1w``, ``1mo``, ``3mo``, ``6mo``, ``week_to_date``, ``month_to_date``, ``1y``, ``alert``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#live_span Powerpack#live_span}
        :param request: request block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#request Powerpack#request}
        :param show_legend: Whether or not to show the legend on this widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#show_legend Powerpack#show_legend}
        :param title: The title of the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title Powerpack#title}
        :param title_align: The alignment of the widget's title. Valid values are ``center``, ``left``, ``right``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_align Powerpack#title_align}
        :param title_size: The size of the widget's title (defaults to 16). Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_size Powerpack#title_size}
        :param xaxis: xaxis block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#xaxis Powerpack#xaxis}
        :param yaxis: yaxis block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#yaxis Powerpack#yaxis}
        '''
        value = PowerpackWidgetDistributionDefinition(
            legend_size=legend_size,
            live_span=live_span,
            request=request,
            show_legend=show_legend,
            title=title,
            title_align=title_align,
            title_size=title_size,
            xaxis=xaxis,
            yaxis=yaxis,
        )

        return typing.cast(None, jsii.invoke(self, "putDistributionDefinition", [value]))

    @jsii.member(jsii_name="putEventStreamDefinition")
    def put_event_stream_definition(
        self,
        *,
        query: builtins.str,
        event_size: typing.Optional[builtins.str] = None,
        live_span: typing.Optional[builtins.str] = None,
        tags_execution: typing.Optional[builtins.str] = None,
        title: typing.Optional[builtins.str] = None,
        title_align: typing.Optional[builtins.str] = None,
        title_size: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param query: The query to use in the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        :param event_size: The size to use to display an event. Valid values are ``s``, ``l``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#event_size Powerpack#event_size}
        :param live_span: The timeframe to use when displaying the widget. Valid values are ``1m``, ``5m``, ``10m``, ``15m``, ``30m``, ``1h``, ``4h``, ``1d``, ``2d``, ``1w``, ``1mo``, ``3mo``, ``6mo``, ``week_to_date``, ``month_to_date``, ``1y``, ``alert``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#live_span Powerpack#live_span}
        :param tags_execution: The execution method for multi-value filters, options: ``and`` or ``or``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#tags_execution Powerpack#tags_execution}
        :param title: The title of the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title Powerpack#title}
        :param title_align: The alignment of the widget's title. Valid values are ``center``, ``left``, ``right``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_align Powerpack#title_align}
        :param title_size: The size of the widget's title (defaults to 16). Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_size Powerpack#title_size}
        '''
        value = PowerpackWidgetEventStreamDefinition(
            query=query,
            event_size=event_size,
            live_span=live_span,
            tags_execution=tags_execution,
            title=title,
            title_align=title_align,
            title_size=title_size,
        )

        return typing.cast(None, jsii.invoke(self, "putEventStreamDefinition", [value]))

    @jsii.member(jsii_name="putEventTimelineDefinition")
    def put_event_timeline_definition(
        self,
        *,
        query: builtins.str,
        live_span: typing.Optional[builtins.str] = None,
        tags_execution: typing.Optional[builtins.str] = None,
        title: typing.Optional[builtins.str] = None,
        title_align: typing.Optional[builtins.str] = None,
        title_size: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param query: The query to use in the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        :param live_span: The timeframe to use when displaying the widget. Valid values are ``1m``, ``5m``, ``10m``, ``15m``, ``30m``, ``1h``, ``4h``, ``1d``, ``2d``, ``1w``, ``1mo``, ``3mo``, ``6mo``, ``week_to_date``, ``month_to_date``, ``1y``, ``alert``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#live_span Powerpack#live_span}
        :param tags_execution: The execution method for multi-value filters, options: ``and`` or ``or``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#tags_execution Powerpack#tags_execution}
        :param title: The title of the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title Powerpack#title}
        :param title_align: The alignment of the widget's title. Valid values are ``center``, ``left``, ``right``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_align Powerpack#title_align}
        :param title_size: The size of the widget's title (defaults to 16). Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_size Powerpack#title_size}
        '''
        value = PowerpackWidgetEventTimelineDefinition(
            query=query,
            live_span=live_span,
            tags_execution=tags_execution,
            title=title,
            title_align=title_align,
            title_size=title_size,
        )

        return typing.cast(None, jsii.invoke(self, "putEventTimelineDefinition", [value]))

    @jsii.member(jsii_name="putFreeTextDefinition")
    def put_free_text_definition(
        self,
        *,
        text: builtins.str,
        color: typing.Optional[builtins.str] = None,
        font_size: typing.Optional[builtins.str] = None,
        text_align: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param text: The text to display in the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#text Powerpack#text}
        :param color: The color of the text in the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#color Powerpack#color}
        :param font_size: The size of the text in the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#font_size Powerpack#font_size}
        :param text_align: The alignment of the text in the widget. Valid values are ``center``, ``left``, ``right``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#text_align Powerpack#text_align}
        '''
        value = PowerpackWidgetFreeTextDefinition(
            text=text, color=color, font_size=font_size, text_align=text_align
        )

        return typing.cast(None, jsii.invoke(self, "putFreeTextDefinition", [value]))

    @jsii.member(jsii_name="putGeomapDefinition")
    def put_geomap_definition(
        self,
        *,
        view: typing.Union[PowerpackWidgetGeomapDefinitionView, typing.Dict[builtins.str, typing.Any]],
        custom_link: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetGeomapDefinitionCustomLink, typing.Dict[builtins.str, typing.Any]]]]] = None,
        live_span: typing.Optional[builtins.str] = None,
        request: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetGeomapDefinitionRequest, typing.Dict[builtins.str, typing.Any]]]]] = None,
        style: typing.Optional[typing.Union[PowerpackWidgetGeomapDefinitionStyle, typing.Dict[builtins.str, typing.Any]]] = None,
        title: typing.Optional[builtins.str] = None,
        title_align: typing.Optional[builtins.str] = None,
        title_size: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param view: view block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#view Powerpack#view}
        :param custom_link: custom_link block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom_link Powerpack#custom_link}
        :param live_span: The timeframe to use when displaying the widget. Valid values are ``1m``, ``5m``, ``10m``, ``15m``, ``30m``, ``1h``, ``4h``, ``1d``, ``2d``, ``1w``, ``1mo``, ``3mo``, ``6mo``, ``week_to_date``, ``month_to_date``, ``1y``, ``alert``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#live_span Powerpack#live_span}
        :param request: request block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#request Powerpack#request}
        :param style: style block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#style Powerpack#style}
        :param title: The title of the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title Powerpack#title}
        :param title_align: The alignment of the widget's title. Valid values are ``center``, ``left``, ``right``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_align Powerpack#title_align}
        :param title_size: The size of the widget's title (defaults to 16). Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_size Powerpack#title_size}
        '''
        value = PowerpackWidgetGeomapDefinition(
            view=view,
            custom_link=custom_link,
            live_span=live_span,
            request=request,
            style=style,
            title=title,
            title_align=title_align,
            title_size=title_size,
        )

        return typing.cast(None, jsii.invoke(self, "putGeomapDefinition", [value]))

    @jsii.member(jsii_name="putHeatmapDefinition")
    def put_heatmap_definition(
        self,
        *,
        custom_link: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHeatmapDefinitionCustomLink, typing.Dict[builtins.str, typing.Any]]]]] = None,
        event: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHeatmapDefinitionEvent, typing.Dict[builtins.str, typing.Any]]]]] = None,
        legend_size: typing.Optional[builtins.str] = None,
        live_span: typing.Optional[builtins.str] = None,
        request: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHeatmapDefinitionRequest, typing.Dict[builtins.str, typing.Any]]]]] = None,
        show_legend: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        title: typing.Optional[builtins.str] = None,
        title_align: typing.Optional[builtins.str] = None,
        title_size: typing.Optional[builtins.str] = None,
        yaxis: typing.Optional[typing.Union[PowerpackWidgetHeatmapDefinitionYaxis, typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param custom_link: custom_link block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom_link Powerpack#custom_link}
        :param event: event block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#event Powerpack#event}
        :param legend_size: The size of the legend displayed in the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#legend_size Powerpack#legend_size}
        :param live_span: The timeframe to use when displaying the widget. Valid values are ``1m``, ``5m``, ``10m``, ``15m``, ``30m``, ``1h``, ``4h``, ``1d``, ``2d``, ``1w``, ``1mo``, ``3mo``, ``6mo``, ``week_to_date``, ``month_to_date``, ``1y``, ``alert``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#live_span Powerpack#live_span}
        :param request: request block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#request Powerpack#request}
        :param show_legend: Whether or not to show the legend on this widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#show_legend Powerpack#show_legend}
        :param title: The title of the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title Powerpack#title}
        :param title_align: The alignment of the widget's title. Valid values are ``center``, ``left``, ``right``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_align Powerpack#title_align}
        :param title_size: The size of the widget's title (defaults to 16). Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_size Powerpack#title_size}
        :param yaxis: yaxis block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#yaxis Powerpack#yaxis}
        '''
        value = PowerpackWidgetHeatmapDefinition(
            custom_link=custom_link,
            event=event,
            legend_size=legend_size,
            live_span=live_span,
            request=request,
            show_legend=show_legend,
            title=title,
            title_align=title_align,
            title_size=title_size,
            yaxis=yaxis,
        )

        return typing.cast(None, jsii.invoke(self, "putHeatmapDefinition", [value]))

    @jsii.member(jsii_name="putHostmapDefinition")
    def put_hostmap_definition(
        self,
        *,
        custom_link: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHostmapDefinitionCustomLink, typing.Dict[builtins.str, typing.Any]]]]] = None,
        group: typing.Optional[typing.Sequence[builtins.str]] = None,
        node_type: typing.Optional[builtins.str] = None,
        no_group_hosts: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        no_metric_hosts: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        request: typing.Optional[typing.Union[PowerpackWidgetHostmapDefinitionRequest, typing.Dict[builtins.str, typing.Any]]] = None,
        scope: typing.Optional[typing.Sequence[builtins.str]] = None,
        style: typing.Optional[typing.Union[PowerpackWidgetHostmapDefinitionStyle, typing.Dict[builtins.str, typing.Any]]] = None,
        title: typing.Optional[builtins.str] = None,
        title_align: typing.Optional[builtins.str] = None,
        title_size: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param custom_link: custom_link block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom_link Powerpack#custom_link}
        :param group: The list of tags to group nodes by. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group Powerpack#group}
        :param node_type: The type of node used. Valid values are ``host``, ``container``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#node_type Powerpack#node_type}
        :param no_group_hosts: A Boolean indicating whether to show ungrouped nodes. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#no_group_hosts Powerpack#no_group_hosts}
        :param no_metric_hosts: A Boolean indicating whether to show nodes with no metrics. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#no_metric_hosts Powerpack#no_metric_hosts}
        :param request: request block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#request Powerpack#request}
        :param scope: The list of tags to filter nodes by. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#scope Powerpack#scope}
        :param style: style block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#style Powerpack#style}
        :param title: The title of the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title Powerpack#title}
        :param title_align: The alignment of the widget's title. Valid values are ``center``, ``left``, ``right``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_align Powerpack#title_align}
        :param title_size: The size of the widget's title (defaults to 16). Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_size Powerpack#title_size}
        '''
        value = PowerpackWidgetHostmapDefinition(
            custom_link=custom_link,
            group=group,
            node_type=node_type,
            no_group_hosts=no_group_hosts,
            no_metric_hosts=no_metric_hosts,
            request=request,
            scope=scope,
            style=style,
            title=title,
            title_align=title_align,
            title_size=title_size,
        )

        return typing.cast(None, jsii.invoke(self, "putHostmapDefinition", [value]))

    @jsii.member(jsii_name="putIframeDefinition")
    def put_iframe_definition(self, *, url: builtins.str) -> None:
        '''
        :param url: The URL to use as a data source for the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#url Powerpack#url}
        '''
        value = PowerpackWidgetIframeDefinition(url=url)

        return typing.cast(None, jsii.invoke(self, "putIframeDefinition", [value]))

    @jsii.member(jsii_name="putImageDefinition")
    def put_image_definition(
        self,
        *,
        url: builtins.str,
        has_background: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        has_border: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        horizontal_align: typing.Optional[builtins.str] = None,
        margin: typing.Optional[builtins.str] = None,
        sizing: typing.Optional[builtins.str] = None,
        url_dark_theme: typing.Optional[builtins.str] = None,
        vertical_align: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param url: The URL to use as a data source for the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#url Powerpack#url}
        :param has_background: Whether to display a background or not. Defaults to ``true``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#has_background Powerpack#has_background}
        :param has_border: Whether to display a border or not. Defaults to ``true``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#has_border Powerpack#has_border}
        :param horizontal_align: The horizontal alignment for the widget. Valid values are ``center``, ``left``, ``right``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#horizontal_align Powerpack#horizontal_align}
        :param margin: The margins to use around the image. Note: ``small`` and ``large`` values are deprecated. Valid values are ``sm``, ``md``, ``lg``, ``small``, ``large``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#margin Powerpack#margin}
        :param sizing: The preferred method to adapt the dimensions of the image. The values are based on the image ``object-fit`` CSS properties. Note: ``zoom``, ``fit`` and ``center`` values are deprecated. Valid values are ``fill``, ``contain``, ``cover``, ``none``, ``scale-down``, ``zoom``, ``fit``, ``center``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sizing Powerpack#sizing}
        :param url_dark_theme: The URL in dark mode to use as a data source for the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#url_dark_theme Powerpack#url_dark_theme}
        :param vertical_align: The vertical alignment for the widget. Valid values are ``center``, ``top``, ``bottom``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#vertical_align Powerpack#vertical_align}
        '''
        value = PowerpackWidgetImageDefinition(
            url=url,
            has_background=has_background,
            has_border=has_border,
            horizontal_align=horizontal_align,
            margin=margin,
            sizing=sizing,
            url_dark_theme=url_dark_theme,
            vertical_align=vertical_align,
        )

        return typing.cast(None, jsii.invoke(self, "putImageDefinition", [value]))

    @jsii.member(jsii_name="putListStreamDefinition")
    def put_list_stream_definition(
        self,
        *,
        request: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetListStreamDefinitionRequest, typing.Dict[builtins.str, typing.Any]]]],
        title: typing.Optional[builtins.str] = None,
        title_align: typing.Optional[builtins.str] = None,
        title_size: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param request: request block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#request Powerpack#request}
        :param title: The title of the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title Powerpack#title}
        :param title_align: The alignment of the widget's title. Valid values are ``center``, ``left``, ``right``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_align Powerpack#title_align}
        :param title_size: The size of the widget's title. Default is 16. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_size Powerpack#title_size}
        '''
        value = PowerpackWidgetListStreamDefinition(
            request=request,
            title=title,
            title_align=title_align,
            title_size=title_size,
        )

        return typing.cast(None, jsii.invoke(self, "putListStreamDefinition", [value]))

    @jsii.member(jsii_name="putLogStreamDefinition")
    def put_log_stream_definition(
        self,
        *,
        columns: typing.Optional[typing.Sequence[builtins.str]] = None,
        indexes: typing.Optional[typing.Sequence[builtins.str]] = None,
        live_span: typing.Optional[builtins.str] = None,
        message_display: typing.Optional[builtins.str] = None,
        query: typing.Optional[builtins.str] = None,
        show_date_column: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        show_message_column: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        sort: typing.Optional[typing.Union[PowerpackWidgetLogStreamDefinitionSort, typing.Dict[builtins.str, typing.Any]]] = None,
        title: typing.Optional[builtins.str] = None,
        title_align: typing.Optional[builtins.str] = None,
        title_size: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param columns: Stringified list of columns to use, for example: ``["column1","column2","column3"]``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#columns Powerpack#columns}
        :param indexes: An array of index names to query in the stream. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#indexes Powerpack#indexes}
        :param live_span: The timeframe to use when displaying the widget. Valid values are ``1m``, ``5m``, ``10m``, ``15m``, ``30m``, ``1h``, ``4h``, ``1d``, ``2d``, ``1w``, ``1mo``, ``3mo``, ``6mo``, ``week_to_date``, ``month_to_date``, ``1y``, ``alert``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#live_span Powerpack#live_span}
        :param message_display: The number of log lines to display. Valid values are ``inline``, ``expanded-md``, ``expanded-lg``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#message_display Powerpack#message_display}
        :param query: The query to use in the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        :param show_date_column: If the date column should be displayed. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#show_date_column Powerpack#show_date_column}
        :param show_message_column: If the message column should be displayed. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#show_message_column Powerpack#show_message_column}
        :param sort: sort block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort Powerpack#sort}
        :param title: The title of the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title Powerpack#title}
        :param title_align: The alignment of the widget's title. Valid values are ``center``, ``left``, ``right``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_align Powerpack#title_align}
        :param title_size: The size of the widget's title (defaults to 16). Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_size Powerpack#title_size}
        '''
        value = PowerpackWidgetLogStreamDefinition(
            columns=columns,
            indexes=indexes,
            live_span=live_span,
            message_display=message_display,
            query=query,
            show_date_column=show_date_column,
            show_message_column=show_message_column,
            sort=sort,
            title=title,
            title_align=title_align,
            title_size=title_size,
        )

        return typing.cast(None, jsii.invoke(self, "putLogStreamDefinition", [value]))

    @jsii.member(jsii_name="putManageStatusDefinition")
    def put_manage_status_definition(
        self,
        *,
        query: builtins.str,
        color_preference: typing.Optional[builtins.str] = None,
        display_format: typing.Optional[builtins.str] = None,
        hide_zero_counts: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        show_last_triggered: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        show_priority: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        sort: typing.Optional[builtins.str] = None,
        summary_type: typing.Optional[builtins.str] = None,
        title: typing.Optional[builtins.str] = None,
        title_align: typing.Optional[builtins.str] = None,
        title_size: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param query: The query to use in the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        :param color_preference: Whether to colorize text or background. Valid values are ``background``, ``text``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#color_preference Powerpack#color_preference}
        :param display_format: The display setting to use. Valid values are ``counts``, ``countsAndList``, ``list``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#display_format Powerpack#display_format}
        :param hide_zero_counts: A Boolean indicating whether to hide empty categories. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#hide_zero_counts Powerpack#hide_zero_counts}
        :param show_last_triggered: A Boolean indicating whether to show when monitors/groups last triggered. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#show_last_triggered Powerpack#show_last_triggered}
        :param show_priority: Whether to show the priorities column. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#show_priority Powerpack#show_priority}
        :param sort: The method to sort the monitors. Valid values are ``name``, ``group``, ``status``, ``tags``, ``triggered``, ``group,asc``, ``group,desc``, ``name,asc``, ``name,desc``, ``status,asc``, ``status,desc``, ``tags,asc``, ``tags,desc``, ``triggered,asc``, ``triggered,desc``, ``priority,asc``, ``priority,desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort Powerpack#sort}
        :param summary_type: The summary type to use. Valid values are ``monitors``, ``groups``, ``combined``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#summary_type Powerpack#summary_type}
        :param title: The title of the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title Powerpack#title}
        :param title_align: The alignment of the widget's title. Valid values are ``center``, ``left``, ``right``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_align Powerpack#title_align}
        :param title_size: The size of the widget's title (defaults to 16). Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_size Powerpack#title_size}
        '''
        value = PowerpackWidgetManageStatusDefinition(
            query=query,
            color_preference=color_preference,
            display_format=display_format,
            hide_zero_counts=hide_zero_counts,
            show_last_triggered=show_last_triggered,
            show_priority=show_priority,
            sort=sort,
            summary_type=summary_type,
            title=title,
            title_align=title_align,
            title_size=title_size,
        )

        return typing.cast(None, jsii.invoke(self, "putManageStatusDefinition", [value]))

    @jsii.member(jsii_name="putNoteDefinition")
    def put_note_definition(
        self,
        *,
        content: builtins.str,
        background_color: typing.Optional[builtins.str] = None,
        font_size: typing.Optional[builtins.str] = None,
        has_padding: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        show_tick: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        text_align: typing.Optional[builtins.str] = None,
        tick_edge: typing.Optional[builtins.str] = None,
        tick_pos: typing.Optional[builtins.str] = None,
        vertical_align: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param content: The content of the note. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#content Powerpack#content}
        :param background_color: The background color of the note. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#background_color Powerpack#background_color}
        :param font_size: The size of the text. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#font_size Powerpack#font_size}
        :param has_padding: Whether to add padding or not. Defaults to ``true``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#has_padding Powerpack#has_padding}
        :param show_tick: Whether to show a tick or not. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#show_tick Powerpack#show_tick}
        :param text_align: The alignment of the widget's text. Valid values are ``center``, ``left``, ``right``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#text_align Powerpack#text_align}
        :param tick_edge: When ``tick = true``, a string indicating on which side of the widget the tick should be displayed. Valid values are ``bottom``, ``left``, ``right``, ``top``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#tick_edge Powerpack#tick_edge}
        :param tick_pos: When ``tick = true``, a string with a percent sign indicating the position of the tick, for example: ``tick_pos = "50%"`` is centered alignment. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#tick_pos Powerpack#tick_pos}
        :param vertical_align: The vertical alignment for the widget. Valid values are ``center``, ``top``, ``bottom``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#vertical_align Powerpack#vertical_align}
        '''
        value = PowerpackWidgetNoteDefinition(
            content=content,
            background_color=background_color,
            font_size=font_size,
            has_padding=has_padding,
            show_tick=show_tick,
            text_align=text_align,
            tick_edge=tick_edge,
            tick_pos=tick_pos,
            vertical_align=vertical_align,
        )

        return typing.cast(None, jsii.invoke(self, "putNoteDefinition", [value]))

    @jsii.member(jsii_name="putQueryTableDefinition")
    def put_query_table_definition(
        self,
        *,
        custom_link: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetQueryTableDefinitionCustomLink", typing.Dict[builtins.str, typing.Any]]]]] = None,
        has_search_bar: typing.Optional[builtins.str] = None,
        live_span: typing.Optional[builtins.str] = None,
        request: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetQueryTableDefinitionRequest", typing.Dict[builtins.str, typing.Any]]]]] = None,
        title: typing.Optional[builtins.str] = None,
        title_align: typing.Optional[builtins.str] = None,
        title_size: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param custom_link: custom_link block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom_link Powerpack#custom_link}
        :param has_search_bar: Controls the display of the search bar. Valid values are ``always``, ``never``, ``auto``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#has_search_bar Powerpack#has_search_bar}
        :param live_span: The timeframe to use when displaying the widget. Valid values are ``1m``, ``5m``, ``10m``, ``15m``, ``30m``, ``1h``, ``4h``, ``1d``, ``2d``, ``1w``, ``1mo``, ``3mo``, ``6mo``, ``week_to_date``, ``month_to_date``, ``1y``, ``alert``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#live_span Powerpack#live_span}
        :param request: request block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#request Powerpack#request}
        :param title: The title of the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title Powerpack#title}
        :param title_align: The alignment of the widget's title. Valid values are ``center``, ``left``, ``right``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_align Powerpack#title_align}
        :param title_size: The size of the widget's title (defaults to 16). Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_size Powerpack#title_size}
        '''
        value = PowerpackWidgetQueryTableDefinition(
            custom_link=custom_link,
            has_search_bar=has_search_bar,
            live_span=live_span,
            request=request,
            title=title,
            title_align=title_align,
            title_size=title_size,
        )

        return typing.cast(None, jsii.invoke(self, "putQueryTableDefinition", [value]))

    @jsii.member(jsii_name="putQueryValueDefinition")
    def put_query_value_definition(
        self,
        *,
        autoscale: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        custom_link: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetQueryValueDefinitionCustomLink", typing.Dict[builtins.str, typing.Any]]]]] = None,
        custom_unit: typing.Optional[builtins.str] = None,
        live_span: typing.Optional[builtins.str] = None,
        precision: typing.Optional[jsii.Number] = None,
        request: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetQueryValueDefinitionRequest", typing.Dict[builtins.str, typing.Any]]]]] = None,
        text_align: typing.Optional[builtins.str] = None,
        timeseries_background: typing.Optional[typing.Union["PowerpackWidgetQueryValueDefinitionTimeseriesBackground", typing.Dict[builtins.str, typing.Any]]] = None,
        title: typing.Optional[builtins.str] = None,
        title_align: typing.Optional[builtins.str] = None,
        title_size: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param autoscale: A Boolean indicating whether to automatically scale the tile. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#autoscale Powerpack#autoscale}
        :param custom_link: custom_link block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom_link Powerpack#custom_link}
        :param custom_unit: The unit for the value displayed in the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom_unit Powerpack#custom_unit}
        :param live_span: The timeframe to use when displaying the widget. Valid values are ``1m``, ``5m``, ``10m``, ``15m``, ``30m``, ``1h``, ``4h``, ``1d``, ``2d``, ``1w``, ``1mo``, ``3mo``, ``6mo``, ``week_to_date``, ``month_to_date``, ``1y``, ``alert``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#live_span Powerpack#live_span}
        :param precision: The precision to use when displaying the tile. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#precision Powerpack#precision}
        :param request: request block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#request Powerpack#request}
        :param text_align: The alignment of the widget's text. Valid values are ``center``, ``left``, ``right``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#text_align Powerpack#text_align}
        :param timeseries_background: timeseries_background block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#timeseries_background Powerpack#timeseries_background}
        :param title: The title of the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title Powerpack#title}
        :param title_align: The alignment of the widget's title. Valid values are ``center``, ``left``, ``right``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_align Powerpack#title_align}
        :param title_size: The size of the widget's title (defaults to 16). Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_size Powerpack#title_size}
        '''
        value = PowerpackWidgetQueryValueDefinition(
            autoscale=autoscale,
            custom_link=custom_link,
            custom_unit=custom_unit,
            live_span=live_span,
            precision=precision,
            request=request,
            text_align=text_align,
            timeseries_background=timeseries_background,
            title=title,
            title_align=title_align,
            title_size=title_size,
        )

        return typing.cast(None, jsii.invoke(self, "putQueryValueDefinition", [value]))

    @jsii.member(jsii_name="putRunWorkflowDefinition")
    def put_run_workflow_definition(
        self,
        *,
        workflow_id: builtins.str,
        custom_link: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetRunWorkflowDefinitionCustomLink", typing.Dict[builtins.str, typing.Any]]]]] = None,
        input: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetRunWorkflowDefinitionInput", typing.Dict[builtins.str, typing.Any]]]]] = None,
        live_span: typing.Optional[builtins.str] = None,
        title: typing.Optional[builtins.str] = None,
        title_align: typing.Optional[builtins.str] = None,
        title_size: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param workflow_id: Workflow ID. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#workflow_id Powerpack#workflow_id}
        :param custom_link: custom_link block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom_link Powerpack#custom_link}
        :param input: input block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#input Powerpack#input}
        :param live_span: The timeframe to use when displaying the widget. Valid values are ``1m``, ``5m``, ``10m``, ``15m``, ``30m``, ``1h``, ``4h``, ``1d``, ``2d``, ``1w``, ``1mo``, ``3mo``, ``6mo``, ``week_to_date``, ``month_to_date``, ``1y``, ``alert``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#live_span Powerpack#live_span}
        :param title: The title of the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title Powerpack#title}
        :param title_align: The alignment of the widget's title. Valid values are ``center``, ``left``, ``right``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_align Powerpack#title_align}
        :param title_size: The size of the widget's title (defaults to 16). Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_size Powerpack#title_size}
        '''
        value = PowerpackWidgetRunWorkflowDefinition(
            workflow_id=workflow_id,
            custom_link=custom_link,
            input=input,
            live_span=live_span,
            title=title,
            title_align=title_align,
            title_size=title_size,
        )

        return typing.cast(None, jsii.invoke(self, "putRunWorkflowDefinition", [value]))

    @jsii.member(jsii_name="putScatterplotDefinition")
    def put_scatterplot_definition(
        self,
        *,
        color_by_groups: typing.Optional[typing.Sequence[builtins.str]] = None,
        custom_link: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetScatterplotDefinitionCustomLink", typing.Dict[builtins.str, typing.Any]]]]] = None,
        live_span: typing.Optional[builtins.str] = None,
        request: typing.Optional[typing.Union["PowerpackWidgetScatterplotDefinitionRequest", typing.Dict[builtins.str, typing.Any]]] = None,
        title: typing.Optional[builtins.str] = None,
        title_align: typing.Optional[builtins.str] = None,
        title_size: typing.Optional[builtins.str] = None,
        xaxis: typing.Optional[typing.Union["PowerpackWidgetScatterplotDefinitionXaxis", typing.Dict[builtins.str, typing.Any]]] = None,
        yaxis: typing.Optional[typing.Union["PowerpackWidgetScatterplotDefinitionYaxis", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param color_by_groups: List of groups used for colors. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#color_by_groups Powerpack#color_by_groups}
        :param custom_link: custom_link block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom_link Powerpack#custom_link}
        :param live_span: The timeframe to use when displaying the widget. Valid values are ``1m``, ``5m``, ``10m``, ``15m``, ``30m``, ``1h``, ``4h``, ``1d``, ``2d``, ``1w``, ``1mo``, ``3mo``, ``6mo``, ``week_to_date``, ``month_to_date``, ``1y``, ``alert``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#live_span Powerpack#live_span}
        :param request: request block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#request Powerpack#request}
        :param title: The title of the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title Powerpack#title}
        :param title_align: The alignment of the widget's title. Valid values are ``center``, ``left``, ``right``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_align Powerpack#title_align}
        :param title_size: The size of the widget's title (defaults to 16). Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_size Powerpack#title_size}
        :param xaxis: xaxis block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#xaxis Powerpack#xaxis}
        :param yaxis: yaxis block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#yaxis Powerpack#yaxis}
        '''
        value = PowerpackWidgetScatterplotDefinition(
            color_by_groups=color_by_groups,
            custom_link=custom_link,
            live_span=live_span,
            request=request,
            title=title,
            title_align=title_align,
            title_size=title_size,
            xaxis=xaxis,
            yaxis=yaxis,
        )

        return typing.cast(None, jsii.invoke(self, "putScatterplotDefinition", [value]))

    @jsii.member(jsii_name="putServiceLevelObjectiveDefinition")
    def put_service_level_objective_definition(
        self,
        *,
        slo_id: builtins.str,
        time_windows: typing.Sequence[builtins.str],
        view_mode: builtins.str,
        view_type: builtins.str,
        additional_query_filters: typing.Optional[builtins.str] = None,
        global_time_target: typing.Optional[builtins.str] = None,
        show_error_budget: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        title: typing.Optional[builtins.str] = None,
        title_align: typing.Optional[builtins.str] = None,
        title_size: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param slo_id: The ID of the service level objective used by the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#slo_id Powerpack#slo_id}
        :param time_windows: A list of time windows to display in the widget. Valid values are ``7d``, ``30d``, ``90d``, ``week_to_date``, ``previous_week``, ``month_to_date``, ``previous_month``, ``global_time``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#time_windows Powerpack#time_windows}
        :param view_mode: The view mode for the widget. Valid values are ``overall``, ``component``, ``both``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#view_mode Powerpack#view_mode}
        :param view_type: The type of view to use when displaying the widget. Only ``detail`` is supported. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#view_type Powerpack#view_type}
        :param additional_query_filters: Additional filters applied to the SLO query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#additional_query_filters Powerpack#additional_query_filters}
        :param global_time_target: The global time target of the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#global_time_target Powerpack#global_time_target}
        :param show_error_budget: Whether to show the error budget or not. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#show_error_budget Powerpack#show_error_budget}
        :param title: The title of the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title Powerpack#title}
        :param title_align: The alignment of the widget's title. Valid values are ``center``, ``left``, ``right``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_align Powerpack#title_align}
        :param title_size: The size of the widget's title (defaults to 16). Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_size Powerpack#title_size}
        '''
        value = PowerpackWidgetServiceLevelObjectiveDefinition(
            slo_id=slo_id,
            time_windows=time_windows,
            view_mode=view_mode,
            view_type=view_type,
            additional_query_filters=additional_query_filters,
            global_time_target=global_time_target,
            show_error_budget=show_error_budget,
            title=title,
            title_align=title_align,
            title_size=title_size,
        )

        return typing.cast(None, jsii.invoke(self, "putServiceLevelObjectiveDefinition", [value]))

    @jsii.member(jsii_name="putServicemapDefinition")
    def put_servicemap_definition(
        self,
        *,
        filters: typing.Sequence[builtins.str],
        service: builtins.str,
        custom_link: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetServicemapDefinitionCustomLink", typing.Dict[builtins.str, typing.Any]]]]] = None,
        title: typing.Optional[builtins.str] = None,
        title_align: typing.Optional[builtins.str] = None,
        title_size: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param filters: Your environment and primary tag (or ``*`` if enabled for your account). Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#filters Powerpack#filters}
        :param service: The ID of the service to map. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#service Powerpack#service}
        :param custom_link: custom_link block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom_link Powerpack#custom_link}
        :param title: The title of the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title Powerpack#title}
        :param title_align: The alignment of the widget's title. Valid values are ``center``, ``left``, ``right``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_align Powerpack#title_align}
        :param title_size: The size of the widget's title (defaults to 16). Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_size Powerpack#title_size}
        '''
        value = PowerpackWidgetServicemapDefinition(
            filters=filters,
            service=service,
            custom_link=custom_link,
            title=title,
            title_align=title_align,
            title_size=title_size,
        )

        return typing.cast(None, jsii.invoke(self, "putServicemapDefinition", [value]))

    @jsii.member(jsii_name="putSloListDefinition")
    def put_slo_list_definition(
        self,
        *,
        request: typing.Union["PowerpackWidgetSloListDefinitionRequest", typing.Dict[builtins.str, typing.Any]],
        title: typing.Optional[builtins.str] = None,
        title_align: typing.Optional[builtins.str] = None,
        title_size: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param request: request block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#request Powerpack#request}
        :param title: The title of the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title Powerpack#title}
        :param title_align: The alignment of the widget's title. Valid values are ``center``, ``left``, ``right``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_align Powerpack#title_align}
        :param title_size: The size of the widget's title (defaults to 16). Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_size Powerpack#title_size}
        '''
        value = PowerpackWidgetSloListDefinition(
            request=request,
            title=title,
            title_align=title_align,
            title_size=title_size,
        )

        return typing.cast(None, jsii.invoke(self, "putSloListDefinition", [value]))

    @jsii.member(jsii_name="putSunburstDefinition")
    def put_sunburst_definition(
        self,
        *,
        custom_link: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetSunburstDefinitionCustomLink", typing.Dict[builtins.str, typing.Any]]]]] = None,
        hide_total: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        legend_inline: typing.Optional[typing.Union["PowerpackWidgetSunburstDefinitionLegendInline", typing.Dict[builtins.str, typing.Any]]] = None,
        legend_table: typing.Optional[typing.Union["PowerpackWidgetSunburstDefinitionLegendTable", typing.Dict[builtins.str, typing.Any]]] = None,
        live_span: typing.Optional[builtins.str] = None,
        request: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetSunburstDefinitionRequest", typing.Dict[builtins.str, typing.Any]]]]] = None,
        title: typing.Optional[builtins.str] = None,
        title_align: typing.Optional[builtins.str] = None,
        title_size: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param custom_link: custom_link block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom_link Powerpack#custom_link}
        :param hide_total: Whether or not to show the total value in the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#hide_total Powerpack#hide_total}
        :param legend_inline: legend_inline block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#legend_inline Powerpack#legend_inline}
        :param legend_table: legend_table block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#legend_table Powerpack#legend_table}
        :param live_span: The timeframe to use when displaying the widget. Valid values are ``1m``, ``5m``, ``10m``, ``15m``, ``30m``, ``1h``, ``4h``, ``1d``, ``2d``, ``1w``, ``1mo``, ``3mo``, ``6mo``, ``week_to_date``, ``month_to_date``, ``1y``, ``alert``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#live_span Powerpack#live_span}
        :param request: request block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#request Powerpack#request}
        :param title: The title of the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title Powerpack#title}
        :param title_align: The alignment of the widget's title. One of ``left``, ``center``, or ``right``. Valid values are ``center``, ``left``, ``right``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_align Powerpack#title_align}
        :param title_size: The size of the widget's title. Default is 16. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_size Powerpack#title_size}
        '''
        value = PowerpackWidgetSunburstDefinition(
            custom_link=custom_link,
            hide_total=hide_total,
            legend_inline=legend_inline,
            legend_table=legend_table,
            live_span=live_span,
            request=request,
            title=title,
            title_align=title_align,
            title_size=title_size,
        )

        return typing.cast(None, jsii.invoke(self, "putSunburstDefinition", [value]))

    @jsii.member(jsii_name="putTimeseriesDefinition")
    def put_timeseries_definition(
        self,
        *,
        custom_link: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetTimeseriesDefinitionCustomLink", typing.Dict[builtins.str, typing.Any]]]]] = None,
        event: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetTimeseriesDefinitionEvent", typing.Dict[builtins.str, typing.Any]]]]] = None,
        legend_columns: typing.Optional[typing.Sequence[builtins.str]] = None,
        legend_layout: typing.Optional[builtins.str] = None,
        legend_size: typing.Optional[builtins.str] = None,
        live_span: typing.Optional[builtins.str] = None,
        marker: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetTimeseriesDefinitionMarker", typing.Dict[builtins.str, typing.Any]]]]] = None,
        request: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetTimeseriesDefinitionRequest", typing.Dict[builtins.str, typing.Any]]]]] = None,
        right_yaxis: typing.Optional[typing.Union["PowerpackWidgetTimeseriesDefinitionRightYaxis", typing.Dict[builtins.str, typing.Any]]] = None,
        show_legend: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        title: typing.Optional[builtins.str] = None,
        title_align: typing.Optional[builtins.str] = None,
        title_size: typing.Optional[builtins.str] = None,
        yaxis: typing.Optional[typing.Union["PowerpackWidgetTimeseriesDefinitionYaxis", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param custom_link: custom_link block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom_link Powerpack#custom_link}
        :param event: event block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#event Powerpack#event}
        :param legend_columns: A list of columns to display in the legend. Valid values are ``value``, ``avg``, ``sum``, ``min``, ``max``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#legend_columns Powerpack#legend_columns}
        :param legend_layout: The layout of the legend displayed in the widget. Valid values are ``auto``, ``horizontal``, ``vertical``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#legend_layout Powerpack#legend_layout}
        :param legend_size: The size of the legend displayed in the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#legend_size Powerpack#legend_size}
        :param live_span: The timeframe to use when displaying the widget. Valid values are ``1m``, ``5m``, ``10m``, ``15m``, ``30m``, ``1h``, ``4h``, ``1d``, ``2d``, ``1w``, ``1mo``, ``3mo``, ``6mo``, ``week_to_date``, ``month_to_date``, ``1y``, ``alert``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#live_span Powerpack#live_span}
        :param marker: marker block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#marker Powerpack#marker}
        :param request: request block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#request Powerpack#request}
        :param right_yaxis: right_yaxis block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#right_yaxis Powerpack#right_yaxis}
        :param show_legend: Whether or not to show the legend on this widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#show_legend Powerpack#show_legend}
        :param title: The title of the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title Powerpack#title}
        :param title_align: The alignment of the widget's title. Valid values are ``center``, ``left``, ``right``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_align Powerpack#title_align}
        :param title_size: The size of the widget's title (defaults to 16). Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_size Powerpack#title_size}
        :param yaxis: yaxis block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#yaxis Powerpack#yaxis}
        '''
        value = PowerpackWidgetTimeseriesDefinition(
            custom_link=custom_link,
            event=event,
            legend_columns=legend_columns,
            legend_layout=legend_layout,
            legend_size=legend_size,
            live_span=live_span,
            marker=marker,
            request=request,
            right_yaxis=right_yaxis,
            show_legend=show_legend,
            title=title,
            title_align=title_align,
            title_size=title_size,
            yaxis=yaxis,
        )

        return typing.cast(None, jsii.invoke(self, "putTimeseriesDefinition", [value]))

    @jsii.member(jsii_name="putToplistDefinition")
    def put_toplist_definition(
        self,
        *,
        custom_link: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetToplistDefinitionCustomLink", typing.Dict[builtins.str, typing.Any]]]]] = None,
        live_span: typing.Optional[builtins.str] = None,
        request: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetToplistDefinitionRequest", typing.Dict[builtins.str, typing.Any]]]]] = None,
        style: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetToplistDefinitionStyle", typing.Dict[builtins.str, typing.Any]]]]] = None,
        title: typing.Optional[builtins.str] = None,
        title_align: typing.Optional[builtins.str] = None,
        title_size: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param custom_link: custom_link block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom_link Powerpack#custom_link}
        :param live_span: The timeframe to use when displaying the widget. Valid values are ``1m``, ``5m``, ``10m``, ``15m``, ``30m``, ``1h``, ``4h``, ``1d``, ``2d``, ``1w``, ``1mo``, ``3mo``, ``6mo``, ``week_to_date``, ``month_to_date``, ``1y``, ``alert``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#live_span Powerpack#live_span}
        :param request: request block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#request Powerpack#request}
        :param style: style block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#style Powerpack#style}
        :param title: The title of the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title Powerpack#title}
        :param title_align: The alignment of the widget's title. Valid values are ``center``, ``left``, ``right``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_align Powerpack#title_align}
        :param title_size: The size of the widget's title (defaults to 16). Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_size Powerpack#title_size}
        '''
        value = PowerpackWidgetToplistDefinition(
            custom_link=custom_link,
            live_span=live_span,
            request=request,
            style=style,
            title=title,
            title_align=title_align,
            title_size=title_size,
        )

        return typing.cast(None, jsii.invoke(self, "putToplistDefinition", [value]))

    @jsii.member(jsii_name="putTopologyMapDefinition")
    def put_topology_map_definition(
        self,
        *,
        custom_link: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetTopologyMapDefinitionCustomLink", typing.Dict[builtins.str, typing.Any]]]]] = None,
        request: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetTopologyMapDefinitionRequest", typing.Dict[builtins.str, typing.Any]]]]] = None,
        title: typing.Optional[builtins.str] = None,
        title_align: typing.Optional[builtins.str] = None,
        title_size: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param custom_link: custom_link block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom_link Powerpack#custom_link}
        :param request: request block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#request Powerpack#request}
        :param title: The title of the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title Powerpack#title}
        :param title_align: The alignment of the widget's title. Valid values are ``center``, ``left``, ``right``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_align Powerpack#title_align}
        :param title_size: The size of the widget's title (defaults to 16). Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_size Powerpack#title_size}
        '''
        value = PowerpackWidgetTopologyMapDefinition(
            custom_link=custom_link,
            request=request,
            title=title,
            title_align=title_align,
            title_size=title_size,
        )

        return typing.cast(None, jsii.invoke(self, "putTopologyMapDefinition", [value]))

    @jsii.member(jsii_name="putTraceServiceDefinition")
    def put_trace_service_definition(
        self,
        *,
        env: builtins.str,
        service: builtins.str,
        span_name: builtins.str,
        display_format: typing.Optional[builtins.str] = None,
        live_span: typing.Optional[builtins.str] = None,
        show_breakdown: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        show_distribution: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        show_errors: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        show_hits: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        show_latency: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        show_resource_list: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        size_format: typing.Optional[builtins.str] = None,
        title: typing.Optional[builtins.str] = None,
        title_align: typing.Optional[builtins.str] = None,
        title_size: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param env: APM environment. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#env Powerpack#env}
        :param service: APM service. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#service Powerpack#service}
        :param span_name: APM span name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#span_name Powerpack#span_name}
        :param display_format: The number of columns to display. Valid values are ``one_column``, ``two_column``, ``three_column``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#display_format Powerpack#display_format}
        :param live_span: The timeframe to use when displaying the widget. Valid values are ``1m``, ``5m``, ``10m``, ``15m``, ``30m``, ``1h``, ``4h``, ``1d``, ``2d``, ``1w``, ``1mo``, ``3mo``, ``6mo``, ``week_to_date``, ``month_to_date``, ``1y``, ``alert``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#live_span Powerpack#live_span}
        :param show_breakdown: Whether to show the latency breakdown or not. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#show_breakdown Powerpack#show_breakdown}
        :param show_distribution: Whether to show the latency distribution or not. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#show_distribution Powerpack#show_distribution}
        :param show_errors: Whether to show the error metrics or not. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#show_errors Powerpack#show_errors}
        :param show_hits: Whether to show the hits metrics or not. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#show_hits Powerpack#show_hits}
        :param show_latency: Whether to show the latency metrics or not. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#show_latency Powerpack#show_latency}
        :param show_resource_list: Whether to show the resource list or not. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#show_resource_list Powerpack#show_resource_list}
        :param size_format: The size of the widget. Valid values are ``small``, ``medium``, ``large``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#size_format Powerpack#size_format}
        :param title: The title of the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title Powerpack#title}
        :param title_align: The alignment of the widget's title. Valid values are ``center``, ``left``, ``right``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_align Powerpack#title_align}
        :param title_size: The size of the widget's title (defaults to 16). Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_size Powerpack#title_size}
        '''
        value = PowerpackWidgetTraceServiceDefinition(
            env=env,
            service=service,
            span_name=span_name,
            display_format=display_format,
            live_span=live_span,
            show_breakdown=show_breakdown,
            show_distribution=show_distribution,
            show_errors=show_errors,
            show_hits=show_hits,
            show_latency=show_latency,
            show_resource_list=show_resource_list,
            size_format=size_format,
            title=title,
            title_align=title_align,
            title_size=title_size,
        )

        return typing.cast(None, jsii.invoke(self, "putTraceServiceDefinition", [value]))

    @jsii.member(jsii_name="putTreemapDefinition")
    def put_treemap_definition(
        self,
        *,
        custom_links: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetTreemapDefinitionCustomLinks", typing.Dict[builtins.str, typing.Any]]]]] = None,
        request: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetTreemapDefinitionRequest", typing.Dict[builtins.str, typing.Any]]]]] = None,
        title: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param custom_links: custom_links block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom_links Powerpack#custom_links}
        :param request: request block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#request Powerpack#request}
        :param title: The title of the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title Powerpack#title}
        '''
        value = PowerpackWidgetTreemapDefinition(
            custom_links=custom_links, request=request, title=title
        )

        return typing.cast(None, jsii.invoke(self, "putTreemapDefinition", [value]))

    @jsii.member(jsii_name="putWidgetLayout")
    def put_widget_layout(
        self,
        *,
        height: jsii.Number,
        width: jsii.Number,
        x: jsii.Number,
        y: jsii.Number,
        is_column_break: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
    ) -> None:
        '''
        :param height: The height of the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#height Powerpack#height}
        :param width: The width of the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#width Powerpack#width}
        :param x: The position of the widget on the x (horizontal) axis. Must be greater than or equal to 0. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#x Powerpack#x}
        :param y: The position of the widget on the y (vertical) axis. Must be greater than or equal to 0. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#y Powerpack#y}
        :param is_column_break: Whether the widget should be the first one on the second column in high density or not. Only one widget in the dashboard should have this property set to ``true``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#is_column_break Powerpack#is_column_break}
        '''
        value = PowerpackWidgetWidgetLayout(
            height=height, width=width, x=x, y=y, is_column_break=is_column_break
        )

        return typing.cast(None, jsii.invoke(self, "putWidgetLayout", [value]))

    @jsii.member(jsii_name="resetAlertGraphDefinition")
    def reset_alert_graph_definition(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAlertGraphDefinition", []))

    @jsii.member(jsii_name="resetAlertValueDefinition")
    def reset_alert_value_definition(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAlertValueDefinition", []))

    @jsii.member(jsii_name="resetChangeDefinition")
    def reset_change_definition(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetChangeDefinition", []))

    @jsii.member(jsii_name="resetCheckStatusDefinition")
    def reset_check_status_definition(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCheckStatusDefinition", []))

    @jsii.member(jsii_name="resetDistributionDefinition")
    def reset_distribution_definition(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDistributionDefinition", []))

    @jsii.member(jsii_name="resetEventStreamDefinition")
    def reset_event_stream_definition(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetEventStreamDefinition", []))

    @jsii.member(jsii_name="resetEventTimelineDefinition")
    def reset_event_timeline_definition(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetEventTimelineDefinition", []))

    @jsii.member(jsii_name="resetFreeTextDefinition")
    def reset_free_text_definition(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFreeTextDefinition", []))

    @jsii.member(jsii_name="resetGeomapDefinition")
    def reset_geomap_definition(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGeomapDefinition", []))

    @jsii.member(jsii_name="resetHeatmapDefinition")
    def reset_heatmap_definition(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHeatmapDefinition", []))

    @jsii.member(jsii_name="resetHostmapDefinition")
    def reset_hostmap_definition(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHostmapDefinition", []))

    @jsii.member(jsii_name="resetIframeDefinition")
    def reset_iframe_definition(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetIframeDefinition", []))

    @jsii.member(jsii_name="resetImageDefinition")
    def reset_image_definition(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetImageDefinition", []))

    @jsii.member(jsii_name="resetListStreamDefinition")
    def reset_list_stream_definition(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetListStreamDefinition", []))

    @jsii.member(jsii_name="resetLogStreamDefinition")
    def reset_log_stream_definition(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLogStreamDefinition", []))

    @jsii.member(jsii_name="resetManageStatusDefinition")
    def reset_manage_status_definition(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetManageStatusDefinition", []))

    @jsii.member(jsii_name="resetNoteDefinition")
    def reset_note_definition(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetNoteDefinition", []))

    @jsii.member(jsii_name="resetQueryTableDefinition")
    def reset_query_table_definition(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetQueryTableDefinition", []))

    @jsii.member(jsii_name="resetQueryValueDefinition")
    def reset_query_value_definition(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetQueryValueDefinition", []))

    @jsii.member(jsii_name="resetRunWorkflowDefinition")
    def reset_run_workflow_definition(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetRunWorkflowDefinition", []))

    @jsii.member(jsii_name="resetScatterplotDefinition")
    def reset_scatterplot_definition(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetScatterplotDefinition", []))

    @jsii.member(jsii_name="resetServiceLevelObjectiveDefinition")
    def reset_service_level_objective_definition(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetServiceLevelObjectiveDefinition", []))

    @jsii.member(jsii_name="resetServicemapDefinition")
    def reset_servicemap_definition(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetServicemapDefinition", []))

    @jsii.member(jsii_name="resetSloListDefinition")
    def reset_slo_list_definition(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSloListDefinition", []))

    @jsii.member(jsii_name="resetSunburstDefinition")
    def reset_sunburst_definition(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSunburstDefinition", []))

    @jsii.member(jsii_name="resetTimeseriesDefinition")
    def reset_timeseries_definition(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTimeseriesDefinition", []))

    @jsii.member(jsii_name="resetToplistDefinition")
    def reset_toplist_definition(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetToplistDefinition", []))

    @jsii.member(jsii_name="resetTopologyMapDefinition")
    def reset_topology_map_definition(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTopologyMapDefinition", []))

    @jsii.member(jsii_name="resetTraceServiceDefinition")
    def reset_trace_service_definition(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTraceServiceDefinition", []))

    @jsii.member(jsii_name="resetTreemapDefinition")
    def reset_treemap_definition(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTreemapDefinition", []))

    @jsii.member(jsii_name="resetWidgetLayout")
    def reset_widget_layout(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetWidgetLayout", []))

    @builtins.property
    @jsii.member(jsii_name="alertGraphDefinition")
    def alert_graph_definition(
        self,
    ) -> PowerpackWidgetAlertGraphDefinitionOutputReference:
        return typing.cast(PowerpackWidgetAlertGraphDefinitionOutputReference, jsii.get(self, "alertGraphDefinition"))

    @builtins.property
    @jsii.member(jsii_name="alertValueDefinition")
    def alert_value_definition(
        self,
    ) -> PowerpackWidgetAlertValueDefinitionOutputReference:
        return typing.cast(PowerpackWidgetAlertValueDefinitionOutputReference, jsii.get(self, "alertValueDefinition"))

    @builtins.property
    @jsii.member(jsii_name="changeDefinition")
    def change_definition(self) -> PowerpackWidgetChangeDefinitionOutputReference:
        return typing.cast(PowerpackWidgetChangeDefinitionOutputReference, jsii.get(self, "changeDefinition"))

    @builtins.property
    @jsii.member(jsii_name="checkStatusDefinition")
    def check_status_definition(
        self,
    ) -> PowerpackWidgetCheckStatusDefinitionOutputReference:
        return typing.cast(PowerpackWidgetCheckStatusDefinitionOutputReference, jsii.get(self, "checkStatusDefinition"))

    @builtins.property
    @jsii.member(jsii_name="distributionDefinition")
    def distribution_definition(
        self,
    ) -> PowerpackWidgetDistributionDefinitionOutputReference:
        return typing.cast(PowerpackWidgetDistributionDefinitionOutputReference, jsii.get(self, "distributionDefinition"))

    @builtins.property
    @jsii.member(jsii_name="eventStreamDefinition")
    def event_stream_definition(
        self,
    ) -> PowerpackWidgetEventStreamDefinitionOutputReference:
        return typing.cast(PowerpackWidgetEventStreamDefinitionOutputReference, jsii.get(self, "eventStreamDefinition"))

    @builtins.property
    @jsii.member(jsii_name="eventTimelineDefinition")
    def event_timeline_definition(
        self,
    ) -> PowerpackWidgetEventTimelineDefinitionOutputReference:
        return typing.cast(PowerpackWidgetEventTimelineDefinitionOutputReference, jsii.get(self, "eventTimelineDefinition"))

    @builtins.property
    @jsii.member(jsii_name="freeTextDefinition")
    def free_text_definition(self) -> PowerpackWidgetFreeTextDefinitionOutputReference:
        return typing.cast(PowerpackWidgetFreeTextDefinitionOutputReference, jsii.get(self, "freeTextDefinition"))

    @builtins.property
    @jsii.member(jsii_name="geomapDefinition")
    def geomap_definition(self) -> PowerpackWidgetGeomapDefinitionOutputReference:
        return typing.cast(PowerpackWidgetGeomapDefinitionOutputReference, jsii.get(self, "geomapDefinition"))

    @builtins.property
    @jsii.member(jsii_name="heatmapDefinition")
    def heatmap_definition(self) -> PowerpackWidgetHeatmapDefinitionOutputReference:
        return typing.cast(PowerpackWidgetHeatmapDefinitionOutputReference, jsii.get(self, "heatmapDefinition"))

    @builtins.property
    @jsii.member(jsii_name="hostmapDefinition")
    def hostmap_definition(self) -> PowerpackWidgetHostmapDefinitionOutputReference:
        return typing.cast(PowerpackWidgetHostmapDefinitionOutputReference, jsii.get(self, "hostmapDefinition"))

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "id"))

    @builtins.property
    @jsii.member(jsii_name="iframeDefinition")
    def iframe_definition(self) -> PowerpackWidgetIframeDefinitionOutputReference:
        return typing.cast(PowerpackWidgetIframeDefinitionOutputReference, jsii.get(self, "iframeDefinition"))

    @builtins.property
    @jsii.member(jsii_name="imageDefinition")
    def image_definition(self) -> PowerpackWidgetImageDefinitionOutputReference:
        return typing.cast(PowerpackWidgetImageDefinitionOutputReference, jsii.get(self, "imageDefinition"))

    @builtins.property
    @jsii.member(jsii_name="listStreamDefinition")
    def list_stream_definition(
        self,
    ) -> PowerpackWidgetListStreamDefinitionOutputReference:
        return typing.cast(PowerpackWidgetListStreamDefinitionOutputReference, jsii.get(self, "listStreamDefinition"))

    @builtins.property
    @jsii.member(jsii_name="logStreamDefinition")
    def log_stream_definition(
        self,
    ) -> PowerpackWidgetLogStreamDefinitionOutputReference:
        return typing.cast(PowerpackWidgetLogStreamDefinitionOutputReference, jsii.get(self, "logStreamDefinition"))

    @builtins.property
    @jsii.member(jsii_name="manageStatusDefinition")
    def manage_status_definition(
        self,
    ) -> PowerpackWidgetManageStatusDefinitionOutputReference:
        return typing.cast(PowerpackWidgetManageStatusDefinitionOutputReference, jsii.get(self, "manageStatusDefinition"))

    @builtins.property
    @jsii.member(jsii_name="noteDefinition")
    def note_definition(self) -> PowerpackWidgetNoteDefinitionOutputReference:
        return typing.cast(PowerpackWidgetNoteDefinitionOutputReference, jsii.get(self, "noteDefinition"))

    @builtins.property
    @jsii.member(jsii_name="queryTableDefinition")
    def query_table_definition(
        self,
    ) -> "PowerpackWidgetQueryTableDefinitionOutputReference":
        return typing.cast("PowerpackWidgetQueryTableDefinitionOutputReference", jsii.get(self, "queryTableDefinition"))

    @builtins.property
    @jsii.member(jsii_name="queryValueDefinition")
    def query_value_definition(
        self,
    ) -> "PowerpackWidgetQueryValueDefinitionOutputReference":
        return typing.cast("PowerpackWidgetQueryValueDefinitionOutputReference", jsii.get(self, "queryValueDefinition"))

    @builtins.property
    @jsii.member(jsii_name="runWorkflowDefinition")
    def run_workflow_definition(
        self,
    ) -> "PowerpackWidgetRunWorkflowDefinitionOutputReference":
        return typing.cast("PowerpackWidgetRunWorkflowDefinitionOutputReference", jsii.get(self, "runWorkflowDefinition"))

    @builtins.property
    @jsii.member(jsii_name="scatterplotDefinition")
    def scatterplot_definition(
        self,
    ) -> "PowerpackWidgetScatterplotDefinitionOutputReference":
        return typing.cast("PowerpackWidgetScatterplotDefinitionOutputReference", jsii.get(self, "scatterplotDefinition"))

    @builtins.property
    @jsii.member(jsii_name="serviceLevelObjectiveDefinition")
    def service_level_objective_definition(
        self,
    ) -> "PowerpackWidgetServiceLevelObjectiveDefinitionOutputReference":
        return typing.cast("PowerpackWidgetServiceLevelObjectiveDefinitionOutputReference", jsii.get(self, "serviceLevelObjectiveDefinition"))

    @builtins.property
    @jsii.member(jsii_name="servicemapDefinition")
    def servicemap_definition(
        self,
    ) -> "PowerpackWidgetServicemapDefinitionOutputReference":
        return typing.cast("PowerpackWidgetServicemapDefinitionOutputReference", jsii.get(self, "servicemapDefinition"))

    @builtins.property
    @jsii.member(jsii_name="sloListDefinition")
    def slo_list_definition(self) -> "PowerpackWidgetSloListDefinitionOutputReference":
        return typing.cast("PowerpackWidgetSloListDefinitionOutputReference", jsii.get(self, "sloListDefinition"))

    @builtins.property
    @jsii.member(jsii_name="sunburstDefinition")
    def sunburst_definition(self) -> "PowerpackWidgetSunburstDefinitionOutputReference":
        return typing.cast("PowerpackWidgetSunburstDefinitionOutputReference", jsii.get(self, "sunburstDefinition"))

    @builtins.property
    @jsii.member(jsii_name="timeseriesDefinition")
    def timeseries_definition(
        self,
    ) -> "PowerpackWidgetTimeseriesDefinitionOutputReference":
        return typing.cast("PowerpackWidgetTimeseriesDefinitionOutputReference", jsii.get(self, "timeseriesDefinition"))

    @builtins.property
    @jsii.member(jsii_name="toplistDefinition")
    def toplist_definition(self) -> "PowerpackWidgetToplistDefinitionOutputReference":
        return typing.cast("PowerpackWidgetToplistDefinitionOutputReference", jsii.get(self, "toplistDefinition"))

    @builtins.property
    @jsii.member(jsii_name="topologyMapDefinition")
    def topology_map_definition(
        self,
    ) -> "PowerpackWidgetTopologyMapDefinitionOutputReference":
        return typing.cast("PowerpackWidgetTopologyMapDefinitionOutputReference", jsii.get(self, "topologyMapDefinition"))

    @builtins.property
    @jsii.member(jsii_name="traceServiceDefinition")
    def trace_service_definition(
        self,
    ) -> "PowerpackWidgetTraceServiceDefinitionOutputReference":
        return typing.cast("PowerpackWidgetTraceServiceDefinitionOutputReference", jsii.get(self, "traceServiceDefinition"))

    @builtins.property
    @jsii.member(jsii_name="treemapDefinition")
    def treemap_definition(self) -> "PowerpackWidgetTreemapDefinitionOutputReference":
        return typing.cast("PowerpackWidgetTreemapDefinitionOutputReference", jsii.get(self, "treemapDefinition"))

    @builtins.property
    @jsii.member(jsii_name="widgetLayout")
    def widget_layout(self) -> "PowerpackWidgetWidgetLayoutOutputReference":
        return typing.cast("PowerpackWidgetWidgetLayoutOutputReference", jsii.get(self, "widgetLayout"))

    @builtins.property
    @jsii.member(jsii_name="alertGraphDefinitionInput")
    def alert_graph_definition_input(
        self,
    ) -> typing.Optional[PowerpackWidgetAlertGraphDefinition]:
        return typing.cast(typing.Optional[PowerpackWidgetAlertGraphDefinition], jsii.get(self, "alertGraphDefinitionInput"))

    @builtins.property
    @jsii.member(jsii_name="alertValueDefinitionInput")
    def alert_value_definition_input(
        self,
    ) -> typing.Optional[PowerpackWidgetAlertValueDefinition]:
        return typing.cast(typing.Optional[PowerpackWidgetAlertValueDefinition], jsii.get(self, "alertValueDefinitionInput"))

    @builtins.property
    @jsii.member(jsii_name="changeDefinitionInput")
    def change_definition_input(
        self,
    ) -> typing.Optional[PowerpackWidgetChangeDefinition]:
        return typing.cast(typing.Optional[PowerpackWidgetChangeDefinition], jsii.get(self, "changeDefinitionInput"))

    @builtins.property
    @jsii.member(jsii_name="checkStatusDefinitionInput")
    def check_status_definition_input(
        self,
    ) -> typing.Optional[PowerpackWidgetCheckStatusDefinition]:
        return typing.cast(typing.Optional[PowerpackWidgetCheckStatusDefinition], jsii.get(self, "checkStatusDefinitionInput"))

    @builtins.property
    @jsii.member(jsii_name="distributionDefinitionInput")
    def distribution_definition_input(
        self,
    ) -> typing.Optional[PowerpackWidgetDistributionDefinition]:
        return typing.cast(typing.Optional[PowerpackWidgetDistributionDefinition], jsii.get(self, "distributionDefinitionInput"))

    @builtins.property
    @jsii.member(jsii_name="eventStreamDefinitionInput")
    def event_stream_definition_input(
        self,
    ) -> typing.Optional[PowerpackWidgetEventStreamDefinition]:
        return typing.cast(typing.Optional[PowerpackWidgetEventStreamDefinition], jsii.get(self, "eventStreamDefinitionInput"))

    @builtins.property
    @jsii.member(jsii_name="eventTimelineDefinitionInput")
    def event_timeline_definition_input(
        self,
    ) -> typing.Optional[PowerpackWidgetEventTimelineDefinition]:
        return typing.cast(typing.Optional[PowerpackWidgetEventTimelineDefinition], jsii.get(self, "eventTimelineDefinitionInput"))

    @builtins.property
    @jsii.member(jsii_name="freeTextDefinitionInput")
    def free_text_definition_input(
        self,
    ) -> typing.Optional[PowerpackWidgetFreeTextDefinition]:
        return typing.cast(typing.Optional[PowerpackWidgetFreeTextDefinition], jsii.get(self, "freeTextDefinitionInput"))

    @builtins.property
    @jsii.member(jsii_name="geomapDefinitionInput")
    def geomap_definition_input(
        self,
    ) -> typing.Optional[PowerpackWidgetGeomapDefinition]:
        return typing.cast(typing.Optional[PowerpackWidgetGeomapDefinition], jsii.get(self, "geomapDefinitionInput"))

    @builtins.property
    @jsii.member(jsii_name="heatmapDefinitionInput")
    def heatmap_definition_input(
        self,
    ) -> typing.Optional[PowerpackWidgetHeatmapDefinition]:
        return typing.cast(typing.Optional[PowerpackWidgetHeatmapDefinition], jsii.get(self, "heatmapDefinitionInput"))

    @builtins.property
    @jsii.member(jsii_name="hostmapDefinitionInput")
    def hostmap_definition_input(
        self,
    ) -> typing.Optional[PowerpackWidgetHostmapDefinition]:
        return typing.cast(typing.Optional[PowerpackWidgetHostmapDefinition], jsii.get(self, "hostmapDefinitionInput"))

    @builtins.property
    @jsii.member(jsii_name="iframeDefinitionInput")
    def iframe_definition_input(
        self,
    ) -> typing.Optional[PowerpackWidgetIframeDefinition]:
        return typing.cast(typing.Optional[PowerpackWidgetIframeDefinition], jsii.get(self, "iframeDefinitionInput"))

    @builtins.property
    @jsii.member(jsii_name="imageDefinitionInput")
    def image_definition_input(self) -> typing.Optional[PowerpackWidgetImageDefinition]:
        return typing.cast(typing.Optional[PowerpackWidgetImageDefinition], jsii.get(self, "imageDefinitionInput"))

    @builtins.property
    @jsii.member(jsii_name="listStreamDefinitionInput")
    def list_stream_definition_input(
        self,
    ) -> typing.Optional[PowerpackWidgetListStreamDefinition]:
        return typing.cast(typing.Optional[PowerpackWidgetListStreamDefinition], jsii.get(self, "listStreamDefinitionInput"))

    @builtins.property
    @jsii.member(jsii_name="logStreamDefinitionInput")
    def log_stream_definition_input(
        self,
    ) -> typing.Optional[PowerpackWidgetLogStreamDefinition]:
        return typing.cast(typing.Optional[PowerpackWidgetLogStreamDefinition], jsii.get(self, "logStreamDefinitionInput"))

    @builtins.property
    @jsii.member(jsii_name="manageStatusDefinitionInput")
    def manage_status_definition_input(
        self,
    ) -> typing.Optional[PowerpackWidgetManageStatusDefinition]:
        return typing.cast(typing.Optional[PowerpackWidgetManageStatusDefinition], jsii.get(self, "manageStatusDefinitionInput"))

    @builtins.property
    @jsii.member(jsii_name="noteDefinitionInput")
    def note_definition_input(self) -> typing.Optional[PowerpackWidgetNoteDefinition]:
        return typing.cast(typing.Optional[PowerpackWidgetNoteDefinition], jsii.get(self, "noteDefinitionInput"))

    @builtins.property
    @jsii.member(jsii_name="queryTableDefinitionInput")
    def query_table_definition_input(
        self,
    ) -> typing.Optional["PowerpackWidgetQueryTableDefinition"]:
        return typing.cast(typing.Optional["PowerpackWidgetQueryTableDefinition"], jsii.get(self, "queryTableDefinitionInput"))

    @builtins.property
    @jsii.member(jsii_name="queryValueDefinitionInput")
    def query_value_definition_input(
        self,
    ) -> typing.Optional["PowerpackWidgetQueryValueDefinition"]:
        return typing.cast(typing.Optional["PowerpackWidgetQueryValueDefinition"], jsii.get(self, "queryValueDefinitionInput"))

    @builtins.property
    @jsii.member(jsii_name="runWorkflowDefinitionInput")
    def run_workflow_definition_input(
        self,
    ) -> typing.Optional["PowerpackWidgetRunWorkflowDefinition"]:
        return typing.cast(typing.Optional["PowerpackWidgetRunWorkflowDefinition"], jsii.get(self, "runWorkflowDefinitionInput"))

    @builtins.property
    @jsii.member(jsii_name="scatterplotDefinitionInput")
    def scatterplot_definition_input(
        self,
    ) -> typing.Optional["PowerpackWidgetScatterplotDefinition"]:
        return typing.cast(typing.Optional["PowerpackWidgetScatterplotDefinition"], jsii.get(self, "scatterplotDefinitionInput"))

    @builtins.property
    @jsii.member(jsii_name="serviceLevelObjectiveDefinitionInput")
    def service_level_objective_definition_input(
        self,
    ) -> typing.Optional["PowerpackWidgetServiceLevelObjectiveDefinition"]:
        return typing.cast(typing.Optional["PowerpackWidgetServiceLevelObjectiveDefinition"], jsii.get(self, "serviceLevelObjectiveDefinitionInput"))

    @builtins.property
    @jsii.member(jsii_name="servicemapDefinitionInput")
    def servicemap_definition_input(
        self,
    ) -> typing.Optional["PowerpackWidgetServicemapDefinition"]:
        return typing.cast(typing.Optional["PowerpackWidgetServicemapDefinition"], jsii.get(self, "servicemapDefinitionInput"))

    @builtins.property
    @jsii.member(jsii_name="sloListDefinitionInput")
    def slo_list_definition_input(
        self,
    ) -> typing.Optional["PowerpackWidgetSloListDefinition"]:
        return typing.cast(typing.Optional["PowerpackWidgetSloListDefinition"], jsii.get(self, "sloListDefinitionInput"))

    @builtins.property
    @jsii.member(jsii_name="sunburstDefinitionInput")
    def sunburst_definition_input(
        self,
    ) -> typing.Optional["PowerpackWidgetSunburstDefinition"]:
        return typing.cast(typing.Optional["PowerpackWidgetSunburstDefinition"], jsii.get(self, "sunburstDefinitionInput"))

    @builtins.property
    @jsii.member(jsii_name="timeseriesDefinitionInput")
    def timeseries_definition_input(
        self,
    ) -> typing.Optional["PowerpackWidgetTimeseriesDefinition"]:
        return typing.cast(typing.Optional["PowerpackWidgetTimeseriesDefinition"], jsii.get(self, "timeseriesDefinitionInput"))

    @builtins.property
    @jsii.member(jsii_name="toplistDefinitionInput")
    def toplist_definition_input(
        self,
    ) -> typing.Optional["PowerpackWidgetToplistDefinition"]:
        return typing.cast(typing.Optional["PowerpackWidgetToplistDefinition"], jsii.get(self, "toplistDefinitionInput"))

    @builtins.property
    @jsii.member(jsii_name="topologyMapDefinitionInput")
    def topology_map_definition_input(
        self,
    ) -> typing.Optional["PowerpackWidgetTopologyMapDefinition"]:
        return typing.cast(typing.Optional["PowerpackWidgetTopologyMapDefinition"], jsii.get(self, "topologyMapDefinitionInput"))

    @builtins.property
    @jsii.member(jsii_name="traceServiceDefinitionInput")
    def trace_service_definition_input(
        self,
    ) -> typing.Optional["PowerpackWidgetTraceServiceDefinition"]:
        return typing.cast(typing.Optional["PowerpackWidgetTraceServiceDefinition"], jsii.get(self, "traceServiceDefinitionInput"))

    @builtins.property
    @jsii.member(jsii_name="treemapDefinitionInput")
    def treemap_definition_input(
        self,
    ) -> typing.Optional["PowerpackWidgetTreemapDefinition"]:
        return typing.cast(typing.Optional["PowerpackWidgetTreemapDefinition"], jsii.get(self, "treemapDefinitionInput"))

    @builtins.property
    @jsii.member(jsii_name="widgetLayoutInput")
    def widget_layout_input(self) -> typing.Optional["PowerpackWidgetWidgetLayout"]:
        return typing.cast(typing.Optional["PowerpackWidgetWidgetLayout"], jsii.get(self, "widgetLayoutInput"))

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidget]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidget]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidget]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__416f8dc993c7d7b376a689ac59bebf173096753875e013004a1a05e8ee797c14)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinition",
    jsii_struct_bases=[],
    name_mapping={
        "custom_link": "customLink",
        "has_search_bar": "hasSearchBar",
        "live_span": "liveSpan",
        "request": "request",
        "title": "title",
        "title_align": "titleAlign",
        "title_size": "titleSize",
    },
)
class PowerpackWidgetQueryTableDefinition:
    def __init__(
        self,
        *,
        custom_link: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetQueryTableDefinitionCustomLink", typing.Dict[builtins.str, typing.Any]]]]] = None,
        has_search_bar: typing.Optional[builtins.str] = None,
        live_span: typing.Optional[builtins.str] = None,
        request: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetQueryTableDefinitionRequest", typing.Dict[builtins.str, typing.Any]]]]] = None,
        title: typing.Optional[builtins.str] = None,
        title_align: typing.Optional[builtins.str] = None,
        title_size: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param custom_link: custom_link block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom_link Powerpack#custom_link}
        :param has_search_bar: Controls the display of the search bar. Valid values are ``always``, ``never``, ``auto``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#has_search_bar Powerpack#has_search_bar}
        :param live_span: The timeframe to use when displaying the widget. Valid values are ``1m``, ``5m``, ``10m``, ``15m``, ``30m``, ``1h``, ``4h``, ``1d``, ``2d``, ``1w``, ``1mo``, ``3mo``, ``6mo``, ``week_to_date``, ``month_to_date``, ``1y``, ``alert``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#live_span Powerpack#live_span}
        :param request: request block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#request Powerpack#request}
        :param title: The title of the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title Powerpack#title}
        :param title_align: The alignment of the widget's title. Valid values are ``center``, ``left``, ``right``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_align Powerpack#title_align}
        :param title_size: The size of the widget's title (defaults to 16). Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_size Powerpack#title_size}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b08789cdbc2d3fac67b96d64dc244d780d5fb4d30cdd177e5a88c7a0aaccb2d3)
            check_type(argname="argument custom_link", value=custom_link, expected_type=type_hints["custom_link"])
            check_type(argname="argument has_search_bar", value=has_search_bar, expected_type=type_hints["has_search_bar"])
            check_type(argname="argument live_span", value=live_span, expected_type=type_hints["live_span"])
            check_type(argname="argument request", value=request, expected_type=type_hints["request"])
            check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            check_type(argname="argument title_align", value=title_align, expected_type=type_hints["title_align"])
            check_type(argname="argument title_size", value=title_size, expected_type=type_hints["title_size"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if custom_link is not None:
            self._values["custom_link"] = custom_link
        if has_search_bar is not None:
            self._values["has_search_bar"] = has_search_bar
        if live_span is not None:
            self._values["live_span"] = live_span
        if request is not None:
            self._values["request"] = request
        if title is not None:
            self._values["title"] = title
        if title_align is not None:
            self._values["title_align"] = title_align
        if title_size is not None:
            self._values["title_size"] = title_size

    @builtins.property
    def custom_link(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetQueryTableDefinitionCustomLink"]]]:
        '''custom_link block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom_link Powerpack#custom_link}
        '''
        result = self._values.get("custom_link")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetQueryTableDefinitionCustomLink"]]], result)

    @builtins.property
    def has_search_bar(self) -> typing.Optional[builtins.str]:
        '''Controls the display of the search bar. Valid values are ``always``, ``never``, ``auto``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#has_search_bar Powerpack#has_search_bar}
        '''
        result = self._values.get("has_search_bar")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def live_span(self) -> typing.Optional[builtins.str]:
        '''The timeframe to use when displaying the widget.

        Valid values are ``1m``, ``5m``, ``10m``, ``15m``, ``30m``, ``1h``, ``4h``, ``1d``, ``2d``, ``1w``, ``1mo``, ``3mo``, ``6mo``, ``week_to_date``, ``month_to_date``, ``1y``, ``alert``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#live_span Powerpack#live_span}
        '''
        result = self._values.get("live_span")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def request(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetQueryTableDefinitionRequest"]]]:
        '''request block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#request Powerpack#request}
        '''
        result = self._values.get("request")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetQueryTableDefinitionRequest"]]], result)

    @builtins.property
    def title(self) -> typing.Optional[builtins.str]:
        '''The title of the widget.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title Powerpack#title}
        '''
        result = self._values.get("title")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def title_align(self) -> typing.Optional[builtins.str]:
        '''The alignment of the widget's title. Valid values are ``center``, ``left``, ``right``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_align Powerpack#title_align}
        '''
        result = self._values.get("title_align")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def title_size(self) -> typing.Optional[builtins.str]:
        '''The size of the widget's title (defaults to 16).

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_size Powerpack#title_size}
        '''
        result = self._values.get("title_size")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryTableDefinition(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionCustomLink",
    jsii_struct_bases=[],
    name_mapping={
        "is_hidden": "isHidden",
        "label": "label",
        "link": "link",
        "override_label": "overrideLabel",
    },
)
class PowerpackWidgetQueryTableDefinitionCustomLink:
    def __init__(
        self,
        *,
        is_hidden: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        label: typing.Optional[builtins.str] = None,
        link: typing.Optional[builtins.str] = None,
        override_label: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param is_hidden: The flag for toggling context menu link visibility. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#is_hidden Powerpack#is_hidden}
        :param label: The label for the custom link URL. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#label Powerpack#label}
        :param link: The URL of the custom link. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#link Powerpack#link}
        :param override_label: The label ID that refers to a context menu link item. When ``override_label`` is provided, the client request omits the label field. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#override_label Powerpack#override_label}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e9aa2a9f56b3e42c525622751f85b19039b3d49e5e8567429e55869f1008a28d)
            check_type(argname="argument is_hidden", value=is_hidden, expected_type=type_hints["is_hidden"])
            check_type(argname="argument label", value=label, expected_type=type_hints["label"])
            check_type(argname="argument link", value=link, expected_type=type_hints["link"])
            check_type(argname="argument override_label", value=override_label, expected_type=type_hints["override_label"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if is_hidden is not None:
            self._values["is_hidden"] = is_hidden
        if label is not None:
            self._values["label"] = label
        if link is not None:
            self._values["link"] = link
        if override_label is not None:
            self._values["override_label"] = override_label

    @builtins.property
    def is_hidden(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        '''The flag for toggling context menu link visibility.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#is_hidden Powerpack#is_hidden}
        '''
        result = self._values.get("is_hidden")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)

    @builtins.property
    def label(self) -> typing.Optional[builtins.str]:
        '''The label for the custom link URL.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#label Powerpack#label}
        '''
        result = self._values.get("label")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def link(self) -> typing.Optional[builtins.str]:
        '''The URL of the custom link.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#link Powerpack#link}
        '''
        result = self._values.get("link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def override_label(self) -> typing.Optional[builtins.str]:
        '''The label ID that refers to a context menu link item.

        When ``override_label`` is provided, the client request omits the label field.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#override_label Powerpack#override_label}
        '''
        result = self._values.get("override_label")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryTableDefinitionCustomLink(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetQueryTableDefinitionCustomLinkList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionCustomLinkList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dafc7197cf3f51f1d97555949c1bd45035e6c3857b28a0febf60b7a8da62b774)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetQueryTableDefinitionCustomLinkOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bc6d2d01783fa4b3748a681aef594ecdb9c0d0145fd137c311b69ef498512333)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetQueryTableDefinitionCustomLinkOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6b645229995ccde1f1436fdd14c674b0145a3b28fba12d4cfb56864b03e6c96c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2c16ddd9dd8c39d63cce3e9a1c2a7ccf1ae52a1435c803b4835a725786bc3732)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dcdf7264533afcd65932b06530f24b5ca79aa8abaacdf391445712a4f962c2dc)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionCustomLink]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionCustomLink]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionCustomLink]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__02e87cafe85121320d53193f4c86304568e21116c8385a6de5827dc2c9c30f50)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetQueryTableDefinitionCustomLinkOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionCustomLinkOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__80a4c9682e51e1de64f1ed23e82a09aa2a510032c711412441c9f18485af1931)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetIsHidden")
    def reset_is_hidden(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetIsHidden", []))

    @jsii.member(jsii_name="resetLabel")
    def reset_label(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLabel", []))

    @jsii.member(jsii_name="resetLink")
    def reset_link(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLink", []))

    @jsii.member(jsii_name="resetOverrideLabel")
    def reset_override_label(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetOverrideLabel", []))

    @builtins.property
    @jsii.member(jsii_name="isHiddenInput")
    def is_hidden_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "isHiddenInput"))

    @builtins.property
    @jsii.member(jsii_name="labelInput")
    def label_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "labelInput"))

    @builtins.property
    @jsii.member(jsii_name="linkInput")
    def link_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "linkInput"))

    @builtins.property
    @jsii.member(jsii_name="overrideLabelInput")
    def override_label_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "overrideLabelInput"))

    @builtins.property
    @jsii.member(jsii_name="isHidden")
    def is_hidden(self) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "isHidden"))

    @is_hidden.setter
    def is_hidden(
        self,
        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5128402f0a8129a93c81d958f03886aed33d95c99b45af6e86afcea0aeb782eb)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "isHidden", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="label")
    def label(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "label"))

    @label.setter
    def label(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5233bef5e2e2ce5ad3a209459d2d3ba54508f6f0b35656ae0434e7d682420c41)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "label", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="link")
    def link(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "link"))

    @link.setter
    def link(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__098a082c5b46f00ab115b2b5e625ec8a20d1230dcf618743d9c630826f52f275)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "link", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="overrideLabel")
    def override_label(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "overrideLabel"))

    @override_label.setter
    def override_label(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d13359b230181fcd65034a263571d3695219a11f920eeadcf77d1ca632df0eb2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "overrideLabel", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryTableDefinitionCustomLink]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryTableDefinitionCustomLink]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryTableDefinitionCustomLink]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b08dfabee1a6ad13f25f36d649632da31f682d3d633a0d57e5970c6e3f951c76)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetQueryTableDefinitionOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8dd65372b12388e65b4f41d5ff48caa175317a0d655336861e5303ddaa0947b1)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putCustomLink")
    def put_custom_link(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryTableDefinitionCustomLink, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4a370a23a65de221bc5b189c5da5826bdba78ce282e3b508754a450b7328419a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putCustomLink", [value]))

    @jsii.member(jsii_name="putRequest")
    def put_request(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetQueryTableDefinitionRequest", typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__32b1ba8377b1eaa08835bdeb5b63254defaf31c577facf3758daf0650e5fc351)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putRequest", [value]))

    @jsii.member(jsii_name="resetCustomLink")
    def reset_custom_link(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCustomLink", []))

    @jsii.member(jsii_name="resetHasSearchBar")
    def reset_has_search_bar(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHasSearchBar", []))

    @jsii.member(jsii_name="resetLiveSpan")
    def reset_live_span(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLiveSpan", []))

    @jsii.member(jsii_name="resetRequest")
    def reset_request(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetRequest", []))

    @jsii.member(jsii_name="resetTitle")
    def reset_title(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTitle", []))

    @jsii.member(jsii_name="resetTitleAlign")
    def reset_title_align(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTitleAlign", []))

    @jsii.member(jsii_name="resetTitleSize")
    def reset_title_size(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTitleSize", []))

    @builtins.property
    @jsii.member(jsii_name="customLink")
    def custom_link(self) -> PowerpackWidgetQueryTableDefinitionCustomLinkList:
        return typing.cast(PowerpackWidgetQueryTableDefinitionCustomLinkList, jsii.get(self, "customLink"))

    @builtins.property
    @jsii.member(jsii_name="request")
    def request(self) -> "PowerpackWidgetQueryTableDefinitionRequestList":
        return typing.cast("PowerpackWidgetQueryTableDefinitionRequestList", jsii.get(self, "request"))

    @builtins.property
    @jsii.member(jsii_name="customLinkInput")
    def custom_link_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionCustomLink]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionCustomLink]]], jsii.get(self, "customLinkInput"))

    @builtins.property
    @jsii.member(jsii_name="hasSearchBarInput")
    def has_search_bar_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "hasSearchBarInput"))

    @builtins.property
    @jsii.member(jsii_name="liveSpanInput")
    def live_span_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "liveSpanInput"))

    @builtins.property
    @jsii.member(jsii_name="requestInput")
    def request_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetQueryTableDefinitionRequest"]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetQueryTableDefinitionRequest"]]], jsii.get(self, "requestInput"))

    @builtins.property
    @jsii.member(jsii_name="titleAlignInput")
    def title_align_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "titleAlignInput"))

    @builtins.property
    @jsii.member(jsii_name="titleInput")
    def title_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "titleInput"))

    @builtins.property
    @jsii.member(jsii_name="titleSizeInput")
    def title_size_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "titleSizeInput"))

    @builtins.property
    @jsii.member(jsii_name="hasSearchBar")
    def has_search_bar(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "hasSearchBar"))

    @has_search_bar.setter
    def has_search_bar(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__115d8586c1c734f2096c3a12ce822f979fe2cd6ef95ade0fffd72c1ffa1b82f6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "hasSearchBar", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="liveSpan")
    def live_span(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "liveSpan"))

    @live_span.setter
    def live_span(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2bb7e30c6cc7b28e7ab687e472f5fcfddb3a8540e5f8edd1f5d8d2cfcc8b600a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "liveSpan", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="title")
    def title(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "title"))

    @title.setter
    def title(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6f33063fc3ff2979d32113ec1ab1cf3358ec35c7fb41f089dcd1c8aa857c4e4c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "title", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="titleAlign")
    def title_align(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "titleAlign"))

    @title_align.setter
    def title_align(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d782b3b3832ec3d434a52cc701391b3a74bae10e7f3121fe2c790c3e79491711)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "titleAlign", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="titleSize")
    def title_size(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "titleSize"))

    @title_size.setter
    def title_size(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4578667aaa48a5e3ac46c1d5e61343f8e120e4eece886fd5b8d399a40ae811cc)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "titleSize", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[PowerpackWidgetQueryTableDefinition]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryTableDefinition], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetQueryTableDefinition],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f386d2fcf384009e73b625c4f2370e9a7a8c586ba6ca6c487a6aeea496726aaa)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequest",
    jsii_struct_bases=[],
    name_mapping={
        "aggregator": "aggregator",
        "alias": "alias",
        "apm_query": "apmQuery",
        "apm_stats_query": "apmStatsQuery",
        "cell_display_mode": "cellDisplayMode",
        "conditional_formats": "conditionalFormats",
        "formula": "formula",
        "limit": "limit",
        "log_query": "logQuery",
        "order": "order",
        "process_query": "processQuery",
        "q": "q",
        "query": "query",
        "rum_query": "rumQuery",
        "security_query": "securityQuery",
        "text_formats": "textFormats",
    },
)
class PowerpackWidgetQueryTableDefinitionRequest:
    def __init__(
        self,
        *,
        aggregator: typing.Optional[builtins.str] = None,
        alias: typing.Optional[builtins.str] = None,
        apm_query: typing.Optional[typing.Union["PowerpackWidgetQueryTableDefinitionRequestApmQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        apm_stats_query: typing.Optional[typing.Union["PowerpackWidgetQueryTableDefinitionRequestApmStatsQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        cell_display_mode: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditional_formats: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetQueryTableDefinitionRequestConditionalFormats", typing.Dict[builtins.str, typing.Any]]]]] = None,
        formula: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetQueryTableDefinitionRequestFormula", typing.Dict[builtins.str, typing.Any]]]]] = None,
        limit: typing.Optional[jsii.Number] = None,
        log_query: typing.Optional[typing.Union["PowerpackWidgetQueryTableDefinitionRequestLogQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        order: typing.Optional[builtins.str] = None,
        process_query: typing.Optional[typing.Union["PowerpackWidgetQueryTableDefinitionRequestProcessQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        q: typing.Optional[builtins.str] = None,
        query: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetQueryTableDefinitionRequestQuery", typing.Dict[builtins.str, typing.Any]]]]] = None,
        rum_query: typing.Optional[typing.Union["PowerpackWidgetQueryTableDefinitionRequestRumQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        security_query: typing.Optional[typing.Union["PowerpackWidgetQueryTableDefinitionRequestSecurityQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        text_formats: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetQueryTableDefinitionRequestTextFormats", typing.Dict[builtins.str, typing.Any]]]]] = None,
    ) -> None:
        '''
        :param aggregator: The aggregator to use for time aggregation. Valid values are ``avg``, ``last``, ``max``, ``min``, ``sum``, ``percentile``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregator Powerpack#aggregator}
        :param alias: The alias for the column name (defaults to metric name). Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#alias Powerpack#alias}
        :param apm_query: apm_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#apm_query Powerpack#apm_query}
        :param apm_stats_query: apm_stats_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#apm_stats_query Powerpack#apm_stats_query}
        :param cell_display_mode: A list of display modes for each table cell. Valid values are ``number``, ``bar``, ``trend``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cell_display_mode Powerpack#cell_display_mode}
        :param conditional_formats: conditional_formats block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#conditional_formats Powerpack#conditional_formats}
        :param formula: formula block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#formula Powerpack#formula}
        :param limit: The number of lines to show in the table. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param log_query: log_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#log_query Powerpack#log_query}
        :param order: The sort order for the rows. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param process_query: process_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#process_query Powerpack#process_query}
        :param q: The metric query to use for this widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#q Powerpack#q}
        :param query: query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        :param rum_query: rum_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#rum_query Powerpack#rum_query}
        :param security_query: security_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#security_query Powerpack#security_query}
        :param text_formats: text_formats block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#text_formats Powerpack#text_formats}
        '''
        if isinstance(apm_query, dict):
            apm_query = PowerpackWidgetQueryTableDefinitionRequestApmQuery(**apm_query)
        if isinstance(apm_stats_query, dict):
            apm_stats_query = PowerpackWidgetQueryTableDefinitionRequestApmStatsQuery(**apm_stats_query)
        if isinstance(log_query, dict):
            log_query = PowerpackWidgetQueryTableDefinitionRequestLogQuery(**log_query)
        if isinstance(process_query, dict):
            process_query = PowerpackWidgetQueryTableDefinitionRequestProcessQuery(**process_query)
        if isinstance(rum_query, dict):
            rum_query = PowerpackWidgetQueryTableDefinitionRequestRumQuery(**rum_query)
        if isinstance(security_query, dict):
            security_query = PowerpackWidgetQueryTableDefinitionRequestSecurityQuery(**security_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d79f6986f6cb59f8b9111da690a21e0b39907aae8a252c6c79ac94c9a511965e)
            check_type(argname="argument aggregator", value=aggregator, expected_type=type_hints["aggregator"])
            check_type(argname="argument alias", value=alias, expected_type=type_hints["alias"])
            check_type(argname="argument apm_query", value=apm_query, expected_type=type_hints["apm_query"])
            check_type(argname="argument apm_stats_query", value=apm_stats_query, expected_type=type_hints["apm_stats_query"])
            check_type(argname="argument cell_display_mode", value=cell_display_mode, expected_type=type_hints["cell_display_mode"])
            check_type(argname="argument conditional_formats", value=conditional_formats, expected_type=type_hints["conditional_formats"])
            check_type(argname="argument formula", value=formula, expected_type=type_hints["formula"])
            check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
            check_type(argname="argument log_query", value=log_query, expected_type=type_hints["log_query"])
            check_type(argname="argument order", value=order, expected_type=type_hints["order"])
            check_type(argname="argument process_query", value=process_query, expected_type=type_hints["process_query"])
            check_type(argname="argument q", value=q, expected_type=type_hints["q"])
            check_type(argname="argument query", value=query, expected_type=type_hints["query"])
            check_type(argname="argument rum_query", value=rum_query, expected_type=type_hints["rum_query"])
            check_type(argname="argument security_query", value=security_query, expected_type=type_hints["security_query"])
            check_type(argname="argument text_formats", value=text_formats, expected_type=type_hints["text_formats"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if aggregator is not None:
            self._values["aggregator"] = aggregator
        if alias is not None:
            self._values["alias"] = alias
        if apm_query is not None:
            self._values["apm_query"] = apm_query
        if apm_stats_query is not None:
            self._values["apm_stats_query"] = apm_stats_query
        if cell_display_mode is not None:
            self._values["cell_display_mode"] = cell_display_mode
        if conditional_formats is not None:
            self._values["conditional_formats"] = conditional_formats
        if formula is not None:
            self._values["formula"] = formula
        if limit is not None:
            self._values["limit"] = limit
        if log_query is not None:
            self._values["log_query"] = log_query
        if order is not None:
            self._values["order"] = order
        if process_query is not None:
            self._values["process_query"] = process_query
        if q is not None:
            self._values["q"] = q
        if query is not None:
            self._values["query"] = query
        if rum_query is not None:
            self._values["rum_query"] = rum_query
        if security_query is not None:
            self._values["security_query"] = security_query
        if text_formats is not None:
            self._values["text_formats"] = text_formats

    @builtins.property
    def aggregator(self) -> typing.Optional[builtins.str]:
        '''The aggregator to use for time aggregation. Valid values are ``avg``, ``last``, ``max``, ``min``, ``sum``, ``percentile``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregator Powerpack#aggregator}
        '''
        result = self._values.get("aggregator")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def alias(self) -> typing.Optional[builtins.str]:
        '''The alias for the column name (defaults to metric name).

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#alias Powerpack#alias}
        '''
        result = self._values.get("alias")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def apm_query(
        self,
    ) -> typing.Optional["PowerpackWidgetQueryTableDefinitionRequestApmQuery"]:
        '''apm_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#apm_query Powerpack#apm_query}
        '''
        result = self._values.get("apm_query")
        return typing.cast(typing.Optional["PowerpackWidgetQueryTableDefinitionRequestApmQuery"], result)

    @builtins.property
    def apm_stats_query(
        self,
    ) -> typing.Optional["PowerpackWidgetQueryTableDefinitionRequestApmStatsQuery"]:
        '''apm_stats_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#apm_stats_query Powerpack#apm_stats_query}
        '''
        result = self._values.get("apm_stats_query")
        return typing.cast(typing.Optional["PowerpackWidgetQueryTableDefinitionRequestApmStatsQuery"], result)

    @builtins.property
    def cell_display_mode(self) -> typing.Optional[typing.List[builtins.str]]:
        '''A list of display modes for each table cell. Valid values are ``number``, ``bar``, ``trend``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cell_display_mode Powerpack#cell_display_mode}
        '''
        result = self._values.get("cell_display_mode")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def conditional_formats(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetQueryTableDefinitionRequestConditionalFormats"]]]:
        '''conditional_formats block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#conditional_formats Powerpack#conditional_formats}
        '''
        result = self._values.get("conditional_formats")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetQueryTableDefinitionRequestConditionalFormats"]]], result)

    @builtins.property
    def formula(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetQueryTableDefinitionRequestFormula"]]]:
        '''formula block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#formula Powerpack#formula}
        '''
        result = self._values.get("formula")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetQueryTableDefinitionRequestFormula"]]], result)

    @builtins.property
    def limit(self) -> typing.Optional[jsii.Number]:
        '''The number of lines to show in the table.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        '''
        result = self._values.get("limit")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def log_query(
        self,
    ) -> typing.Optional["PowerpackWidgetQueryTableDefinitionRequestLogQuery"]:
        '''log_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#log_query Powerpack#log_query}
        '''
        result = self._values.get("log_query")
        return typing.cast(typing.Optional["PowerpackWidgetQueryTableDefinitionRequestLogQuery"], result)

    @builtins.property
    def order(self) -> typing.Optional[builtins.str]:
        '''The sort order for the rows. Valid values are ``asc``, ``desc``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        result = self._values.get("order")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def process_query(
        self,
    ) -> typing.Optional["PowerpackWidgetQueryTableDefinitionRequestProcessQuery"]:
        '''process_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#process_query Powerpack#process_query}
        '''
        result = self._values.get("process_query")
        return typing.cast(typing.Optional["PowerpackWidgetQueryTableDefinitionRequestProcessQuery"], result)

    @builtins.property
    def q(self) -> typing.Optional[builtins.str]:
        '''The metric query to use for this widget.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#q Powerpack#q}
        '''
        result = self._values.get("q")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def query(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetQueryTableDefinitionRequestQuery"]]]:
        '''query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        '''
        result = self._values.get("query")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetQueryTableDefinitionRequestQuery"]]], result)

    @builtins.property
    def rum_query(
        self,
    ) -> typing.Optional["PowerpackWidgetQueryTableDefinitionRequestRumQuery"]:
        '''rum_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#rum_query Powerpack#rum_query}
        '''
        result = self._values.get("rum_query")
        return typing.cast(typing.Optional["PowerpackWidgetQueryTableDefinitionRequestRumQuery"], result)

    @builtins.property
    def security_query(
        self,
    ) -> typing.Optional["PowerpackWidgetQueryTableDefinitionRequestSecurityQuery"]:
        '''security_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#security_query Powerpack#security_query}
        '''
        result = self._values.get("security_query")
        return typing.cast(typing.Optional["PowerpackWidgetQueryTableDefinitionRequestSecurityQuery"], result)

    @builtins.property
    def text_formats(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetQueryTableDefinitionRequestTextFormats"]]]:
        '''text_formats block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#text_formats Powerpack#text_formats}
        '''
        result = self._values.get("text_formats")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetQueryTableDefinitionRequestTextFormats"]]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryTableDefinitionRequest(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestApmQuery",
    jsii_struct_bases=[],
    name_mapping={
        "index": "index",
        "compute_query": "computeQuery",
        "group_by": "groupBy",
        "multi_compute": "multiCompute",
        "search_query": "searchQuery",
    },
)
class PowerpackWidgetQueryTableDefinitionRequestApmQuery:
    def __init__(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union["PowerpackWidgetQueryTableDefinitionRequestApmQueryComputeQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetQueryTableDefinitionRequestApmQueryGroupBy", typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetQueryTableDefinitionRequestApmQueryMultiCompute", typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        if isinstance(compute_query, dict):
            compute_query = PowerpackWidgetQueryTableDefinitionRequestApmQueryComputeQuery(**compute_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__42fa91f177b88eb2632d5c7eaf04bcd8b551fcbbbb6868102c57eafe19098993)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
            check_type(argname="argument compute_query", value=compute_query, expected_type=type_hints["compute_query"])
            check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
            check_type(argname="argument multi_compute", value=multi_compute, expected_type=type_hints["multi_compute"])
            check_type(argname="argument search_query", value=search_query, expected_type=type_hints["search_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "index": index,
        }
        if compute_query is not None:
            self._values["compute_query"] = compute_query
        if group_by is not None:
            self._values["group_by"] = group_by
        if multi_compute is not None:
            self._values["multi_compute"] = multi_compute
        if search_query is not None:
            self._values["search_query"] = search_query

    @builtins.property
    def index(self) -> builtins.str:
        '''The name of the index to query.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        '''
        result = self._values.get("index")
        assert result is not None, "Required property 'index' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def compute_query(
        self,
    ) -> typing.Optional["PowerpackWidgetQueryTableDefinitionRequestApmQueryComputeQuery"]:
        '''compute_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        '''
        result = self._values.get("compute_query")
        return typing.cast(typing.Optional["PowerpackWidgetQueryTableDefinitionRequestApmQueryComputeQuery"], result)

    @builtins.property
    def group_by(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetQueryTableDefinitionRequestApmQueryGroupBy"]]]:
        '''group_by block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        '''
        result = self._values.get("group_by")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetQueryTableDefinitionRequestApmQueryGroupBy"]]], result)

    @builtins.property
    def multi_compute(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetQueryTableDefinitionRequestApmQueryMultiCompute"]]]:
        '''multi_compute block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        '''
        result = self._values.get("multi_compute")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetQueryTableDefinitionRequestApmQueryMultiCompute"]]], result)

    @builtins.property
    def search_query(self) -> typing.Optional[builtins.str]:
        '''The search query to use.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        result = self._values.get("search_query")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryTableDefinitionRequestApmQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestApmQueryComputeQuery",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetQueryTableDefinitionRequestApmQueryComputeQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6e9a6062e1d87bee0491c14abd3e1149823ee939aa3a84de6559863b8fc7bc16)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryTableDefinitionRequestApmQueryComputeQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetQueryTableDefinitionRequestApmQueryComputeQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestApmQueryComputeQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__47168c22326ad9ea6148dd4e5645ddfb881ec0a8346261bd389a7a729708e370)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7f02010f45f87016115599ef35d41742c3a63304193bdcfb81447a981b6823ca)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cdb2a76b11aa7d89effba048b75cd4f9d200b84e67ab3f8f0a4bde619a72668e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__76eec39d4f3a8cfd6b4b201f4158e7abf7638cd461573721cddb7a3188e6c3ff)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetQueryTableDefinitionRequestApmQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryTableDefinitionRequestApmQueryComputeQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetQueryTableDefinitionRequestApmQueryComputeQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c9355a8c5a2fdfe4148a5cf39bc44512e3988653686f4d559fda6071aa770399)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestApmQueryGroupBy",
    jsii_struct_bases=[],
    name_mapping={"facet": "facet", "limit": "limit", "sort_query": "sortQuery"},
)
class PowerpackWidgetQueryTableDefinitionRequestApmQueryGroupBy:
    def __init__(
        self,
        *,
        facet: typing.Optional[builtins.str] = None,
        limit: typing.Optional[jsii.Number] = None,
        sort_query: typing.Optional[typing.Union["PowerpackWidgetQueryTableDefinitionRequestApmQueryGroupBySortQuery", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param limit: The maximum number of items in the group. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param sort_query: sort_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        if isinstance(sort_query, dict):
            sort_query = PowerpackWidgetQueryTableDefinitionRequestApmQueryGroupBySortQuery(**sort_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__644031880a0b82b71c67791597e9f145672ad15250e981349767b33a1ac83431)
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
            check_type(argname="argument sort_query", value=sort_query, expected_type=type_hints["sort_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if facet is not None:
            self._values["facet"] = facet
        if limit is not None:
            self._values["limit"] = limit
        if sort_query is not None:
            self._values["sort_query"] = sort_query

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def limit(self) -> typing.Optional[jsii.Number]:
        '''The maximum number of items in the group.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        '''
        result = self._values.get("limit")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def sort_query(
        self,
    ) -> typing.Optional["PowerpackWidgetQueryTableDefinitionRequestApmQueryGroupBySortQuery"]:
        '''sort_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        result = self._values.get("sort_query")
        return typing.cast(typing.Optional["PowerpackWidgetQueryTableDefinitionRequestApmQueryGroupBySortQuery"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryTableDefinitionRequestApmQueryGroupBy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetQueryTableDefinitionRequestApmQueryGroupByList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestApmQueryGroupByList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4fa4161935db1f3974c4c3f160fb022bd1b737f5277c87749596f214c191cbb3)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetQueryTableDefinitionRequestApmQueryGroupByOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__037241aaf900b5ea45912c6fab778e05fe266d090bbd78af897e63c4a316832c)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetQueryTableDefinitionRequestApmQueryGroupByOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f1151b5fcc513682a0533fc2e1fdd807c1e6d2f7ce9a8c0e12bc367f2942cacd)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f384588f0972eb4570a05919f9cca4f59cb57608d5761cd6e45223347ba889e2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a2d519914ce1c5c20f5e3e4b5f9f86c3575cd8535082e72dc97e1d45bd8d5c6c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionRequestApmQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionRequestApmQueryGroupBy]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionRequestApmQueryGroupBy]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__897b9607019863682b44a224e763fd709204022bf401964c9c1582d840bad6b9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetQueryTableDefinitionRequestApmQueryGroupByOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestApmQueryGroupByOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__252a7bf86cb6bbb9be55191bdb270d6a804993be42165e623951cc5dac78cb14)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putSortQuery")
    def put_sort_query(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        value = PowerpackWidgetQueryTableDefinitionRequestApmQueryGroupBySortQuery(
            aggregation=aggregation, order=order, facet=facet
        )

        return typing.cast(None, jsii.invoke(self, "putSortQuery", [value]))

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetLimit")
    def reset_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLimit", []))

    @jsii.member(jsii_name="resetSortQuery")
    def reset_sort_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSortQuery", []))

    @builtins.property
    @jsii.member(jsii_name="sortQuery")
    def sort_query(
        self,
    ) -> "PowerpackWidgetQueryTableDefinitionRequestApmQueryGroupBySortQueryOutputReference":
        return typing.cast("PowerpackWidgetQueryTableDefinitionRequestApmQueryGroupBySortQueryOutputReference", jsii.get(self, "sortQuery"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="limitInput")
    def limit_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "limitInput"))

    @builtins.property
    @jsii.member(jsii_name="sortQueryInput")
    def sort_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetQueryTableDefinitionRequestApmQueryGroupBySortQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetQueryTableDefinitionRequestApmQueryGroupBySortQuery"], jsii.get(self, "sortQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__92171a397762d835d79af119fcf2f09757bbf319c819bef3f7039c770194d6b9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="limit")
    def limit(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "limit"))

    @limit.setter
    def limit(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2533a65870252dd0a6fd53f8a21498f23853d84413c3ea6cca3d963eb4b9cf6c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "limit", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryTableDefinitionRequestApmQueryGroupBy]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryTableDefinitionRequestApmQueryGroupBy]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryTableDefinitionRequestApmQueryGroupBy]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e7d75f4123b3e0de4d17ef95cb587d64ab923268d81de879b533a3226cbcc8c4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestApmQueryGroupBySortQuery",
    jsii_struct_bases=[],
    name_mapping={"aggregation": "aggregation", "order": "order", "facet": "facet"},
)
class PowerpackWidgetQueryTableDefinitionRequestApmQueryGroupBySortQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7c0ac2f53bca6ce250abe4f642b5b90245aa934b3a0b3e967351129c3d4ba777)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument order", value=order, expected_type=type_hints["order"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
            "order": order,
        }
        if facet is not None:
            self._values["facet"] = facet

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def order(self) -> builtins.str:
        '''Widget sorting methods. Valid values are ``asc``, ``desc``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        result = self._values.get("order")
        assert result is not None, "Required property 'order' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryTableDefinitionRequestApmQueryGroupBySortQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetQueryTableDefinitionRequestApmQueryGroupBySortQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestApmQueryGroupBySortQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2b457ed9bc6b7dcc373edab8614aa585d1a7cdbb0d4d0547f9554ae7236a40ba)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="orderInput")
    def order_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "orderInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__541519e825ab9585c5a51e127ea26948c18df19bc7f52a50bfa52fa200a01382)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ca9e86f4728c4fe15e81ca038257adc0e203767b9cfb6e7ee768fd0465ac7a48)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="order")
    def order(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "order"))

    @order.setter
    def order(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3c92146c7f2e6ac9cdae97464ab53b309785ac32059866d71006cd6215ad49af)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "order", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetQueryTableDefinitionRequestApmQueryGroupBySortQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryTableDefinitionRequestApmQueryGroupBySortQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetQueryTableDefinitionRequestApmQueryGroupBySortQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__03493f3340bc8513be5a36a3589817d72d6503abf5aee02423710dbd755fa993)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestApmQueryMultiCompute",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetQueryTableDefinitionRequestApmQueryMultiCompute:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b2845eef83d6e1d1a42986794faa2e858098709d1ce2b147b48c0f0547bc746b)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryTableDefinitionRequestApmQueryMultiCompute(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetQueryTableDefinitionRequestApmQueryMultiComputeList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestApmQueryMultiComputeList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6e0f379a709cf0f6f386c88395482ac8fc09e6c6b85c9c200bf8957fe9017be8)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetQueryTableDefinitionRequestApmQueryMultiComputeOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ffc8fba663f7e9645935e05261c59baca664e3bc585983315e84d99cdb0537db)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetQueryTableDefinitionRequestApmQueryMultiComputeOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__65b188c53842f46e994cc1cb85d933c71fc36d443bbce78308f6aa7b442da4c0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6e9cf5b0702e0b154c313957b124e35e43238736933d3816f28fed908ac70143)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__51e2fec3c87835936fa994bf54672e644c539e395f32e3048f622f589193a5ca)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionRequestApmQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionRequestApmQueryMultiCompute]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionRequestApmQueryMultiCompute]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__768528065a6e96d18406ef1e94a7889d7a02439a66820ae765b9813cb58bc676)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetQueryTableDefinitionRequestApmQueryMultiComputeOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestApmQueryMultiComputeOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a6c4839740446ef1fb684fe783272649ecd286ea45b59cd2f2afcbe4b3b0f47c)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a5565e105f74c8682a542c26f25687b556def587d180a26e334d67f479611209)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__246618906ab86e0829b54a08d18eccf5cdb2a11fb2ddc169681e00b943d76afb)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ae2dbd7b5ffdbddefeecb3fc995868b14f0e8e0b0c8461253ea64cec282441be)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryTableDefinitionRequestApmQueryMultiCompute]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryTableDefinitionRequestApmQueryMultiCompute]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryTableDefinitionRequestApmQueryMultiCompute]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fcb3a1cf9f4cecdaeb5d5c02ecea5f56e434b4261ea87c464cdb19eafc15027c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetQueryTableDefinitionRequestApmQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestApmQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__49820b34baf6e28902ce6361a5fd4551bd2d351e164f8cf48f8c68493356df19)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putComputeQuery")
    def put_compute_query(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        value = PowerpackWidgetQueryTableDefinitionRequestApmQueryComputeQuery(
            aggregation=aggregation, facet=facet, interval=interval
        )

        return typing.cast(None, jsii.invoke(self, "putComputeQuery", [value]))

    @jsii.member(jsii_name="putGroupBy")
    def put_group_by(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryTableDefinitionRequestApmQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8313504e6f7370bec33bb42a3324cf6fee6ee71055ebea173a3ebda72776deda)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putGroupBy", [value]))

    @jsii.member(jsii_name="putMultiCompute")
    def put_multi_compute(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryTableDefinitionRequestApmQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__74930203ab6b7f66ed2941994905e15d46ff583a6dc5c0a947b01edd3a628cca)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putMultiCompute", [value]))

    @jsii.member(jsii_name="resetComputeQuery")
    def reset_compute_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetComputeQuery", []))

    @jsii.member(jsii_name="resetGroupBy")
    def reset_group_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGroupBy", []))

    @jsii.member(jsii_name="resetMultiCompute")
    def reset_multi_compute(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMultiCompute", []))

    @jsii.member(jsii_name="resetSearchQuery")
    def reset_search_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSearchQuery", []))

    @builtins.property
    @jsii.member(jsii_name="computeQuery")
    def compute_query(
        self,
    ) -> PowerpackWidgetQueryTableDefinitionRequestApmQueryComputeQueryOutputReference:
        return typing.cast(PowerpackWidgetQueryTableDefinitionRequestApmQueryComputeQueryOutputReference, jsii.get(self, "computeQuery"))

    @builtins.property
    @jsii.member(jsii_name="groupBy")
    def group_by(self) -> PowerpackWidgetQueryTableDefinitionRequestApmQueryGroupByList:
        return typing.cast(PowerpackWidgetQueryTableDefinitionRequestApmQueryGroupByList, jsii.get(self, "groupBy"))

    @builtins.property
    @jsii.member(jsii_name="multiCompute")
    def multi_compute(
        self,
    ) -> PowerpackWidgetQueryTableDefinitionRequestApmQueryMultiComputeList:
        return typing.cast(PowerpackWidgetQueryTableDefinitionRequestApmQueryMultiComputeList, jsii.get(self, "multiCompute"))

    @builtins.property
    @jsii.member(jsii_name="computeQueryInput")
    def compute_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetQueryTableDefinitionRequestApmQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryTableDefinitionRequestApmQueryComputeQuery], jsii.get(self, "computeQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="groupByInput")
    def group_by_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionRequestApmQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionRequestApmQueryGroupBy]]], jsii.get(self, "groupByInput"))

    @builtins.property
    @jsii.member(jsii_name="indexInput")
    def index_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "indexInput"))

    @builtins.property
    @jsii.member(jsii_name="multiComputeInput")
    def multi_compute_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionRequestApmQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionRequestApmQueryMultiCompute]]], jsii.get(self, "multiComputeInput"))

    @builtins.property
    @jsii.member(jsii_name="searchQueryInput")
    def search_query_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "searchQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="index")
    def index(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "index"))

    @index.setter
    def index(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__176d7b0307c655a7cb43709000190c7780ad8079e49197ad6a327a8ee6ec54c0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "index", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="searchQuery")
    def search_query(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "searchQuery"))

    @search_query.setter
    def search_query(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__760adbf6ac2d17a5ae00b7f64429002b9247393a5d4a4edd8f362ad4dd0ae25f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "searchQuery", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetQueryTableDefinitionRequestApmQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryTableDefinitionRequestApmQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetQueryTableDefinitionRequestApmQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__916a85586cbf5d84a9c90a3b0b024fedc0cc22fda6a6478246c936c5f4567ddf)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestApmStatsQuery",
    jsii_struct_bases=[],
    name_mapping={
        "env": "env",
        "name": "name",
        "primary_tag": "primaryTag",
        "row_type": "rowType",
        "service": "service",
        "columns": "columns",
        "resource": "resource",
    },
)
class PowerpackWidgetQueryTableDefinitionRequestApmStatsQuery:
    def __init__(
        self,
        *,
        env: builtins.str,
        name: builtins.str,
        primary_tag: builtins.str,
        row_type: builtins.str,
        service: builtins.str,
        columns: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetQueryTableDefinitionRequestApmStatsQueryColumns", typing.Dict[builtins.str, typing.Any]]]]] = None,
        resource: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param env: The environment name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#env Powerpack#env}
        :param name: The operation name associated with the service. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param primary_tag: The organization's host group name and value. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag Powerpack#primary_tag}
        :param row_type: The level of detail for the request. Valid values are ``service``, ``resource``, ``span``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#row_type Powerpack#row_type}
        :param service: The service name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#service Powerpack#service}
        :param columns: columns block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#columns Powerpack#columns}
        :param resource: The resource name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#resource Powerpack#resource}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ac3b621d1cb4f7f2ae822bf99196e4f94a415fc7fb8be5223c6e4461c724b965)
            check_type(argname="argument env", value=env, expected_type=type_hints["env"])
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument primary_tag", value=primary_tag, expected_type=type_hints["primary_tag"])
            check_type(argname="argument row_type", value=row_type, expected_type=type_hints["row_type"])
            check_type(argname="argument service", value=service, expected_type=type_hints["service"])
            check_type(argname="argument columns", value=columns, expected_type=type_hints["columns"])
            check_type(argname="argument resource", value=resource, expected_type=type_hints["resource"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "env": env,
            "name": name,
            "primary_tag": primary_tag,
            "row_type": row_type,
            "service": service,
        }
        if columns is not None:
            self._values["columns"] = columns
        if resource is not None:
            self._values["resource"] = resource

    @builtins.property
    def env(self) -> builtins.str:
        '''The environment name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#env Powerpack#env}
        '''
        result = self._values.get("env")
        assert result is not None, "Required property 'env' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def name(self) -> builtins.str:
        '''The operation name associated with the service.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        '''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def primary_tag(self) -> builtins.str:
        '''The organization's host group name and value.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag Powerpack#primary_tag}
        '''
        result = self._values.get("primary_tag")
        assert result is not None, "Required property 'primary_tag' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def row_type(self) -> builtins.str:
        '''The level of detail for the request. Valid values are ``service``, ``resource``, ``span``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#row_type Powerpack#row_type}
        '''
        result = self._values.get("row_type")
        assert result is not None, "Required property 'row_type' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def service(self) -> builtins.str:
        '''The service name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#service Powerpack#service}
        '''
        result = self._values.get("service")
        assert result is not None, "Required property 'service' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def columns(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetQueryTableDefinitionRequestApmStatsQueryColumns"]]]:
        '''columns block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#columns Powerpack#columns}
        '''
        result = self._values.get("columns")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetQueryTableDefinitionRequestApmStatsQueryColumns"]]], result)

    @builtins.property
    def resource(self) -> typing.Optional[builtins.str]:
        '''The resource name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#resource Powerpack#resource}
        '''
        result = self._values.get("resource")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryTableDefinitionRequestApmStatsQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestApmStatsQueryColumns",
    jsii_struct_bases=[],
    name_mapping={
        "name": "name",
        "alias": "alias",
        "cell_display_mode": "cellDisplayMode",
        "order": "order",
    },
)
class PowerpackWidgetQueryTableDefinitionRequestApmStatsQueryColumns:
    def __init__(
        self,
        *,
        name: builtins.str,
        alias: typing.Optional[builtins.str] = None,
        cell_display_mode: typing.Optional[builtins.str] = None,
        order: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param name: The column name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param alias: A user-assigned alias for the column. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#alias Powerpack#alias}
        :param cell_display_mode: A list of display modes for each table cell. Valid values are ``number``, ``bar``, ``trend``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cell_display_mode Powerpack#cell_display_mode}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5f49a5463591a2151bcd5c540dd65097afddd5f358741f55512a9cc60cfcaa01)
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument alias", value=alias, expected_type=type_hints["alias"])
            check_type(argname="argument cell_display_mode", value=cell_display_mode, expected_type=type_hints["cell_display_mode"])
            check_type(argname="argument order", value=order, expected_type=type_hints["order"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "name": name,
        }
        if alias is not None:
            self._values["alias"] = alias
        if cell_display_mode is not None:
            self._values["cell_display_mode"] = cell_display_mode
        if order is not None:
            self._values["order"] = order

    @builtins.property
    def name(self) -> builtins.str:
        '''The column name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        '''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def alias(self) -> typing.Optional[builtins.str]:
        '''A user-assigned alias for the column.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#alias Powerpack#alias}
        '''
        result = self._values.get("alias")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def cell_display_mode(self) -> typing.Optional[builtins.str]:
        '''A list of display modes for each table cell. Valid values are ``number``, ``bar``, ``trend``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cell_display_mode Powerpack#cell_display_mode}
        '''
        result = self._values.get("cell_display_mode")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def order(self) -> typing.Optional[builtins.str]:
        '''Widget sorting methods. Valid values are ``asc``, ``desc``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        result = self._values.get("order")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryTableDefinitionRequestApmStatsQueryColumns(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetQueryTableDefinitionRequestApmStatsQueryColumnsList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestApmStatsQueryColumnsList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__17bc74b71ef84806324d3d00fdbbed5777cd3190c6d7f4eb489f428e0903a364)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetQueryTableDefinitionRequestApmStatsQueryColumnsOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5acfb40b874131d2a3098796d64d8f960d54a013c4942bbf3893ca88a86ee0c1)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetQueryTableDefinitionRequestApmStatsQueryColumnsOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1c2a576ce9a704a1b06335d6d2581526bf1c5ed3fafbf7353819200843af6276)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bb7063b2a18129530946a35f0d3b6f7e6a40c29329e27e55786dfb9699cbe700)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__20ff51d4670529836bbfb0c5672c60755b5f9656bfb5ab90fe48b059ec83ffec)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionRequestApmStatsQueryColumns]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionRequestApmStatsQueryColumns]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionRequestApmStatsQueryColumns]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__474330139309cc15cfdb0d1f2cf0b8187fbf49febb0071a1504833fab8a1799a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetQueryTableDefinitionRequestApmStatsQueryColumnsOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestApmStatsQueryColumnsOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7c20703f118e228c37e877260a320ab8db5db90d19ebe7e5312dd00826c3fda3)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetAlias")
    def reset_alias(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAlias", []))

    @jsii.member(jsii_name="resetCellDisplayMode")
    def reset_cell_display_mode(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCellDisplayMode", []))

    @jsii.member(jsii_name="resetOrder")
    def reset_order(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetOrder", []))

    @builtins.property
    @jsii.member(jsii_name="aliasInput")
    def alias_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aliasInput"))

    @builtins.property
    @jsii.member(jsii_name="cellDisplayModeInput")
    def cell_display_mode_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "cellDisplayModeInput"))

    @builtins.property
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property
    @jsii.member(jsii_name="orderInput")
    def order_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "orderInput"))

    @builtins.property
    @jsii.member(jsii_name="alias")
    def alias(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "alias"))

    @alias.setter
    def alias(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2bf016722247b84e3b2b706d16197d70f72dd0b7d1d63ce30c07fcde7da486ae)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "alias", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="cellDisplayMode")
    def cell_display_mode(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "cellDisplayMode"))

    @cell_display_mode.setter
    def cell_display_mode(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8e9b37812bfdee3d81e9fe609dd6531f70dca1d6b30c3c67519bdae418c359fd)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "cellDisplayMode", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ab09708b8b55918c46fbc1a46a3bc1e22685d6e3423fe036135422fd2a2d1e0d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "name", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="order")
    def order(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "order"))

    @order.setter
    def order(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__031f7464ec6163fb8702141790a903d0115ed94b1a5bfe3836f5d9eb8337df73)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "order", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryTableDefinitionRequestApmStatsQueryColumns]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryTableDefinitionRequestApmStatsQueryColumns]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryTableDefinitionRequestApmStatsQueryColumns]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e9746debc01514c35b75e4f2af06ccae23607a51e63f58f7f6fc7d6042c98d62)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetQueryTableDefinitionRequestApmStatsQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestApmStatsQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3ca6880d1dcdce4a405c515bb85456221eccb949f31366bb6ac3b00efd437e94)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putColumns")
    def put_columns(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryTableDefinitionRequestApmStatsQueryColumns, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5c01bfc0bbccd29723263fc3f6b40ac6eceefa05a5d9aae67a99840b1f2f41cf)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putColumns", [value]))

    @jsii.member(jsii_name="resetColumns")
    def reset_columns(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetColumns", []))

    @jsii.member(jsii_name="resetResource")
    def reset_resource(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetResource", []))

    @builtins.property
    @jsii.member(jsii_name="columns")
    def columns(
        self,
    ) -> PowerpackWidgetQueryTableDefinitionRequestApmStatsQueryColumnsList:
        return typing.cast(PowerpackWidgetQueryTableDefinitionRequestApmStatsQueryColumnsList, jsii.get(self, "columns"))

    @builtins.property
    @jsii.member(jsii_name="columnsInput")
    def columns_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionRequestApmStatsQueryColumns]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionRequestApmStatsQueryColumns]]], jsii.get(self, "columnsInput"))

    @builtins.property
    @jsii.member(jsii_name="envInput")
    def env_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "envInput"))

    @builtins.property
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property
    @jsii.member(jsii_name="primaryTagInput")
    def primary_tag_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "primaryTagInput"))

    @builtins.property
    @jsii.member(jsii_name="resourceInput")
    def resource_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "resourceInput"))

    @builtins.property
    @jsii.member(jsii_name="rowTypeInput")
    def row_type_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "rowTypeInput"))

    @builtins.property
    @jsii.member(jsii_name="serviceInput")
    def service_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "serviceInput"))

    @builtins.property
    @jsii.member(jsii_name="env")
    def env(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "env"))

    @env.setter
    def env(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d3397795acf37e54bf28a88fb61111a05780383ff183d93c9e5851cacd21ea7f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "env", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__275dcaf4ccd022172cb9265225f4682e0812e747154bfdd6d1badc4fb7c5556b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "name", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="primaryTag")
    def primary_tag(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "primaryTag"))

    @primary_tag.setter
    def primary_tag(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__41ff25b9ee178578610657ff1510eb98ef4bb17aa667972713de202d0093ea78)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "primaryTag", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="resource")
    def resource(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "resource"))

    @resource.setter
    def resource(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a1ed71f28f5af26b738e427feba9512c947e48a245b98591af5236002aa6ee4e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "resource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="rowType")
    def row_type(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "rowType"))

    @row_type.setter
    def row_type(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__81856404325f643856537585885170fa83c61e3c336dd1d5ce67c8d9f34b65af)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "rowType", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="service")
    def service(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "service"))

    @service.setter
    def service(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dd81a3218b87196ee4696fcccc41efab7d844ea9b49c6d098699fac99b99709a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "service", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetQueryTableDefinitionRequestApmStatsQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryTableDefinitionRequestApmStatsQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetQueryTableDefinitionRequestApmStatsQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5fc5addd3afe5fb859764e0cce93721ba7cf69553ed5cdc845e108f55b4db9dd)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestConditionalFormats",
    jsii_struct_bases=[],
    name_mapping={
        "comparator": "comparator",
        "palette": "palette",
        "value": "value",
        "custom_bg_color": "customBgColor",
        "custom_fg_color": "customFgColor",
        "hide_value": "hideValue",
        "image_url": "imageUrl",
        "metric": "metric",
        "timeframe": "timeframe",
    },
)
class PowerpackWidgetQueryTableDefinitionRequestConditionalFormats:
    def __init__(
        self,
        *,
        comparator: builtins.str,
        palette: builtins.str,
        value: jsii.Number,
        custom_bg_color: typing.Optional[builtins.str] = None,
        custom_fg_color: typing.Optional[builtins.str] = None,
        hide_value: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        image_url: typing.Optional[builtins.str] = None,
        metric: typing.Optional[builtins.str] = None,
        timeframe: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param comparator: The comparator to use. Valid values are ``=``, ``>``, ``>=``, ``<``, ``<=``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#comparator Powerpack#comparator}
        :param palette: The color palette to apply. Valid values are ``blue``, ``custom_bg``, ``custom_image``, ``custom_text``, ``gray_on_white``, ``grey``, ``green``, ``orange``, ``red``, ``red_on_white``, ``white_on_gray``, ``white_on_green``, ``green_on_white``, ``white_on_red``, ``white_on_yellow``, ``yellow_on_white``, ``black_on_light_yellow``, ``black_on_light_green``, ``black_on_light_red``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette Powerpack#palette}
        :param value: A value for the comparator. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#value Powerpack#value}
        :param custom_bg_color: The color palette to apply to the background, same values available as palette. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom_bg_color Powerpack#custom_bg_color}
        :param custom_fg_color: The color palette to apply to the foreground, same values available as palette. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom_fg_color Powerpack#custom_fg_color}
        :param hide_value: Setting this to True hides values. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#hide_value Powerpack#hide_value}
        :param image_url: Displays an image as the background. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#image_url Powerpack#image_url}
        :param metric: The metric from the request to correlate with this conditional format. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        :param timeframe: Defines the displayed timeframe. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#timeframe Powerpack#timeframe}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c7bb30b5cceae25a94cb387e2cec20fa8fef290f5c6489955afc7823cd06d5d7)
            check_type(argname="argument comparator", value=comparator, expected_type=type_hints["comparator"])
            check_type(argname="argument palette", value=palette, expected_type=type_hints["palette"])
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument custom_bg_color", value=custom_bg_color, expected_type=type_hints["custom_bg_color"])
            check_type(argname="argument custom_fg_color", value=custom_fg_color, expected_type=type_hints["custom_fg_color"])
            check_type(argname="argument hide_value", value=hide_value, expected_type=type_hints["hide_value"])
            check_type(argname="argument image_url", value=image_url, expected_type=type_hints["image_url"])
            check_type(argname="argument metric", value=metric, expected_type=type_hints["metric"])
            check_type(argname="argument timeframe", value=timeframe, expected_type=type_hints["timeframe"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "comparator": comparator,
            "palette": palette,
            "value": value,
        }
        if custom_bg_color is not None:
            self._values["custom_bg_color"] = custom_bg_color
        if custom_fg_color is not None:
            self._values["custom_fg_color"] = custom_fg_color
        if hide_value is not None:
            self._values["hide_value"] = hide_value
        if image_url is not None:
            self._values["image_url"] = image_url
        if metric is not None:
            self._values["metric"] = metric
        if timeframe is not None:
            self._values["timeframe"] = timeframe

    @builtins.property
    def comparator(self) -> builtins.str:
        '''The comparator to use. Valid values are ``=``, ``>``, ``>=``, ``<``, ``<=``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#comparator Powerpack#comparator}
        '''
        result = self._values.get("comparator")
        assert result is not None, "Required property 'comparator' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def palette(self) -> builtins.str:
        '''The color palette to apply.

        Valid values are ``blue``, ``custom_bg``, ``custom_image``, ``custom_text``, ``gray_on_white``, ``grey``, ``green``, ``orange``, ``red``, ``red_on_white``, ``white_on_gray``, ``white_on_green``, ``green_on_white``, ``white_on_red``, ``white_on_yellow``, ``yellow_on_white``, ``black_on_light_yellow``, ``black_on_light_green``, ``black_on_light_red``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette Powerpack#palette}
        '''
        result = self._values.get("palette")
        assert result is not None, "Required property 'palette' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def value(self) -> jsii.Number:
        '''A value for the comparator.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#value Powerpack#value}
        '''
        result = self._values.get("value")
        assert result is not None, "Required property 'value' is missing"
        return typing.cast(jsii.Number, result)

    @builtins.property
    def custom_bg_color(self) -> typing.Optional[builtins.str]:
        '''The color palette to apply to the background, same values available as palette.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom_bg_color Powerpack#custom_bg_color}
        '''
        result = self._values.get("custom_bg_color")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def custom_fg_color(self) -> typing.Optional[builtins.str]:
        '''The color palette to apply to the foreground, same values available as palette.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom_fg_color Powerpack#custom_fg_color}
        '''
        result = self._values.get("custom_fg_color")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def hide_value(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        '''Setting this to True hides values.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#hide_value Powerpack#hide_value}
        '''
        result = self._values.get("hide_value")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)

    @builtins.property
    def image_url(self) -> typing.Optional[builtins.str]:
        '''Displays an image as the background.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#image_url Powerpack#image_url}
        '''
        result = self._values.get("image_url")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def metric(self) -> typing.Optional[builtins.str]:
        '''The metric from the request to correlate with this conditional format.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        '''
        result = self._values.get("metric")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def timeframe(self) -> typing.Optional[builtins.str]:
        '''Defines the displayed timeframe.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#timeframe Powerpack#timeframe}
        '''
        result = self._values.get("timeframe")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryTableDefinitionRequestConditionalFormats(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetQueryTableDefinitionRequestConditionalFormatsList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestConditionalFormatsList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__57e045f93488e6efb82676a985f3fc5ea775d9ed8d38d4689ccef6b94c4bc06f)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetQueryTableDefinitionRequestConditionalFormatsOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7294de63dcee74ebce4f998002f4bbe2dee22ab19d47476ccba3cf7ef3337f40)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetQueryTableDefinitionRequestConditionalFormatsOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e4040b3c83a1a66c60e7e8c9326344c0c66bb9c3cf6f664a46fdecfae76057b1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dcef8f2a63977f7e9ac19b143eba67d1ba6c3ec7e9aa9002c15c5528d6ec47db)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f1707ba7d10660a3c9d42632606ce2f8e23871a62094baa985599e1af613f939)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionRequestConditionalFormats]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionRequestConditionalFormats]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionRequestConditionalFormats]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__078850f069fdb3907ece17ef3bb55799811002c374317a137968e9d2974ca8fe)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetQueryTableDefinitionRequestConditionalFormatsOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestConditionalFormatsOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4e350e63248d241d43836ec7b13e73a656887eba0ae4eaf92bdec6ce62563083)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetCustomBgColor")
    def reset_custom_bg_color(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCustomBgColor", []))

    @jsii.member(jsii_name="resetCustomFgColor")
    def reset_custom_fg_color(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCustomFgColor", []))

    @jsii.member(jsii_name="resetHideValue")
    def reset_hide_value(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHideValue", []))

    @jsii.member(jsii_name="resetImageUrl")
    def reset_image_url(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetImageUrl", []))

    @jsii.member(jsii_name="resetMetric")
    def reset_metric(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMetric", []))

    @jsii.member(jsii_name="resetTimeframe")
    def reset_timeframe(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTimeframe", []))

    @builtins.property
    @jsii.member(jsii_name="comparatorInput")
    def comparator_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "comparatorInput"))

    @builtins.property
    @jsii.member(jsii_name="customBgColorInput")
    def custom_bg_color_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "customBgColorInput"))

    @builtins.property
    @jsii.member(jsii_name="customFgColorInput")
    def custom_fg_color_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "customFgColorInput"))

    @builtins.property
    @jsii.member(jsii_name="hideValueInput")
    def hide_value_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "hideValueInput"))

    @builtins.property
    @jsii.member(jsii_name="imageUrlInput")
    def image_url_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "imageUrlInput"))

    @builtins.property
    @jsii.member(jsii_name="metricInput")
    def metric_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "metricInput"))

    @builtins.property
    @jsii.member(jsii_name="paletteInput")
    def palette_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "paletteInput"))

    @builtins.property
    @jsii.member(jsii_name="timeframeInput")
    def timeframe_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "timeframeInput"))

    @builtins.property
    @jsii.member(jsii_name="valueInput")
    def value_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "valueInput"))

    @builtins.property
    @jsii.member(jsii_name="comparator")
    def comparator(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "comparator"))

    @comparator.setter
    def comparator(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cdd2b47fc2bb10055199772b9bd57ad3f543c2dcbbab20b358d72e58a6457191)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "comparator", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="customBgColor")
    def custom_bg_color(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "customBgColor"))

    @custom_bg_color.setter
    def custom_bg_color(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a8ef05683c550ce63dc20220c2c8ccd57f25373fa3d149c617814e26b996c2fb)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "customBgColor", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="customFgColor")
    def custom_fg_color(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "customFgColor"))

    @custom_fg_color.setter
    def custom_fg_color(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a0ddc7b55aae3ef462b11629d3151e0072fb6a1ab98cf670dc11e5295da2a862)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "customFgColor", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="hideValue")
    def hide_value(self) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "hideValue"))

    @hide_value.setter
    def hide_value(
        self,
        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fd2935bb52cc9cf8f1587ecc3151c26786ab1cfc61bf8777ccaf2fe20a9ae79e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "hideValue", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="imageUrl")
    def image_url(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "imageUrl"))

    @image_url.setter
    def image_url(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dce92b5c292f70bbbdd014b4e77729af1bab5032205c99284a12227329a6bdee)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "imageUrl", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="metric")
    def metric(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "metric"))

    @metric.setter
    def metric(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ef829497898a67ba08da687168e7f2f64c85252bb2d747b891839922c9630984)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "metric", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="palette")
    def palette(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "palette"))

    @palette.setter
    def palette(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9358a537aaa3a01132031c49fc9f9ac289d59b56b55387c57bc078b5780c2c95)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "palette", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="timeframe")
    def timeframe(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "timeframe"))

    @timeframe.setter
    def timeframe(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__093c2fa040aeb5da4d4d5f36516fc3ba6e45e4bd50a5ac60f2b6c795e5100f42)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "timeframe", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="value")
    def value(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "value"))

    @value.setter
    def value(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__74fb65771cbba35c467119743701ff71b9b803ffc0a1205978491d873cef3296)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "value", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryTableDefinitionRequestConditionalFormats]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryTableDefinitionRequestConditionalFormats]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryTableDefinitionRequestConditionalFormats]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__727b327ef5cd31af33ac7f0ad5682be59afd2972d44bbf9610990ec97610919a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestFormula",
    jsii_struct_bases=[],
    name_mapping={
        "formula_expression": "formulaExpression",
        "alias": "alias",
        "cell_display_mode": "cellDisplayMode",
        "cell_display_mode_options": "cellDisplayModeOptions",
        "conditional_formats": "conditionalFormats",
        "limit": "limit",
        "number_format": "numberFormat",
        "style": "style",
    },
)
class PowerpackWidgetQueryTableDefinitionRequestFormula:
    def __init__(
        self,
        *,
        formula_expression: builtins.str,
        alias: typing.Optional[builtins.str] = None,
        cell_display_mode: typing.Optional[builtins.str] = None,
        cell_display_mode_options: typing.Optional[typing.Union["PowerpackWidgetQueryTableDefinitionRequestFormulaCellDisplayModeOptions", typing.Dict[builtins.str, typing.Any]]] = None,
        conditional_formats: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetQueryTableDefinitionRequestFormulaConditionalFormats", typing.Dict[builtins.str, typing.Any]]]]] = None,
        limit: typing.Optional[typing.Union["PowerpackWidgetQueryTableDefinitionRequestFormulaLimit", typing.Dict[builtins.str, typing.Any]]] = None,
        number_format: typing.Optional[typing.Union["PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormat", typing.Dict[builtins.str, typing.Any]]] = None,
        style: typing.Optional[typing.Union["PowerpackWidgetQueryTableDefinitionRequestFormulaStyle", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param formula_expression: A string expression built from queries, formulas, and functions. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#formula_expression Powerpack#formula_expression}
        :param alias: An expression alias. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#alias Powerpack#alias}
        :param cell_display_mode: A list of display modes for each table cell. Valid values are ``number``, ``bar``, ``trend``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cell_display_mode Powerpack#cell_display_mode}
        :param cell_display_mode_options: cell_display_mode_options block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cell_display_mode_options Powerpack#cell_display_mode_options}
        :param conditional_formats: conditional_formats block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#conditional_formats Powerpack#conditional_formats}
        :param limit: limit block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param number_format: number_format block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#number_format Powerpack#number_format}
        :param style: style block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#style Powerpack#style}
        '''
        if isinstance(cell_display_mode_options, dict):
            cell_display_mode_options = PowerpackWidgetQueryTableDefinitionRequestFormulaCellDisplayModeOptions(**cell_display_mode_options)
        if isinstance(limit, dict):
            limit = PowerpackWidgetQueryTableDefinitionRequestFormulaLimit(**limit)
        if isinstance(number_format, dict):
            number_format = PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormat(**number_format)
        if isinstance(style, dict):
            style = PowerpackWidgetQueryTableDefinitionRequestFormulaStyle(**style)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__81e01fa81fe369ecc5188234ff523eeb79cb24387691e9f336c04119dcae23e7)
            check_type(argname="argument formula_expression", value=formula_expression, expected_type=type_hints["formula_expression"])
            check_type(argname="argument alias", value=alias, expected_type=type_hints["alias"])
            check_type(argname="argument cell_display_mode", value=cell_display_mode, expected_type=type_hints["cell_display_mode"])
            check_type(argname="argument cell_display_mode_options", value=cell_display_mode_options, expected_type=type_hints["cell_display_mode_options"])
            check_type(argname="argument conditional_formats", value=conditional_formats, expected_type=type_hints["conditional_formats"])
            check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
            check_type(argname="argument number_format", value=number_format, expected_type=type_hints["number_format"])
            check_type(argname="argument style", value=style, expected_type=type_hints["style"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "formula_expression": formula_expression,
        }
        if alias is not None:
            self._values["alias"] = alias
        if cell_display_mode is not None:
            self._values["cell_display_mode"] = cell_display_mode
        if cell_display_mode_options is not None:
            self._values["cell_display_mode_options"] = cell_display_mode_options
        if conditional_formats is not None:
            self._values["conditional_formats"] = conditional_formats
        if limit is not None:
            self._values["limit"] = limit
        if number_format is not None:
            self._values["number_format"] = number_format
        if style is not None:
            self._values["style"] = style

    @builtins.property
    def formula_expression(self) -> builtins.str:
        '''A string expression built from queries, formulas, and functions.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#formula_expression Powerpack#formula_expression}
        '''
        result = self._values.get("formula_expression")
        assert result is not None, "Required property 'formula_expression' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def alias(self) -> typing.Optional[builtins.str]:
        '''An expression alias.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#alias Powerpack#alias}
        '''
        result = self._values.get("alias")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def cell_display_mode(self) -> typing.Optional[builtins.str]:
        '''A list of display modes for each table cell. Valid values are ``number``, ``bar``, ``trend``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cell_display_mode Powerpack#cell_display_mode}
        '''
        result = self._values.get("cell_display_mode")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def cell_display_mode_options(
        self,
    ) -> typing.Optional["PowerpackWidgetQueryTableDefinitionRequestFormulaCellDisplayModeOptions"]:
        '''cell_display_mode_options block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cell_display_mode_options Powerpack#cell_display_mode_options}
        '''
        result = self._values.get("cell_display_mode_options")
        return typing.cast(typing.Optional["PowerpackWidgetQueryTableDefinitionRequestFormulaCellDisplayModeOptions"], result)

    @builtins.property
    def conditional_formats(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetQueryTableDefinitionRequestFormulaConditionalFormats"]]]:
        '''conditional_formats block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#conditional_formats Powerpack#conditional_formats}
        '''
        result = self._values.get("conditional_formats")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetQueryTableDefinitionRequestFormulaConditionalFormats"]]], result)

    @builtins.property
    def limit(
        self,
    ) -> typing.Optional["PowerpackWidgetQueryTableDefinitionRequestFormulaLimit"]:
        '''limit block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        '''
        result = self._values.get("limit")
        return typing.cast(typing.Optional["PowerpackWidgetQueryTableDefinitionRequestFormulaLimit"], result)

    @builtins.property
    def number_format(
        self,
    ) -> typing.Optional["PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormat"]:
        '''number_format block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#number_format Powerpack#number_format}
        '''
        result = self._values.get("number_format")
        return typing.cast(typing.Optional["PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormat"], result)

    @builtins.property
    def style(
        self,
    ) -> typing.Optional["PowerpackWidgetQueryTableDefinitionRequestFormulaStyle"]:
        '''style block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#style Powerpack#style}
        '''
        result = self._values.get("style")
        return typing.cast(typing.Optional["PowerpackWidgetQueryTableDefinitionRequestFormulaStyle"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryTableDefinitionRequestFormula(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestFormulaCellDisplayModeOptions",
    jsii_struct_bases=[],
    name_mapping={"trend_type": "trendType", "y_scale": "yScale"},
)
class PowerpackWidgetQueryTableDefinitionRequestFormulaCellDisplayModeOptions:
    def __init__(
        self,
        *,
        trend_type: typing.Optional[builtins.str] = None,
        y_scale: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param trend_type: The type of trend line to display. Valid values are ``area``, ``line``, ``bars``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#trend_type Powerpack#trend_type}
        :param y_scale: The scale of the y-axis. Valid values are ``shared``, ``independent``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#y_scale Powerpack#y_scale}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5c7166396ce6716d564bb0c43911d68bed4c9245294986f3865d0cc06b6b2fb0)
            check_type(argname="argument trend_type", value=trend_type, expected_type=type_hints["trend_type"])
            check_type(argname="argument y_scale", value=y_scale, expected_type=type_hints["y_scale"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if trend_type is not None:
            self._values["trend_type"] = trend_type
        if y_scale is not None:
            self._values["y_scale"] = y_scale

    @builtins.property
    def trend_type(self) -> typing.Optional[builtins.str]:
        '''The type of trend line to display. Valid values are ``area``, ``line``, ``bars``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#trend_type Powerpack#trend_type}
        '''
        result = self._values.get("trend_type")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def y_scale(self) -> typing.Optional[builtins.str]:
        '''The scale of the y-axis. Valid values are ``shared``, ``independent``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#y_scale Powerpack#y_scale}
        '''
        result = self._values.get("y_scale")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryTableDefinitionRequestFormulaCellDisplayModeOptions(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetQueryTableDefinitionRequestFormulaCellDisplayModeOptionsOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestFormulaCellDisplayModeOptionsOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__da43c074c9e56af84120713afe8660d837903264b2bb68cc15305f3af2d32ac0)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetTrendType")
    def reset_trend_type(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTrendType", []))

    @jsii.member(jsii_name="resetYScale")
    def reset_y_scale(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetYScale", []))

    @builtins.property
    @jsii.member(jsii_name="trendTypeInput")
    def trend_type_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "trendTypeInput"))

    @builtins.property
    @jsii.member(jsii_name="yScaleInput")
    def y_scale_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "yScaleInput"))

    @builtins.property
    @jsii.member(jsii_name="trendType")
    def trend_type(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "trendType"))

    @trend_type.setter
    def trend_type(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4cf1a31c52a6025cfbbd9e008292ee630de68c25ad3d3ec90eb79dd4104fe46c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "trendType", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="yScale")
    def y_scale(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "yScale"))

    @y_scale.setter
    def y_scale(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__86a97005d9f2feca3c87aab83fc9e5cf0fad162fff0ed35f916f8822a07e7ae9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "yScale", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetQueryTableDefinitionRequestFormulaCellDisplayModeOptions]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryTableDefinitionRequestFormulaCellDisplayModeOptions], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetQueryTableDefinitionRequestFormulaCellDisplayModeOptions],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__814e1011a89987e127840b1bb768d76fcc45118bb4b9700b656f7f8d8e7a8be0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestFormulaConditionalFormats",
    jsii_struct_bases=[],
    name_mapping={
        "comparator": "comparator",
        "palette": "palette",
        "value": "value",
        "custom_bg_color": "customBgColor",
        "custom_fg_color": "customFgColor",
        "hide_value": "hideValue",
        "image_url": "imageUrl",
        "metric": "metric",
        "timeframe": "timeframe",
    },
)
class PowerpackWidgetQueryTableDefinitionRequestFormulaConditionalFormats:
    def __init__(
        self,
        *,
        comparator: builtins.str,
        palette: builtins.str,
        value: jsii.Number,
        custom_bg_color: typing.Optional[builtins.str] = None,
        custom_fg_color: typing.Optional[builtins.str] = None,
        hide_value: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        image_url: typing.Optional[builtins.str] = None,
        metric: typing.Optional[builtins.str] = None,
        timeframe: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param comparator: The comparator to use. Valid values are ``=``, ``>``, ``>=``, ``<``, ``<=``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#comparator Powerpack#comparator}
        :param palette: The color palette to apply. Valid values are ``blue``, ``custom_bg``, ``custom_image``, ``custom_text``, ``gray_on_white``, ``grey``, ``green``, ``orange``, ``red``, ``red_on_white``, ``white_on_gray``, ``white_on_green``, ``green_on_white``, ``white_on_red``, ``white_on_yellow``, ``yellow_on_white``, ``black_on_light_yellow``, ``black_on_light_green``, ``black_on_light_red``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette Powerpack#palette}
        :param value: A value for the comparator. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#value Powerpack#value}
        :param custom_bg_color: The color palette to apply to the background, same values available as palette. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom_bg_color Powerpack#custom_bg_color}
        :param custom_fg_color: The color palette to apply to the foreground, same values available as palette. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom_fg_color Powerpack#custom_fg_color}
        :param hide_value: Setting this to True hides values. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#hide_value Powerpack#hide_value}
        :param image_url: Displays an image as the background. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#image_url Powerpack#image_url}
        :param metric: The metric from the request to correlate with this conditional format. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        :param timeframe: Defines the displayed timeframe. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#timeframe Powerpack#timeframe}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3a383747d45579ec7422dd4c0d3302a7a75a1182b42ea061274fd346f0506c9d)
            check_type(argname="argument comparator", value=comparator, expected_type=type_hints["comparator"])
            check_type(argname="argument palette", value=palette, expected_type=type_hints["palette"])
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument custom_bg_color", value=custom_bg_color, expected_type=type_hints["custom_bg_color"])
            check_type(argname="argument custom_fg_color", value=custom_fg_color, expected_type=type_hints["custom_fg_color"])
            check_type(argname="argument hide_value", value=hide_value, expected_type=type_hints["hide_value"])
            check_type(argname="argument image_url", value=image_url, expected_type=type_hints["image_url"])
            check_type(argname="argument metric", value=metric, expected_type=type_hints["metric"])
            check_type(argname="argument timeframe", value=timeframe, expected_type=type_hints["timeframe"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "comparator": comparator,
            "palette": palette,
            "value": value,
        }
        if custom_bg_color is not None:
            self._values["custom_bg_color"] = custom_bg_color
        if custom_fg_color is not None:
            self._values["custom_fg_color"] = custom_fg_color
        if hide_value is not None:
            self._values["hide_value"] = hide_value
        if image_url is not None:
            self._values["image_url"] = image_url
        if metric is not None:
            self._values["metric"] = metric
        if timeframe is not None:
            self._values["timeframe"] = timeframe

    @builtins.property
    def comparator(self) -> builtins.str:
        '''The comparator to use. Valid values are ``=``, ``>``, ``>=``, ``<``, ``<=``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#comparator Powerpack#comparator}
        '''
        result = self._values.get("comparator")
        assert result is not None, "Required property 'comparator' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def palette(self) -> builtins.str:
        '''The color palette to apply.

        Valid values are ``blue``, ``custom_bg``, ``custom_image``, ``custom_text``, ``gray_on_white``, ``grey``, ``green``, ``orange``, ``red``, ``red_on_white``, ``white_on_gray``, ``white_on_green``, ``green_on_white``, ``white_on_red``, ``white_on_yellow``, ``yellow_on_white``, ``black_on_light_yellow``, ``black_on_light_green``, ``black_on_light_red``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette Powerpack#palette}
        '''
        result = self._values.get("palette")
        assert result is not None, "Required property 'palette' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def value(self) -> jsii.Number:
        '''A value for the comparator.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#value Powerpack#value}
        '''
        result = self._values.get("value")
        assert result is not None, "Required property 'value' is missing"
        return typing.cast(jsii.Number, result)

    @builtins.property
    def custom_bg_color(self) -> typing.Optional[builtins.str]:
        '''The color palette to apply to the background, same values available as palette.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom_bg_color Powerpack#custom_bg_color}
        '''
        result = self._values.get("custom_bg_color")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def custom_fg_color(self) -> typing.Optional[builtins.str]:
        '''The color palette to apply to the foreground, same values available as palette.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom_fg_color Powerpack#custom_fg_color}
        '''
        result = self._values.get("custom_fg_color")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def hide_value(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        '''Setting this to True hides values.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#hide_value Powerpack#hide_value}
        '''
        result = self._values.get("hide_value")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)

    @builtins.property
    def image_url(self) -> typing.Optional[builtins.str]:
        '''Displays an image as the background.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#image_url Powerpack#image_url}
        '''
        result = self._values.get("image_url")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def metric(self) -> typing.Optional[builtins.str]:
        '''The metric from the request to correlate with this conditional format.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        '''
        result = self._values.get("metric")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def timeframe(self) -> typing.Optional[builtins.str]:
        '''Defines the displayed timeframe.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#timeframe Powerpack#timeframe}
        '''
        result = self._values.get("timeframe")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryTableDefinitionRequestFormulaConditionalFormats(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetQueryTableDefinitionRequestFormulaConditionalFormatsList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestFormulaConditionalFormatsList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ff9d339e802a530c5e883efd9614a05198c04e16ff882a2f491e7eb037c965f8)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetQueryTableDefinitionRequestFormulaConditionalFormatsOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bde252ac2ea124f6e89f94e8928810da296fe4e50186e065a3e42899b5596d1a)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetQueryTableDefinitionRequestFormulaConditionalFormatsOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__985917859b82698026cbfa876354f8b195a37280d61e49263cc55a6d16e397b7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__93327080af408dc805b702c55541a439b75fa1c04f19cee863bd5d1103564895)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a5f20d8e662821d578ad40565f6e4ba92de6891bbc4a23433937a9120c31ab8a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionRequestFormulaConditionalFormats]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionRequestFormulaConditionalFormats]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionRequestFormulaConditionalFormats]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2a9e9f3b22f77158a7f3fb14c08a0ebd06908e19b125db752aae74c088f5a7bc)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetQueryTableDefinitionRequestFormulaConditionalFormatsOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestFormulaConditionalFormatsOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__513ee38dd503bcd13eb52e6754a2d851cd5a3b1d7587530080b8147f97b20d68)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetCustomBgColor")
    def reset_custom_bg_color(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCustomBgColor", []))

    @jsii.member(jsii_name="resetCustomFgColor")
    def reset_custom_fg_color(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCustomFgColor", []))

    @jsii.member(jsii_name="resetHideValue")
    def reset_hide_value(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHideValue", []))

    @jsii.member(jsii_name="resetImageUrl")
    def reset_image_url(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetImageUrl", []))

    @jsii.member(jsii_name="resetMetric")
    def reset_metric(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMetric", []))

    @jsii.member(jsii_name="resetTimeframe")
    def reset_timeframe(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTimeframe", []))

    @builtins.property
    @jsii.member(jsii_name="comparatorInput")
    def comparator_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "comparatorInput"))

    @builtins.property
    @jsii.member(jsii_name="customBgColorInput")
    def custom_bg_color_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "customBgColorInput"))

    @builtins.property
    @jsii.member(jsii_name="customFgColorInput")
    def custom_fg_color_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "customFgColorInput"))

    @builtins.property
    @jsii.member(jsii_name="hideValueInput")
    def hide_value_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "hideValueInput"))

    @builtins.property
    @jsii.member(jsii_name="imageUrlInput")
    def image_url_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "imageUrlInput"))

    @builtins.property
    @jsii.member(jsii_name="metricInput")
    def metric_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "metricInput"))

    @builtins.property
    @jsii.member(jsii_name="paletteInput")
    def palette_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "paletteInput"))

    @builtins.property
    @jsii.member(jsii_name="timeframeInput")
    def timeframe_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "timeframeInput"))

    @builtins.property
    @jsii.member(jsii_name="valueInput")
    def value_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "valueInput"))

    @builtins.property
    @jsii.member(jsii_name="comparator")
    def comparator(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "comparator"))

    @comparator.setter
    def comparator(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1e6f246f5a8690f18ea88bc96d79f3e7b4f03071d3b812b30af94690e89d3446)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "comparator", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="customBgColor")
    def custom_bg_color(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "customBgColor"))

    @custom_bg_color.setter
    def custom_bg_color(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__287c8644a0417f85c66bd16c0308aa17667b7f0baca4a3729b9a2776d486099d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "customBgColor", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="customFgColor")
    def custom_fg_color(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "customFgColor"))

    @custom_fg_color.setter
    def custom_fg_color(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ba4ee9790f148342d04d00c7fe09f5d70f4a1b28413624fe44ed6a5a2a09a407)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "customFgColor", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="hideValue")
    def hide_value(self) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "hideValue"))

    @hide_value.setter
    def hide_value(
        self,
        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ea590fd07105d5940ed912aaa52f44e919af368f6d28939d73ca98593330808c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "hideValue", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="imageUrl")
    def image_url(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "imageUrl"))

    @image_url.setter
    def image_url(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d919270e80645f925a8a262cbd464ab858a8c5c6cda0fb7c28d64727aed2d930)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "imageUrl", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="metric")
    def metric(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "metric"))

    @metric.setter
    def metric(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f85a43d681bd5f6cb47afdf4e943b180d4796289afc13cf9bf83d68078a3d486)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "metric", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="palette")
    def palette(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "palette"))

    @palette.setter
    def palette(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__58d42e027c949e2ace2cf4f2c02df2a748901d968c8d52eca612bf45d9a7d126)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "palette", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="timeframe")
    def timeframe(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "timeframe"))

    @timeframe.setter
    def timeframe(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4405cec0e517718001974242b6aeab093a8d6b9a9ad0708be8307e544c2c0d05)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "timeframe", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="value")
    def value(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "value"))

    @value.setter
    def value(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d0b092a9c43ee9b69b2811b9872b2fee893fda5345eca5d8c8fe00d2e3c72c8f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "value", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryTableDefinitionRequestFormulaConditionalFormats]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryTableDefinitionRequestFormulaConditionalFormats]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryTableDefinitionRequestFormulaConditionalFormats]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7c11999f7b66fbfa0fa5051a9592c0516a397b13d104b944ab16ce01ef4e6097)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestFormulaLimit",
    jsii_struct_bases=[],
    name_mapping={"count": "count", "order": "order"},
)
class PowerpackWidgetQueryTableDefinitionRequestFormulaLimit:
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        order: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param count: The number of results to return. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#count Powerpack#count}
        :param order: The direction of the sort. Valid values are ``asc``, ``desc``. Defaults to ``"desc"``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7831b0b36685102c953c36282006967cb1a7c940e1c1ea09969070bc869b43db)
            check_type(argname="argument count", value=count, expected_type=type_hints["count"])
            check_type(argname="argument order", value=order, expected_type=type_hints["order"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if count is not None:
            self._values["count"] = count
        if order is not None:
            self._values["order"] = order

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''The number of results to return.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#count Powerpack#count}
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def order(self) -> typing.Optional[builtins.str]:
        '''The direction of the sort. Valid values are ``asc``, ``desc``. Defaults to ``"desc"``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        result = self._values.get("order")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryTableDefinitionRequestFormulaLimit(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetQueryTableDefinitionRequestFormulaLimitOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestFormulaLimitOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__94aa4453129d43848960b51c3d24763c54a2e6329da4d903cd9dfb00c41d7c3b)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetCount")
    def reset_count(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCount", []))

    @jsii.member(jsii_name="resetOrder")
    def reset_order(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetOrder", []))

    @builtins.property
    @jsii.member(jsii_name="countInput")
    def count_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "countInput"))

    @builtins.property
    @jsii.member(jsii_name="orderInput")
    def order_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "orderInput"))

    @builtins.property
    @jsii.member(jsii_name="count")
    def count(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "count"))

    @count.setter
    def count(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e771dc7f9a35fb777ea6d81499f08dfd2403bbd6bf8259acf412a3de8441ce82)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "count", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="order")
    def order(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "order"))

    @order.setter
    def order(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__492d1658b09f25d8844b08059e08b7de44c3e4c032a6a3b514cccfa3c6ac85a4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "order", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetQueryTableDefinitionRequestFormulaLimit]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryTableDefinitionRequestFormulaLimit], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetQueryTableDefinitionRequestFormulaLimit],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7317ea44466f3d178f5e86f6a35b4453398ac343186284f1d622bd8846bfe945)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetQueryTableDefinitionRequestFormulaList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestFormulaList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__39e8cb0dea665585f33495f926947de5296f616b01c59f75c38afac5b725f58c)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetQueryTableDefinitionRequestFormulaOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b929f1f36a5270191739a8a05cd98b9ee1e7fb0ccaf3cb777ead893be1113f03)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetQueryTableDefinitionRequestFormulaOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__29bd3b8c3a5a76345b537abea9c018e8b39a3ecac49f7f7245349904e0144a00)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c0e3cf2fd24bdc407e50e9834872dcba20544e80e4a3cffd9f8ff43d91b82c0b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e445f00a3fa116539abc59bed5f778f0c5205f460e3c5aa166019773169a5a40)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionRequestFormula]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionRequestFormula]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionRequestFormula]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8fa167b8ccf4d59d956709ef70c35c8af462f13c98916258c15699d20eac3a88)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormat",
    jsii_struct_bases=[],
    name_mapping={"unit": "unit", "unit_scale": "unitScale"},
)
class PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormat:
    def __init__(
        self,
        *,
        unit: typing.Union["PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormatUnit", typing.Dict[builtins.str, typing.Any]],
        unit_scale: typing.Optional[typing.Union["PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormatUnitScale", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param unit: unit block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit Powerpack#unit}
        :param unit_scale: unit_scale block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit_scale Powerpack#unit_scale}
        '''
        if isinstance(unit, dict):
            unit = PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormatUnit(**unit)
        if isinstance(unit_scale, dict):
            unit_scale = PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormatUnitScale(**unit_scale)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__687eb8eaeb43370a850dde7651344ef4c11dc717a06ed89041c9c95a681a8026)
            check_type(argname="argument unit", value=unit, expected_type=type_hints["unit"])
            check_type(argname="argument unit_scale", value=unit_scale, expected_type=type_hints["unit_scale"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "unit": unit,
        }
        if unit_scale is not None:
            self._values["unit_scale"] = unit_scale

    @builtins.property
    def unit(
        self,
    ) -> "PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormatUnit":
        '''unit block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit Powerpack#unit}
        '''
        result = self._values.get("unit")
        assert result is not None, "Required property 'unit' is missing"
        return typing.cast("PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormatUnit", result)

    @builtins.property
    def unit_scale(
        self,
    ) -> typing.Optional["PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormatUnitScale"]:
        '''unit_scale block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit_scale Powerpack#unit_scale}
        '''
        result = self._values.get("unit_scale")
        return typing.cast(typing.Optional["PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormatUnitScale"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormat(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormatOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormatOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1cfa2a6dd4a70a9bf1190819a60cae131d63c43e935d5ca8161251f3e3290c14)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putUnit")
    def put_unit(
        self,
        *,
        canonical: typing.Optional[typing.Union["PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormatUnitCanonical", typing.Dict[builtins.str, typing.Any]]] = None,
        custom: typing.Optional[typing.Union["PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormatUnitCustom", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param canonical: canonical block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#canonical Powerpack#canonical}
        :param custom: custom block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom Powerpack#custom}
        '''
        value = PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormatUnit(
            canonical=canonical, custom=custom
        )

        return typing.cast(None, jsii.invoke(self, "putUnit", [value]))

    @jsii.member(jsii_name="putUnitScale")
    def put_unit_scale(self, *, unit_name: builtins.str) -> None:
        '''
        :param unit_name: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit_name Powerpack#unit_name}.
        '''
        value = PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormatUnitScale(
            unit_name=unit_name
        )

        return typing.cast(None, jsii.invoke(self, "putUnitScale", [value]))

    @jsii.member(jsii_name="resetUnitScale")
    def reset_unit_scale(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetUnitScale", []))

    @builtins.property
    @jsii.member(jsii_name="unit")
    def unit(
        self,
    ) -> "PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormatUnitOutputReference":
        return typing.cast("PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormatUnitOutputReference", jsii.get(self, "unit"))

    @builtins.property
    @jsii.member(jsii_name="unitScale")
    def unit_scale(
        self,
    ) -> "PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormatUnitScaleOutputReference":
        return typing.cast("PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormatUnitScaleOutputReference", jsii.get(self, "unitScale"))

    @builtins.property
    @jsii.member(jsii_name="unitInput")
    def unit_input(
        self,
    ) -> typing.Optional["PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormatUnit"]:
        return typing.cast(typing.Optional["PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormatUnit"], jsii.get(self, "unitInput"))

    @builtins.property
    @jsii.member(jsii_name="unitScaleInput")
    def unit_scale_input(
        self,
    ) -> typing.Optional["PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormatUnitScale"]:
        return typing.cast(typing.Optional["PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormatUnitScale"], jsii.get(self, "unitScaleInput"))

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormat]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormat], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormat],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__95f99a447d82f0306ec8c4d50fa63d8f7fa8c9123a9f16d79f34c36e8cc1887f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormatUnit",
    jsii_struct_bases=[],
    name_mapping={"canonical": "canonical", "custom": "custom"},
)
class PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormatUnit:
    def __init__(
        self,
        *,
        canonical: typing.Optional[typing.Union["PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormatUnitCanonical", typing.Dict[builtins.str, typing.Any]]] = None,
        custom: typing.Optional[typing.Union["PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormatUnitCustom", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param canonical: canonical block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#canonical Powerpack#canonical}
        :param custom: custom block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom Powerpack#custom}
        '''
        if isinstance(canonical, dict):
            canonical = PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormatUnitCanonical(**canonical)
        if isinstance(custom, dict):
            custom = PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormatUnitCustom(**custom)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3c3d579b6b0de7d1fd1030de63df1babf1edf67db66bf708428f0da8fdd6eb2e)
            check_type(argname="argument canonical", value=canonical, expected_type=type_hints["canonical"])
            check_type(argname="argument custom", value=custom, expected_type=type_hints["custom"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if canonical is not None:
            self._values["canonical"] = canonical
        if custom is not None:
            self._values["custom"] = custom

    @builtins.property
    def canonical(
        self,
    ) -> typing.Optional["PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormatUnitCanonical"]:
        '''canonical block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#canonical Powerpack#canonical}
        '''
        result = self._values.get("canonical")
        return typing.cast(typing.Optional["PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormatUnitCanonical"], result)

    @builtins.property
    def custom(
        self,
    ) -> typing.Optional["PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormatUnitCustom"]:
        '''custom block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom Powerpack#custom}
        '''
        result = self._values.get("custom")
        return typing.cast(typing.Optional["PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormatUnitCustom"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormatUnit(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormatUnitCanonical",
    jsii_struct_bases=[],
    name_mapping={"unit_name": "unitName", "per_unit_name": "perUnitName"},
)
class PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormatUnitCanonical:
    def __init__(
        self,
        *,
        unit_name: builtins.str,
        per_unit_name: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param unit_name: Unit name. It should be in singular form ('megabyte' and not 'megabytes'). Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit_name Powerpack#unit_name}
        :param per_unit_name: per unit name. If you want to represent megabytes/s, you set 'unit_name' = 'megabyte' and 'per_unit_name = 'second'. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#per_unit_name Powerpack#per_unit_name}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__14872c65db454d600eac7bc62133be70af071b0acaffe8f67a560718b2ab48ea)
            check_type(argname="argument unit_name", value=unit_name, expected_type=type_hints["unit_name"])
            check_type(argname="argument per_unit_name", value=per_unit_name, expected_type=type_hints["per_unit_name"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "unit_name": unit_name,
        }
        if per_unit_name is not None:
            self._values["per_unit_name"] = per_unit_name

    @builtins.property
    def unit_name(self) -> builtins.str:
        '''Unit name. It should be in singular form ('megabyte' and not 'megabytes').

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit_name Powerpack#unit_name}
        '''
        result = self._values.get("unit_name")
        assert result is not None, "Required property 'unit_name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def per_unit_name(self) -> typing.Optional[builtins.str]:
        '''per unit name. If you want to represent megabytes/s, you set 'unit_name' = 'megabyte' and 'per_unit_name = 'second'.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#per_unit_name Powerpack#per_unit_name}
        '''
        result = self._values.get("per_unit_name")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormatUnitCanonical(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormatUnitCanonicalOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormatUnitCanonicalOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__49d50957f8f2a95188964e0a51cf02a9cbee0c92e50a9f6a919d831600fb6adc)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetPerUnitName")
    def reset_per_unit_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPerUnitName", []))

    @builtins.property
    @jsii.member(jsii_name="perUnitNameInput")
    def per_unit_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "perUnitNameInput"))

    @builtins.property
    @jsii.member(jsii_name="unitNameInput")
    def unit_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "unitNameInput"))

    @builtins.property
    @jsii.member(jsii_name="perUnitName")
    def per_unit_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "perUnitName"))

    @per_unit_name.setter
    def per_unit_name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__da71f7fa36ce8e597fcbc3739d0585dc5b7102c761d0b500908711b27f0d6eb3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "perUnitName", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="unitName")
    def unit_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "unitName"))

    @unit_name.setter
    def unit_name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__99369e8ab3d1dad0670396c294b2f4c796aa50a8653d350fba6f4c2e2c83dadd)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "unitName", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormatUnitCanonical]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormatUnitCanonical], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormatUnitCanonical],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f59a4f6b656212efca61b989b29091ac06d5da40d695a62a3e80f7aa75d43f5f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormatUnitCustom",
    jsii_struct_bases=[],
    name_mapping={"label": "label"},
)
class PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormatUnitCustom:
    def __init__(self, *, label: builtins.str) -> None:
        '''
        :param label: Unit label. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#label Powerpack#label}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f8c1c1beed3d581646ee1d6a5680b7672e7ea310d5922b0c73db655596cc4ac2)
            check_type(argname="argument label", value=label, expected_type=type_hints["label"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "label": label,
        }

    @builtins.property
    def label(self) -> builtins.str:
        '''Unit label.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#label Powerpack#label}
        '''
        result = self._values.get("label")
        assert result is not None, "Required property 'label' is missing"
        return typing.cast(builtins.str, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormatUnitCustom(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormatUnitCustomOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormatUnitCustomOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__30c4486f6514802a4ba2dfdc5f6c148adfb9a8338b96fb1a2f836da20a7166e2)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @builtins.property
    @jsii.member(jsii_name="labelInput")
    def label_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "labelInput"))

    @builtins.property
    @jsii.member(jsii_name="label")
    def label(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "label"))

    @label.setter
    def label(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8ed2676aa60579d00b3bcc6435d11452f4e41786a74d6ccab5c0477fea8510a1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "label", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormatUnitCustom]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormatUnitCustom], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormatUnitCustom],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3ccfdf7e5e11396472863296a7bbf9de58551ea51f4ecd756ffdd83efe57e4e9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormatUnitOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormatUnitOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__42c5ac889850a1276c354ddec03226c98429de9e6bbdcc2766fee8c70066fae7)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putCanonical")
    def put_canonical(
        self,
        *,
        unit_name: builtins.str,
        per_unit_name: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param unit_name: Unit name. It should be in singular form ('megabyte' and not 'megabytes'). Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit_name Powerpack#unit_name}
        :param per_unit_name: per unit name. If you want to represent megabytes/s, you set 'unit_name' = 'megabyte' and 'per_unit_name = 'second'. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#per_unit_name Powerpack#per_unit_name}
        '''
        value = PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormatUnitCanonical(
            unit_name=unit_name, per_unit_name=per_unit_name
        )

        return typing.cast(None, jsii.invoke(self, "putCanonical", [value]))

    @jsii.member(jsii_name="putCustom")
    def put_custom(self, *, label: builtins.str) -> None:
        '''
        :param label: Unit label. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#label Powerpack#label}
        '''
        value = PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormatUnitCustom(
            label=label
        )

        return typing.cast(None, jsii.invoke(self, "putCustom", [value]))

    @jsii.member(jsii_name="resetCanonical")
    def reset_canonical(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCanonical", []))

    @jsii.member(jsii_name="resetCustom")
    def reset_custom(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCustom", []))

    @builtins.property
    @jsii.member(jsii_name="canonical")
    def canonical(
        self,
    ) -> PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormatUnitCanonicalOutputReference:
        return typing.cast(PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormatUnitCanonicalOutputReference, jsii.get(self, "canonical"))

    @builtins.property
    @jsii.member(jsii_name="custom")
    def custom(
        self,
    ) -> PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormatUnitCustomOutputReference:
        return typing.cast(PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormatUnitCustomOutputReference, jsii.get(self, "custom"))

    @builtins.property
    @jsii.member(jsii_name="canonicalInput")
    def canonical_input(
        self,
    ) -> typing.Optional[PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormatUnitCanonical]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormatUnitCanonical], jsii.get(self, "canonicalInput"))

    @builtins.property
    @jsii.member(jsii_name="customInput")
    def custom_input(
        self,
    ) -> typing.Optional[PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormatUnitCustom]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormatUnitCustom], jsii.get(self, "customInput"))

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormatUnit]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormatUnit], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormatUnit],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5447c92fcd6a808b8b8748b14cc1c7f40fd6785503eab5693eb16b3febf076d6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormatUnitScale",
    jsii_struct_bases=[],
    name_mapping={"unit_name": "unitName"},
)
class PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormatUnitScale:
    def __init__(self, *, unit_name: builtins.str) -> None:
        '''
        :param unit_name: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit_name Powerpack#unit_name}.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2b700329fc6612071f2a259a024f794c0a240f5bb457181f3af261776ea00481)
            check_type(argname="argument unit_name", value=unit_name, expected_type=type_hints["unit_name"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "unit_name": unit_name,
        }

    @builtins.property
    def unit_name(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit_name Powerpack#unit_name}.'''
        result = self._values.get("unit_name")
        assert result is not None, "Required property 'unit_name' is missing"
        return typing.cast(builtins.str, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormatUnitScale(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormatUnitScaleOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormatUnitScaleOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__32adba3d0c1262dd40a503720f4eca5aa018404b379b6d55a5a8ac5f5aa741e3)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @builtins.property
    @jsii.member(jsii_name="unitNameInput")
    def unit_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "unitNameInput"))

    @builtins.property
    @jsii.member(jsii_name="unitName")
    def unit_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "unitName"))

    @unit_name.setter
    def unit_name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__930a6fb6f4fb93fd24c00638fa88b2a12411e238365d0bd0df15b29f799b0c64)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "unitName", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormatUnitScale]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormatUnitScale], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormatUnitScale],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b38db0af8472ec5fbf798e8e622d11152bb7ee035739a2d8fe672cadfaf0cacb)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetQueryTableDefinitionRequestFormulaOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestFormulaOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ec8e999631aa5c7eda0c2e6adc54818081658f0f6d50a4df19185a62a7487057)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putCellDisplayModeOptions")
    def put_cell_display_mode_options(
        self,
        *,
        trend_type: typing.Optional[builtins.str] = None,
        y_scale: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param trend_type: The type of trend line to display. Valid values are ``area``, ``line``, ``bars``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#trend_type Powerpack#trend_type}
        :param y_scale: The scale of the y-axis. Valid values are ``shared``, ``independent``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#y_scale Powerpack#y_scale}
        '''
        value = PowerpackWidgetQueryTableDefinitionRequestFormulaCellDisplayModeOptions(
            trend_type=trend_type, y_scale=y_scale
        )

        return typing.cast(None, jsii.invoke(self, "putCellDisplayModeOptions", [value]))

    @jsii.member(jsii_name="putConditionalFormats")
    def put_conditional_formats(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryTableDefinitionRequestFormulaConditionalFormats, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b01a3708e47e57cd9c9e6c007b027a4c7fe391c8a29b1c417dcf0cbb23d6252b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putConditionalFormats", [value]))

    @jsii.member(jsii_name="putLimit")
    def put_limit(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        order: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param count: The number of results to return. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#count Powerpack#count}
        :param order: The direction of the sort. Valid values are ``asc``, ``desc``. Defaults to ``"desc"``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        value = PowerpackWidgetQueryTableDefinitionRequestFormulaLimit(
            count=count, order=order
        )

        return typing.cast(None, jsii.invoke(self, "putLimit", [value]))

    @jsii.member(jsii_name="putNumberFormat")
    def put_number_format(
        self,
        *,
        unit: typing.Union[PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormatUnit, typing.Dict[builtins.str, typing.Any]],
        unit_scale: typing.Optional[typing.Union[PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormatUnitScale, typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param unit: unit block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit Powerpack#unit}
        :param unit_scale: unit_scale block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit_scale Powerpack#unit_scale}
        '''
        value = PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormat(
            unit=unit, unit_scale=unit_scale
        )

        return typing.cast(None, jsii.invoke(self, "putNumberFormat", [value]))

    @jsii.member(jsii_name="putStyle")
    def put_style(
        self,
        *,
        palette: typing.Optional[builtins.str] = None,
        palette_index: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param palette: The color palette used to display the formula. A guide to the available color palettes can be found at https://docs.datadoghq.com/dashboards/guide/widget_colors. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette Powerpack#palette}
        :param palette_index: Index specifying which color to use within the palette. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette_index Powerpack#palette_index}
        '''
        value = PowerpackWidgetQueryTableDefinitionRequestFormulaStyle(
            palette=palette, palette_index=palette_index
        )

        return typing.cast(None, jsii.invoke(self, "putStyle", [value]))

    @jsii.member(jsii_name="resetAlias")
    def reset_alias(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAlias", []))

    @jsii.member(jsii_name="resetCellDisplayMode")
    def reset_cell_display_mode(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCellDisplayMode", []))

    @jsii.member(jsii_name="resetCellDisplayModeOptions")
    def reset_cell_display_mode_options(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCellDisplayModeOptions", []))

    @jsii.member(jsii_name="resetConditionalFormats")
    def reset_conditional_formats(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetConditionalFormats", []))

    @jsii.member(jsii_name="resetLimit")
    def reset_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLimit", []))

    @jsii.member(jsii_name="resetNumberFormat")
    def reset_number_format(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetNumberFormat", []))

    @jsii.member(jsii_name="resetStyle")
    def reset_style(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetStyle", []))

    @builtins.property
    @jsii.member(jsii_name="cellDisplayModeOptions")
    def cell_display_mode_options(
        self,
    ) -> PowerpackWidgetQueryTableDefinitionRequestFormulaCellDisplayModeOptionsOutputReference:
        return typing.cast(PowerpackWidgetQueryTableDefinitionRequestFormulaCellDisplayModeOptionsOutputReference, jsii.get(self, "cellDisplayModeOptions"))

    @builtins.property
    @jsii.member(jsii_name="conditionalFormats")
    def conditional_formats(
        self,
    ) -> PowerpackWidgetQueryTableDefinitionRequestFormulaConditionalFormatsList:
        return typing.cast(PowerpackWidgetQueryTableDefinitionRequestFormulaConditionalFormatsList, jsii.get(self, "conditionalFormats"))

    @builtins.property
    @jsii.member(jsii_name="limit")
    def limit(
        self,
    ) -> PowerpackWidgetQueryTableDefinitionRequestFormulaLimitOutputReference:
        return typing.cast(PowerpackWidgetQueryTableDefinitionRequestFormulaLimitOutputReference, jsii.get(self, "limit"))

    @builtins.property
    @jsii.member(jsii_name="numberFormat")
    def number_format(
        self,
    ) -> PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormatOutputReference:
        return typing.cast(PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormatOutputReference, jsii.get(self, "numberFormat"))

    @builtins.property
    @jsii.member(jsii_name="style")
    def style(
        self,
    ) -> "PowerpackWidgetQueryTableDefinitionRequestFormulaStyleOutputReference":
        return typing.cast("PowerpackWidgetQueryTableDefinitionRequestFormulaStyleOutputReference", jsii.get(self, "style"))

    @builtins.property
    @jsii.member(jsii_name="aliasInput")
    def alias_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aliasInput"))

    @builtins.property
    @jsii.member(jsii_name="cellDisplayModeInput")
    def cell_display_mode_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "cellDisplayModeInput"))

    @builtins.property
    @jsii.member(jsii_name="cellDisplayModeOptionsInput")
    def cell_display_mode_options_input(
        self,
    ) -> typing.Optional[PowerpackWidgetQueryTableDefinitionRequestFormulaCellDisplayModeOptions]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryTableDefinitionRequestFormulaCellDisplayModeOptions], jsii.get(self, "cellDisplayModeOptionsInput"))

    @builtins.property
    @jsii.member(jsii_name="conditionalFormatsInput")
    def conditional_formats_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionRequestFormulaConditionalFormats]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionRequestFormulaConditionalFormats]]], jsii.get(self, "conditionalFormatsInput"))

    @builtins.property
    @jsii.member(jsii_name="formulaExpressionInput")
    def formula_expression_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "formulaExpressionInput"))

    @builtins.property
    @jsii.member(jsii_name="limitInput")
    def limit_input(
        self,
    ) -> typing.Optional[PowerpackWidgetQueryTableDefinitionRequestFormulaLimit]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryTableDefinitionRequestFormulaLimit], jsii.get(self, "limitInput"))

    @builtins.property
    @jsii.member(jsii_name="numberFormatInput")
    def number_format_input(
        self,
    ) -> typing.Optional[PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormat]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormat], jsii.get(self, "numberFormatInput"))

    @builtins.property
    @jsii.member(jsii_name="styleInput")
    def style_input(
        self,
    ) -> typing.Optional["PowerpackWidgetQueryTableDefinitionRequestFormulaStyle"]:
        return typing.cast(typing.Optional["PowerpackWidgetQueryTableDefinitionRequestFormulaStyle"], jsii.get(self, "styleInput"))

    @builtins.property
    @jsii.member(jsii_name="alias")
    def alias(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "alias"))

    @alias.setter
    def alias(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__64fca3d8d4f995f6b4bf040c02dd13a929a43e15cf807f89219d0337f71320b7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "alias", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="cellDisplayMode")
    def cell_display_mode(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "cellDisplayMode"))

    @cell_display_mode.setter
    def cell_display_mode(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2a44454f27715074a685693b31930dbe0400d65044c121ee9b65e2cb0443e082)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "cellDisplayMode", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="formulaExpression")
    def formula_expression(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "formulaExpression"))

    @formula_expression.setter
    def formula_expression(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__db314c1e7fa537e30c1cecfc4fe4f17ef761820b9beb1a5f123f24dcd8934537)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "formulaExpression", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryTableDefinitionRequestFormula]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryTableDefinitionRequestFormula]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryTableDefinitionRequestFormula]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__63e84c9bb90b188865c71aa56e61eb1f349ec105014772c4e7b861a85063ec94)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestFormulaStyle",
    jsii_struct_bases=[],
    name_mapping={"palette": "palette", "palette_index": "paletteIndex"},
)
class PowerpackWidgetQueryTableDefinitionRequestFormulaStyle:
    def __init__(
        self,
        *,
        palette: typing.Optional[builtins.str] = None,
        palette_index: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param palette: The color palette used to display the formula. A guide to the available color palettes can be found at https://docs.datadoghq.com/dashboards/guide/widget_colors. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette Powerpack#palette}
        :param palette_index: Index specifying which color to use within the palette. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette_index Powerpack#palette_index}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__40fb9713da94c15c14a8f659803163c1acc55b137ecd3bbd0da40ac54edee15d)
            check_type(argname="argument palette", value=palette, expected_type=type_hints["palette"])
            check_type(argname="argument palette_index", value=palette_index, expected_type=type_hints["palette_index"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if palette is not None:
            self._values["palette"] = palette
        if palette_index is not None:
            self._values["palette_index"] = palette_index

    @builtins.property
    def palette(self) -> typing.Optional[builtins.str]:
        '''The color palette used to display the formula.

        A guide to the available color palettes can be found at https://docs.datadoghq.com/dashboards/guide/widget_colors.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette Powerpack#palette}
        '''
        result = self._values.get("palette")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def palette_index(self) -> typing.Optional[jsii.Number]:
        '''Index specifying which color to use within the palette.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette_index Powerpack#palette_index}
        '''
        result = self._values.get("palette_index")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryTableDefinitionRequestFormulaStyle(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetQueryTableDefinitionRequestFormulaStyleOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestFormulaStyleOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__944c5939c6ef5cead34d8ce682496077f60a1926ffcf5456e1e4553fc010dfd0)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetPalette")
    def reset_palette(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPalette", []))

    @jsii.member(jsii_name="resetPaletteIndex")
    def reset_palette_index(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPaletteIndex", []))

    @builtins.property
    @jsii.member(jsii_name="paletteIndexInput")
    def palette_index_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "paletteIndexInput"))

    @builtins.property
    @jsii.member(jsii_name="paletteInput")
    def palette_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "paletteInput"))

    @builtins.property
    @jsii.member(jsii_name="palette")
    def palette(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "palette"))

    @palette.setter
    def palette(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__762022e995512bb70471ee2405a121e48cf3c17309acf68939a9e09ea1a0a97e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "palette", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="paletteIndex")
    def palette_index(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "paletteIndex"))

    @palette_index.setter
    def palette_index(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d3f68d39c0b170a199957b2582bc49c570bef0c5e5acb91532d7ea4b4195cbe0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "paletteIndex", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetQueryTableDefinitionRequestFormulaStyle]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryTableDefinitionRequestFormulaStyle], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetQueryTableDefinitionRequestFormulaStyle],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__627361ab2299df459b25f5eb9e42e9d45234cb22a40883fb891cf0be619c0b25)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetQueryTableDefinitionRequestList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__20bdb9f800ab8ed19aebdb359123770627cf4addd3676af083eee7c49193f162)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetQueryTableDefinitionRequestOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b8b0d5dcc71dc390bb8fd80b6e55f15eb3aed30044c03fdb228bb40b4ead0bbb)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetQueryTableDefinitionRequestOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3fe548a77e71f04ca3645fc97c0b240246747d133c2b667ad2a1c991ab83c3ff)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2736037ef790be1335b49eb3f0f42744827e846b7069e97a3d0e4eba4698b3a2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__32ec4206eac397f4b14ee4ef8fa02f6e992159ee3f1b854f4dd757f0e170e3d6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionRequest]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionRequest]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionRequest]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fc3542198b4fd5dd5005c9b6759d923f8a51797d322f5c161abdcdb2b6e19f44)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestLogQuery",
    jsii_struct_bases=[],
    name_mapping={
        "index": "index",
        "compute_query": "computeQuery",
        "group_by": "groupBy",
        "multi_compute": "multiCompute",
        "search_query": "searchQuery",
    },
)
class PowerpackWidgetQueryTableDefinitionRequestLogQuery:
    def __init__(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union["PowerpackWidgetQueryTableDefinitionRequestLogQueryComputeQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetQueryTableDefinitionRequestLogQueryGroupBy", typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetQueryTableDefinitionRequestLogQueryMultiCompute", typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        if isinstance(compute_query, dict):
            compute_query = PowerpackWidgetQueryTableDefinitionRequestLogQueryComputeQuery(**compute_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fbf80a0d93aacdedebc834f151f800c7d74f68a5e72d95f62e03eeccade3f5b2)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
            check_type(argname="argument compute_query", value=compute_query, expected_type=type_hints["compute_query"])
            check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
            check_type(argname="argument multi_compute", value=multi_compute, expected_type=type_hints["multi_compute"])
            check_type(argname="argument search_query", value=search_query, expected_type=type_hints["search_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "index": index,
        }
        if compute_query is not None:
            self._values["compute_query"] = compute_query
        if group_by is not None:
            self._values["group_by"] = group_by
        if multi_compute is not None:
            self._values["multi_compute"] = multi_compute
        if search_query is not None:
            self._values["search_query"] = search_query

    @builtins.property
    def index(self) -> builtins.str:
        '''The name of the index to query.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        '''
        result = self._values.get("index")
        assert result is not None, "Required property 'index' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def compute_query(
        self,
    ) -> typing.Optional["PowerpackWidgetQueryTableDefinitionRequestLogQueryComputeQuery"]:
        '''compute_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        '''
        result = self._values.get("compute_query")
        return typing.cast(typing.Optional["PowerpackWidgetQueryTableDefinitionRequestLogQueryComputeQuery"], result)

    @builtins.property
    def group_by(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetQueryTableDefinitionRequestLogQueryGroupBy"]]]:
        '''group_by block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        '''
        result = self._values.get("group_by")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetQueryTableDefinitionRequestLogQueryGroupBy"]]], result)

    @builtins.property
    def multi_compute(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetQueryTableDefinitionRequestLogQueryMultiCompute"]]]:
        '''multi_compute block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        '''
        result = self._values.get("multi_compute")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetQueryTableDefinitionRequestLogQueryMultiCompute"]]], result)

    @builtins.property
    def search_query(self) -> typing.Optional[builtins.str]:
        '''The search query to use.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        result = self._values.get("search_query")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryTableDefinitionRequestLogQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestLogQueryComputeQuery",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetQueryTableDefinitionRequestLogQueryComputeQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7897d93f8f519fd60a3e2d8066b6f08162b32e1a579048d3bf35eaf31b1f8bb3)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryTableDefinitionRequestLogQueryComputeQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetQueryTableDefinitionRequestLogQueryComputeQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestLogQueryComputeQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b54122b718235fc15d9084aee96b144a58d666284006eff8a0006073b1b0ace2)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e875da36633c4be1e48a8af08a21bc00a7fa23add4afc053372c62b3ec304a1b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0dbcd0c0c6caaa98a86fec8ebef305d37b2678c630b665a9ecc145e1a6147aba)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b0da63d705a9f54ce76264247d9e8ec937fbb1d3149b21f0bce690fae7c06240)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetQueryTableDefinitionRequestLogQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryTableDefinitionRequestLogQueryComputeQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetQueryTableDefinitionRequestLogQueryComputeQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fcd8fdf2e11d5dc1506eb21de7f28c890d021eb47f3c20b23c1b02ab693b0673)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestLogQueryGroupBy",
    jsii_struct_bases=[],
    name_mapping={"facet": "facet", "limit": "limit", "sort_query": "sortQuery"},
)
class PowerpackWidgetQueryTableDefinitionRequestLogQueryGroupBy:
    def __init__(
        self,
        *,
        facet: typing.Optional[builtins.str] = None,
        limit: typing.Optional[jsii.Number] = None,
        sort_query: typing.Optional[typing.Union["PowerpackWidgetQueryTableDefinitionRequestLogQueryGroupBySortQuery", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param limit: The maximum number of items in the group. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param sort_query: sort_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        if isinstance(sort_query, dict):
            sort_query = PowerpackWidgetQueryTableDefinitionRequestLogQueryGroupBySortQuery(**sort_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ea3776cd1d2cdba96896e050f0328f46e93a057a750a43d38691eb2c3d33aae8)
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
            check_type(argname="argument sort_query", value=sort_query, expected_type=type_hints["sort_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if facet is not None:
            self._values["facet"] = facet
        if limit is not None:
            self._values["limit"] = limit
        if sort_query is not None:
            self._values["sort_query"] = sort_query

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def limit(self) -> typing.Optional[jsii.Number]:
        '''The maximum number of items in the group.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        '''
        result = self._values.get("limit")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def sort_query(
        self,
    ) -> typing.Optional["PowerpackWidgetQueryTableDefinitionRequestLogQueryGroupBySortQuery"]:
        '''sort_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        result = self._values.get("sort_query")
        return typing.cast(typing.Optional["PowerpackWidgetQueryTableDefinitionRequestLogQueryGroupBySortQuery"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryTableDefinitionRequestLogQueryGroupBy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetQueryTableDefinitionRequestLogQueryGroupByList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestLogQueryGroupByList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1f8ada28cca6ec54b394f4eab84ed657086c224cc87bddf1e5e636c2fe39f58a)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetQueryTableDefinitionRequestLogQueryGroupByOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__56d4ecf3753318abf55eef03158bcb792d602711e959238e4362aaf52e9b8460)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetQueryTableDefinitionRequestLogQueryGroupByOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fef917689c7e91e38bb2dc9cc30e72619ee09c8f498a47a5961e085868db4490)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__411f2afd727f6c5eb594fbb639e1cae2a0986c5d4095eaaf4e892c449ee7f3e6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__363266372e885feb54151c00878ee27fff057fd375980b424fa593bfa521addc)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionRequestLogQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionRequestLogQueryGroupBy]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionRequestLogQueryGroupBy]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__380e983ef2a710cbfe7c88aa1970cc0cc1d812bde6bb264d1749a09bfec14c1d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetQueryTableDefinitionRequestLogQueryGroupByOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestLogQueryGroupByOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4cf8d084044c9e9718793ee037c4af7c5a506fb9efde2a5b672fa9c5c00add7c)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putSortQuery")
    def put_sort_query(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        value = PowerpackWidgetQueryTableDefinitionRequestLogQueryGroupBySortQuery(
            aggregation=aggregation, order=order, facet=facet
        )

        return typing.cast(None, jsii.invoke(self, "putSortQuery", [value]))

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetLimit")
    def reset_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLimit", []))

    @jsii.member(jsii_name="resetSortQuery")
    def reset_sort_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSortQuery", []))

    @builtins.property
    @jsii.member(jsii_name="sortQuery")
    def sort_query(
        self,
    ) -> "PowerpackWidgetQueryTableDefinitionRequestLogQueryGroupBySortQueryOutputReference":
        return typing.cast("PowerpackWidgetQueryTableDefinitionRequestLogQueryGroupBySortQueryOutputReference", jsii.get(self, "sortQuery"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="limitInput")
    def limit_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "limitInput"))

    @builtins.property
    @jsii.member(jsii_name="sortQueryInput")
    def sort_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetQueryTableDefinitionRequestLogQueryGroupBySortQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetQueryTableDefinitionRequestLogQueryGroupBySortQuery"], jsii.get(self, "sortQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6abe64ba4adc306f31ba02d2607a63aad84e7d89c176e4c77499aa4657b54336)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="limit")
    def limit(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "limit"))

    @limit.setter
    def limit(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3c9e0994f9c3e7e2a041353b5ca08ae832a162ce3fc5b6fcb73ebaf8be30067e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "limit", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryTableDefinitionRequestLogQueryGroupBy]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryTableDefinitionRequestLogQueryGroupBy]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryTableDefinitionRequestLogQueryGroupBy]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__73d796361a581c1061ebcefbbaaa8fe6382d2c5969a6ef5d2d1bfb1b127a7d44)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestLogQueryGroupBySortQuery",
    jsii_struct_bases=[],
    name_mapping={"aggregation": "aggregation", "order": "order", "facet": "facet"},
)
class PowerpackWidgetQueryTableDefinitionRequestLogQueryGroupBySortQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__45733c902c6dd9c946d624acad6e2ef83d9f325ddb07f15ce3c95e51aa2a1656)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument order", value=order, expected_type=type_hints["order"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
            "order": order,
        }
        if facet is not None:
            self._values["facet"] = facet

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def order(self) -> builtins.str:
        '''Widget sorting methods. Valid values are ``asc``, ``desc``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        result = self._values.get("order")
        assert result is not None, "Required property 'order' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryTableDefinitionRequestLogQueryGroupBySortQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetQueryTableDefinitionRequestLogQueryGroupBySortQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestLogQueryGroupBySortQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bee115771a1b2ed16b1588e15264bb8e1a6f7c4c6310debb2e5a57ca2364f6b0)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="orderInput")
    def order_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "orderInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3bb08b54d8c70b3810776feb01e56f4c7a4019aa1dc2b0053d828c419c67fd40)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6276070f9bd6ae8b142395702050f6327279acce7b5761cae00332e3043859bf)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="order")
    def order(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "order"))

    @order.setter
    def order(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5aff92ab2ead4eb35b4d37d44b63b1ee203d1d0ba0a6bdee4e692a4f2d6122eb)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "order", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetQueryTableDefinitionRequestLogQueryGroupBySortQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryTableDefinitionRequestLogQueryGroupBySortQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetQueryTableDefinitionRequestLogQueryGroupBySortQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__94b37e306ead7c2f7ae35ce234b701dff936524d6835a0220167d95243ab6442)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestLogQueryMultiCompute",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetQueryTableDefinitionRequestLogQueryMultiCompute:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1b2647f88650578c9f4ace8dea223fe3ef22f69a50dd387b0aa98fa728565eb3)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryTableDefinitionRequestLogQueryMultiCompute(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetQueryTableDefinitionRequestLogQueryMultiComputeList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestLogQueryMultiComputeList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__78e7034356f3f9213588af6c2afa817cae2e24c1fa832ede493c3ca0e1882a50)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetQueryTableDefinitionRequestLogQueryMultiComputeOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__79dc39aa80148a457fe21808c8d11d801c62ed3efebd3f4a0348e1e91aa0c708)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetQueryTableDefinitionRequestLogQueryMultiComputeOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__852e2b001e25d818759812b16f7b300a9cd737fc95e4df0382a6a053b10086b3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0cd764251ad7bc104e9e07680da391a719af26773955dc646d88812e3de94fc1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f01eb1ba8aa697d90750df114286f8281ae2c1f45f131a18e96d150c92d110f9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionRequestLogQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionRequestLogQueryMultiCompute]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionRequestLogQueryMultiCompute]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d6ddd693381ec587e3d39cf5ac712b4e73951537cfaaad8e5edaf02884bf78f4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetQueryTableDefinitionRequestLogQueryMultiComputeOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestLogQueryMultiComputeOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__43b4dfb0728c2c5f83db638d2a2f6b311fcc9048a91adce0ce4fe5144ca6aaf4)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a8d206bb1895e49926f00cf30dbf9f9b4c09c5cfacb6eb9145a5950298cdee9e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c963f4d3e4b3beb530744d9ccac59e9e878b2dca71df4fb66f29d60e60485dc8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0639ff82942ce74e7ee54daad7773e580566d811f211219d42b76a3db2871e81)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryTableDefinitionRequestLogQueryMultiCompute]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryTableDefinitionRequestLogQueryMultiCompute]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryTableDefinitionRequestLogQueryMultiCompute]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3a60e0f86da9a68c54dfeeba1d77881ca6ba671a69eeb2d69bfed9be425a0f0f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetQueryTableDefinitionRequestLogQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestLogQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__54ce6e5d1f37d27af9bd5ed101a2d80c00b65917f637ffb3205f9ac993802455)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putComputeQuery")
    def put_compute_query(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        value = PowerpackWidgetQueryTableDefinitionRequestLogQueryComputeQuery(
            aggregation=aggregation, facet=facet, interval=interval
        )

        return typing.cast(None, jsii.invoke(self, "putComputeQuery", [value]))

    @jsii.member(jsii_name="putGroupBy")
    def put_group_by(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryTableDefinitionRequestLogQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__896dbe03d7d2d84f6b8a29aadda818b902f7027b15025a6f987fa6443f775e9f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putGroupBy", [value]))

    @jsii.member(jsii_name="putMultiCompute")
    def put_multi_compute(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryTableDefinitionRequestLogQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ed18e8dcf1f67f677315247ceb2f1e0f3be526f8a2b6874e4daddde44f3c869e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putMultiCompute", [value]))

    @jsii.member(jsii_name="resetComputeQuery")
    def reset_compute_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetComputeQuery", []))

    @jsii.member(jsii_name="resetGroupBy")
    def reset_group_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGroupBy", []))

    @jsii.member(jsii_name="resetMultiCompute")
    def reset_multi_compute(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMultiCompute", []))

    @jsii.member(jsii_name="resetSearchQuery")
    def reset_search_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSearchQuery", []))

    @builtins.property
    @jsii.member(jsii_name="computeQuery")
    def compute_query(
        self,
    ) -> PowerpackWidgetQueryTableDefinitionRequestLogQueryComputeQueryOutputReference:
        return typing.cast(PowerpackWidgetQueryTableDefinitionRequestLogQueryComputeQueryOutputReference, jsii.get(self, "computeQuery"))

    @builtins.property
    @jsii.member(jsii_name="groupBy")
    def group_by(self) -> PowerpackWidgetQueryTableDefinitionRequestLogQueryGroupByList:
        return typing.cast(PowerpackWidgetQueryTableDefinitionRequestLogQueryGroupByList, jsii.get(self, "groupBy"))

    @builtins.property
    @jsii.member(jsii_name="multiCompute")
    def multi_compute(
        self,
    ) -> PowerpackWidgetQueryTableDefinitionRequestLogQueryMultiComputeList:
        return typing.cast(PowerpackWidgetQueryTableDefinitionRequestLogQueryMultiComputeList, jsii.get(self, "multiCompute"))

    @builtins.property
    @jsii.member(jsii_name="computeQueryInput")
    def compute_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetQueryTableDefinitionRequestLogQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryTableDefinitionRequestLogQueryComputeQuery], jsii.get(self, "computeQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="groupByInput")
    def group_by_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionRequestLogQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionRequestLogQueryGroupBy]]], jsii.get(self, "groupByInput"))

    @builtins.property
    @jsii.member(jsii_name="indexInput")
    def index_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "indexInput"))

    @builtins.property
    @jsii.member(jsii_name="multiComputeInput")
    def multi_compute_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionRequestLogQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionRequestLogQueryMultiCompute]]], jsii.get(self, "multiComputeInput"))

    @builtins.property
    @jsii.member(jsii_name="searchQueryInput")
    def search_query_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "searchQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="index")
    def index(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "index"))

    @index.setter
    def index(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9473779c8e64850d0226443468707fa7f9987c6c074a2167c86e05450e7c7c98)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "index", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="searchQuery")
    def search_query(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "searchQuery"))

    @search_query.setter
    def search_query(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ca24a81ad2df9daa31f487d411d34e5699c8256695f192d4f4fdfcbddbbeaf4e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "searchQuery", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetQueryTableDefinitionRequestLogQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryTableDefinitionRequestLogQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetQueryTableDefinitionRequestLogQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__05b89ca7abf4b20537db51b8fc6fd5551a7be2bfa4576c0279d2a616f6707d60)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetQueryTableDefinitionRequestOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__58b684aaf1d754509fbba3cdec8fb103b47cd4dbb3703b38d3f35073d0a067ec)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putApmQuery")
    def put_apm_query(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union[PowerpackWidgetQueryTableDefinitionRequestApmQueryComputeQuery, typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryTableDefinitionRequestApmQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryTableDefinitionRequestApmQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        value = PowerpackWidgetQueryTableDefinitionRequestApmQuery(
            index=index,
            compute_query=compute_query,
            group_by=group_by,
            multi_compute=multi_compute,
            search_query=search_query,
        )

        return typing.cast(None, jsii.invoke(self, "putApmQuery", [value]))

    @jsii.member(jsii_name="putApmStatsQuery")
    def put_apm_stats_query(
        self,
        *,
        env: builtins.str,
        name: builtins.str,
        primary_tag: builtins.str,
        row_type: builtins.str,
        service: builtins.str,
        columns: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryTableDefinitionRequestApmStatsQueryColumns, typing.Dict[builtins.str, typing.Any]]]]] = None,
        resource: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param env: The environment name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#env Powerpack#env}
        :param name: The operation name associated with the service. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param primary_tag: The organization's host group name and value. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag Powerpack#primary_tag}
        :param row_type: The level of detail for the request. Valid values are ``service``, ``resource``, ``span``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#row_type Powerpack#row_type}
        :param service: The service name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#service Powerpack#service}
        :param columns: columns block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#columns Powerpack#columns}
        :param resource: The resource name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#resource Powerpack#resource}
        '''
        value = PowerpackWidgetQueryTableDefinitionRequestApmStatsQuery(
            env=env,
            name=name,
            primary_tag=primary_tag,
            row_type=row_type,
            service=service,
            columns=columns,
            resource=resource,
        )

        return typing.cast(None, jsii.invoke(self, "putApmStatsQuery", [value]))

    @jsii.member(jsii_name="putConditionalFormats")
    def put_conditional_formats(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryTableDefinitionRequestConditionalFormats, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d79faffce65de29dc82743fc9dd0808d853cb5b97409c48ae85d6627c0501b34)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putConditionalFormats", [value]))

    @jsii.member(jsii_name="putFormula")
    def put_formula(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryTableDefinitionRequestFormula, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2761e6701c91473ab513448e52ecf27f5e2e85a987c0cf5c4f9bb2dea39f7a9a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putFormula", [value]))

    @jsii.member(jsii_name="putLogQuery")
    def put_log_query(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union[PowerpackWidgetQueryTableDefinitionRequestLogQueryComputeQuery, typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryTableDefinitionRequestLogQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryTableDefinitionRequestLogQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        value = PowerpackWidgetQueryTableDefinitionRequestLogQuery(
            index=index,
            compute_query=compute_query,
            group_by=group_by,
            multi_compute=multi_compute,
            search_query=search_query,
        )

        return typing.cast(None, jsii.invoke(self, "putLogQuery", [value]))

    @jsii.member(jsii_name="putProcessQuery")
    def put_process_query(
        self,
        *,
        metric: builtins.str,
        filter_by: typing.Optional[typing.Sequence[builtins.str]] = None,
        limit: typing.Optional[jsii.Number] = None,
        search_by: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param metric: Your chosen metric. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        :param filter_by: A list of processes. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#filter_by Powerpack#filter_by}
        :param limit: The max number of items in the filter list. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param search_by: Your chosen search term. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_by Powerpack#search_by}
        '''
        value = PowerpackWidgetQueryTableDefinitionRequestProcessQuery(
            metric=metric, filter_by=filter_by, limit=limit, search_by=search_by
        )

        return typing.cast(None, jsii.invoke(self, "putProcessQuery", [value]))

    @jsii.member(jsii_name="putQuery")
    def put_query(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetQueryTableDefinitionRequestQuery", typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__11cb3c89728a5338836fa4b230709c29386503a764469000bdd226e1b454dff0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putQuery", [value]))

    @jsii.member(jsii_name="putRumQuery")
    def put_rum_query(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union["PowerpackWidgetQueryTableDefinitionRequestRumQueryComputeQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetQueryTableDefinitionRequestRumQueryGroupBy", typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetQueryTableDefinitionRequestRumQueryMultiCompute", typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        value = PowerpackWidgetQueryTableDefinitionRequestRumQuery(
            index=index,
            compute_query=compute_query,
            group_by=group_by,
            multi_compute=multi_compute,
            search_query=search_query,
        )

        return typing.cast(None, jsii.invoke(self, "putRumQuery", [value]))

    @jsii.member(jsii_name="putSecurityQuery")
    def put_security_query(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union["PowerpackWidgetQueryTableDefinitionRequestSecurityQueryComputeQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetQueryTableDefinitionRequestSecurityQueryGroupBy", typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetQueryTableDefinitionRequestSecurityQueryMultiCompute", typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        value = PowerpackWidgetQueryTableDefinitionRequestSecurityQuery(
            index=index,
            compute_query=compute_query,
            group_by=group_by,
            multi_compute=multi_compute,
            search_query=search_query,
        )

        return typing.cast(None, jsii.invoke(self, "putSecurityQuery", [value]))

    @jsii.member(jsii_name="putTextFormats")
    def put_text_formats(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetQueryTableDefinitionRequestTextFormats", typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__08c0babebe6043e73dd2fe9ef29e89ff60dc9e588df4c3700c23f074ec27ee7d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putTextFormats", [value]))

    @jsii.member(jsii_name="resetAggregator")
    def reset_aggregator(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAggregator", []))

    @jsii.member(jsii_name="resetAlias")
    def reset_alias(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAlias", []))

    @jsii.member(jsii_name="resetApmQuery")
    def reset_apm_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetApmQuery", []))

    @jsii.member(jsii_name="resetApmStatsQuery")
    def reset_apm_stats_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetApmStatsQuery", []))

    @jsii.member(jsii_name="resetCellDisplayMode")
    def reset_cell_display_mode(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCellDisplayMode", []))

    @jsii.member(jsii_name="resetConditionalFormats")
    def reset_conditional_formats(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetConditionalFormats", []))

    @jsii.member(jsii_name="resetFormula")
    def reset_formula(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFormula", []))

    @jsii.member(jsii_name="resetLimit")
    def reset_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLimit", []))

    @jsii.member(jsii_name="resetLogQuery")
    def reset_log_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLogQuery", []))

    @jsii.member(jsii_name="resetOrder")
    def reset_order(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetOrder", []))

    @jsii.member(jsii_name="resetProcessQuery")
    def reset_process_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetProcessQuery", []))

    @jsii.member(jsii_name="resetQ")
    def reset_q(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetQ", []))

    @jsii.member(jsii_name="resetQuery")
    def reset_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetQuery", []))

    @jsii.member(jsii_name="resetRumQuery")
    def reset_rum_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetRumQuery", []))

    @jsii.member(jsii_name="resetSecurityQuery")
    def reset_security_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSecurityQuery", []))

    @jsii.member(jsii_name="resetTextFormats")
    def reset_text_formats(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTextFormats", []))

    @builtins.property
    @jsii.member(jsii_name="apmQuery")
    def apm_query(
        self,
    ) -> PowerpackWidgetQueryTableDefinitionRequestApmQueryOutputReference:
        return typing.cast(PowerpackWidgetQueryTableDefinitionRequestApmQueryOutputReference, jsii.get(self, "apmQuery"))

    @builtins.property
    @jsii.member(jsii_name="apmStatsQuery")
    def apm_stats_query(
        self,
    ) -> PowerpackWidgetQueryTableDefinitionRequestApmStatsQueryOutputReference:
        return typing.cast(PowerpackWidgetQueryTableDefinitionRequestApmStatsQueryOutputReference, jsii.get(self, "apmStatsQuery"))

    @builtins.property
    @jsii.member(jsii_name="conditionalFormats")
    def conditional_formats(
        self,
    ) -> PowerpackWidgetQueryTableDefinitionRequestConditionalFormatsList:
        return typing.cast(PowerpackWidgetQueryTableDefinitionRequestConditionalFormatsList, jsii.get(self, "conditionalFormats"))

    @builtins.property
    @jsii.member(jsii_name="formula")
    def formula(self) -> PowerpackWidgetQueryTableDefinitionRequestFormulaList:
        return typing.cast(PowerpackWidgetQueryTableDefinitionRequestFormulaList, jsii.get(self, "formula"))

    @builtins.property
    @jsii.member(jsii_name="logQuery")
    def log_query(
        self,
    ) -> PowerpackWidgetQueryTableDefinitionRequestLogQueryOutputReference:
        return typing.cast(PowerpackWidgetQueryTableDefinitionRequestLogQueryOutputReference, jsii.get(self, "logQuery"))

    @builtins.property
    @jsii.member(jsii_name="processQuery")
    def process_query(
        self,
    ) -> "PowerpackWidgetQueryTableDefinitionRequestProcessQueryOutputReference":
        return typing.cast("PowerpackWidgetQueryTableDefinitionRequestProcessQueryOutputReference", jsii.get(self, "processQuery"))

    @builtins.property
    @jsii.member(jsii_name="query")
    def query(self) -> "PowerpackWidgetQueryTableDefinitionRequestQueryList":
        return typing.cast("PowerpackWidgetQueryTableDefinitionRequestQueryList", jsii.get(self, "query"))

    @builtins.property
    @jsii.member(jsii_name="rumQuery")
    def rum_query(
        self,
    ) -> "PowerpackWidgetQueryTableDefinitionRequestRumQueryOutputReference":
        return typing.cast("PowerpackWidgetQueryTableDefinitionRequestRumQueryOutputReference", jsii.get(self, "rumQuery"))

    @builtins.property
    @jsii.member(jsii_name="securityQuery")
    def security_query(
        self,
    ) -> "PowerpackWidgetQueryTableDefinitionRequestSecurityQueryOutputReference":
        return typing.cast("PowerpackWidgetQueryTableDefinitionRequestSecurityQueryOutputReference", jsii.get(self, "securityQuery"))

    @builtins.property
    @jsii.member(jsii_name="textFormats")
    def text_formats(
        self,
    ) -> "PowerpackWidgetQueryTableDefinitionRequestTextFormatsList":
        return typing.cast("PowerpackWidgetQueryTableDefinitionRequestTextFormatsList", jsii.get(self, "textFormats"))

    @builtins.property
    @jsii.member(jsii_name="aggregatorInput")
    def aggregator_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregatorInput"))

    @builtins.property
    @jsii.member(jsii_name="aliasInput")
    def alias_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aliasInput"))

    @builtins.property
    @jsii.member(jsii_name="apmQueryInput")
    def apm_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetQueryTableDefinitionRequestApmQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryTableDefinitionRequestApmQuery], jsii.get(self, "apmQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="apmStatsQueryInput")
    def apm_stats_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetQueryTableDefinitionRequestApmStatsQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryTableDefinitionRequestApmStatsQuery], jsii.get(self, "apmStatsQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="cellDisplayModeInput")
    def cell_display_mode_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "cellDisplayModeInput"))

    @builtins.property
    @jsii.member(jsii_name="conditionalFormatsInput")
    def conditional_formats_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionRequestConditionalFormats]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionRequestConditionalFormats]]], jsii.get(self, "conditionalFormatsInput"))

    @builtins.property
    @jsii.member(jsii_name="formulaInput")
    def formula_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionRequestFormula]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionRequestFormula]]], jsii.get(self, "formulaInput"))

    @builtins.property
    @jsii.member(jsii_name="limitInput")
    def limit_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "limitInput"))

    @builtins.property
    @jsii.member(jsii_name="logQueryInput")
    def log_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetQueryTableDefinitionRequestLogQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryTableDefinitionRequestLogQuery], jsii.get(self, "logQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="orderInput")
    def order_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "orderInput"))

    @builtins.property
    @jsii.member(jsii_name="processQueryInput")
    def process_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetQueryTableDefinitionRequestProcessQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetQueryTableDefinitionRequestProcessQuery"], jsii.get(self, "processQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="qInput")
    def q_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "qInput"))

    @builtins.property
    @jsii.member(jsii_name="queryInput")
    def query_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetQueryTableDefinitionRequestQuery"]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetQueryTableDefinitionRequestQuery"]]], jsii.get(self, "queryInput"))

    @builtins.property
    @jsii.member(jsii_name="rumQueryInput")
    def rum_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetQueryTableDefinitionRequestRumQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetQueryTableDefinitionRequestRumQuery"], jsii.get(self, "rumQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="securityQueryInput")
    def security_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetQueryTableDefinitionRequestSecurityQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetQueryTableDefinitionRequestSecurityQuery"], jsii.get(self, "securityQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="textFormatsInput")
    def text_formats_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetQueryTableDefinitionRequestTextFormats"]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetQueryTableDefinitionRequestTextFormats"]]], jsii.get(self, "textFormatsInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregator")
    def aggregator(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregator"))

    @aggregator.setter
    def aggregator(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f56380a0304f3854f3a52687d3aefc78f35b1efb65dd4dabde35a21a70630161)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregator", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="alias")
    def alias(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "alias"))

    @alias.setter
    def alias(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0a01ba3e380300160e6677ec9055f91d0fb54d7e99f84992356dea97d8483e21)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "alias", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="cellDisplayMode")
    def cell_display_mode(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "cellDisplayMode"))

    @cell_display_mode.setter
    def cell_display_mode(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__175c54cca84e2b5ffb31dcad72d944f766468ae8154d4f66e6808676e68edcf2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "cellDisplayMode", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="limit")
    def limit(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "limit"))

    @limit.setter
    def limit(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__759d29c41d6c9b21a34ca3583d21563178873457e3eae1387003b966ade9bb4d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "limit", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="order")
    def order(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "order"))

    @order.setter
    def order(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1141994aee0ef697d8c4c199aae201c4d88206c966aec13de74eff82bb6b4e77)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "order", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="q")
    def q(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "q"))

    @q.setter
    def q(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__adc91ba07fa4fb88f3d43aa9cb0d126679c63d803a88a2d2eb3e9cafa637b5d4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "q", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryTableDefinitionRequest]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryTableDefinitionRequest]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryTableDefinitionRequest]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8d4b758193acd28763491169221ef38b225666dfa501d55bedd794a5f47d79d8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestProcessQuery",
    jsii_struct_bases=[],
    name_mapping={
        "metric": "metric",
        "filter_by": "filterBy",
        "limit": "limit",
        "search_by": "searchBy",
    },
)
class PowerpackWidgetQueryTableDefinitionRequestProcessQuery:
    def __init__(
        self,
        *,
        metric: builtins.str,
        filter_by: typing.Optional[typing.Sequence[builtins.str]] = None,
        limit: typing.Optional[jsii.Number] = None,
        search_by: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param metric: Your chosen metric. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        :param filter_by: A list of processes. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#filter_by Powerpack#filter_by}
        :param limit: The max number of items in the filter list. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param search_by: Your chosen search term. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_by Powerpack#search_by}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8ca6c475810ad3e89bea42427788a237f73775535babe4df49d435e77b3a3b98)
            check_type(argname="argument metric", value=metric, expected_type=type_hints["metric"])
            check_type(argname="argument filter_by", value=filter_by, expected_type=type_hints["filter_by"])
            check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
            check_type(argname="argument search_by", value=search_by, expected_type=type_hints["search_by"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "metric": metric,
        }
        if filter_by is not None:
            self._values["filter_by"] = filter_by
        if limit is not None:
            self._values["limit"] = limit
        if search_by is not None:
            self._values["search_by"] = search_by

    @builtins.property
    def metric(self) -> builtins.str:
        '''Your chosen metric.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        '''
        result = self._values.get("metric")
        assert result is not None, "Required property 'metric' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def filter_by(self) -> typing.Optional[typing.List[builtins.str]]:
        '''A list of processes.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#filter_by Powerpack#filter_by}
        '''
        result = self._values.get("filter_by")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def limit(self) -> typing.Optional[jsii.Number]:
        '''The max number of items in the filter list.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        '''
        result = self._values.get("limit")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def search_by(self) -> typing.Optional[builtins.str]:
        '''Your chosen search term.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_by Powerpack#search_by}
        '''
        result = self._values.get("search_by")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryTableDefinitionRequestProcessQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetQueryTableDefinitionRequestProcessQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestProcessQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__29aac02f7b028bac0715b30eddb5f93e063e71628e013d40638b10a831ec321a)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFilterBy")
    def reset_filter_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFilterBy", []))

    @jsii.member(jsii_name="resetLimit")
    def reset_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLimit", []))

    @jsii.member(jsii_name="resetSearchBy")
    def reset_search_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSearchBy", []))

    @builtins.property
    @jsii.member(jsii_name="filterByInput")
    def filter_by_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "filterByInput"))

    @builtins.property
    @jsii.member(jsii_name="limitInput")
    def limit_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "limitInput"))

    @builtins.property
    @jsii.member(jsii_name="metricInput")
    def metric_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "metricInput"))

    @builtins.property
    @jsii.member(jsii_name="searchByInput")
    def search_by_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "searchByInput"))

    @builtins.property
    @jsii.member(jsii_name="filterBy")
    def filter_by(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "filterBy"))

    @filter_by.setter
    def filter_by(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__86465005af0e09908940b067be330eb9d12b53d63b154cc54303069e86ebbebd)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "filterBy", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="limit")
    def limit(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "limit"))

    @limit.setter
    def limit(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__15c5ef7c83aeacedf3970f86f4b275fb8500e37db06d02c8487afd7558dfa64c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "limit", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="metric")
    def metric(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "metric"))

    @metric.setter
    def metric(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ef11c1591a32c778e722e76252fa7200bf13e40b81d38d57f738765a0c0aef81)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "metric", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="searchBy")
    def search_by(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "searchBy"))

    @search_by.setter
    def search_by(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d3ddc19d2fd8df6e794f56e6fad371b694b99ad04f879a41d54a1e14b83451bb)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "searchBy", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetQueryTableDefinitionRequestProcessQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryTableDefinitionRequestProcessQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetQueryTableDefinitionRequestProcessQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a36c7675eea94b6570907ff265ce02ffef5808f617f5917434e43135e4adf64d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestQuery",
    jsii_struct_bases=[],
    name_mapping={
        "apm_dependency_stats_query": "apmDependencyStatsQuery",
        "apm_resource_stats_query": "apmResourceStatsQuery",
        "cloud_cost_query": "cloudCostQuery",
        "event_query": "eventQuery",
        "metric_query": "metricQuery",
        "process_query": "processQuery",
        "slo_query": "sloQuery",
    },
)
class PowerpackWidgetQueryTableDefinitionRequestQuery:
    def __init__(
        self,
        *,
        apm_dependency_stats_query: typing.Optional[typing.Union["PowerpackWidgetQueryTableDefinitionRequestQueryApmDependencyStatsQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        apm_resource_stats_query: typing.Optional[typing.Union["PowerpackWidgetQueryTableDefinitionRequestQueryApmResourceStatsQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        cloud_cost_query: typing.Optional[typing.Union["PowerpackWidgetQueryTableDefinitionRequestQueryCloudCostQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        event_query: typing.Optional[typing.Union["PowerpackWidgetQueryTableDefinitionRequestQueryEventQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        metric_query: typing.Optional[typing.Union["PowerpackWidgetQueryTableDefinitionRequestQueryMetricQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        process_query: typing.Optional[typing.Union["PowerpackWidgetQueryTableDefinitionRequestQueryProcessQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        slo_query: typing.Optional[typing.Union["PowerpackWidgetQueryTableDefinitionRequestQuerySloQuery", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param apm_dependency_stats_query: apm_dependency_stats_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#apm_dependency_stats_query Powerpack#apm_dependency_stats_query}
        :param apm_resource_stats_query: apm_resource_stats_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#apm_resource_stats_query Powerpack#apm_resource_stats_query}
        :param cloud_cost_query: cloud_cost_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cloud_cost_query Powerpack#cloud_cost_query}
        :param event_query: event_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#event_query Powerpack#event_query}
        :param metric_query: metric_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric_query Powerpack#metric_query}
        :param process_query: process_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#process_query Powerpack#process_query}
        :param slo_query: slo_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#slo_query Powerpack#slo_query}
        '''
        if isinstance(apm_dependency_stats_query, dict):
            apm_dependency_stats_query = PowerpackWidgetQueryTableDefinitionRequestQueryApmDependencyStatsQuery(**apm_dependency_stats_query)
        if isinstance(apm_resource_stats_query, dict):
            apm_resource_stats_query = PowerpackWidgetQueryTableDefinitionRequestQueryApmResourceStatsQuery(**apm_resource_stats_query)
        if isinstance(cloud_cost_query, dict):
            cloud_cost_query = PowerpackWidgetQueryTableDefinitionRequestQueryCloudCostQuery(**cloud_cost_query)
        if isinstance(event_query, dict):
            event_query = PowerpackWidgetQueryTableDefinitionRequestQueryEventQuery(**event_query)
        if isinstance(metric_query, dict):
            metric_query = PowerpackWidgetQueryTableDefinitionRequestQueryMetricQuery(**metric_query)
        if isinstance(process_query, dict):
            process_query = PowerpackWidgetQueryTableDefinitionRequestQueryProcessQuery(**process_query)
        if isinstance(slo_query, dict):
            slo_query = PowerpackWidgetQueryTableDefinitionRequestQuerySloQuery(**slo_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__73174199126ef72cb5aa991cb144a39fc47bfba7449a9db5de2943baed19dc2e)
            check_type(argname="argument apm_dependency_stats_query", value=apm_dependency_stats_query, expected_type=type_hints["apm_dependency_stats_query"])
            check_type(argname="argument apm_resource_stats_query", value=apm_resource_stats_query, expected_type=type_hints["apm_resource_stats_query"])
            check_type(argname="argument cloud_cost_query", value=cloud_cost_query, expected_type=type_hints["cloud_cost_query"])
            check_type(argname="argument event_query", value=event_query, expected_type=type_hints["event_query"])
            check_type(argname="argument metric_query", value=metric_query, expected_type=type_hints["metric_query"])
            check_type(argname="argument process_query", value=process_query, expected_type=type_hints["process_query"])
            check_type(argname="argument slo_query", value=slo_query, expected_type=type_hints["slo_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if apm_dependency_stats_query is not None:
            self._values["apm_dependency_stats_query"] = apm_dependency_stats_query
        if apm_resource_stats_query is not None:
            self._values["apm_resource_stats_query"] = apm_resource_stats_query
        if cloud_cost_query is not None:
            self._values["cloud_cost_query"] = cloud_cost_query
        if event_query is not None:
            self._values["event_query"] = event_query
        if metric_query is not None:
            self._values["metric_query"] = metric_query
        if process_query is not None:
            self._values["process_query"] = process_query
        if slo_query is not None:
            self._values["slo_query"] = slo_query

    @builtins.property
    def apm_dependency_stats_query(
        self,
    ) -> typing.Optional["PowerpackWidgetQueryTableDefinitionRequestQueryApmDependencyStatsQuery"]:
        '''apm_dependency_stats_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#apm_dependency_stats_query Powerpack#apm_dependency_stats_query}
        '''
        result = self._values.get("apm_dependency_stats_query")
        return typing.cast(typing.Optional["PowerpackWidgetQueryTableDefinitionRequestQueryApmDependencyStatsQuery"], result)

    @builtins.property
    def apm_resource_stats_query(
        self,
    ) -> typing.Optional["PowerpackWidgetQueryTableDefinitionRequestQueryApmResourceStatsQuery"]:
        '''apm_resource_stats_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#apm_resource_stats_query Powerpack#apm_resource_stats_query}
        '''
        result = self._values.get("apm_resource_stats_query")
        return typing.cast(typing.Optional["PowerpackWidgetQueryTableDefinitionRequestQueryApmResourceStatsQuery"], result)

    @builtins.property
    def cloud_cost_query(
        self,
    ) -> typing.Optional["PowerpackWidgetQueryTableDefinitionRequestQueryCloudCostQuery"]:
        '''cloud_cost_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cloud_cost_query Powerpack#cloud_cost_query}
        '''
        result = self._values.get("cloud_cost_query")
        return typing.cast(typing.Optional["PowerpackWidgetQueryTableDefinitionRequestQueryCloudCostQuery"], result)

    @builtins.property
    def event_query(
        self,
    ) -> typing.Optional["PowerpackWidgetQueryTableDefinitionRequestQueryEventQuery"]:
        '''event_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#event_query Powerpack#event_query}
        '''
        result = self._values.get("event_query")
        return typing.cast(typing.Optional["PowerpackWidgetQueryTableDefinitionRequestQueryEventQuery"], result)

    @builtins.property
    def metric_query(
        self,
    ) -> typing.Optional["PowerpackWidgetQueryTableDefinitionRequestQueryMetricQuery"]:
        '''metric_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric_query Powerpack#metric_query}
        '''
        result = self._values.get("metric_query")
        return typing.cast(typing.Optional["PowerpackWidgetQueryTableDefinitionRequestQueryMetricQuery"], result)

    @builtins.property
    def process_query(
        self,
    ) -> typing.Optional["PowerpackWidgetQueryTableDefinitionRequestQueryProcessQuery"]:
        '''process_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#process_query Powerpack#process_query}
        '''
        result = self._values.get("process_query")
        return typing.cast(typing.Optional["PowerpackWidgetQueryTableDefinitionRequestQueryProcessQuery"], result)

    @builtins.property
    def slo_query(
        self,
    ) -> typing.Optional["PowerpackWidgetQueryTableDefinitionRequestQuerySloQuery"]:
        '''slo_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#slo_query Powerpack#slo_query}
        '''
        result = self._values.get("slo_query")
        return typing.cast(typing.Optional["PowerpackWidgetQueryTableDefinitionRequestQuerySloQuery"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryTableDefinitionRequestQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestQueryApmDependencyStatsQuery",
    jsii_struct_bases=[],
    name_mapping={
        "data_source": "dataSource",
        "env": "env",
        "name": "name",
        "operation_name": "operationName",
        "resource_name": "resourceName",
        "service": "service",
        "stat": "stat",
        "cross_org_uuids": "crossOrgUuids",
        "is_upstream": "isUpstream",
        "primary_tag_name": "primaryTagName",
        "primary_tag_value": "primaryTagValue",
    },
)
class PowerpackWidgetQueryTableDefinitionRequestQueryApmDependencyStatsQuery:
    def __init__(
        self,
        *,
        data_source: builtins.str,
        env: builtins.str,
        name: builtins.str,
        operation_name: builtins.str,
        resource_name: builtins.str,
        service: builtins.str,
        stat: builtins.str,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        is_upstream: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        primary_tag_name: typing.Optional[builtins.str] = None,
        primary_tag_value: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param data_source: The data source for APM Dependency Stats queries. Valid values are ``apm_dependency_stats``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param env: APM environment. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#env Powerpack#env}
        :param name: The name of query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param operation_name: Name of operation on service. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#operation_name Powerpack#operation_name}
        :param resource_name: APM resource. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#resource_name Powerpack#resource_name}
        :param service: APM service. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#service Powerpack#service}
        :param stat: APM statistic. Valid values are ``avg_duration``, ``avg_root_duration``, ``avg_spans_per_trace``, ``error_rate``, ``pct_exec_time``, ``pct_of_traces``, ``total_traces_count``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#stat Powerpack#stat}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param is_upstream: Determines whether stats for upstream or downstream dependencies should be queried. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#is_upstream Powerpack#is_upstream}
        :param primary_tag_name: The name of the second primary tag used within APM; required when ``primary_tag_value`` is specified. See https://docs.datadoghq.com/tracing/guide/setting_primary_tags_to_scope/#add-a-second-primary-tag-in-datadog. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_name Powerpack#primary_tag_name}
        :param primary_tag_value: Filter APM data by the second primary tag. ``primary_tag_name`` must also be specified. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_value Powerpack#primary_tag_value}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a1b9d2358d4936966ef9bd0ee3a01cee706541c0e94896f876c3a7e309353f74)
            check_type(argname="argument data_source", value=data_source, expected_type=type_hints["data_source"])
            check_type(argname="argument env", value=env, expected_type=type_hints["env"])
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument operation_name", value=operation_name, expected_type=type_hints["operation_name"])
            check_type(argname="argument resource_name", value=resource_name, expected_type=type_hints["resource_name"])
            check_type(argname="argument service", value=service, expected_type=type_hints["service"])
            check_type(argname="argument stat", value=stat, expected_type=type_hints["stat"])
            check_type(argname="argument cross_org_uuids", value=cross_org_uuids, expected_type=type_hints["cross_org_uuids"])
            check_type(argname="argument is_upstream", value=is_upstream, expected_type=type_hints["is_upstream"])
            check_type(argname="argument primary_tag_name", value=primary_tag_name, expected_type=type_hints["primary_tag_name"])
            check_type(argname="argument primary_tag_value", value=primary_tag_value, expected_type=type_hints["primary_tag_value"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "data_source": data_source,
            "env": env,
            "name": name,
            "operation_name": operation_name,
            "resource_name": resource_name,
            "service": service,
            "stat": stat,
        }
        if cross_org_uuids is not None:
            self._values["cross_org_uuids"] = cross_org_uuids
        if is_upstream is not None:
            self._values["is_upstream"] = is_upstream
        if primary_tag_name is not None:
            self._values["primary_tag_name"] = primary_tag_name
        if primary_tag_value is not None:
            self._values["primary_tag_value"] = primary_tag_value

    @builtins.property
    def data_source(self) -> builtins.str:
        '''The data source for APM Dependency Stats queries. Valid values are ``apm_dependency_stats``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        '''
        result = self._values.get("data_source")
        assert result is not None, "Required property 'data_source' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def env(self) -> builtins.str:
        '''APM environment.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#env Powerpack#env}
        '''
        result = self._values.get("env")
        assert result is not None, "Required property 'env' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def name(self) -> builtins.str:
        '''The name of query for use in formulas.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        '''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def operation_name(self) -> builtins.str:
        '''Name of operation on service.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#operation_name Powerpack#operation_name}
        '''
        result = self._values.get("operation_name")
        assert result is not None, "Required property 'operation_name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def resource_name(self) -> builtins.str:
        '''APM resource.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#resource_name Powerpack#resource_name}
        '''
        result = self._values.get("resource_name")
        assert result is not None, "Required property 'resource_name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def service(self) -> builtins.str:
        '''APM service.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#service Powerpack#service}
        '''
        result = self._values.get("service")
        assert result is not None, "Required property 'service' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def stat(self) -> builtins.str:
        '''APM statistic. Valid values are ``avg_duration``, ``avg_root_duration``, ``avg_spans_per_trace``, ``error_rate``, ``pct_exec_time``, ``pct_of_traces``, ``total_traces_count``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#stat Powerpack#stat}
        '''
        result = self._values.get("stat")
        assert result is not None, "Required property 'stat' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def cross_org_uuids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''The source organization UUID for cross organization queries. Feature in Private Beta.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        '''
        result = self._values.get("cross_org_uuids")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def is_upstream(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        '''Determines whether stats for upstream or downstream dependencies should be queried.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#is_upstream Powerpack#is_upstream}
        '''
        result = self._values.get("is_upstream")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)

    @builtins.property
    def primary_tag_name(self) -> typing.Optional[builtins.str]:
        '''The name of the second primary tag used within APM; required when ``primary_tag_value`` is specified. See https://docs.datadoghq.com/tracing/guide/setting_primary_tags_to_scope/#add-a-second-primary-tag-in-datadog.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_name Powerpack#primary_tag_name}
        '''
        result = self._values.get("primary_tag_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def primary_tag_value(self) -> typing.Optional[builtins.str]:
        '''Filter APM data by the second primary tag. ``primary_tag_name`` must also be specified.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_value Powerpack#primary_tag_value}
        '''
        result = self._values.get("primary_tag_value")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryTableDefinitionRequestQueryApmDependencyStatsQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetQueryTableDefinitionRequestQueryApmDependencyStatsQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestQueryApmDependencyStatsQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d26d812ca6b51350753d9a3ad585b4120beb7e49a6bf617f86bf78be86282d0b)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetCrossOrgUuids")
    def reset_cross_org_uuids(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCrossOrgUuids", []))

    @jsii.member(jsii_name="resetIsUpstream")
    def reset_is_upstream(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetIsUpstream", []))

    @jsii.member(jsii_name="resetPrimaryTagName")
    def reset_primary_tag_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPrimaryTagName", []))

    @jsii.member(jsii_name="resetPrimaryTagValue")
    def reset_primary_tag_value(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPrimaryTagValue", []))

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuidsInput")
    def cross_org_uuids_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "crossOrgUuidsInput"))

    @builtins.property
    @jsii.member(jsii_name="dataSourceInput")
    def data_source_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "dataSourceInput"))

    @builtins.property
    @jsii.member(jsii_name="envInput")
    def env_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "envInput"))

    @builtins.property
    @jsii.member(jsii_name="isUpstreamInput")
    def is_upstream_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "isUpstreamInput"))

    @builtins.property
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property
    @jsii.member(jsii_name="operationNameInput")
    def operation_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "operationNameInput"))

    @builtins.property
    @jsii.member(jsii_name="primaryTagNameInput")
    def primary_tag_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "primaryTagNameInput"))

    @builtins.property
    @jsii.member(jsii_name="primaryTagValueInput")
    def primary_tag_value_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "primaryTagValueInput"))

    @builtins.property
    @jsii.member(jsii_name="resourceNameInput")
    def resource_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "resourceNameInput"))

    @builtins.property
    @jsii.member(jsii_name="serviceInput")
    def service_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "serviceInput"))

    @builtins.property
    @jsii.member(jsii_name="statInput")
    def stat_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "statInput"))

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuids")
    def cross_org_uuids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "crossOrgUuids"))

    @cross_org_uuids.setter
    def cross_org_uuids(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9a3057f83a027b127aca0ac93d20544a5a326676e07cefff1f4bf14bdfdee59f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "crossOrgUuids", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="dataSource")
    def data_source(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "dataSource"))

    @data_source.setter
    def data_source(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2dbdc39afef3a432c21f4edc9dbcfe4418d61ce529d18030c45160dde60e3d27)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "dataSource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="env")
    def env(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "env"))

    @env.setter
    def env(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e2da9038e85f9888e7ce2b2a1ce8337f7ee86bfcba4463f8bbbf52a122ab8a07)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "env", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="isUpstream")
    def is_upstream(self) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "isUpstream"))

    @is_upstream.setter
    def is_upstream(
        self,
        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0a923904645f56f8c21b98a02998e403a0f42bebf27e860192991907a6386904)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "isUpstream", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bfd7e6698dc39e4994161b98f50ea6d4a3599e4713dc5fbaa08a47932a75d2f3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "name", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="operationName")
    def operation_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "operationName"))

    @operation_name.setter
    def operation_name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cb215f961820a72904a4b2772417b0231451d16584fe107db132c2d02237e669)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "operationName", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="primaryTagName")
    def primary_tag_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "primaryTagName"))

    @primary_tag_name.setter
    def primary_tag_name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__27d0faffdd59b12774b41851bb623036528310b552b28bde695cad08c61382cf)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "primaryTagName", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="primaryTagValue")
    def primary_tag_value(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "primaryTagValue"))

    @primary_tag_value.setter
    def primary_tag_value(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6b815befa03c867b202fcdb30c84c3318d30fac4806d9910a42ee3171f932128)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "primaryTagValue", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="resourceName")
    def resource_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "resourceName"))

    @resource_name.setter
    def resource_name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__566227170711c18137b1fb223985094c5151d79f2e2ec4e4db1ef1c94114240d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "resourceName", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="service")
    def service(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "service"))

    @service.setter
    def service(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cf47d3e2de2d7fb9113cb9837d828088e081b685a82ffd951e438f1fedaff80a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "service", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="stat")
    def stat(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "stat"))

    @stat.setter
    def stat(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__15cfcabcf809f4cda52d73f2e208350f72c2abb22457ba082452a944d9430833)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "stat", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetQueryTableDefinitionRequestQueryApmDependencyStatsQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryTableDefinitionRequestQueryApmDependencyStatsQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetQueryTableDefinitionRequestQueryApmDependencyStatsQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d91e018b2ecb86cb08a83e6fb8151e106fa5c5d98469eaaa973560b19705a2d4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestQueryApmResourceStatsQuery",
    jsii_struct_bases=[],
    name_mapping={
        "data_source": "dataSource",
        "env": "env",
        "name": "name",
        "service": "service",
        "stat": "stat",
        "cross_org_uuids": "crossOrgUuids",
        "group_by": "groupBy",
        "operation_name": "operationName",
        "primary_tag_name": "primaryTagName",
        "primary_tag_value": "primaryTagValue",
        "resource_name": "resourceName",
    },
)
class PowerpackWidgetQueryTableDefinitionRequestQueryApmResourceStatsQuery:
    def __init__(
        self,
        *,
        data_source: builtins.str,
        env: builtins.str,
        name: builtins.str,
        service: builtins.str,
        stat: builtins.str,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        group_by: typing.Optional[typing.Sequence[builtins.str]] = None,
        operation_name: typing.Optional[builtins.str] = None,
        primary_tag_name: typing.Optional[builtins.str] = None,
        primary_tag_value: typing.Optional[builtins.str] = None,
        resource_name: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param data_source: The data source for APM Resource Stats queries. Valid values are ``apm_resource_stats``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param env: APM environment. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#env Powerpack#env}
        :param name: The name of query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param service: APM service. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#service Powerpack#service}
        :param stat: APM statistic. Valid values are ``errors``, ``error_rate``, ``hits``, ``latency_avg``, ``latency_distribution``, ``latency_max``, ``latency_p50``, ``latency_p75``, ``latency_p90``, ``latency_p95``, ``latency_p99``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#stat Powerpack#stat}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param group_by: Array of fields to group results by. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param operation_name: Name of operation on service. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#operation_name Powerpack#operation_name}
        :param primary_tag_name: The name of the second primary tag used within APM; required when ``primary_tag_value`` is specified. See https://docs.datadoghq.com/tracing/guide/setting_primary_tags_to_scope/#add-a-second-primary-tag-in-datadog. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_name Powerpack#primary_tag_name}
        :param primary_tag_value: Filter APM data by the second primary tag. ``primary_tag_name`` must also be specified. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_value Powerpack#primary_tag_value}
        :param resource_name: APM resource. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#resource_name Powerpack#resource_name}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__945a837745f963c87641629c5fbe27fd65d0536c91e430921345c57006b102a5)
            check_type(argname="argument data_source", value=data_source, expected_type=type_hints["data_source"])
            check_type(argname="argument env", value=env, expected_type=type_hints["env"])
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument service", value=service, expected_type=type_hints["service"])
            check_type(argname="argument stat", value=stat, expected_type=type_hints["stat"])
            check_type(argname="argument cross_org_uuids", value=cross_org_uuids, expected_type=type_hints["cross_org_uuids"])
            check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
            check_type(argname="argument operation_name", value=operation_name, expected_type=type_hints["operation_name"])
            check_type(argname="argument primary_tag_name", value=primary_tag_name, expected_type=type_hints["primary_tag_name"])
            check_type(argname="argument primary_tag_value", value=primary_tag_value, expected_type=type_hints["primary_tag_value"])
            check_type(argname="argument resource_name", value=resource_name, expected_type=type_hints["resource_name"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "data_source": data_source,
            "env": env,
            "name": name,
            "service": service,
            "stat": stat,
        }
        if cross_org_uuids is not None:
            self._values["cross_org_uuids"] = cross_org_uuids
        if group_by is not None:
            self._values["group_by"] = group_by
        if operation_name is not None:
            self._values["operation_name"] = operation_name
        if primary_tag_name is not None:
            self._values["primary_tag_name"] = primary_tag_name
        if primary_tag_value is not None:
            self._values["primary_tag_value"] = primary_tag_value
        if resource_name is not None:
            self._values["resource_name"] = resource_name

    @builtins.property
    def data_source(self) -> builtins.str:
        '''The data source for APM Resource Stats queries. Valid values are ``apm_resource_stats``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        '''
        result = self._values.get("data_source")
        assert result is not None, "Required property 'data_source' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def env(self) -> builtins.str:
        '''APM environment.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#env Powerpack#env}
        '''
        result = self._values.get("env")
        assert result is not None, "Required property 'env' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def name(self) -> builtins.str:
        '''The name of query for use in formulas.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        '''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def service(self) -> builtins.str:
        '''APM service.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#service Powerpack#service}
        '''
        result = self._values.get("service")
        assert result is not None, "Required property 'service' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def stat(self) -> builtins.str:
        '''APM statistic. Valid values are ``errors``, ``error_rate``, ``hits``, ``latency_avg``, ``latency_distribution``, ``latency_max``, ``latency_p50``, ``latency_p75``, ``latency_p90``, ``latency_p95``, ``latency_p99``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#stat Powerpack#stat}
        '''
        result = self._values.get("stat")
        assert result is not None, "Required property 'stat' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def cross_org_uuids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''The source organization UUID for cross organization queries. Feature in Private Beta.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        '''
        result = self._values.get("cross_org_uuids")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def group_by(self) -> typing.Optional[typing.List[builtins.str]]:
        '''Array of fields to group results by.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        '''
        result = self._values.get("group_by")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def operation_name(self) -> typing.Optional[builtins.str]:
        '''Name of operation on service.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#operation_name Powerpack#operation_name}
        '''
        result = self._values.get("operation_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def primary_tag_name(self) -> typing.Optional[builtins.str]:
        '''The name of the second primary tag used within APM; required when ``primary_tag_value`` is specified. See https://docs.datadoghq.com/tracing/guide/setting_primary_tags_to_scope/#add-a-second-primary-tag-in-datadog.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_name Powerpack#primary_tag_name}
        '''
        result = self._values.get("primary_tag_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def primary_tag_value(self) -> typing.Optional[builtins.str]:
        '''Filter APM data by the second primary tag. ``primary_tag_name`` must also be specified.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_value Powerpack#primary_tag_value}
        '''
        result = self._values.get("primary_tag_value")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def resource_name(self) -> typing.Optional[builtins.str]:
        '''APM resource.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#resource_name Powerpack#resource_name}
        '''
        result = self._values.get("resource_name")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryTableDefinitionRequestQueryApmResourceStatsQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetQueryTableDefinitionRequestQueryApmResourceStatsQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestQueryApmResourceStatsQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4e5a56e06027b55d7ef112986e766ab612de116b4720d54a43171aca60ea1390)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetCrossOrgUuids")
    def reset_cross_org_uuids(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCrossOrgUuids", []))

    @jsii.member(jsii_name="resetGroupBy")
    def reset_group_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGroupBy", []))

    @jsii.member(jsii_name="resetOperationName")
    def reset_operation_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetOperationName", []))

    @jsii.member(jsii_name="resetPrimaryTagName")
    def reset_primary_tag_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPrimaryTagName", []))

    @jsii.member(jsii_name="resetPrimaryTagValue")
    def reset_primary_tag_value(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPrimaryTagValue", []))

    @jsii.member(jsii_name="resetResourceName")
    def reset_resource_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetResourceName", []))

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuidsInput")
    def cross_org_uuids_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "crossOrgUuidsInput"))

    @builtins.property
    @jsii.member(jsii_name="dataSourceInput")
    def data_source_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "dataSourceInput"))

    @builtins.property
    @jsii.member(jsii_name="envInput")
    def env_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "envInput"))

    @builtins.property
    @jsii.member(jsii_name="groupByInput")
    def group_by_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "groupByInput"))

    @builtins.property
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property
    @jsii.member(jsii_name="operationNameInput")
    def operation_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "operationNameInput"))

    @builtins.property
    @jsii.member(jsii_name="primaryTagNameInput")
    def primary_tag_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "primaryTagNameInput"))

    @builtins.property
    @jsii.member(jsii_name="primaryTagValueInput")
    def primary_tag_value_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "primaryTagValueInput"))

    @builtins.property
    @jsii.member(jsii_name="resourceNameInput")
    def resource_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "resourceNameInput"))

    @builtins.property
    @jsii.member(jsii_name="serviceInput")
    def service_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "serviceInput"))

    @builtins.property
    @jsii.member(jsii_name="statInput")
    def stat_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "statInput"))

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuids")
    def cross_org_uuids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "crossOrgUuids"))

    @cross_org_uuids.setter
    def cross_org_uuids(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f53f31b4c5b5d175a9ae61c6794f34b67de25f9b5cd8d7203d053beb3cb5e4a3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "crossOrgUuids", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="dataSource")
    def data_source(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "dataSource"))

    @data_source.setter
    def data_source(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c960c98b0b4d18463c7a9a1c5ff4893c2def05dfca3b70a7754172849a9560c7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "dataSource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="env")
    def env(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "env"))

    @env.setter
    def env(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6f85e8a757217c2c04e0630bd87597c4f51ceff44e55470aeec3bef85128ec0e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "env", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="groupBy")
    def group_by(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "groupBy"))

    @group_by.setter
    def group_by(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1d585adc48cefd0fa5a54178d1ed83dee9322c4dcb4000ac120b1421a6e74d00)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "groupBy", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5c5c1e5470ffa939a448ff0b8de1f13eb3cd01a423e736ebeed50aa6c7b98525)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "name", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="operationName")
    def operation_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "operationName"))

    @operation_name.setter
    def operation_name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bf57df06714d056b8edaf4283e41bb527d323b118d231f3d269d37ee63882191)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "operationName", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="primaryTagName")
    def primary_tag_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "primaryTagName"))

    @primary_tag_name.setter
    def primary_tag_name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f477c1b981b680dc8bfb715d353a39be2a17c8fa9296422c165b417c790f3097)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "primaryTagName", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="primaryTagValue")
    def primary_tag_value(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "primaryTagValue"))

    @primary_tag_value.setter
    def primary_tag_value(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e084171bb8be598c79e85e2e7a16e1baedeaef5d1fc5fce4dbeb9eec25111716)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "primaryTagValue", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="resourceName")
    def resource_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "resourceName"))

    @resource_name.setter
    def resource_name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9857ba664f8feaaeb71c35d0024a914be68df34c96abaf6ed03593152352ebb5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "resourceName", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="service")
    def service(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "service"))

    @service.setter
    def service(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6a3bf281af3c3e32a523e47d1836ba74eb208ca6d0dc8129264984e2d7b5fc02)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "service", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="stat")
    def stat(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "stat"))

    @stat.setter
    def stat(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3f02aa82a2029f29d8216289c3dbcba1cf58a0f7f094109844fc666010907499)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "stat", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetQueryTableDefinitionRequestQueryApmResourceStatsQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryTableDefinitionRequestQueryApmResourceStatsQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetQueryTableDefinitionRequestQueryApmResourceStatsQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3786bcc7f219eb260e70a1ca52fa32172e212accaecbd4f9cbc60a8ed130cdc8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestQueryCloudCostQuery",
    jsii_struct_bases=[],
    name_mapping={
        "data_source": "dataSource",
        "name": "name",
        "query": "query",
        "aggregator": "aggregator",
        "cross_org_uuids": "crossOrgUuids",
    },
)
class PowerpackWidgetQueryTableDefinitionRequestQueryCloudCostQuery:
    def __init__(
        self,
        *,
        data_source: builtins.str,
        name: builtins.str,
        query: builtins.str,
        aggregator: typing.Optional[builtins.str] = None,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
    ) -> None:
        '''
        :param data_source: The data source for cloud cost queries. Valid values are ``cloud_cost``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param name: The name of the query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param query: The cloud cost query definition. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        :param aggregator: The aggregation methods available for cloud cost queries. Valid values are ``avg``, ``last``, ``max``, ``min``, ``sum``, ``percentile``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregator Powerpack#aggregator}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3a2c2641d15205cb77582fc3bbea9e7e06c0325313fb78062cbe907117f9cdc5)
            check_type(argname="argument data_source", value=data_source, expected_type=type_hints["data_source"])
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument query", value=query, expected_type=type_hints["query"])
            check_type(argname="argument aggregator", value=aggregator, expected_type=type_hints["aggregator"])
            check_type(argname="argument cross_org_uuids", value=cross_org_uuids, expected_type=type_hints["cross_org_uuids"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "data_source": data_source,
            "name": name,
            "query": query,
        }
        if aggregator is not None:
            self._values["aggregator"] = aggregator
        if cross_org_uuids is not None:
            self._values["cross_org_uuids"] = cross_org_uuids

    @builtins.property
    def data_source(self) -> builtins.str:
        '''The data source for cloud cost queries. Valid values are ``cloud_cost``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        '''
        result = self._values.get("data_source")
        assert result is not None, "Required property 'data_source' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def name(self) -> builtins.str:
        '''The name of the query for use in formulas.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        '''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def query(self) -> builtins.str:
        '''The cloud cost query definition.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        '''
        result = self._values.get("query")
        assert result is not None, "Required property 'query' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def aggregator(self) -> typing.Optional[builtins.str]:
        '''The aggregation methods available for cloud cost queries. Valid values are ``avg``, ``last``, ``max``, ``min``, ``sum``, ``percentile``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregator Powerpack#aggregator}
        '''
        result = self._values.get("aggregator")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def cross_org_uuids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''The source organization UUID for cross organization queries. Feature in Private Beta.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        '''
        result = self._values.get("cross_org_uuids")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryTableDefinitionRequestQueryCloudCostQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetQueryTableDefinitionRequestQueryCloudCostQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestQueryCloudCostQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__208869ceb75d9588d7bc5cad53e9e6105f1a1c8ebeaf57d59d10c6047d350497)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetAggregator")
    def reset_aggregator(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAggregator", []))

    @jsii.member(jsii_name="resetCrossOrgUuids")
    def reset_cross_org_uuids(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCrossOrgUuids", []))

    @builtins.property
    @jsii.member(jsii_name="aggregatorInput")
    def aggregator_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregatorInput"))

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuidsInput")
    def cross_org_uuids_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "crossOrgUuidsInput"))

    @builtins.property
    @jsii.member(jsii_name="dataSourceInput")
    def data_source_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "dataSourceInput"))

    @builtins.property
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property
    @jsii.member(jsii_name="queryInput")
    def query_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "queryInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregator")
    def aggregator(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregator"))

    @aggregator.setter
    def aggregator(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__58aa65861e88f1590077f1fcee71b75ae0620b6cf10e797773f048c734a80e05)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregator", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuids")
    def cross_org_uuids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "crossOrgUuids"))

    @cross_org_uuids.setter
    def cross_org_uuids(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4d0cf760de690d29b96c6ed7e3724ceaac443230ced22ae63019726da256101d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "crossOrgUuids", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="dataSource")
    def data_source(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "dataSource"))

    @data_source.setter
    def data_source(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c77c6c6e73a60884c88c478e20fe949c149ebb96ee40e896cfb4cbe1b001fc51)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "dataSource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8eb4fba5ed72da1dd82084b944ded149c5baa6bbf1b979d8cd41379e3489a62d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "name", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="query")
    def query(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "query"))

    @query.setter
    def query(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__282ab60622cb005a8cbc9b240ede4a9e38c0003edc5353894baee3b37f4df854)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "query", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetQueryTableDefinitionRequestQueryCloudCostQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryTableDefinitionRequestQueryCloudCostQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetQueryTableDefinitionRequestQueryCloudCostQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__341076c33f6f5844b8b2a4ed367fb5a3141305dc52140ebaf2f3bb319136e437)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestQueryEventQuery",
    jsii_struct_bases=[],
    name_mapping={
        "compute": "compute",
        "data_source": "dataSource",
        "name": "name",
        "cross_org_uuids": "crossOrgUuids",
        "group_by": "groupBy",
        "indexes": "indexes",
        "search": "search",
        "storage": "storage",
    },
)
class PowerpackWidgetQueryTableDefinitionRequestQueryEventQuery:
    def __init__(
        self,
        *,
        compute: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetQueryTableDefinitionRequestQueryEventQueryCompute", typing.Dict[builtins.str, typing.Any]]]],
        data_source: builtins.str,
        name: builtins.str,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetQueryTableDefinitionRequestQueryEventQueryGroupBy", typing.Dict[builtins.str, typing.Any]]]]] = None,
        indexes: typing.Optional[typing.Sequence[builtins.str]] = None,
        search: typing.Optional[typing.Union["PowerpackWidgetQueryTableDefinitionRequestQueryEventQuerySearch", typing.Dict[builtins.str, typing.Any]]] = None,
        storage: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param compute: compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute Powerpack#compute}
        :param data_source: The data source for event platform-based queries. Valid values are ``logs``, ``spans``, ``network``, ``rum``, ``security_signals``, ``profiles``, ``audit``, ``events``, ``ci_tests``, ``ci_pipelines``, ``incident_analytics``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param name: The name of query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param indexes: An array of index names to query in the stream. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#indexes Powerpack#indexes}
        :param search: search block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search Powerpack#search}
        :param storage: Storage location (private beta). Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#storage Powerpack#storage}
        '''
        if isinstance(search, dict):
            search = PowerpackWidgetQueryTableDefinitionRequestQueryEventQuerySearch(**search)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d134459f519bac9d2f3e30c8f0b3ec0b24d84dd05897e79374eb70b1202e530a)
            check_type(argname="argument compute", value=compute, expected_type=type_hints["compute"])
            check_type(argname="argument data_source", value=data_source, expected_type=type_hints["data_source"])
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument cross_org_uuids", value=cross_org_uuids, expected_type=type_hints["cross_org_uuids"])
            check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
            check_type(argname="argument indexes", value=indexes, expected_type=type_hints["indexes"])
            check_type(argname="argument search", value=search, expected_type=type_hints["search"])
            check_type(argname="argument storage", value=storage, expected_type=type_hints["storage"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "compute": compute,
            "data_source": data_source,
            "name": name,
        }
        if cross_org_uuids is not None:
            self._values["cross_org_uuids"] = cross_org_uuids
        if group_by is not None:
            self._values["group_by"] = group_by
        if indexes is not None:
            self._values["indexes"] = indexes
        if search is not None:
            self._values["search"] = search
        if storage is not None:
            self._values["storage"] = storage

    @builtins.property
    def compute(
        self,
    ) -> typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetQueryTableDefinitionRequestQueryEventQueryCompute"]]:
        '''compute block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute Powerpack#compute}
        '''
        result = self._values.get("compute")
        assert result is not None, "Required property 'compute' is missing"
        return typing.cast(typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetQueryTableDefinitionRequestQueryEventQueryCompute"]], result)

    @builtins.property
    def data_source(self) -> builtins.str:
        '''The data source for event platform-based queries.

        Valid values are ``logs``, ``spans``, ``network``, ``rum``, ``security_signals``, ``profiles``, ``audit``, ``events``, ``ci_tests``, ``ci_pipelines``, ``incident_analytics``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        '''
        result = self._values.get("data_source")
        assert result is not None, "Required property 'data_source' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def name(self) -> builtins.str:
        '''The name of query for use in formulas.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        '''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def cross_org_uuids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''The source organization UUID for cross organization queries. Feature in Private Beta.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        '''
        result = self._values.get("cross_org_uuids")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def group_by(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetQueryTableDefinitionRequestQueryEventQueryGroupBy"]]]:
        '''group_by block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        '''
        result = self._values.get("group_by")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetQueryTableDefinitionRequestQueryEventQueryGroupBy"]]], result)

    @builtins.property
    def indexes(self) -> typing.Optional[typing.List[builtins.str]]:
        '''An array of index names to query in the stream.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#indexes Powerpack#indexes}
        '''
        result = self._values.get("indexes")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def search(
        self,
    ) -> typing.Optional["PowerpackWidgetQueryTableDefinitionRequestQueryEventQuerySearch"]:
        '''search block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search Powerpack#search}
        '''
        result = self._values.get("search")
        return typing.cast(typing.Optional["PowerpackWidgetQueryTableDefinitionRequestQueryEventQuerySearch"], result)

    @builtins.property
    def storage(self) -> typing.Optional[builtins.str]:
        '''Storage location (private beta).

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#storage Powerpack#storage}
        '''
        result = self._values.get("storage")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryTableDefinitionRequestQueryEventQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestQueryEventQueryCompute",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "interval": "interval",
        "metric": "metric",
    },
)
class PowerpackWidgetQueryTableDefinitionRequestQueryEventQueryCompute:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        interval: typing.Optional[jsii.Number] = None,
        metric: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation methods for event platform queries. Valid values are ``count``, ``cardinality``, ``median``, ``pc75``, ``pc90``, ``pc95``, ``pc98``, ``pc99``, ``sum``, ``min``, ``max``, ``avg``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param interval: A time interval in milliseconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        :param metric: The measurable attribute to compute. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6f81b312850f33f1993485fc15dbe456534300d30356b235e10206e1145c9a3b)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
            check_type(argname="argument metric", value=metric, expected_type=type_hints["metric"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if interval is not None:
            self._values["interval"] = interval
        if metric is not None:
            self._values["metric"] = metric

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation methods for event platform queries.

        Valid values are ``count``, ``cardinality``, ``median``, ``pc75``, ``pc90``, ``pc95``, ``pc98``, ``pc99``, ``sum``, ``min``, ``max``, ``avg``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''A time interval in milliseconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def metric(self) -> typing.Optional[builtins.str]:
        '''The measurable attribute to compute.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        '''
        result = self._values.get("metric")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryTableDefinitionRequestQueryEventQueryCompute(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetQueryTableDefinitionRequestQueryEventQueryComputeList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestQueryEventQueryComputeList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f45ff148d3c568b269621f45f3ef9d664a64ac7db32a2c89b01d466814f657a4)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetQueryTableDefinitionRequestQueryEventQueryComputeOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b78402ad7e12a0194504b73817d378ed7df6cb6e416d58710ff3d51cad7d2439)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetQueryTableDefinitionRequestQueryEventQueryComputeOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d3a741fcdfe3dfd111ed5eedb9593baee7e9bb6bec39291f2012e93f33d7ce9e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__04a94fdcf3f2e52cd4ab42ac43c5734487efd0b6b25b275345ae6aa3a40f0c36)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7aa9318dc675018e3d2facc99b59919d5eaf64ceab976147eda7819fd1f25c63)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionRequestQueryEventQueryCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionRequestQueryEventQueryCompute]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionRequestQueryEventQueryCompute]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__80d31b41a97728c7fc70d725fc3436ae2c41d4ec5627585888993694b1484340)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetQueryTableDefinitionRequestQueryEventQueryComputeOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestQueryEventQueryComputeOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__59ba06231b19d52e2857faa67038b72287129ce01097912aebc0fdfece67bcc7)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @jsii.member(jsii_name="resetMetric")
    def reset_metric(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMetric", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="metricInput")
    def metric_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "metricInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b23b24fc0a6dd5979b174755df00f5c4b6c0218bf8f320a22075e6df15fc1527)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fd91ee515a1bebe5f227d1f19790ebaa39f4879e2d382ac163f5c70b58e09f62)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="metric")
    def metric(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "metric"))

    @metric.setter
    def metric(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9090de4a0b2a98c909508fb73b0c4ce1dead8f0ef64a44620de8bef39ca6b3e1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "metric", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryTableDefinitionRequestQueryEventQueryCompute]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryTableDefinitionRequestQueryEventQueryCompute]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryTableDefinitionRequestQueryEventQueryCompute]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cedbcd03890e1808920a42116318f295282412aa283aa2ee175d25503987b8ef)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestQueryEventQueryGroupBy",
    jsii_struct_bases=[],
    name_mapping={"facet": "facet", "limit": "limit", "sort": "sort"},
)
class PowerpackWidgetQueryTableDefinitionRequestQueryEventQueryGroupBy:
    def __init__(
        self,
        *,
        facet: builtins.str,
        limit: typing.Optional[jsii.Number] = None,
        sort: typing.Optional[typing.Union["PowerpackWidgetQueryTableDefinitionRequestQueryEventQueryGroupBySort", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param facet: The event facet. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param limit: The number of groups to return. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param sort: sort block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort Powerpack#sort}
        '''
        if isinstance(sort, dict):
            sort = PowerpackWidgetQueryTableDefinitionRequestQueryEventQueryGroupBySort(**sort)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d063465d994784fd3d191a7784f649d1ca334b85482eba23111421b69a7d4850)
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
            check_type(argname="argument sort", value=sort, expected_type=type_hints["sort"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "facet": facet,
        }
        if limit is not None:
            self._values["limit"] = limit
        if sort is not None:
            self._values["sort"] = sort

    @builtins.property
    def facet(self) -> builtins.str:
        '''The event facet.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        assert result is not None, "Required property 'facet' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def limit(self) -> typing.Optional[jsii.Number]:
        '''The number of groups to return.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        '''
        result = self._values.get("limit")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def sort(
        self,
    ) -> typing.Optional["PowerpackWidgetQueryTableDefinitionRequestQueryEventQueryGroupBySort"]:
        '''sort block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort Powerpack#sort}
        '''
        result = self._values.get("sort")
        return typing.cast(typing.Optional["PowerpackWidgetQueryTableDefinitionRequestQueryEventQueryGroupBySort"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryTableDefinitionRequestQueryEventQueryGroupBy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetQueryTableDefinitionRequestQueryEventQueryGroupByList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestQueryEventQueryGroupByList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ccb3dd9bda4989bca68f958d9d20a68a55f561224cfd577cef85b29b1f4fbaf8)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetQueryTableDefinitionRequestQueryEventQueryGroupByOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6b7f0a06ef513161ff2d5c154c552a592611ffc0357fb7b249e72c5f6306bf48)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetQueryTableDefinitionRequestQueryEventQueryGroupByOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b6211c2068b698e37000f61c5b024f0daeb022844e430f88640db6d8f9d7737f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0a5d2a411987ed667314cb260254d7e899d3f13c7581b6846911daacab21f7a2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__09820e8dbf2d6a91108736e0edb0619bec114d6f9c3a0ad2e3d0948cbd3632de)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionRequestQueryEventQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionRequestQueryEventQueryGroupBy]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionRequestQueryEventQueryGroupBy]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b65bf5c39e2251d0fd06ff707faa516ac784d61e4b9c04faef0214318c483621)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetQueryTableDefinitionRequestQueryEventQueryGroupByOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestQueryEventQueryGroupByOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__74bb395272986725e34cc09ce02634545625db44d6d50742beadac5965009446)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putSort")
    def put_sort(
        self,
        *,
        aggregation: builtins.str,
        metric: typing.Optional[builtins.str] = None,
        order: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation methods for the event platform queries. Valid values are ``count``, ``cardinality``, ``median``, ``pc75``, ``pc90``, ``pc95``, ``pc98``, ``pc99``, ``sum``, ``min``, ``max``, ``avg``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param metric: The metric used for sorting group by results. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        :param order: Direction of sort. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        value = PowerpackWidgetQueryTableDefinitionRequestQueryEventQueryGroupBySort(
            aggregation=aggregation, metric=metric, order=order
        )

        return typing.cast(None, jsii.invoke(self, "putSort", [value]))

    @jsii.member(jsii_name="resetLimit")
    def reset_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLimit", []))

    @jsii.member(jsii_name="resetSort")
    def reset_sort(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSort", []))

    @builtins.property
    @jsii.member(jsii_name="sort")
    def sort(
        self,
    ) -> "PowerpackWidgetQueryTableDefinitionRequestQueryEventQueryGroupBySortOutputReference":
        return typing.cast("PowerpackWidgetQueryTableDefinitionRequestQueryEventQueryGroupBySortOutputReference", jsii.get(self, "sort"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="limitInput")
    def limit_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "limitInput"))

    @builtins.property
    @jsii.member(jsii_name="sortInput")
    def sort_input(
        self,
    ) -> typing.Optional["PowerpackWidgetQueryTableDefinitionRequestQueryEventQueryGroupBySort"]:
        return typing.cast(typing.Optional["PowerpackWidgetQueryTableDefinitionRequestQueryEventQueryGroupBySort"], jsii.get(self, "sortInput"))

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4552d4c8d7f7f0b9f513629ff85a41606a2b2a42b7ec95f8e0647cb722e43c76)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="limit")
    def limit(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "limit"))

    @limit.setter
    def limit(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__26be0d926e67f6ea574791d6db4068d891abe6c294d29fbade8fa34032de7e93)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "limit", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryTableDefinitionRequestQueryEventQueryGroupBy]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryTableDefinitionRequestQueryEventQueryGroupBy]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryTableDefinitionRequestQueryEventQueryGroupBy]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__26c2f0e23deb7940f0ef4e6db4c33489899e1d672db612c530b1c6ebb4af1b01)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestQueryEventQueryGroupBySort",
    jsii_struct_bases=[],
    name_mapping={"aggregation": "aggregation", "metric": "metric", "order": "order"},
)
class PowerpackWidgetQueryTableDefinitionRequestQueryEventQueryGroupBySort:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        metric: typing.Optional[builtins.str] = None,
        order: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation methods for the event platform queries. Valid values are ``count``, ``cardinality``, ``median``, ``pc75``, ``pc90``, ``pc95``, ``pc98``, ``pc99``, ``sum``, ``min``, ``max``, ``avg``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param metric: The metric used for sorting group by results. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        :param order: Direction of sort. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b704ffba0947582b8fc74a84ff8cff88d060bbbc10bc2883e7375db56ab9c3c5)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument metric", value=metric, expected_type=type_hints["metric"])
            check_type(argname="argument order", value=order, expected_type=type_hints["order"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if metric is not None:
            self._values["metric"] = metric
        if order is not None:
            self._values["order"] = order

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation methods for the event platform queries.

        Valid values are ``count``, ``cardinality``, ``median``, ``pc75``, ``pc90``, ``pc95``, ``pc98``, ``pc99``, ``sum``, ``min``, ``max``, ``avg``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def metric(self) -> typing.Optional[builtins.str]:
        '''The metric used for sorting group by results.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        '''
        result = self._values.get("metric")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def order(self) -> typing.Optional[builtins.str]:
        '''Direction of sort. Valid values are ``asc``, ``desc``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        result = self._values.get("order")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryTableDefinitionRequestQueryEventQueryGroupBySort(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetQueryTableDefinitionRequestQueryEventQueryGroupBySortOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestQueryEventQueryGroupBySortOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__94fa7155d2931dbcb5d94061c03c926a33cf290f40c9757e38d5c8cc1079581e)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetMetric")
    def reset_metric(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMetric", []))

    @jsii.member(jsii_name="resetOrder")
    def reset_order(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetOrder", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="metricInput")
    def metric_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "metricInput"))

    @builtins.property
    @jsii.member(jsii_name="orderInput")
    def order_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "orderInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f6fdab0e7df42740540ee6c2673f638131435876cc84683775215c016d372029)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="metric")
    def metric(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "metric"))

    @metric.setter
    def metric(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8528e4d8e29a1be264019be7b31c623871f8b88b0cf199fed0f921350a0864a8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "metric", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="order")
    def order(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "order"))

    @order.setter
    def order(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e024d953b7868e8ba357cda59ed45cce9e73344a6242e60300600c3c8e4090e8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "order", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetQueryTableDefinitionRequestQueryEventQueryGroupBySort]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryTableDefinitionRequestQueryEventQueryGroupBySort], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetQueryTableDefinitionRequestQueryEventQueryGroupBySort],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ff4ae8e6c0ce0557f67ffc02ce0fd20fa396fad0f6646972e7b624529218a2e0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetQueryTableDefinitionRequestQueryEventQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestQueryEventQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bcf3cd2fd9bf4a3b8a2fcbc0c9819a90362a2d38ca6191820fd60a940e05318e)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putCompute")
    def put_compute(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryTableDefinitionRequestQueryEventQueryCompute, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__87ac0a438b699332e469fa0c917850f7786487191c393c766a64d2db3ccf77d9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putCompute", [value]))

    @jsii.member(jsii_name="putGroupBy")
    def put_group_by(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryTableDefinitionRequestQueryEventQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ae49e1af3fcb81fddece100a63a8d8f82c35020b39f2129d3accfb8b0e97e547)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putGroupBy", [value]))

    @jsii.member(jsii_name="putSearch")
    def put_search(self, *, query: builtins.str) -> None:
        '''
        :param query: The events search string. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        '''
        value = PowerpackWidgetQueryTableDefinitionRequestQueryEventQuerySearch(
            query=query
        )

        return typing.cast(None, jsii.invoke(self, "putSearch", [value]))

    @jsii.member(jsii_name="resetCrossOrgUuids")
    def reset_cross_org_uuids(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCrossOrgUuids", []))

    @jsii.member(jsii_name="resetGroupBy")
    def reset_group_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGroupBy", []))

    @jsii.member(jsii_name="resetIndexes")
    def reset_indexes(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetIndexes", []))

    @jsii.member(jsii_name="resetSearch")
    def reset_search(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSearch", []))

    @jsii.member(jsii_name="resetStorage")
    def reset_storage(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetStorage", []))

    @builtins.property
    @jsii.member(jsii_name="compute")
    def compute(
        self,
    ) -> PowerpackWidgetQueryTableDefinitionRequestQueryEventQueryComputeList:
        return typing.cast(PowerpackWidgetQueryTableDefinitionRequestQueryEventQueryComputeList, jsii.get(self, "compute"))

    @builtins.property
    @jsii.member(jsii_name="groupBy")
    def group_by(
        self,
    ) -> PowerpackWidgetQueryTableDefinitionRequestQueryEventQueryGroupByList:
        return typing.cast(PowerpackWidgetQueryTableDefinitionRequestQueryEventQueryGroupByList, jsii.get(self, "groupBy"))

    @builtins.property
    @jsii.member(jsii_name="search")
    def search(
        self,
    ) -> "PowerpackWidgetQueryTableDefinitionRequestQueryEventQuerySearchOutputReference":
        return typing.cast("PowerpackWidgetQueryTableDefinitionRequestQueryEventQuerySearchOutputReference", jsii.get(self, "search"))

    @builtins.property
    @jsii.member(jsii_name="computeInput")
    def compute_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionRequestQueryEventQueryCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionRequestQueryEventQueryCompute]]], jsii.get(self, "computeInput"))

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuidsInput")
    def cross_org_uuids_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "crossOrgUuidsInput"))

    @builtins.property
    @jsii.member(jsii_name="dataSourceInput")
    def data_source_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "dataSourceInput"))

    @builtins.property
    @jsii.member(jsii_name="groupByInput")
    def group_by_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionRequestQueryEventQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionRequestQueryEventQueryGroupBy]]], jsii.get(self, "groupByInput"))

    @builtins.property
    @jsii.member(jsii_name="indexesInput")
    def indexes_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "indexesInput"))

    @builtins.property
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property
    @jsii.member(jsii_name="searchInput")
    def search_input(
        self,
    ) -> typing.Optional["PowerpackWidgetQueryTableDefinitionRequestQueryEventQuerySearch"]:
        return typing.cast(typing.Optional["PowerpackWidgetQueryTableDefinitionRequestQueryEventQuerySearch"], jsii.get(self, "searchInput"))

    @builtins.property
    @jsii.member(jsii_name="storageInput")
    def storage_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "storageInput"))

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuids")
    def cross_org_uuids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "crossOrgUuids"))

    @cross_org_uuids.setter
    def cross_org_uuids(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__693168fe130e083febea40939a16d0946f79ea7c4e9fa8dbebd2cf7f7580b24d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "crossOrgUuids", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="dataSource")
    def data_source(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "dataSource"))

    @data_source.setter
    def data_source(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4f26424f205e9351130d24acf072abdbf19d4f7a8b883045400af04146033d97)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "dataSource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="indexes")
    def indexes(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "indexes"))

    @indexes.setter
    def indexes(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f6efde42245fa8bf5d5ac1e77a7bd7ee03da9292de8e24430c3a55fbaaf181e1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "indexes", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__024216014dfaee7f541fc1d1c3dc6ab4e289641682a2a20b32723729774f2581)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "name", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="storage")
    def storage(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "storage"))

    @storage.setter
    def storage(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9a1c91de48668a3ebb162599c80152b1a8b7efbe7bafecd10266bd093ceb6a20)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "storage", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetQueryTableDefinitionRequestQueryEventQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryTableDefinitionRequestQueryEventQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetQueryTableDefinitionRequestQueryEventQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__91534f52ff854e9f90296fe5d04c90d66a4250615a9ed6836e8797b8964c2534)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestQueryEventQuerySearch",
    jsii_struct_bases=[],
    name_mapping={"query": "query"},
)
class PowerpackWidgetQueryTableDefinitionRequestQueryEventQuerySearch:
    def __init__(self, *, query: builtins.str) -> None:
        '''
        :param query: The events search string. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__29b42643b0d827ea73f0e981644fed7bdbaefdbb74f9cfdfcbea7f41818872f8)
            check_type(argname="argument query", value=query, expected_type=type_hints["query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "query": query,
        }

    @builtins.property
    def query(self) -> builtins.str:
        '''The events search string.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        '''
        result = self._values.get("query")
        assert result is not None, "Required property 'query' is missing"
        return typing.cast(builtins.str, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryTableDefinitionRequestQueryEventQuerySearch(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetQueryTableDefinitionRequestQueryEventQuerySearchOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestQueryEventQuerySearchOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__68f1ba9bd3303ccce8726e0459cd1063ede3c2b8be5109cfbc7a0fc8115f418c)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @builtins.property
    @jsii.member(jsii_name="queryInput")
    def query_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "queryInput"))

    @builtins.property
    @jsii.member(jsii_name="query")
    def query(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "query"))

    @query.setter
    def query(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4dfa01a3d013de788f546a0f13a655ea3139dbb4fd68c3164a736bbf247b8ac7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "query", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetQueryTableDefinitionRequestQueryEventQuerySearch]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryTableDefinitionRequestQueryEventQuerySearch], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetQueryTableDefinitionRequestQueryEventQuerySearch],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5445b50bf847d138bda5dd404dd3a038b9cc84118398ce2ea429c5d94256442f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetQueryTableDefinitionRequestQueryList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestQueryList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__35eb9e51d9445e83aeb5b61b5d77d1af46b0618bca507f7088467094fc70fbaf)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetQueryTableDefinitionRequestQueryOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d0f7f8daa73fbccc49c5afdf21d766b4914aa77541d688facc6bdfe21223d057)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetQueryTableDefinitionRequestQueryOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__43a20ee665c2387afa0e7df6cb3454798a546fe2f8ef06279ad95956de5d4e58)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6c79d04b8e8e517877bc11ddc2906e7f62ad35cca6d3b11379f1dc3599881e98)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7e803853b9dd10ec404d81fc10dd56ddfb0198cafecf1be4a1f2fbee600f8a32)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionRequestQuery]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionRequestQuery]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionRequestQuery]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f9543f81f5d642dafb2bde9ea2969fa00ea787215764d904426bc66a55ed2ea5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestQueryMetricQuery",
    jsii_struct_bases=[],
    name_mapping={
        "name": "name",
        "query": "query",
        "aggregator": "aggregator",
        "cross_org_uuids": "crossOrgUuids",
        "data_source": "dataSource",
    },
)
class PowerpackWidgetQueryTableDefinitionRequestQueryMetricQuery:
    def __init__(
        self,
        *,
        name: builtins.str,
        query: builtins.str,
        aggregator: typing.Optional[builtins.str] = None,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        data_source: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param name: The name of the query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param query: The metrics query definition. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        :param aggregator: The aggregation methods available for metrics queries. Valid values are ``avg``, ``min``, ``max``, ``sum``, ``last``, ``area``, ``l2norm``, ``percentile``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregator Powerpack#aggregator}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param data_source: The data source for metrics queries. Defaults to ``"metrics"``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fad421ecdddeaf0147063f87cb17cdae8c0c2c9502227602fecf0831c00b1969)
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument query", value=query, expected_type=type_hints["query"])
            check_type(argname="argument aggregator", value=aggregator, expected_type=type_hints["aggregator"])
            check_type(argname="argument cross_org_uuids", value=cross_org_uuids, expected_type=type_hints["cross_org_uuids"])
            check_type(argname="argument data_source", value=data_source, expected_type=type_hints["data_source"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "name": name,
            "query": query,
        }
        if aggregator is not None:
            self._values["aggregator"] = aggregator
        if cross_org_uuids is not None:
            self._values["cross_org_uuids"] = cross_org_uuids
        if data_source is not None:
            self._values["data_source"] = data_source

    @builtins.property
    def name(self) -> builtins.str:
        '''The name of the query for use in formulas.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        '''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def query(self) -> builtins.str:
        '''The metrics query definition.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        '''
        result = self._values.get("query")
        assert result is not None, "Required property 'query' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def aggregator(self) -> typing.Optional[builtins.str]:
        '''The aggregation methods available for metrics queries. Valid values are ``avg``, ``min``, ``max``, ``sum``, ``last``, ``area``, ``l2norm``, ``percentile``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregator Powerpack#aggregator}
        '''
        result = self._values.get("aggregator")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def cross_org_uuids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''The source organization UUID for cross organization queries. Feature in Private Beta.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        '''
        result = self._values.get("cross_org_uuids")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def data_source(self) -> typing.Optional[builtins.str]:
        '''The data source for metrics queries. Defaults to ``"metrics"``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        '''
        result = self._values.get("data_source")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryTableDefinitionRequestQueryMetricQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetQueryTableDefinitionRequestQueryMetricQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestQueryMetricQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e7dd5fcd2132d1bdbebeecade92616fcea9b2e77f4d61850e47802246dbc0b0a)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetAggregator")
    def reset_aggregator(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAggregator", []))

    @jsii.member(jsii_name="resetCrossOrgUuids")
    def reset_cross_org_uuids(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCrossOrgUuids", []))

    @jsii.member(jsii_name="resetDataSource")
    def reset_data_source(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDataSource", []))

    @builtins.property
    @jsii.member(jsii_name="aggregatorInput")
    def aggregator_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregatorInput"))

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuidsInput")
    def cross_org_uuids_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "crossOrgUuidsInput"))

    @builtins.property
    @jsii.member(jsii_name="dataSourceInput")
    def data_source_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "dataSourceInput"))

    @builtins.property
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property
    @jsii.member(jsii_name="queryInput")
    def query_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "queryInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregator")
    def aggregator(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregator"))

    @aggregator.setter
    def aggregator(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8351cd2e077bcd6879402fc2753d2f193c603a17a0e85a435ca361c7a107d3b2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregator", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuids")
    def cross_org_uuids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "crossOrgUuids"))

    @cross_org_uuids.setter
    def cross_org_uuids(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a989e2f027c04bcdc7e17143791c9628d4b01e2737587fa5f982b53d4d01b8df)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "crossOrgUuids", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="dataSource")
    def data_source(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "dataSource"))

    @data_source.setter
    def data_source(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__97cc6b39acbad8afb7cef29ad4da360a0800117da0021e9cf3d2be54c1fb8bf3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "dataSource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__186c4b111724a3b7bf108ed4db228463369982befe0900a3e591e44adce0a4dc)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "name", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="query")
    def query(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "query"))

    @query.setter
    def query(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__abb395f3929424411e444ed18f05293a35ece34c4dfde3a445a8679425b5000e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "query", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetQueryTableDefinitionRequestQueryMetricQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryTableDefinitionRequestQueryMetricQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetQueryTableDefinitionRequestQueryMetricQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__50cff926c4f756b816e471a07647b13dcfa13fdb65711ed76463ee89a245e8b2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetQueryTableDefinitionRequestQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9b39b27bd5138d4bbb9307cd1a19aebd8444d1d501f3621a5882627860aa9ab9)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putApmDependencyStatsQuery")
    def put_apm_dependency_stats_query(
        self,
        *,
        data_source: builtins.str,
        env: builtins.str,
        name: builtins.str,
        operation_name: builtins.str,
        resource_name: builtins.str,
        service: builtins.str,
        stat: builtins.str,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        is_upstream: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        primary_tag_name: typing.Optional[builtins.str] = None,
        primary_tag_value: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param data_source: The data source for APM Dependency Stats queries. Valid values are ``apm_dependency_stats``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param env: APM environment. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#env Powerpack#env}
        :param name: The name of query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param operation_name: Name of operation on service. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#operation_name Powerpack#operation_name}
        :param resource_name: APM resource. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#resource_name Powerpack#resource_name}
        :param service: APM service. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#service Powerpack#service}
        :param stat: APM statistic. Valid values are ``avg_duration``, ``avg_root_duration``, ``avg_spans_per_trace``, ``error_rate``, ``pct_exec_time``, ``pct_of_traces``, ``total_traces_count``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#stat Powerpack#stat}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param is_upstream: Determines whether stats for upstream or downstream dependencies should be queried. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#is_upstream Powerpack#is_upstream}
        :param primary_tag_name: The name of the second primary tag used within APM; required when ``primary_tag_value`` is specified. See https://docs.datadoghq.com/tracing/guide/setting_primary_tags_to_scope/#add-a-second-primary-tag-in-datadog. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_name Powerpack#primary_tag_name}
        :param primary_tag_value: Filter APM data by the second primary tag. ``primary_tag_name`` must also be specified. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_value Powerpack#primary_tag_value}
        '''
        value = PowerpackWidgetQueryTableDefinitionRequestQueryApmDependencyStatsQuery(
            data_source=data_source,
            env=env,
            name=name,
            operation_name=operation_name,
            resource_name=resource_name,
            service=service,
            stat=stat,
            cross_org_uuids=cross_org_uuids,
            is_upstream=is_upstream,
            primary_tag_name=primary_tag_name,
            primary_tag_value=primary_tag_value,
        )

        return typing.cast(None, jsii.invoke(self, "putApmDependencyStatsQuery", [value]))

    @jsii.member(jsii_name="putApmResourceStatsQuery")
    def put_apm_resource_stats_query(
        self,
        *,
        data_source: builtins.str,
        env: builtins.str,
        name: builtins.str,
        service: builtins.str,
        stat: builtins.str,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        group_by: typing.Optional[typing.Sequence[builtins.str]] = None,
        operation_name: typing.Optional[builtins.str] = None,
        primary_tag_name: typing.Optional[builtins.str] = None,
        primary_tag_value: typing.Optional[builtins.str] = None,
        resource_name: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param data_source: The data source for APM Resource Stats queries. Valid values are ``apm_resource_stats``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param env: APM environment. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#env Powerpack#env}
        :param name: The name of query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param service: APM service. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#service Powerpack#service}
        :param stat: APM statistic. Valid values are ``errors``, ``error_rate``, ``hits``, ``latency_avg``, ``latency_distribution``, ``latency_max``, ``latency_p50``, ``latency_p75``, ``latency_p90``, ``latency_p95``, ``latency_p99``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#stat Powerpack#stat}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param group_by: Array of fields to group results by. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param operation_name: Name of operation on service. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#operation_name Powerpack#operation_name}
        :param primary_tag_name: The name of the second primary tag used within APM; required when ``primary_tag_value`` is specified. See https://docs.datadoghq.com/tracing/guide/setting_primary_tags_to_scope/#add-a-second-primary-tag-in-datadog. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_name Powerpack#primary_tag_name}
        :param primary_tag_value: Filter APM data by the second primary tag. ``primary_tag_name`` must also be specified. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_value Powerpack#primary_tag_value}
        :param resource_name: APM resource. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#resource_name Powerpack#resource_name}
        '''
        value = PowerpackWidgetQueryTableDefinitionRequestQueryApmResourceStatsQuery(
            data_source=data_source,
            env=env,
            name=name,
            service=service,
            stat=stat,
            cross_org_uuids=cross_org_uuids,
            group_by=group_by,
            operation_name=operation_name,
            primary_tag_name=primary_tag_name,
            primary_tag_value=primary_tag_value,
            resource_name=resource_name,
        )

        return typing.cast(None, jsii.invoke(self, "putApmResourceStatsQuery", [value]))

    @jsii.member(jsii_name="putCloudCostQuery")
    def put_cloud_cost_query(
        self,
        *,
        data_source: builtins.str,
        name: builtins.str,
        query: builtins.str,
        aggregator: typing.Optional[builtins.str] = None,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
    ) -> None:
        '''
        :param data_source: The data source for cloud cost queries. Valid values are ``cloud_cost``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param name: The name of the query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param query: The cloud cost query definition. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        :param aggregator: The aggregation methods available for cloud cost queries. Valid values are ``avg``, ``last``, ``max``, ``min``, ``sum``, ``percentile``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregator Powerpack#aggregator}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        '''
        value = PowerpackWidgetQueryTableDefinitionRequestQueryCloudCostQuery(
            data_source=data_source,
            name=name,
            query=query,
            aggregator=aggregator,
            cross_org_uuids=cross_org_uuids,
        )

        return typing.cast(None, jsii.invoke(self, "putCloudCostQuery", [value]))

    @jsii.member(jsii_name="putEventQuery")
    def put_event_query(
        self,
        *,
        compute: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryTableDefinitionRequestQueryEventQueryCompute, typing.Dict[builtins.str, typing.Any]]]],
        data_source: builtins.str,
        name: builtins.str,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryTableDefinitionRequestQueryEventQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
        indexes: typing.Optional[typing.Sequence[builtins.str]] = None,
        search: typing.Optional[typing.Union[PowerpackWidgetQueryTableDefinitionRequestQueryEventQuerySearch, typing.Dict[builtins.str, typing.Any]]] = None,
        storage: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param compute: compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute Powerpack#compute}
        :param data_source: The data source for event platform-based queries. Valid values are ``logs``, ``spans``, ``network``, ``rum``, ``security_signals``, ``profiles``, ``audit``, ``events``, ``ci_tests``, ``ci_pipelines``, ``incident_analytics``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param name: The name of query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param indexes: An array of index names to query in the stream. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#indexes Powerpack#indexes}
        :param search: search block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search Powerpack#search}
        :param storage: Storage location (private beta). Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#storage Powerpack#storage}
        '''
        value = PowerpackWidgetQueryTableDefinitionRequestQueryEventQuery(
            compute=compute,
            data_source=data_source,
            name=name,
            cross_org_uuids=cross_org_uuids,
            group_by=group_by,
            indexes=indexes,
            search=search,
            storage=storage,
        )

        return typing.cast(None, jsii.invoke(self, "putEventQuery", [value]))

    @jsii.member(jsii_name="putMetricQuery")
    def put_metric_query(
        self,
        *,
        name: builtins.str,
        query: builtins.str,
        aggregator: typing.Optional[builtins.str] = None,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        data_source: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param name: The name of the query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param query: The metrics query definition. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        :param aggregator: The aggregation methods available for metrics queries. Valid values are ``avg``, ``min``, ``max``, ``sum``, ``last``, ``area``, ``l2norm``, ``percentile``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregator Powerpack#aggregator}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param data_source: The data source for metrics queries. Defaults to ``"metrics"``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        '''
        value = PowerpackWidgetQueryTableDefinitionRequestQueryMetricQuery(
            name=name,
            query=query,
            aggregator=aggregator,
            cross_org_uuids=cross_org_uuids,
            data_source=data_source,
        )

        return typing.cast(None, jsii.invoke(self, "putMetricQuery", [value]))

    @jsii.member(jsii_name="putProcessQuery")
    def put_process_query(
        self,
        *,
        data_source: builtins.str,
        metric: builtins.str,
        name: builtins.str,
        aggregator: typing.Optional[builtins.str] = None,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        is_normalized_cpu: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        limit: typing.Optional[jsii.Number] = None,
        sort: typing.Optional[builtins.str] = None,
        tag_filters: typing.Optional[typing.Sequence[builtins.str]] = None,
        text_filter: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param data_source: The data source for process queries. Valid values are ``process``, ``container``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param metric: The process metric name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        :param name: The name of query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param aggregator: The aggregation methods available for metrics queries. Valid values are ``avg``, ``min``, ``max``, ``sum``, ``last``, ``area``, ``l2norm``, ``percentile``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregator Powerpack#aggregator}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param is_normalized_cpu: Whether to normalize the CPU percentages. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#is_normalized_cpu Powerpack#is_normalized_cpu}
        :param limit: The number of hits to return. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param sort: The direction of the sort. Valid values are ``asc``, ``desc``. Defaults to ``"desc"``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort Powerpack#sort}
        :param tag_filters: An array of tags to filter by. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#tag_filters Powerpack#tag_filters}
        :param text_filter: The text to use as a filter. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#text_filter Powerpack#text_filter}
        '''
        value = PowerpackWidgetQueryTableDefinitionRequestQueryProcessQuery(
            data_source=data_source,
            metric=metric,
            name=name,
            aggregator=aggregator,
            cross_org_uuids=cross_org_uuids,
            is_normalized_cpu=is_normalized_cpu,
            limit=limit,
            sort=sort,
            tag_filters=tag_filters,
            text_filter=text_filter,
        )

        return typing.cast(None, jsii.invoke(self, "putProcessQuery", [value]))

    @jsii.member(jsii_name="putSloQuery")
    def put_slo_query(
        self,
        *,
        data_source: builtins.str,
        measure: builtins.str,
        slo_id: builtins.str,
        additional_query_filters: typing.Optional[builtins.str] = None,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        group_mode: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
        slo_query_type: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param data_source: The data source for SLO queries. Valid values are ``slo``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param measure: SLO measures queries. Valid values are ``good_events``, ``bad_events``, ``good_minutes``, ``bad_minutes``, ``slo_status``, ``error_budget_remaining``, ``burn_rate``, ``error_budget_burndown``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#measure Powerpack#measure}
        :param slo_id: ID of an SLO to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#slo_id Powerpack#slo_id}
        :param additional_query_filters: Additional filters applied to the SLO query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#additional_query_filters Powerpack#additional_query_filters}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param group_mode: Group mode to query measures. Valid values are ``overall``, ``components``. Defaults to ``"overall"``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_mode Powerpack#group_mode}
        :param name: The name of query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param slo_query_type: type of the SLO to query. Valid values are ``metric``, ``monitor``, ``time_slice``. Defaults to ``"metric"``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#slo_query_type Powerpack#slo_query_type}
        '''
        value = PowerpackWidgetQueryTableDefinitionRequestQuerySloQuery(
            data_source=data_source,
            measure=measure,
            slo_id=slo_id,
            additional_query_filters=additional_query_filters,
            cross_org_uuids=cross_org_uuids,
            group_mode=group_mode,
            name=name,
            slo_query_type=slo_query_type,
        )

        return typing.cast(None, jsii.invoke(self, "putSloQuery", [value]))

    @jsii.member(jsii_name="resetApmDependencyStatsQuery")
    def reset_apm_dependency_stats_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetApmDependencyStatsQuery", []))

    @jsii.member(jsii_name="resetApmResourceStatsQuery")
    def reset_apm_resource_stats_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetApmResourceStatsQuery", []))

    @jsii.member(jsii_name="resetCloudCostQuery")
    def reset_cloud_cost_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCloudCostQuery", []))

    @jsii.member(jsii_name="resetEventQuery")
    def reset_event_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetEventQuery", []))

    @jsii.member(jsii_name="resetMetricQuery")
    def reset_metric_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMetricQuery", []))

    @jsii.member(jsii_name="resetProcessQuery")
    def reset_process_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetProcessQuery", []))

    @jsii.member(jsii_name="resetSloQuery")
    def reset_slo_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSloQuery", []))

    @builtins.property
    @jsii.member(jsii_name="apmDependencyStatsQuery")
    def apm_dependency_stats_query(
        self,
    ) -> PowerpackWidgetQueryTableDefinitionRequestQueryApmDependencyStatsQueryOutputReference:
        return typing.cast(PowerpackWidgetQueryTableDefinitionRequestQueryApmDependencyStatsQueryOutputReference, jsii.get(self, "apmDependencyStatsQuery"))

    @builtins.property
    @jsii.member(jsii_name="apmResourceStatsQuery")
    def apm_resource_stats_query(
        self,
    ) -> PowerpackWidgetQueryTableDefinitionRequestQueryApmResourceStatsQueryOutputReference:
        return typing.cast(PowerpackWidgetQueryTableDefinitionRequestQueryApmResourceStatsQueryOutputReference, jsii.get(self, "apmResourceStatsQuery"))

    @builtins.property
    @jsii.member(jsii_name="cloudCostQuery")
    def cloud_cost_query(
        self,
    ) -> PowerpackWidgetQueryTableDefinitionRequestQueryCloudCostQueryOutputReference:
        return typing.cast(PowerpackWidgetQueryTableDefinitionRequestQueryCloudCostQueryOutputReference, jsii.get(self, "cloudCostQuery"))

    @builtins.property
    @jsii.member(jsii_name="eventQuery")
    def event_query(
        self,
    ) -> PowerpackWidgetQueryTableDefinitionRequestQueryEventQueryOutputReference:
        return typing.cast(PowerpackWidgetQueryTableDefinitionRequestQueryEventQueryOutputReference, jsii.get(self, "eventQuery"))

    @builtins.property
    @jsii.member(jsii_name="metricQuery")
    def metric_query(
        self,
    ) -> PowerpackWidgetQueryTableDefinitionRequestQueryMetricQueryOutputReference:
        return typing.cast(PowerpackWidgetQueryTableDefinitionRequestQueryMetricQueryOutputReference, jsii.get(self, "metricQuery"))

    @builtins.property
    @jsii.member(jsii_name="processQuery")
    def process_query(
        self,
    ) -> "PowerpackWidgetQueryTableDefinitionRequestQueryProcessQueryOutputReference":
        return typing.cast("PowerpackWidgetQueryTableDefinitionRequestQueryProcessQueryOutputReference", jsii.get(self, "processQuery"))

    @builtins.property
    @jsii.member(jsii_name="sloQuery")
    def slo_query(
        self,
    ) -> "PowerpackWidgetQueryTableDefinitionRequestQuerySloQueryOutputReference":
        return typing.cast("PowerpackWidgetQueryTableDefinitionRequestQuerySloQueryOutputReference", jsii.get(self, "sloQuery"))

    @builtins.property
    @jsii.member(jsii_name="apmDependencyStatsQueryInput")
    def apm_dependency_stats_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetQueryTableDefinitionRequestQueryApmDependencyStatsQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryTableDefinitionRequestQueryApmDependencyStatsQuery], jsii.get(self, "apmDependencyStatsQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="apmResourceStatsQueryInput")
    def apm_resource_stats_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetQueryTableDefinitionRequestQueryApmResourceStatsQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryTableDefinitionRequestQueryApmResourceStatsQuery], jsii.get(self, "apmResourceStatsQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="cloudCostQueryInput")
    def cloud_cost_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetQueryTableDefinitionRequestQueryCloudCostQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryTableDefinitionRequestQueryCloudCostQuery], jsii.get(self, "cloudCostQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="eventQueryInput")
    def event_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetQueryTableDefinitionRequestQueryEventQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryTableDefinitionRequestQueryEventQuery], jsii.get(self, "eventQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="metricQueryInput")
    def metric_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetQueryTableDefinitionRequestQueryMetricQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryTableDefinitionRequestQueryMetricQuery], jsii.get(self, "metricQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="processQueryInput")
    def process_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetQueryTableDefinitionRequestQueryProcessQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetQueryTableDefinitionRequestQueryProcessQuery"], jsii.get(self, "processQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="sloQueryInput")
    def slo_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetQueryTableDefinitionRequestQuerySloQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetQueryTableDefinitionRequestQuerySloQuery"], jsii.get(self, "sloQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryTableDefinitionRequestQuery]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryTableDefinitionRequestQuery]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryTableDefinitionRequestQuery]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2196510c2c991eae805b9eec20ffddf6666c854123ce429a5ed397cd53b07d03)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestQueryProcessQuery",
    jsii_struct_bases=[],
    name_mapping={
        "data_source": "dataSource",
        "metric": "metric",
        "name": "name",
        "aggregator": "aggregator",
        "cross_org_uuids": "crossOrgUuids",
        "is_normalized_cpu": "isNormalizedCpu",
        "limit": "limit",
        "sort": "sort",
        "tag_filters": "tagFilters",
        "text_filter": "textFilter",
    },
)
class PowerpackWidgetQueryTableDefinitionRequestQueryProcessQuery:
    def __init__(
        self,
        *,
        data_source: builtins.str,
        metric: builtins.str,
        name: builtins.str,
        aggregator: typing.Optional[builtins.str] = None,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        is_normalized_cpu: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        limit: typing.Optional[jsii.Number] = None,
        sort: typing.Optional[builtins.str] = None,
        tag_filters: typing.Optional[typing.Sequence[builtins.str]] = None,
        text_filter: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param data_source: The data source for process queries. Valid values are ``process``, ``container``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param metric: The process metric name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        :param name: The name of query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param aggregator: The aggregation methods available for metrics queries. Valid values are ``avg``, ``min``, ``max``, ``sum``, ``last``, ``area``, ``l2norm``, ``percentile``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregator Powerpack#aggregator}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param is_normalized_cpu: Whether to normalize the CPU percentages. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#is_normalized_cpu Powerpack#is_normalized_cpu}
        :param limit: The number of hits to return. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param sort: The direction of the sort. Valid values are ``asc``, ``desc``. Defaults to ``"desc"``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort Powerpack#sort}
        :param tag_filters: An array of tags to filter by. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#tag_filters Powerpack#tag_filters}
        :param text_filter: The text to use as a filter. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#text_filter Powerpack#text_filter}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__326a29aa8dbd207402b23010fc19b8f0f6b495086728c97d69b5ba6f443389c9)
            check_type(argname="argument data_source", value=data_source, expected_type=type_hints["data_source"])
            check_type(argname="argument metric", value=metric, expected_type=type_hints["metric"])
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument aggregator", value=aggregator, expected_type=type_hints["aggregator"])
            check_type(argname="argument cross_org_uuids", value=cross_org_uuids, expected_type=type_hints["cross_org_uuids"])
            check_type(argname="argument is_normalized_cpu", value=is_normalized_cpu, expected_type=type_hints["is_normalized_cpu"])
            check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
            check_type(argname="argument sort", value=sort, expected_type=type_hints["sort"])
            check_type(argname="argument tag_filters", value=tag_filters, expected_type=type_hints["tag_filters"])
            check_type(argname="argument text_filter", value=text_filter, expected_type=type_hints["text_filter"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "data_source": data_source,
            "metric": metric,
            "name": name,
        }
        if aggregator is not None:
            self._values["aggregator"] = aggregator
        if cross_org_uuids is not None:
            self._values["cross_org_uuids"] = cross_org_uuids
        if is_normalized_cpu is not None:
            self._values["is_normalized_cpu"] = is_normalized_cpu
        if limit is not None:
            self._values["limit"] = limit
        if sort is not None:
            self._values["sort"] = sort
        if tag_filters is not None:
            self._values["tag_filters"] = tag_filters
        if text_filter is not None:
            self._values["text_filter"] = text_filter

    @builtins.property
    def data_source(self) -> builtins.str:
        '''The data source for process queries. Valid values are ``process``, ``container``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        '''
        result = self._values.get("data_source")
        assert result is not None, "Required property 'data_source' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def metric(self) -> builtins.str:
        '''The process metric name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        '''
        result = self._values.get("metric")
        assert result is not None, "Required property 'metric' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def name(self) -> builtins.str:
        '''The name of query for use in formulas.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        '''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def aggregator(self) -> typing.Optional[builtins.str]:
        '''The aggregation methods available for metrics queries. Valid values are ``avg``, ``min``, ``max``, ``sum``, ``last``, ``area``, ``l2norm``, ``percentile``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregator Powerpack#aggregator}
        '''
        result = self._values.get("aggregator")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def cross_org_uuids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''The source organization UUID for cross organization queries. Feature in Private Beta.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        '''
        result = self._values.get("cross_org_uuids")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def is_normalized_cpu(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        '''Whether to normalize the CPU percentages.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#is_normalized_cpu Powerpack#is_normalized_cpu}
        '''
        result = self._values.get("is_normalized_cpu")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)

    @builtins.property
    def limit(self) -> typing.Optional[jsii.Number]:
        '''The number of hits to return.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        '''
        result = self._values.get("limit")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def sort(self) -> typing.Optional[builtins.str]:
        '''The direction of the sort. Valid values are ``asc``, ``desc``. Defaults to ``"desc"``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort Powerpack#sort}
        '''
        result = self._values.get("sort")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def tag_filters(self) -> typing.Optional[typing.List[builtins.str]]:
        '''An array of tags to filter by.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#tag_filters Powerpack#tag_filters}
        '''
        result = self._values.get("tag_filters")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def text_filter(self) -> typing.Optional[builtins.str]:
        '''The text to use as a filter.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#text_filter Powerpack#text_filter}
        '''
        result = self._values.get("text_filter")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryTableDefinitionRequestQueryProcessQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetQueryTableDefinitionRequestQueryProcessQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestQueryProcessQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7208908033ae5129ae52e20cf44c143015c44c8c01785e4b94882a89b5748e3a)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetAggregator")
    def reset_aggregator(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAggregator", []))

    @jsii.member(jsii_name="resetCrossOrgUuids")
    def reset_cross_org_uuids(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCrossOrgUuids", []))

    @jsii.member(jsii_name="resetIsNormalizedCpu")
    def reset_is_normalized_cpu(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetIsNormalizedCpu", []))

    @jsii.member(jsii_name="resetLimit")
    def reset_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLimit", []))

    @jsii.member(jsii_name="resetSort")
    def reset_sort(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSort", []))

    @jsii.member(jsii_name="resetTagFilters")
    def reset_tag_filters(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTagFilters", []))

    @jsii.member(jsii_name="resetTextFilter")
    def reset_text_filter(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTextFilter", []))

    @builtins.property
    @jsii.member(jsii_name="aggregatorInput")
    def aggregator_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregatorInput"))

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuidsInput")
    def cross_org_uuids_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "crossOrgUuidsInput"))

    @builtins.property
    @jsii.member(jsii_name="dataSourceInput")
    def data_source_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "dataSourceInput"))

    @builtins.property
    @jsii.member(jsii_name="isNormalizedCpuInput")
    def is_normalized_cpu_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "isNormalizedCpuInput"))

    @builtins.property
    @jsii.member(jsii_name="limitInput")
    def limit_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "limitInput"))

    @builtins.property
    @jsii.member(jsii_name="metricInput")
    def metric_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "metricInput"))

    @builtins.property
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property
    @jsii.member(jsii_name="sortInput")
    def sort_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "sortInput"))

    @builtins.property
    @jsii.member(jsii_name="tagFiltersInput")
    def tag_filters_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "tagFiltersInput"))

    @builtins.property
    @jsii.member(jsii_name="textFilterInput")
    def text_filter_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "textFilterInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregator")
    def aggregator(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregator"))

    @aggregator.setter
    def aggregator(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bfe1fd9afd88b5e8361d6d7f707f3b9925770d858a3d3853d44da890d98163d1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregator", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuids")
    def cross_org_uuids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "crossOrgUuids"))

    @cross_org_uuids.setter
    def cross_org_uuids(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4826325bd79065163b2b77cf82f16b4e0a066691b74e5efce514952845d236d1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "crossOrgUuids", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="dataSource")
    def data_source(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "dataSource"))

    @data_source.setter
    def data_source(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__89f025c51d65d37fe47b33ab860a20251586f8b7475caf349b15ffb390f607af)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "dataSource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="isNormalizedCpu")
    def is_normalized_cpu(
        self,
    ) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "isNormalizedCpu"))

    @is_normalized_cpu.setter
    def is_normalized_cpu(
        self,
        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e81141587ee9841a571469c580aa997db25c869b283d0ff75adb9d21c2dcec96)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "isNormalizedCpu", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="limit")
    def limit(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "limit"))

    @limit.setter
    def limit(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c8a7e22178a38911c7661e9364e27594c75efeeda25ee4c8754ee45658c375f9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "limit", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="metric")
    def metric(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "metric"))

    @metric.setter
    def metric(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e4e30456fe545d2ca3ed3810b922fe99b733bf6a2fff19d334e1bdecff973fd2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "metric", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__adde77a2a2edd145f4d370d423c431eafaef2e83310ad0b7d1a82e1629d73d99)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "name", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="sort")
    def sort(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "sort"))

    @sort.setter
    def sort(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c053df742da9a7f5ed266738311d11214e7590e9912e588d4cfb147e30c7b488)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "sort", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="tagFilters")
    def tag_filters(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "tagFilters"))

    @tag_filters.setter
    def tag_filters(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0bafdbe0e5c6dc4c1ec6c7a0e9e90e4fb365a75c79ea22bca119fefc2ca4fdd0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "tagFilters", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="textFilter")
    def text_filter(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "textFilter"))

    @text_filter.setter
    def text_filter(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fa8cdc28981e33d074903ef42cb9125ebb61fb59ff119709d6ccd9d643ca98ca)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "textFilter", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetQueryTableDefinitionRequestQueryProcessQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryTableDefinitionRequestQueryProcessQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetQueryTableDefinitionRequestQueryProcessQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__14ff4c5d348d1b95013d1dc217b7734158bfa923b5439e2f896e70585524bae1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestQuerySloQuery",
    jsii_struct_bases=[],
    name_mapping={
        "data_source": "dataSource",
        "measure": "measure",
        "slo_id": "sloId",
        "additional_query_filters": "additionalQueryFilters",
        "cross_org_uuids": "crossOrgUuids",
        "group_mode": "groupMode",
        "name": "name",
        "slo_query_type": "sloQueryType",
    },
)
class PowerpackWidgetQueryTableDefinitionRequestQuerySloQuery:
    def __init__(
        self,
        *,
        data_source: builtins.str,
        measure: builtins.str,
        slo_id: builtins.str,
        additional_query_filters: typing.Optional[builtins.str] = None,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        group_mode: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
        slo_query_type: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param data_source: The data source for SLO queries. Valid values are ``slo``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param measure: SLO measures queries. Valid values are ``good_events``, ``bad_events``, ``good_minutes``, ``bad_minutes``, ``slo_status``, ``error_budget_remaining``, ``burn_rate``, ``error_budget_burndown``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#measure Powerpack#measure}
        :param slo_id: ID of an SLO to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#slo_id Powerpack#slo_id}
        :param additional_query_filters: Additional filters applied to the SLO query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#additional_query_filters Powerpack#additional_query_filters}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param group_mode: Group mode to query measures. Valid values are ``overall``, ``components``. Defaults to ``"overall"``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_mode Powerpack#group_mode}
        :param name: The name of query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param slo_query_type: type of the SLO to query. Valid values are ``metric``, ``monitor``, ``time_slice``. Defaults to ``"metric"``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#slo_query_type Powerpack#slo_query_type}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__25f1981fd78db2beb656a6036b38a25c0d5a97604437a3f61bf70fa533e3e84a)
            check_type(argname="argument data_source", value=data_source, expected_type=type_hints["data_source"])
            check_type(argname="argument measure", value=measure, expected_type=type_hints["measure"])
            check_type(argname="argument slo_id", value=slo_id, expected_type=type_hints["slo_id"])
            check_type(argname="argument additional_query_filters", value=additional_query_filters, expected_type=type_hints["additional_query_filters"])
            check_type(argname="argument cross_org_uuids", value=cross_org_uuids, expected_type=type_hints["cross_org_uuids"])
            check_type(argname="argument group_mode", value=group_mode, expected_type=type_hints["group_mode"])
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument slo_query_type", value=slo_query_type, expected_type=type_hints["slo_query_type"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "data_source": data_source,
            "measure": measure,
            "slo_id": slo_id,
        }
        if additional_query_filters is not None:
            self._values["additional_query_filters"] = additional_query_filters
        if cross_org_uuids is not None:
            self._values["cross_org_uuids"] = cross_org_uuids
        if group_mode is not None:
            self._values["group_mode"] = group_mode
        if name is not None:
            self._values["name"] = name
        if slo_query_type is not None:
            self._values["slo_query_type"] = slo_query_type

    @builtins.property
    def data_source(self) -> builtins.str:
        '''The data source for SLO queries. Valid values are ``slo``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        '''
        result = self._values.get("data_source")
        assert result is not None, "Required property 'data_source' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def measure(self) -> builtins.str:
        '''SLO measures queries. Valid values are ``good_events``, ``bad_events``, ``good_minutes``, ``bad_minutes``, ``slo_status``, ``error_budget_remaining``, ``burn_rate``, ``error_budget_burndown``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#measure Powerpack#measure}
        '''
        result = self._values.get("measure")
        assert result is not None, "Required property 'measure' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def slo_id(self) -> builtins.str:
        '''ID of an SLO to query.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#slo_id Powerpack#slo_id}
        '''
        result = self._values.get("slo_id")
        assert result is not None, "Required property 'slo_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def additional_query_filters(self) -> typing.Optional[builtins.str]:
        '''Additional filters applied to the SLO query.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#additional_query_filters Powerpack#additional_query_filters}
        '''
        result = self._values.get("additional_query_filters")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def cross_org_uuids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''The source organization UUID for cross organization queries. Feature in Private Beta.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        '''
        result = self._values.get("cross_org_uuids")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def group_mode(self) -> typing.Optional[builtins.str]:
        '''Group mode to query measures. Valid values are ``overall``, ``components``. Defaults to ``"overall"``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_mode Powerpack#group_mode}
        '''
        result = self._values.get("group_mode")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''The name of query for use in formulas.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        '''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def slo_query_type(self) -> typing.Optional[builtins.str]:
        '''type of the SLO to query. Valid values are ``metric``, ``monitor``, ``time_slice``. Defaults to ``"metric"``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#slo_query_type Powerpack#slo_query_type}
        '''
        result = self._values.get("slo_query_type")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryTableDefinitionRequestQuerySloQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetQueryTableDefinitionRequestQuerySloQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestQuerySloQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7fdf1632ca0d0451641b181367c6bd4376c8bce4fe1b8efb4819c48bb3f92bde)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetAdditionalQueryFilters")
    def reset_additional_query_filters(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAdditionalQueryFilters", []))

    @jsii.member(jsii_name="resetCrossOrgUuids")
    def reset_cross_org_uuids(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCrossOrgUuids", []))

    @jsii.member(jsii_name="resetGroupMode")
    def reset_group_mode(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGroupMode", []))

    @jsii.member(jsii_name="resetName")
    def reset_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetName", []))

    @jsii.member(jsii_name="resetSloQueryType")
    def reset_slo_query_type(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSloQueryType", []))

    @builtins.property
    @jsii.member(jsii_name="additionalQueryFiltersInput")
    def additional_query_filters_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "additionalQueryFiltersInput"))

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuidsInput")
    def cross_org_uuids_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "crossOrgUuidsInput"))

    @builtins.property
    @jsii.member(jsii_name="dataSourceInput")
    def data_source_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "dataSourceInput"))

    @builtins.property
    @jsii.member(jsii_name="groupModeInput")
    def group_mode_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "groupModeInput"))

    @builtins.property
    @jsii.member(jsii_name="measureInput")
    def measure_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "measureInput"))

    @builtins.property
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property
    @jsii.member(jsii_name="sloIdInput")
    def slo_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "sloIdInput"))

    @builtins.property
    @jsii.member(jsii_name="sloQueryTypeInput")
    def slo_query_type_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "sloQueryTypeInput"))

    @builtins.property
    @jsii.member(jsii_name="additionalQueryFilters")
    def additional_query_filters(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "additionalQueryFilters"))

    @additional_query_filters.setter
    def additional_query_filters(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ba9a04f472a9ceb39ecfcd1e1a5979ac1a8e5fa9c59fd0ec75e244a061f86bc2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "additionalQueryFilters", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuids")
    def cross_org_uuids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "crossOrgUuids"))

    @cross_org_uuids.setter
    def cross_org_uuids(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f97c38f3ba010fd7bc83633daf024c322da41c8944bbc9e0e4e2401a67426524)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "crossOrgUuids", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="dataSource")
    def data_source(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "dataSource"))

    @data_source.setter
    def data_source(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e3babebabf66a0d6321121d5c33e98aac3142a70cecb442b7d8fe2ff3e1b1bd2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "dataSource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="groupMode")
    def group_mode(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "groupMode"))

    @group_mode.setter
    def group_mode(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__981f6ff0bfbac290706889817a0b791e1d55d22cc03cbf6913dccfd5802e60f4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "groupMode", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="measure")
    def measure(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "measure"))

    @measure.setter
    def measure(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a105ce01f2126aeb484810fc86a625c3b670faeaea71e08407368e01bab2f895)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "measure", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__99a55068cb2d5dba115a45b584fe32e179f1d10c21456ef6793938a376cdcb05)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "name", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="sloId")
    def slo_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "sloId"))

    @slo_id.setter
    def slo_id(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dca72e29cf6a901b5b96d3525ed018ac4b7e97032b6b608c4ac3ad0f0501072e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "sloId", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="sloQueryType")
    def slo_query_type(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "sloQueryType"))

    @slo_query_type.setter
    def slo_query_type(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0a1416491dd7147e4a1e082f247fd1b2fa326da08fa3e4a60c2198a4bc56d55a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "sloQueryType", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetQueryTableDefinitionRequestQuerySloQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryTableDefinitionRequestQuerySloQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetQueryTableDefinitionRequestQuerySloQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a6ab87ad862b41190ffe7d2938c3ad85d348a293081fb5db406f1e61750b6c0e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestRumQuery",
    jsii_struct_bases=[],
    name_mapping={
        "index": "index",
        "compute_query": "computeQuery",
        "group_by": "groupBy",
        "multi_compute": "multiCompute",
        "search_query": "searchQuery",
    },
)
class PowerpackWidgetQueryTableDefinitionRequestRumQuery:
    def __init__(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union["PowerpackWidgetQueryTableDefinitionRequestRumQueryComputeQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetQueryTableDefinitionRequestRumQueryGroupBy", typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetQueryTableDefinitionRequestRumQueryMultiCompute", typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        if isinstance(compute_query, dict):
            compute_query = PowerpackWidgetQueryTableDefinitionRequestRumQueryComputeQuery(**compute_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ee68d4afe66831466f09108e5a2705edd9f59010202740b571fe14561bcef956)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
            check_type(argname="argument compute_query", value=compute_query, expected_type=type_hints["compute_query"])
            check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
            check_type(argname="argument multi_compute", value=multi_compute, expected_type=type_hints["multi_compute"])
            check_type(argname="argument search_query", value=search_query, expected_type=type_hints["search_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "index": index,
        }
        if compute_query is not None:
            self._values["compute_query"] = compute_query
        if group_by is not None:
            self._values["group_by"] = group_by
        if multi_compute is not None:
            self._values["multi_compute"] = multi_compute
        if search_query is not None:
            self._values["search_query"] = search_query

    @builtins.property
    def index(self) -> builtins.str:
        '''The name of the index to query.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        '''
        result = self._values.get("index")
        assert result is not None, "Required property 'index' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def compute_query(
        self,
    ) -> typing.Optional["PowerpackWidgetQueryTableDefinitionRequestRumQueryComputeQuery"]:
        '''compute_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        '''
        result = self._values.get("compute_query")
        return typing.cast(typing.Optional["PowerpackWidgetQueryTableDefinitionRequestRumQueryComputeQuery"], result)

    @builtins.property
    def group_by(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetQueryTableDefinitionRequestRumQueryGroupBy"]]]:
        '''group_by block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        '''
        result = self._values.get("group_by")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetQueryTableDefinitionRequestRumQueryGroupBy"]]], result)

    @builtins.property
    def multi_compute(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetQueryTableDefinitionRequestRumQueryMultiCompute"]]]:
        '''multi_compute block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        '''
        result = self._values.get("multi_compute")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetQueryTableDefinitionRequestRumQueryMultiCompute"]]], result)

    @builtins.property
    def search_query(self) -> typing.Optional[builtins.str]:
        '''The search query to use.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        result = self._values.get("search_query")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryTableDefinitionRequestRumQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestRumQueryComputeQuery",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetQueryTableDefinitionRequestRumQueryComputeQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__462ddfc00a86ae0ab4d4f44ca801825e4ebeac1fd1108d5cab32593a20732b85)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryTableDefinitionRequestRumQueryComputeQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetQueryTableDefinitionRequestRumQueryComputeQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestRumQueryComputeQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6b9ccfaae436d9662b1f2a5b1953ff04eb1ab8e5af15f84f16a874ccc65b5733)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8350aa26358e79aabbaccff8ef0135ca26359579ec33f87a5ba6e19feac8f85e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__69597dc872740ba9103caa43af33458d48132fc516da8a5f8730213e6200c66a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__30df64ca280b564b924d83765693c1b195635d144c51d92f6726435dd64a1575)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetQueryTableDefinitionRequestRumQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryTableDefinitionRequestRumQueryComputeQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetQueryTableDefinitionRequestRumQueryComputeQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__36dc59900b99a182ca622a8e1380e3fdb0075910b3c27e8321e7e061f8003290)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestRumQueryGroupBy",
    jsii_struct_bases=[],
    name_mapping={"facet": "facet", "limit": "limit", "sort_query": "sortQuery"},
)
class PowerpackWidgetQueryTableDefinitionRequestRumQueryGroupBy:
    def __init__(
        self,
        *,
        facet: typing.Optional[builtins.str] = None,
        limit: typing.Optional[jsii.Number] = None,
        sort_query: typing.Optional[typing.Union["PowerpackWidgetQueryTableDefinitionRequestRumQueryGroupBySortQuery", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param limit: The maximum number of items in the group. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param sort_query: sort_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        if isinstance(sort_query, dict):
            sort_query = PowerpackWidgetQueryTableDefinitionRequestRumQueryGroupBySortQuery(**sort_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2bfdf3a18953c2cd114bf618c835eb05f5be80c9e220e5ba6c4df07e9ba00a30)
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
            check_type(argname="argument sort_query", value=sort_query, expected_type=type_hints["sort_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if facet is not None:
            self._values["facet"] = facet
        if limit is not None:
            self._values["limit"] = limit
        if sort_query is not None:
            self._values["sort_query"] = sort_query

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def limit(self) -> typing.Optional[jsii.Number]:
        '''The maximum number of items in the group.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        '''
        result = self._values.get("limit")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def sort_query(
        self,
    ) -> typing.Optional["PowerpackWidgetQueryTableDefinitionRequestRumQueryGroupBySortQuery"]:
        '''sort_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        result = self._values.get("sort_query")
        return typing.cast(typing.Optional["PowerpackWidgetQueryTableDefinitionRequestRumQueryGroupBySortQuery"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryTableDefinitionRequestRumQueryGroupBy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetQueryTableDefinitionRequestRumQueryGroupByList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestRumQueryGroupByList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4ef594a518ce9bfd931486e0bf4e21a0012b329a329bba5d32666ac6d480cca3)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetQueryTableDefinitionRequestRumQueryGroupByOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4b3d8e2db264d0966c9623b8ee43c2b4cf575e7a804fa3c5083170591fb3547c)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetQueryTableDefinitionRequestRumQueryGroupByOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__72c9459b00f1ed4358d2337d8279260cc80166a85d1684bf55e34b9344d37704)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a51bd31d4282a978b6a7b600bda1d4f59df8aa16c804f39cefd6fa6277050eba)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e54d96cc79eb1de28209654cdda4f0a7ac2ef18387a1257d1d5e8617920c5bd8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionRequestRumQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionRequestRumQueryGroupBy]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionRequestRumQueryGroupBy]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a3665967afba47cc472bcff8088a50732bcf4a412ce715ca2b0808c439890d6f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetQueryTableDefinitionRequestRumQueryGroupByOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestRumQueryGroupByOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dae8136fd4d809d50994510028fa9aada6275b56c44d750afef1a7cd01457da5)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putSortQuery")
    def put_sort_query(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        value = PowerpackWidgetQueryTableDefinitionRequestRumQueryGroupBySortQuery(
            aggregation=aggregation, order=order, facet=facet
        )

        return typing.cast(None, jsii.invoke(self, "putSortQuery", [value]))

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetLimit")
    def reset_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLimit", []))

    @jsii.member(jsii_name="resetSortQuery")
    def reset_sort_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSortQuery", []))

    @builtins.property
    @jsii.member(jsii_name="sortQuery")
    def sort_query(
        self,
    ) -> "PowerpackWidgetQueryTableDefinitionRequestRumQueryGroupBySortQueryOutputReference":
        return typing.cast("PowerpackWidgetQueryTableDefinitionRequestRumQueryGroupBySortQueryOutputReference", jsii.get(self, "sortQuery"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="limitInput")
    def limit_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "limitInput"))

    @builtins.property
    @jsii.member(jsii_name="sortQueryInput")
    def sort_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetQueryTableDefinitionRequestRumQueryGroupBySortQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetQueryTableDefinitionRequestRumQueryGroupBySortQuery"], jsii.get(self, "sortQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__01b8ff5ff52c48ded9dc1a8a3e56ba9820a41a7282061426534089783b9f3fe9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="limit")
    def limit(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "limit"))

    @limit.setter
    def limit(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__956cdf048dabd1002a53079dd5f23becc25fa90b438cc89b3b92fc560b18fed7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "limit", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryTableDefinitionRequestRumQueryGroupBy]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryTableDefinitionRequestRumQueryGroupBy]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryTableDefinitionRequestRumQueryGroupBy]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4ce36199569b29aa1821afb5a6c9e699310ad64f891215cc9421be70e94d4de0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestRumQueryGroupBySortQuery",
    jsii_struct_bases=[],
    name_mapping={"aggregation": "aggregation", "order": "order", "facet": "facet"},
)
class PowerpackWidgetQueryTableDefinitionRequestRumQueryGroupBySortQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__00a2fa4ab36cf23a89e72605c7380f322bd385adf6766d1df241c54d333789bf)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument order", value=order, expected_type=type_hints["order"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
            "order": order,
        }
        if facet is not None:
            self._values["facet"] = facet

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def order(self) -> builtins.str:
        '''Widget sorting methods. Valid values are ``asc``, ``desc``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        result = self._values.get("order")
        assert result is not None, "Required property 'order' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryTableDefinitionRequestRumQueryGroupBySortQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetQueryTableDefinitionRequestRumQueryGroupBySortQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestRumQueryGroupBySortQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__30ac34c3404fd96fe700cfa877e519b1c602f0457667b7fa891605e58b09519e)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="orderInput")
    def order_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "orderInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ed153a857fbcc7b59242be4fbc52297c7a216cf31eebb2f07438331681937578)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6ea11171394ba495d3a1835b3c92bd987f4abeebbb67b5ab104f490fe57a3b4a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="order")
    def order(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "order"))

    @order.setter
    def order(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e77717026bc60f60f82f01ba55778df4e280bb0713fd3e7b9ed620dc6aec4e85)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "order", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetQueryTableDefinitionRequestRumQueryGroupBySortQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryTableDefinitionRequestRumQueryGroupBySortQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetQueryTableDefinitionRequestRumQueryGroupBySortQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1a7123420e914f8cd4cdf2950823e7745c815b0198a094f49d7c2da809a2d1c0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestRumQueryMultiCompute",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetQueryTableDefinitionRequestRumQueryMultiCompute:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__603f52a5cacd0c9999a0f580067429f8175a613b0cdaa4b8c97fa93679e4220e)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryTableDefinitionRequestRumQueryMultiCompute(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetQueryTableDefinitionRequestRumQueryMultiComputeList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestRumQueryMultiComputeList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1496f3d733d28fe87f5581871afd7bb376e63c9bf22b4cf2546bfb94fbe68a60)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetQueryTableDefinitionRequestRumQueryMultiComputeOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__de182dca575f5346648597a0cd42d845455701f4efbfe3a8df40601ec1d57241)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetQueryTableDefinitionRequestRumQueryMultiComputeOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3cbfacbf9a67846825febfff1bd59fd0b74518474f9d8e064b607bf737f8813a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__82dc8a15d023a9df5ec132970c871a8f5f3ac818a852753b0d20d2e9ee1312ef)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__02b1193ba01a509abbc4717028345170ffb7ca4456b0059325830910f55805cb)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionRequestRumQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionRequestRumQueryMultiCompute]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionRequestRumQueryMultiCompute]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3ca7feb1490c1f366b6b28d28463b3587af077b1f51174350d387706e74b7190)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetQueryTableDefinitionRequestRumQueryMultiComputeOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestRumQueryMultiComputeOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__840ed1f0c4fed7593407cc89904ea6d150af08920ed648436e65a71d2d9f1577)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__12d4ca9a26ac4b93f9299164a3a87d7bd0501b657630cdd49b214583b39be47d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dc8de752823454e9de25f7f404ffde916b4c2adccdacaf8950ee4f07d85dc7cf)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__58ea0911c19cf29868389de46a061a0cad7302aedfc0809f2c0a5e0ce7cdcb2e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryTableDefinitionRequestRumQueryMultiCompute]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryTableDefinitionRequestRumQueryMultiCompute]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryTableDefinitionRequestRumQueryMultiCompute]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8e9123e2bc32019f243b0ad0dee9916a5e1f7f5601bed01bd7808613ea45f1f5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetQueryTableDefinitionRequestRumQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestRumQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8d3212538bd804e7c521dce343c628fe5e25bfd03313d1d1dd611f28f2b3e323)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putComputeQuery")
    def put_compute_query(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        value = PowerpackWidgetQueryTableDefinitionRequestRumQueryComputeQuery(
            aggregation=aggregation, facet=facet, interval=interval
        )

        return typing.cast(None, jsii.invoke(self, "putComputeQuery", [value]))

    @jsii.member(jsii_name="putGroupBy")
    def put_group_by(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryTableDefinitionRequestRumQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f4b9ede13ba36dca4aee61dea4b4783cba9c81281ba74c89a8f85149b342f194)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putGroupBy", [value]))

    @jsii.member(jsii_name="putMultiCompute")
    def put_multi_compute(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryTableDefinitionRequestRumQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__18baa7f7d27fcc94ff6d446c1075f8f5e17b954a8e779f33fd7602469be7a12c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putMultiCompute", [value]))

    @jsii.member(jsii_name="resetComputeQuery")
    def reset_compute_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetComputeQuery", []))

    @jsii.member(jsii_name="resetGroupBy")
    def reset_group_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGroupBy", []))

    @jsii.member(jsii_name="resetMultiCompute")
    def reset_multi_compute(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMultiCompute", []))

    @jsii.member(jsii_name="resetSearchQuery")
    def reset_search_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSearchQuery", []))

    @builtins.property
    @jsii.member(jsii_name="computeQuery")
    def compute_query(
        self,
    ) -> PowerpackWidgetQueryTableDefinitionRequestRumQueryComputeQueryOutputReference:
        return typing.cast(PowerpackWidgetQueryTableDefinitionRequestRumQueryComputeQueryOutputReference, jsii.get(self, "computeQuery"))

    @builtins.property
    @jsii.member(jsii_name="groupBy")
    def group_by(self) -> PowerpackWidgetQueryTableDefinitionRequestRumQueryGroupByList:
        return typing.cast(PowerpackWidgetQueryTableDefinitionRequestRumQueryGroupByList, jsii.get(self, "groupBy"))

    @builtins.property
    @jsii.member(jsii_name="multiCompute")
    def multi_compute(
        self,
    ) -> PowerpackWidgetQueryTableDefinitionRequestRumQueryMultiComputeList:
        return typing.cast(PowerpackWidgetQueryTableDefinitionRequestRumQueryMultiComputeList, jsii.get(self, "multiCompute"))

    @builtins.property
    @jsii.member(jsii_name="computeQueryInput")
    def compute_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetQueryTableDefinitionRequestRumQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryTableDefinitionRequestRumQueryComputeQuery], jsii.get(self, "computeQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="groupByInput")
    def group_by_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionRequestRumQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionRequestRumQueryGroupBy]]], jsii.get(self, "groupByInput"))

    @builtins.property
    @jsii.member(jsii_name="indexInput")
    def index_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "indexInput"))

    @builtins.property
    @jsii.member(jsii_name="multiComputeInput")
    def multi_compute_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionRequestRumQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionRequestRumQueryMultiCompute]]], jsii.get(self, "multiComputeInput"))

    @builtins.property
    @jsii.member(jsii_name="searchQueryInput")
    def search_query_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "searchQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="index")
    def index(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "index"))

    @index.setter
    def index(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c9499ea2b6592d6363527d6c5c13ac2d35a85f5ae8fda19368026b717fa2f49d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "index", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="searchQuery")
    def search_query(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "searchQuery"))

    @search_query.setter
    def search_query(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6dc570fef305db1cc2926e3579dad3ea428f2e316a775cbb95482d53dbd44954)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "searchQuery", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetQueryTableDefinitionRequestRumQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryTableDefinitionRequestRumQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetQueryTableDefinitionRequestRumQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__761632ef89475ffd0b140b7abfba7b53d146f56c62dcb1154e77335d5194a1eb)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestSecurityQuery",
    jsii_struct_bases=[],
    name_mapping={
        "index": "index",
        "compute_query": "computeQuery",
        "group_by": "groupBy",
        "multi_compute": "multiCompute",
        "search_query": "searchQuery",
    },
)
class PowerpackWidgetQueryTableDefinitionRequestSecurityQuery:
    def __init__(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union["PowerpackWidgetQueryTableDefinitionRequestSecurityQueryComputeQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetQueryTableDefinitionRequestSecurityQueryGroupBy", typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetQueryTableDefinitionRequestSecurityQueryMultiCompute", typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        if isinstance(compute_query, dict):
            compute_query = PowerpackWidgetQueryTableDefinitionRequestSecurityQueryComputeQuery(**compute_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__aeed11d1580506f81ffe240e8d1fecd109e9a4b118808c3621e88dfb4f05144a)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
            check_type(argname="argument compute_query", value=compute_query, expected_type=type_hints["compute_query"])
            check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
            check_type(argname="argument multi_compute", value=multi_compute, expected_type=type_hints["multi_compute"])
            check_type(argname="argument search_query", value=search_query, expected_type=type_hints["search_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "index": index,
        }
        if compute_query is not None:
            self._values["compute_query"] = compute_query
        if group_by is not None:
            self._values["group_by"] = group_by
        if multi_compute is not None:
            self._values["multi_compute"] = multi_compute
        if search_query is not None:
            self._values["search_query"] = search_query

    @builtins.property
    def index(self) -> builtins.str:
        '''The name of the index to query.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        '''
        result = self._values.get("index")
        assert result is not None, "Required property 'index' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def compute_query(
        self,
    ) -> typing.Optional["PowerpackWidgetQueryTableDefinitionRequestSecurityQueryComputeQuery"]:
        '''compute_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        '''
        result = self._values.get("compute_query")
        return typing.cast(typing.Optional["PowerpackWidgetQueryTableDefinitionRequestSecurityQueryComputeQuery"], result)

    @builtins.property
    def group_by(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetQueryTableDefinitionRequestSecurityQueryGroupBy"]]]:
        '''group_by block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        '''
        result = self._values.get("group_by")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetQueryTableDefinitionRequestSecurityQueryGroupBy"]]], result)

    @builtins.property
    def multi_compute(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetQueryTableDefinitionRequestSecurityQueryMultiCompute"]]]:
        '''multi_compute block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        '''
        result = self._values.get("multi_compute")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetQueryTableDefinitionRequestSecurityQueryMultiCompute"]]], result)

    @builtins.property
    def search_query(self) -> typing.Optional[builtins.str]:
        '''The search query to use.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        result = self._values.get("search_query")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryTableDefinitionRequestSecurityQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestSecurityQueryComputeQuery",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetQueryTableDefinitionRequestSecurityQueryComputeQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e04de7de2212164663ff4eccb844ce04966503c92efa7fb25cee91543a6a40b5)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryTableDefinitionRequestSecurityQueryComputeQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetQueryTableDefinitionRequestSecurityQueryComputeQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestSecurityQueryComputeQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b2bd61ef5e0143139a81613dbc677fa6e4522b14dd6f179557e399f5bc5ef63f)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4721597dbe82c0bcb75ccc59b47e8570e51273fbb658ffad47be0614d2a56c63)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__447de83ada2350462548da30a474b32bf27285f227045c0cfc720e83460fa9a4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e7b1108c35a6a43718fe35baadfbc3a9485eb564231493f9e82e267660bc2383)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetQueryTableDefinitionRequestSecurityQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryTableDefinitionRequestSecurityQueryComputeQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetQueryTableDefinitionRequestSecurityQueryComputeQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fad64f413f928e34652b9ece946378ac9cda1bb0d58d67abeb86a4b4cbe0ea5e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestSecurityQueryGroupBy",
    jsii_struct_bases=[],
    name_mapping={"facet": "facet", "limit": "limit", "sort_query": "sortQuery"},
)
class PowerpackWidgetQueryTableDefinitionRequestSecurityQueryGroupBy:
    def __init__(
        self,
        *,
        facet: typing.Optional[builtins.str] = None,
        limit: typing.Optional[jsii.Number] = None,
        sort_query: typing.Optional[typing.Union["PowerpackWidgetQueryTableDefinitionRequestSecurityQueryGroupBySortQuery", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param limit: The maximum number of items in the group. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param sort_query: sort_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        if isinstance(sort_query, dict):
            sort_query = PowerpackWidgetQueryTableDefinitionRequestSecurityQueryGroupBySortQuery(**sort_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__054b4d5226ed16d1781b4c5244e11bb96fc292d71b46a75b45e35d279328a6a1)
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
            check_type(argname="argument sort_query", value=sort_query, expected_type=type_hints["sort_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if facet is not None:
            self._values["facet"] = facet
        if limit is not None:
            self._values["limit"] = limit
        if sort_query is not None:
            self._values["sort_query"] = sort_query

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def limit(self) -> typing.Optional[jsii.Number]:
        '''The maximum number of items in the group.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        '''
        result = self._values.get("limit")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def sort_query(
        self,
    ) -> typing.Optional["PowerpackWidgetQueryTableDefinitionRequestSecurityQueryGroupBySortQuery"]:
        '''sort_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        result = self._values.get("sort_query")
        return typing.cast(typing.Optional["PowerpackWidgetQueryTableDefinitionRequestSecurityQueryGroupBySortQuery"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryTableDefinitionRequestSecurityQueryGroupBy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetQueryTableDefinitionRequestSecurityQueryGroupByList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestSecurityQueryGroupByList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b37a3aa1b9a8b357910aff435603cb7d2907fe74add327e825fd7550d62e75fd)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetQueryTableDefinitionRequestSecurityQueryGroupByOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__533b12f52b0ce2626610f73e992c522c00c6ca5ef3ab2a392644c9e7dabe2db8)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetQueryTableDefinitionRequestSecurityQueryGroupByOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5f2a70380463ac14d612a845b9404ad495e55232c67fca3cde0ccfc597c21c19)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__23f14f7249c8d019187edb5905ca306b33f2abc77d7918b3cd5598b254e9c0dc)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__85cc972590dd38b71c20e195f6f03646a43b2b5c4e8989727d18b402cb9fd4bc)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionRequestSecurityQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionRequestSecurityQueryGroupBy]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionRequestSecurityQueryGroupBy]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e7fb8a24e821d19921f2a3f7d04da86f5810c9b7f70bf08510768652544a32a6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetQueryTableDefinitionRequestSecurityQueryGroupByOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestSecurityQueryGroupByOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__45c3b6d4882b7ae877cfcc283b9d192e5c0a9b465036aff1d2e9ece2946498fa)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putSortQuery")
    def put_sort_query(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        value = PowerpackWidgetQueryTableDefinitionRequestSecurityQueryGroupBySortQuery(
            aggregation=aggregation, order=order, facet=facet
        )

        return typing.cast(None, jsii.invoke(self, "putSortQuery", [value]))

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetLimit")
    def reset_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLimit", []))

    @jsii.member(jsii_name="resetSortQuery")
    def reset_sort_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSortQuery", []))

    @builtins.property
    @jsii.member(jsii_name="sortQuery")
    def sort_query(
        self,
    ) -> "PowerpackWidgetQueryTableDefinitionRequestSecurityQueryGroupBySortQueryOutputReference":
        return typing.cast("PowerpackWidgetQueryTableDefinitionRequestSecurityQueryGroupBySortQueryOutputReference", jsii.get(self, "sortQuery"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="limitInput")
    def limit_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "limitInput"))

    @builtins.property
    @jsii.member(jsii_name="sortQueryInput")
    def sort_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetQueryTableDefinitionRequestSecurityQueryGroupBySortQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetQueryTableDefinitionRequestSecurityQueryGroupBySortQuery"], jsii.get(self, "sortQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2abbd70e877be8c503c5410e441889c714f62ae89373303a7afe118b2ccb3a5d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="limit")
    def limit(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "limit"))

    @limit.setter
    def limit(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1d93e18325f343b54853f9bbee968e3064d388d67e0d5cdaafee2d33f0287468)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "limit", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryTableDefinitionRequestSecurityQueryGroupBy]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryTableDefinitionRequestSecurityQueryGroupBy]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryTableDefinitionRequestSecurityQueryGroupBy]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9fc139bf74e1492f465edfdcfe8e4b9f3b2dc0baaff6e480e07cc36d8627c9ec)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestSecurityQueryGroupBySortQuery",
    jsii_struct_bases=[],
    name_mapping={"aggregation": "aggregation", "order": "order", "facet": "facet"},
)
class PowerpackWidgetQueryTableDefinitionRequestSecurityQueryGroupBySortQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8a4bd704d37529ad1ab07fa07b2eeb20f60b33dd2dfce755336a9fa6de5d199a)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument order", value=order, expected_type=type_hints["order"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
            "order": order,
        }
        if facet is not None:
            self._values["facet"] = facet

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def order(self) -> builtins.str:
        '''Widget sorting methods. Valid values are ``asc``, ``desc``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        result = self._values.get("order")
        assert result is not None, "Required property 'order' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryTableDefinitionRequestSecurityQueryGroupBySortQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetQueryTableDefinitionRequestSecurityQueryGroupBySortQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestSecurityQueryGroupBySortQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d601e6e5c9f8e7a4739eb010164e0e8622334fdd0d7803671dd9ddac1af7fdf5)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="orderInput")
    def order_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "orderInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cf8d4a453885d3bc4fea90c06c2425e6fd2e5e18cd87750c1d9a1eb2d2865ba2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5c40ac6a5fa77af19c870f8bbcf232527a866da7b772bd5d9e6b51dc91e4ee96)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="order")
    def order(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "order"))

    @order.setter
    def order(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__22c266d74ef1134d1d1bfd1448cb01f13ce8c4666079be2ee5d46dc2b76c0004)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "order", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetQueryTableDefinitionRequestSecurityQueryGroupBySortQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryTableDefinitionRequestSecurityQueryGroupBySortQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetQueryTableDefinitionRequestSecurityQueryGroupBySortQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a61b35e7076243f1bc8b1a4a6f9349747d31eb61072dad07e2d69cc1af38dea3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestSecurityQueryMultiCompute",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetQueryTableDefinitionRequestSecurityQueryMultiCompute:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a823ae4eb42de7a134fbbbeef5805e56c9e9786bc097b221d666e5f3edbc56de)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryTableDefinitionRequestSecurityQueryMultiCompute(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetQueryTableDefinitionRequestSecurityQueryMultiComputeList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestSecurityQueryMultiComputeList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b2fcaa2c9310508af1b57f1e769791462b79c636ab6dd7130ffee9ec0dadd989)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetQueryTableDefinitionRequestSecurityQueryMultiComputeOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b7254d57f0eb207f5b6fc3df11ccf88d26aa59b39c0a095caea19b4b6cfd509f)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetQueryTableDefinitionRequestSecurityQueryMultiComputeOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d56ed4278ec72127b43246457288fcdf3d8289ba7ac1d8666039edb8d45606ce)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9c2c1adacd3fa3c467738f8dca9dc2ff6330cbe82ff6c14e76170580c135a011)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c02281fa551f825cca86238ac75a8e6851646e266c12c16c5674997a3c38e4fc)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionRequestSecurityQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionRequestSecurityQueryMultiCompute]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionRequestSecurityQueryMultiCompute]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1991cdbb3b4919b0fe7c1e6ecb1828c2ac752357e44d3a805fe2a78b70d4fe0e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetQueryTableDefinitionRequestSecurityQueryMultiComputeOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestSecurityQueryMultiComputeOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a47370af69fcb118640186d0d4f10beb7422d66389656d22a569ca96fdabec6a)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f614a022c7a8aad0db70a5c096e7a434b4c82426880e0fe45a20fcb64be168d6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d2a3edea5ead5eb089a5fcd4d3f35a4e4cbd3825f8ed017c1f1c83752611f4e2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3d308501da217617cb1b758319f889ac89c20339274f9a3d6ab0330f66426e66)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryTableDefinitionRequestSecurityQueryMultiCompute]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryTableDefinitionRequestSecurityQueryMultiCompute]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryTableDefinitionRequestSecurityQueryMultiCompute]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fb4d68d10719a8ce151697c09369181ccb346cd70c647fb38286e549ddfbbe94)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetQueryTableDefinitionRequestSecurityQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestSecurityQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f26d0e7bedffa940045970b09e76335075306f423bfa2e40398f701c82049aa2)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putComputeQuery")
    def put_compute_query(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        value = PowerpackWidgetQueryTableDefinitionRequestSecurityQueryComputeQuery(
            aggregation=aggregation, facet=facet, interval=interval
        )

        return typing.cast(None, jsii.invoke(self, "putComputeQuery", [value]))

    @jsii.member(jsii_name="putGroupBy")
    def put_group_by(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryTableDefinitionRequestSecurityQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a430c4796d972d2115c147ab1a6e04850dbb0b0dec1a2fa70e451078a70f1a1f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putGroupBy", [value]))

    @jsii.member(jsii_name="putMultiCompute")
    def put_multi_compute(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryTableDefinitionRequestSecurityQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c8b592b2d3c134afe9a96adab090f688f3d7a39dd19dd2e35443fbbbb4f7ab97)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putMultiCompute", [value]))

    @jsii.member(jsii_name="resetComputeQuery")
    def reset_compute_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetComputeQuery", []))

    @jsii.member(jsii_name="resetGroupBy")
    def reset_group_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGroupBy", []))

    @jsii.member(jsii_name="resetMultiCompute")
    def reset_multi_compute(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMultiCompute", []))

    @jsii.member(jsii_name="resetSearchQuery")
    def reset_search_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSearchQuery", []))

    @builtins.property
    @jsii.member(jsii_name="computeQuery")
    def compute_query(
        self,
    ) -> PowerpackWidgetQueryTableDefinitionRequestSecurityQueryComputeQueryOutputReference:
        return typing.cast(PowerpackWidgetQueryTableDefinitionRequestSecurityQueryComputeQueryOutputReference, jsii.get(self, "computeQuery"))

    @builtins.property
    @jsii.member(jsii_name="groupBy")
    def group_by(
        self,
    ) -> PowerpackWidgetQueryTableDefinitionRequestSecurityQueryGroupByList:
        return typing.cast(PowerpackWidgetQueryTableDefinitionRequestSecurityQueryGroupByList, jsii.get(self, "groupBy"))

    @builtins.property
    @jsii.member(jsii_name="multiCompute")
    def multi_compute(
        self,
    ) -> PowerpackWidgetQueryTableDefinitionRequestSecurityQueryMultiComputeList:
        return typing.cast(PowerpackWidgetQueryTableDefinitionRequestSecurityQueryMultiComputeList, jsii.get(self, "multiCompute"))

    @builtins.property
    @jsii.member(jsii_name="computeQueryInput")
    def compute_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetQueryTableDefinitionRequestSecurityQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryTableDefinitionRequestSecurityQueryComputeQuery], jsii.get(self, "computeQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="groupByInput")
    def group_by_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionRequestSecurityQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionRequestSecurityQueryGroupBy]]], jsii.get(self, "groupByInput"))

    @builtins.property
    @jsii.member(jsii_name="indexInput")
    def index_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "indexInput"))

    @builtins.property
    @jsii.member(jsii_name="multiComputeInput")
    def multi_compute_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionRequestSecurityQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionRequestSecurityQueryMultiCompute]]], jsii.get(self, "multiComputeInput"))

    @builtins.property
    @jsii.member(jsii_name="searchQueryInput")
    def search_query_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "searchQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="index")
    def index(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "index"))

    @index.setter
    def index(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__db5c9478751548d5c9a2a63313b7e150ba49c45f467fbc8876af3db47d595f85)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "index", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="searchQuery")
    def search_query(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "searchQuery"))

    @search_query.setter
    def search_query(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__20228f0f458c3c44398173248323fd6be17f1a99fa6db1ed8e9b49e6e2b5c054)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "searchQuery", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetQueryTableDefinitionRequestSecurityQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryTableDefinitionRequestSecurityQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetQueryTableDefinitionRequestSecurityQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5b49dd1305c5293e645a4ddd333f5b076953c1c44e06e1cee4e54cfabdd7fc13)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestTextFormats",
    jsii_struct_bases=[],
    name_mapping={"text_format": "textFormat"},
)
class PowerpackWidgetQueryTableDefinitionRequestTextFormats:
    def __init__(
        self,
        *,
        text_format: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetQueryTableDefinitionRequestTextFormatsTextFormat", typing.Dict[builtins.str, typing.Any]]]]] = None,
    ) -> None:
        '''
        :param text_format: text_format block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#text_format Powerpack#text_format}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3f0b4a61c8f4c3e6f114ec238c211926e98489585feb678ec7d253eb58886fef)
            check_type(argname="argument text_format", value=text_format, expected_type=type_hints["text_format"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if text_format is not None:
            self._values["text_format"] = text_format

    @builtins.property
    def text_format(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetQueryTableDefinitionRequestTextFormatsTextFormat"]]]:
        '''text_format block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#text_format Powerpack#text_format}
        '''
        result = self._values.get("text_format")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetQueryTableDefinitionRequestTextFormatsTextFormat"]]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryTableDefinitionRequestTextFormats(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetQueryTableDefinitionRequestTextFormatsList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestTextFormatsList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__149969e8c11674f79ea78b89979ce773fede623912df3d5b41151b38fc4d7c9e)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetQueryTableDefinitionRequestTextFormatsOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5e555e47af618157298c50f9c160353b2ac366e0fdf6906df71aa4c09f317c05)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetQueryTableDefinitionRequestTextFormatsOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cc596856de65609be933e95146a109b3c3f54f06ce6be56d4cf3f6c04afe882d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__83dca426985f2d2d5c579a965cedebb3c316aedabcb70dd2c9f8f0f941c62e06)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8170d9ea8c0be42282f5f34719b8a6053b08d3c128630cddf9ed396dfcb03d8c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionRequestTextFormats]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionRequestTextFormats]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionRequestTextFormats]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a7b7a0f3bd44010c9df35466f765b205935b8e3fa0153b35da0d7cdd41475bfb)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetQueryTableDefinitionRequestTextFormatsOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestTextFormatsOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8ee6ec5b453672112d51dd60a46244d5a0139198dea56f7901d1ff28b0364607)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putTextFormat")
    def put_text_format(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetQueryTableDefinitionRequestTextFormatsTextFormat", typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dba45885c31d4e81e4fd211cbe4cae4da885090b4d7cdbaad5c2b0a1e92805e9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putTextFormat", [value]))

    @jsii.member(jsii_name="resetTextFormat")
    def reset_text_format(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTextFormat", []))

    @builtins.property
    @jsii.member(jsii_name="textFormat")
    def text_format(
        self,
    ) -> "PowerpackWidgetQueryTableDefinitionRequestTextFormatsTextFormatList":
        return typing.cast("PowerpackWidgetQueryTableDefinitionRequestTextFormatsTextFormatList", jsii.get(self, "textFormat"))

    @builtins.property
    @jsii.member(jsii_name="textFormatInput")
    def text_format_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetQueryTableDefinitionRequestTextFormatsTextFormat"]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetQueryTableDefinitionRequestTextFormatsTextFormat"]]], jsii.get(self, "textFormatInput"))

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryTableDefinitionRequestTextFormats]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryTableDefinitionRequestTextFormats]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryTableDefinitionRequestTextFormats]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8e412b07ac12c8d800d3bea22f18480a3991131435cd65b7ba2459b229443d6e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestTextFormatsTextFormat",
    jsii_struct_bases=[],
    name_mapping={
        "match": "match",
        "custom_bg_color": "customBgColor",
        "custom_fg_color": "customFgColor",
        "palette": "palette",
        "replace": "replace",
    },
)
class PowerpackWidgetQueryTableDefinitionRequestTextFormatsTextFormat:
    def __init__(
        self,
        *,
        match: typing.Union["PowerpackWidgetQueryTableDefinitionRequestTextFormatsTextFormatMatch", typing.Dict[builtins.str, typing.Any]],
        custom_bg_color: typing.Optional[builtins.str] = None,
        custom_fg_color: typing.Optional[builtins.str] = None,
        palette: typing.Optional[builtins.str] = None,
        replace: typing.Optional[typing.Union["PowerpackWidgetQueryTableDefinitionRequestTextFormatsTextFormatReplace", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param match: match block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#match Powerpack#match}
        :param custom_bg_color: The custom color palette to apply to the background. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom_bg_color Powerpack#custom_bg_color}
        :param custom_fg_color: The custom color palette to apply to the foreground text. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom_fg_color Powerpack#custom_fg_color}
        :param palette: The color palette to apply. Valid values are ``white_on_red``, ``white_on_yellow``, ``white_on_green``, ``black_on_light_red``, ``black_on_light_yellow``, ``black_on_light_green``, ``red_on_white``, ``yellow_on_white``, ``green_on_white``, ``custom_bg``, ``custom_text``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette Powerpack#palette}
        :param replace: replace block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#replace Powerpack#replace}
        '''
        if isinstance(match, dict):
            match = PowerpackWidgetQueryTableDefinitionRequestTextFormatsTextFormatMatch(**match)
        if isinstance(replace, dict):
            replace = PowerpackWidgetQueryTableDefinitionRequestTextFormatsTextFormatReplace(**replace)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1b84555894bd04faa0e927cd7b5e19889449974663f26a6f223730352faaae4c)
            check_type(argname="argument match", value=match, expected_type=type_hints["match"])
            check_type(argname="argument custom_bg_color", value=custom_bg_color, expected_type=type_hints["custom_bg_color"])
            check_type(argname="argument custom_fg_color", value=custom_fg_color, expected_type=type_hints["custom_fg_color"])
            check_type(argname="argument palette", value=palette, expected_type=type_hints["palette"])
            check_type(argname="argument replace", value=replace, expected_type=type_hints["replace"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "match": match,
        }
        if custom_bg_color is not None:
            self._values["custom_bg_color"] = custom_bg_color
        if custom_fg_color is not None:
            self._values["custom_fg_color"] = custom_fg_color
        if palette is not None:
            self._values["palette"] = palette
        if replace is not None:
            self._values["replace"] = replace

    @builtins.property
    def match(
        self,
    ) -> "PowerpackWidgetQueryTableDefinitionRequestTextFormatsTextFormatMatch":
        '''match block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#match Powerpack#match}
        '''
        result = self._values.get("match")
        assert result is not None, "Required property 'match' is missing"
        return typing.cast("PowerpackWidgetQueryTableDefinitionRequestTextFormatsTextFormatMatch", result)

    @builtins.property
    def custom_bg_color(self) -> typing.Optional[builtins.str]:
        '''The custom color palette to apply to the background.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom_bg_color Powerpack#custom_bg_color}
        '''
        result = self._values.get("custom_bg_color")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def custom_fg_color(self) -> typing.Optional[builtins.str]:
        '''The custom color palette to apply to the foreground text.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom_fg_color Powerpack#custom_fg_color}
        '''
        result = self._values.get("custom_fg_color")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def palette(self) -> typing.Optional[builtins.str]:
        '''The color palette to apply. Valid values are ``white_on_red``, ``white_on_yellow``, ``white_on_green``, ``black_on_light_red``, ``black_on_light_yellow``, ``black_on_light_green``, ``red_on_white``, ``yellow_on_white``, ``green_on_white``, ``custom_bg``, ``custom_text``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette Powerpack#palette}
        '''
        result = self._values.get("palette")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def replace(
        self,
    ) -> typing.Optional["PowerpackWidgetQueryTableDefinitionRequestTextFormatsTextFormatReplace"]:
        '''replace block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#replace Powerpack#replace}
        '''
        result = self._values.get("replace")
        return typing.cast(typing.Optional["PowerpackWidgetQueryTableDefinitionRequestTextFormatsTextFormatReplace"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryTableDefinitionRequestTextFormatsTextFormat(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetQueryTableDefinitionRequestTextFormatsTextFormatList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestTextFormatsTextFormatList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dbf2e381dfc69b3100d0663a4eb69dac0719ff987d25535fc1b6b40486f8fda2)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetQueryTableDefinitionRequestTextFormatsTextFormatOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__845dae9010a031711f633b91d17ed4d3b9e909faeba6b4192905c5783074c20f)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetQueryTableDefinitionRequestTextFormatsTextFormatOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__81447ef309394ed9570c0599262b48395c2847c7b5ffd6832c2422db76f0d77f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2f6d06cdbb1a9a992bc06c79b52a7f0590166797fb78c8d15d80ec402cb76287)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dd437af81146002fef98c146c95e325799e755e85d4ff7b06fae7d9099712508)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionRequestTextFormatsTextFormat]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionRequestTextFormatsTextFormat]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionRequestTextFormatsTextFormat]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fabf6fe088a5940615b81ac10823d37d16b674ef9407aa9b6667b8b568c284cc)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestTextFormatsTextFormatMatch",
    jsii_struct_bases=[],
    name_mapping={"type": "type", "value": "value"},
)
class PowerpackWidgetQueryTableDefinitionRequestTextFormatsTextFormatMatch:
    def __init__(self, *, type: builtins.str, value: builtins.str) -> None:
        '''
        :param type: Match or compare option. Valid values are ``is``, ``is_not``, ``contains``, ``does_not_contain``, ``starts_with``, ``ends_with``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#type Powerpack#type}
        :param value: Table Widget Match String. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#value Powerpack#value}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0579b04fcdcebf1a6d97f6a99c707619a30690034ee42f91aa17f520b9a95de4)
            check_type(argname="argument type", value=type, expected_type=type_hints["type"])
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "type": type,
            "value": value,
        }

    @builtins.property
    def type(self) -> builtins.str:
        '''Match or compare option. Valid values are ``is``, ``is_not``, ``contains``, ``does_not_contain``, ``starts_with``, ``ends_with``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#type Powerpack#type}
        '''
        result = self._values.get("type")
        assert result is not None, "Required property 'type' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def value(self) -> builtins.str:
        '''Table Widget Match String.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#value Powerpack#value}
        '''
        result = self._values.get("value")
        assert result is not None, "Required property 'value' is missing"
        return typing.cast(builtins.str, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryTableDefinitionRequestTextFormatsTextFormatMatch(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetQueryTableDefinitionRequestTextFormatsTextFormatMatchOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestTextFormatsTextFormatMatchOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__97d9761c32cedcd8888317b9efbd583e44c50a210faef9cf03290155282c9a8f)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @builtins.property
    @jsii.member(jsii_name="typeInput")
    def type_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "typeInput"))

    @builtins.property
    @jsii.member(jsii_name="valueInput")
    def value_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "valueInput"))

    @builtins.property
    @jsii.member(jsii_name="type")
    def type(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "type"))

    @type.setter
    def type(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__80337ca77f33cb9026644e7f41555a998cd6eab9beda87b972b0f9e83fe4ab6d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "type", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="value")
    def value(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "value"))

    @value.setter
    def value(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1a3dc99bb1f62a2f0cf44c0e7cce24b084dbbf48b71239825e961050b3afbbe9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "value", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetQueryTableDefinitionRequestTextFormatsTextFormatMatch]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryTableDefinitionRequestTextFormatsTextFormatMatch], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetQueryTableDefinitionRequestTextFormatsTextFormatMatch],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6bfa25ee8faca13d8fb3a994ac74ba00f4b32dbb85952475e959ad78aff8bd09)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetQueryTableDefinitionRequestTextFormatsTextFormatOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestTextFormatsTextFormatOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2f9de0c4d8b7340ad6c100f2733017d69d08927a2bdb7110b3d32d04d57b8b22)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putMatch")
    def put_match(self, *, type: builtins.str, value: builtins.str) -> None:
        '''
        :param type: Match or compare option. Valid values are ``is``, ``is_not``, ``contains``, ``does_not_contain``, ``starts_with``, ``ends_with``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#type Powerpack#type}
        :param value: Table Widget Match String. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#value Powerpack#value}
        '''
        value_ = PowerpackWidgetQueryTableDefinitionRequestTextFormatsTextFormatMatch(
            type=type, value=value
        )

        return typing.cast(None, jsii.invoke(self, "putMatch", [value_]))

    @jsii.member(jsii_name="putReplace")
    def put_replace(
        self,
        *,
        type: builtins.str,
        with_: builtins.str,
        substring: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param type: Table widget text format replace all type. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#type Powerpack#type}
        :param with_: Table Widget Match String. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#with Powerpack#with}
        :param substring: Text that will be replaced. Must be used with type ``substring``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#substring Powerpack#substring}
        '''
        value = PowerpackWidgetQueryTableDefinitionRequestTextFormatsTextFormatReplace(
            type=type, with_=with_, substring=substring
        )

        return typing.cast(None, jsii.invoke(self, "putReplace", [value]))

    @jsii.member(jsii_name="resetCustomBgColor")
    def reset_custom_bg_color(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCustomBgColor", []))

    @jsii.member(jsii_name="resetCustomFgColor")
    def reset_custom_fg_color(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCustomFgColor", []))

    @jsii.member(jsii_name="resetPalette")
    def reset_palette(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPalette", []))

    @jsii.member(jsii_name="resetReplace")
    def reset_replace(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetReplace", []))

    @builtins.property
    @jsii.member(jsii_name="match")
    def match(
        self,
    ) -> PowerpackWidgetQueryTableDefinitionRequestTextFormatsTextFormatMatchOutputReference:
        return typing.cast(PowerpackWidgetQueryTableDefinitionRequestTextFormatsTextFormatMatchOutputReference, jsii.get(self, "match"))

    @builtins.property
    @jsii.member(jsii_name="replace")
    def replace(
        self,
    ) -> "PowerpackWidgetQueryTableDefinitionRequestTextFormatsTextFormatReplaceOutputReference":
        return typing.cast("PowerpackWidgetQueryTableDefinitionRequestTextFormatsTextFormatReplaceOutputReference", jsii.get(self, "replace"))

    @builtins.property
    @jsii.member(jsii_name="customBgColorInput")
    def custom_bg_color_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "customBgColorInput"))

    @builtins.property
    @jsii.member(jsii_name="customFgColorInput")
    def custom_fg_color_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "customFgColorInput"))

    @builtins.property
    @jsii.member(jsii_name="matchInput")
    def match_input(
        self,
    ) -> typing.Optional[PowerpackWidgetQueryTableDefinitionRequestTextFormatsTextFormatMatch]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryTableDefinitionRequestTextFormatsTextFormatMatch], jsii.get(self, "matchInput"))

    @builtins.property
    @jsii.member(jsii_name="paletteInput")
    def palette_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "paletteInput"))

    @builtins.property
    @jsii.member(jsii_name="replaceInput")
    def replace_input(
        self,
    ) -> typing.Optional["PowerpackWidgetQueryTableDefinitionRequestTextFormatsTextFormatReplace"]:
        return typing.cast(typing.Optional["PowerpackWidgetQueryTableDefinitionRequestTextFormatsTextFormatReplace"], jsii.get(self, "replaceInput"))

    @builtins.property
    @jsii.member(jsii_name="customBgColor")
    def custom_bg_color(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "customBgColor"))

    @custom_bg_color.setter
    def custom_bg_color(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bf5c06c10e767b72212ee4ac0ae41f65a93df39ceefc45d5f1227fd3f60789b8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "customBgColor", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="customFgColor")
    def custom_fg_color(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "customFgColor"))

    @custom_fg_color.setter
    def custom_fg_color(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__41000a02431b4f43b887d5a2ed2ac696b983ff2053418d26687c827303c4b52f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "customFgColor", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="palette")
    def palette(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "palette"))

    @palette.setter
    def palette(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4a1af9353cdc77fed5ca67b321f855f9096d8f6a8afe7688067c5baa8350df11)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "palette", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryTableDefinitionRequestTextFormatsTextFormat]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryTableDefinitionRequestTextFormatsTextFormat]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryTableDefinitionRequestTextFormatsTextFormat]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c68490ca3013df5d05f4f5d5d733fd97258c1cc7889a8420ef2fe2859c31c73d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestTextFormatsTextFormatReplace",
    jsii_struct_bases=[],
    name_mapping={"type": "type", "with_": "with", "substring": "substring"},
)
class PowerpackWidgetQueryTableDefinitionRequestTextFormatsTextFormatReplace:
    def __init__(
        self,
        *,
        type: builtins.str,
        with_: builtins.str,
        substring: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param type: Table widget text format replace all type. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#type Powerpack#type}
        :param with_: Table Widget Match String. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#with Powerpack#with}
        :param substring: Text that will be replaced. Must be used with type ``substring``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#substring Powerpack#substring}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__823eb0cb66a3c77d6bd343eb90ad883e5198995c6a0a8eb616ed98be0b37b4cb)
            check_type(argname="argument type", value=type, expected_type=type_hints["type"])
            check_type(argname="argument with_", value=with_, expected_type=type_hints["with_"])
            check_type(argname="argument substring", value=substring, expected_type=type_hints["substring"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "type": type,
            "with_": with_,
        }
        if substring is not None:
            self._values["substring"] = substring

    @builtins.property
    def type(self) -> builtins.str:
        '''Table widget text format replace all type.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#type Powerpack#type}
        '''
        result = self._values.get("type")
        assert result is not None, "Required property 'type' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def with_(self) -> builtins.str:
        '''Table Widget Match String.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#with Powerpack#with}
        '''
        result = self._values.get("with_")
        assert result is not None, "Required property 'with_' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def substring(self) -> typing.Optional[builtins.str]:
        '''Text that will be replaced. Must be used with type ``substring``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#substring Powerpack#substring}
        '''
        result = self._values.get("substring")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryTableDefinitionRequestTextFormatsTextFormatReplace(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetQueryTableDefinitionRequestTextFormatsTextFormatReplaceOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryTableDefinitionRequestTextFormatsTextFormatReplaceOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__67eec1668c92f8c9571690bdf30b1235318a55b5fc8c4a3dc19f014f57401ed9)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetSubstring")
    def reset_substring(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSubstring", []))

    @builtins.property
    @jsii.member(jsii_name="substringInput")
    def substring_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "substringInput"))

    @builtins.property
    @jsii.member(jsii_name="typeInput")
    def type_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "typeInput"))

    @builtins.property
    @jsii.member(jsii_name="withInput")
    def with_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "withInput"))

    @builtins.property
    @jsii.member(jsii_name="substring")
    def substring(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "substring"))

    @substring.setter
    def substring(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8b5ff9e066a0902c9fdafab085f8dec02962967d7391aa12b97418de2fa6b20d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "substring", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="type")
    def type(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "type"))

    @type.setter
    def type(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f6b96049aa3a8fd89c4e842b877746fed3e0634ea52dcf9092a4ee9edcf1f4b0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "type", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="with")
    def with_(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "with"))

    @with_.setter
    def with_(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__83c10734da9845b79c5c1447480056e40d9f0904b21fd8a29fc655b2e0a2837a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "with", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetQueryTableDefinitionRequestTextFormatsTextFormatReplace]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryTableDefinitionRequestTextFormatsTextFormatReplace], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetQueryTableDefinitionRequestTextFormatsTextFormatReplace],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a675c15c0a0ea56a3ecb04970d665d9f57441eca5f8381944bbfabc56cff2378)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinition",
    jsii_struct_bases=[],
    name_mapping={
        "autoscale": "autoscale",
        "custom_link": "customLink",
        "custom_unit": "customUnit",
        "live_span": "liveSpan",
        "precision": "precision",
        "request": "request",
        "text_align": "textAlign",
        "timeseries_background": "timeseriesBackground",
        "title": "title",
        "title_align": "titleAlign",
        "title_size": "titleSize",
    },
)
class PowerpackWidgetQueryValueDefinition:
    def __init__(
        self,
        *,
        autoscale: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        custom_link: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetQueryValueDefinitionCustomLink", typing.Dict[builtins.str, typing.Any]]]]] = None,
        custom_unit: typing.Optional[builtins.str] = None,
        live_span: typing.Optional[builtins.str] = None,
        precision: typing.Optional[jsii.Number] = None,
        request: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetQueryValueDefinitionRequest", typing.Dict[builtins.str, typing.Any]]]]] = None,
        text_align: typing.Optional[builtins.str] = None,
        timeseries_background: typing.Optional[typing.Union["PowerpackWidgetQueryValueDefinitionTimeseriesBackground", typing.Dict[builtins.str, typing.Any]]] = None,
        title: typing.Optional[builtins.str] = None,
        title_align: typing.Optional[builtins.str] = None,
        title_size: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param autoscale: A Boolean indicating whether to automatically scale the tile. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#autoscale Powerpack#autoscale}
        :param custom_link: custom_link block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom_link Powerpack#custom_link}
        :param custom_unit: The unit for the value displayed in the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom_unit Powerpack#custom_unit}
        :param live_span: The timeframe to use when displaying the widget. Valid values are ``1m``, ``5m``, ``10m``, ``15m``, ``30m``, ``1h``, ``4h``, ``1d``, ``2d``, ``1w``, ``1mo``, ``3mo``, ``6mo``, ``week_to_date``, ``month_to_date``, ``1y``, ``alert``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#live_span Powerpack#live_span}
        :param precision: The precision to use when displaying the tile. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#precision Powerpack#precision}
        :param request: request block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#request Powerpack#request}
        :param text_align: The alignment of the widget's text. Valid values are ``center``, ``left``, ``right``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#text_align Powerpack#text_align}
        :param timeseries_background: timeseries_background block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#timeseries_background Powerpack#timeseries_background}
        :param title: The title of the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title Powerpack#title}
        :param title_align: The alignment of the widget's title. Valid values are ``center``, ``left``, ``right``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_align Powerpack#title_align}
        :param title_size: The size of the widget's title (defaults to 16). Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_size Powerpack#title_size}
        '''
        if isinstance(timeseries_background, dict):
            timeseries_background = PowerpackWidgetQueryValueDefinitionTimeseriesBackground(**timeseries_background)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a99ccf2ca9b683ebe61c49cea7b1843a232569d685e47f4d4ff9f70aa6fae0a0)
            check_type(argname="argument autoscale", value=autoscale, expected_type=type_hints["autoscale"])
            check_type(argname="argument custom_link", value=custom_link, expected_type=type_hints["custom_link"])
            check_type(argname="argument custom_unit", value=custom_unit, expected_type=type_hints["custom_unit"])
            check_type(argname="argument live_span", value=live_span, expected_type=type_hints["live_span"])
            check_type(argname="argument precision", value=precision, expected_type=type_hints["precision"])
            check_type(argname="argument request", value=request, expected_type=type_hints["request"])
            check_type(argname="argument text_align", value=text_align, expected_type=type_hints["text_align"])
            check_type(argname="argument timeseries_background", value=timeseries_background, expected_type=type_hints["timeseries_background"])
            check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            check_type(argname="argument title_align", value=title_align, expected_type=type_hints["title_align"])
            check_type(argname="argument title_size", value=title_size, expected_type=type_hints["title_size"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if autoscale is not None:
            self._values["autoscale"] = autoscale
        if custom_link is not None:
            self._values["custom_link"] = custom_link
        if custom_unit is not None:
            self._values["custom_unit"] = custom_unit
        if live_span is not None:
            self._values["live_span"] = live_span
        if precision is not None:
            self._values["precision"] = precision
        if request is not None:
            self._values["request"] = request
        if text_align is not None:
            self._values["text_align"] = text_align
        if timeseries_background is not None:
            self._values["timeseries_background"] = timeseries_background
        if title is not None:
            self._values["title"] = title
        if title_align is not None:
            self._values["title_align"] = title_align
        if title_size is not None:
            self._values["title_size"] = title_size

    @builtins.property
    def autoscale(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        '''A Boolean indicating whether to automatically scale the tile.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#autoscale Powerpack#autoscale}
        '''
        result = self._values.get("autoscale")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)

    @builtins.property
    def custom_link(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetQueryValueDefinitionCustomLink"]]]:
        '''custom_link block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom_link Powerpack#custom_link}
        '''
        result = self._values.get("custom_link")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetQueryValueDefinitionCustomLink"]]], result)

    @builtins.property
    def custom_unit(self) -> typing.Optional[builtins.str]:
        '''The unit for the value displayed in the widget.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom_unit Powerpack#custom_unit}
        '''
        result = self._values.get("custom_unit")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def live_span(self) -> typing.Optional[builtins.str]:
        '''The timeframe to use when displaying the widget.

        Valid values are ``1m``, ``5m``, ``10m``, ``15m``, ``30m``, ``1h``, ``4h``, ``1d``, ``2d``, ``1w``, ``1mo``, ``3mo``, ``6mo``, ``week_to_date``, ``month_to_date``, ``1y``, ``alert``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#live_span Powerpack#live_span}
        '''
        result = self._values.get("live_span")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def precision(self) -> typing.Optional[jsii.Number]:
        '''The precision to use when displaying the tile.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#precision Powerpack#precision}
        '''
        result = self._values.get("precision")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def request(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetQueryValueDefinitionRequest"]]]:
        '''request block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#request Powerpack#request}
        '''
        result = self._values.get("request")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetQueryValueDefinitionRequest"]]], result)

    @builtins.property
    def text_align(self) -> typing.Optional[builtins.str]:
        '''The alignment of the widget's text. Valid values are ``center``, ``left``, ``right``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#text_align Powerpack#text_align}
        '''
        result = self._values.get("text_align")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def timeseries_background(
        self,
    ) -> typing.Optional["PowerpackWidgetQueryValueDefinitionTimeseriesBackground"]:
        '''timeseries_background block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#timeseries_background Powerpack#timeseries_background}
        '''
        result = self._values.get("timeseries_background")
        return typing.cast(typing.Optional["PowerpackWidgetQueryValueDefinitionTimeseriesBackground"], result)

    @builtins.property
    def title(self) -> typing.Optional[builtins.str]:
        '''The title of the widget.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title Powerpack#title}
        '''
        result = self._values.get("title")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def title_align(self) -> typing.Optional[builtins.str]:
        '''The alignment of the widget's title. Valid values are ``center``, ``left``, ``right``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_align Powerpack#title_align}
        '''
        result = self._values.get("title_align")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def title_size(self) -> typing.Optional[builtins.str]:
        '''The size of the widget's title (defaults to 16).

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_size Powerpack#title_size}
        '''
        result = self._values.get("title_size")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryValueDefinition(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionCustomLink",
    jsii_struct_bases=[],
    name_mapping={
        "is_hidden": "isHidden",
        "label": "label",
        "link": "link",
        "override_label": "overrideLabel",
    },
)
class PowerpackWidgetQueryValueDefinitionCustomLink:
    def __init__(
        self,
        *,
        is_hidden: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        label: typing.Optional[builtins.str] = None,
        link: typing.Optional[builtins.str] = None,
        override_label: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param is_hidden: The flag for toggling context menu link visibility. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#is_hidden Powerpack#is_hidden}
        :param label: The label for the custom link URL. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#label Powerpack#label}
        :param link: The URL of the custom link. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#link Powerpack#link}
        :param override_label: The label ID that refers to a context menu link item. When ``override_label`` is provided, the client request omits the label field. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#override_label Powerpack#override_label}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9ac79fcd389b453793f3e92c79572375a7538d1db0bce63734bb6d47bfc4de06)
            check_type(argname="argument is_hidden", value=is_hidden, expected_type=type_hints["is_hidden"])
            check_type(argname="argument label", value=label, expected_type=type_hints["label"])
            check_type(argname="argument link", value=link, expected_type=type_hints["link"])
            check_type(argname="argument override_label", value=override_label, expected_type=type_hints["override_label"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if is_hidden is not None:
            self._values["is_hidden"] = is_hidden
        if label is not None:
            self._values["label"] = label
        if link is not None:
            self._values["link"] = link
        if override_label is not None:
            self._values["override_label"] = override_label

    @builtins.property
    def is_hidden(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        '''The flag for toggling context menu link visibility.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#is_hidden Powerpack#is_hidden}
        '''
        result = self._values.get("is_hidden")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)

    @builtins.property
    def label(self) -> typing.Optional[builtins.str]:
        '''The label for the custom link URL.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#label Powerpack#label}
        '''
        result = self._values.get("label")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def link(self) -> typing.Optional[builtins.str]:
        '''The URL of the custom link.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#link Powerpack#link}
        '''
        result = self._values.get("link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def override_label(self) -> typing.Optional[builtins.str]:
        '''The label ID that refers to a context menu link item.

        When ``override_label`` is provided, the client request omits the label field.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#override_label Powerpack#override_label}
        '''
        result = self._values.get("override_label")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryValueDefinitionCustomLink(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetQueryValueDefinitionCustomLinkList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionCustomLinkList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__504a33e7f1b670f3566cde0539b535ceefa12af61956fbe508b41b78671808de)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetQueryValueDefinitionCustomLinkOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__847345a43a4fe8b48957e61b7d613c6387ea4bae1078ef11448cfb2fd01d6942)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetQueryValueDefinitionCustomLinkOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__14a55cffeec17418a12dffb42c9da7d20cc7405012ce147a4ae9da8854969907)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f74910e062ab30e3cec60292d58d9cdc40f8577f95fac16014f6ed634f4534fc)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__50a6fee26543bc306b7b256e34d3d42f6330e134c4b1f35064b7f7a3257cca0f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionCustomLink]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionCustomLink]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionCustomLink]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__352a54ce72cfea76a2b84b5a486744757d38cae6fcc856d08bfa2f2c477e6ee0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetQueryValueDefinitionCustomLinkOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionCustomLinkOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7df26ee7fb24f6918194dc2e613d831527db07b02b10407a6246cc099105d12e)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetIsHidden")
    def reset_is_hidden(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetIsHidden", []))

    @jsii.member(jsii_name="resetLabel")
    def reset_label(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLabel", []))

    @jsii.member(jsii_name="resetLink")
    def reset_link(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLink", []))

    @jsii.member(jsii_name="resetOverrideLabel")
    def reset_override_label(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetOverrideLabel", []))

    @builtins.property
    @jsii.member(jsii_name="isHiddenInput")
    def is_hidden_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "isHiddenInput"))

    @builtins.property
    @jsii.member(jsii_name="labelInput")
    def label_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "labelInput"))

    @builtins.property
    @jsii.member(jsii_name="linkInput")
    def link_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "linkInput"))

    @builtins.property
    @jsii.member(jsii_name="overrideLabelInput")
    def override_label_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "overrideLabelInput"))

    @builtins.property
    @jsii.member(jsii_name="isHidden")
    def is_hidden(self) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "isHidden"))

    @is_hidden.setter
    def is_hidden(
        self,
        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ace57bab8a3cf3955fed49a6aff667f5f9d9a636edeb5d10d2ed12af236e277b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "isHidden", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="label")
    def label(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "label"))

    @label.setter
    def label(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9619b493ee7a2ab6d259d9e288f6b6575c042522bb107d24c03d490c023692ea)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "label", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="link")
    def link(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "link"))

    @link.setter
    def link(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6afe4673c7d56c1d29bfa42c9e7e67d023a732da0d050d2766fd062878bdf4e5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "link", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="overrideLabel")
    def override_label(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "overrideLabel"))

    @override_label.setter
    def override_label(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0362a2dda45c34c733b61c560a037f0096b7dbc157a4a1a6eed4a0000fe933ef)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "overrideLabel", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryValueDefinitionCustomLink]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryValueDefinitionCustomLink]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryValueDefinitionCustomLink]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e3abdae3536b6d34dd9a635a664596b506b1748d7f761d424d76697ce6adc14a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetQueryValueDefinitionOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__77814b2b54d571779dda0a3ad94f02e1973319c7cc97a032454544dec9d09c2a)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putCustomLink")
    def put_custom_link(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryValueDefinitionCustomLink, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bde55d98c59414d405730a6609872e42e58a2ebf9ded140458579bcbfd500f6d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putCustomLink", [value]))

    @jsii.member(jsii_name="putRequest")
    def put_request(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetQueryValueDefinitionRequest", typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dcd0af970bdb3f521678f2048d9018fea075dd8e206d8eef117336cd4952b36d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putRequest", [value]))

    @jsii.member(jsii_name="putTimeseriesBackground")
    def put_timeseries_background(
        self,
        *,
        type: builtins.str,
        yaxis: typing.Optional[typing.Union["PowerpackWidgetQueryValueDefinitionTimeseriesBackgroundYaxis", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param type: Whether the Timeseries is made using an area or bars. Valid values are ``bars``, ``area``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#type Powerpack#type}
        :param yaxis: yaxis block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#yaxis Powerpack#yaxis}
        '''
        value = PowerpackWidgetQueryValueDefinitionTimeseriesBackground(
            type=type, yaxis=yaxis
        )

        return typing.cast(None, jsii.invoke(self, "putTimeseriesBackground", [value]))

    @jsii.member(jsii_name="resetAutoscale")
    def reset_autoscale(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAutoscale", []))

    @jsii.member(jsii_name="resetCustomLink")
    def reset_custom_link(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCustomLink", []))

    @jsii.member(jsii_name="resetCustomUnit")
    def reset_custom_unit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCustomUnit", []))

    @jsii.member(jsii_name="resetLiveSpan")
    def reset_live_span(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLiveSpan", []))

    @jsii.member(jsii_name="resetPrecision")
    def reset_precision(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPrecision", []))

    @jsii.member(jsii_name="resetRequest")
    def reset_request(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetRequest", []))

    @jsii.member(jsii_name="resetTextAlign")
    def reset_text_align(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTextAlign", []))

    @jsii.member(jsii_name="resetTimeseriesBackground")
    def reset_timeseries_background(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTimeseriesBackground", []))

    @jsii.member(jsii_name="resetTitle")
    def reset_title(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTitle", []))

    @jsii.member(jsii_name="resetTitleAlign")
    def reset_title_align(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTitleAlign", []))

    @jsii.member(jsii_name="resetTitleSize")
    def reset_title_size(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTitleSize", []))

    @builtins.property
    @jsii.member(jsii_name="customLink")
    def custom_link(self) -> PowerpackWidgetQueryValueDefinitionCustomLinkList:
        return typing.cast(PowerpackWidgetQueryValueDefinitionCustomLinkList, jsii.get(self, "customLink"))

    @builtins.property
    @jsii.member(jsii_name="request")
    def request(self) -> "PowerpackWidgetQueryValueDefinitionRequestList":
        return typing.cast("PowerpackWidgetQueryValueDefinitionRequestList", jsii.get(self, "request"))

    @builtins.property
    @jsii.member(jsii_name="timeseriesBackground")
    def timeseries_background(
        self,
    ) -> "PowerpackWidgetQueryValueDefinitionTimeseriesBackgroundOutputReference":
        return typing.cast("PowerpackWidgetQueryValueDefinitionTimeseriesBackgroundOutputReference", jsii.get(self, "timeseriesBackground"))

    @builtins.property
    @jsii.member(jsii_name="autoscaleInput")
    def autoscale_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "autoscaleInput"))

    @builtins.property
    @jsii.member(jsii_name="customLinkInput")
    def custom_link_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionCustomLink]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionCustomLink]]], jsii.get(self, "customLinkInput"))

    @builtins.property
    @jsii.member(jsii_name="customUnitInput")
    def custom_unit_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "customUnitInput"))

    @builtins.property
    @jsii.member(jsii_name="liveSpanInput")
    def live_span_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "liveSpanInput"))

    @builtins.property
    @jsii.member(jsii_name="precisionInput")
    def precision_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "precisionInput"))

    @builtins.property
    @jsii.member(jsii_name="requestInput")
    def request_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetQueryValueDefinitionRequest"]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetQueryValueDefinitionRequest"]]], jsii.get(self, "requestInput"))

    @builtins.property
    @jsii.member(jsii_name="textAlignInput")
    def text_align_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "textAlignInput"))

    @builtins.property
    @jsii.member(jsii_name="timeseriesBackgroundInput")
    def timeseries_background_input(
        self,
    ) -> typing.Optional["PowerpackWidgetQueryValueDefinitionTimeseriesBackground"]:
        return typing.cast(typing.Optional["PowerpackWidgetQueryValueDefinitionTimeseriesBackground"], jsii.get(self, "timeseriesBackgroundInput"))

    @builtins.property
    @jsii.member(jsii_name="titleAlignInput")
    def title_align_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "titleAlignInput"))

    @builtins.property
    @jsii.member(jsii_name="titleInput")
    def title_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "titleInput"))

    @builtins.property
    @jsii.member(jsii_name="titleSizeInput")
    def title_size_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "titleSizeInput"))

    @builtins.property
    @jsii.member(jsii_name="autoscale")
    def autoscale(self) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "autoscale"))

    @autoscale.setter
    def autoscale(
        self,
        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__50ee9bce9554c1987ed922e1e38d2acf540cfa8d77a8d5a5f420af3801e214ee)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "autoscale", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="customUnit")
    def custom_unit(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "customUnit"))

    @custom_unit.setter
    def custom_unit(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__493b3878bf627132a3293a185b0f7ad42de68014e3c4bdd2ccddc516b6e17747)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "customUnit", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="liveSpan")
    def live_span(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "liveSpan"))

    @live_span.setter
    def live_span(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f79219046bf56a7123e3f7dd0899e3a31054b2b3ee113bbd6281f6eaacd25adc)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "liveSpan", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="precision")
    def precision(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "precision"))

    @precision.setter
    def precision(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2bf2e54304dcf5f35003ceb52c3002c7d7a1abf57beef84ada5836a44bd91cfc)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "precision", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="textAlign")
    def text_align(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "textAlign"))

    @text_align.setter
    def text_align(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b5284dd38c1d74d8934116bbec69aec873eb781004df8a1eccd10a7ebf597d11)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "textAlign", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="title")
    def title(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "title"))

    @title.setter
    def title(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__01910f370f624a53f1348389949c1339cca39f179257ef0e3897c4ac893e1dc6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "title", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="titleAlign")
    def title_align(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "titleAlign"))

    @title_align.setter
    def title_align(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2b480ddbf3e75f57a334a47504d61d4699cf4e16d1d94f8970b2df1da24b3dd8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "titleAlign", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="titleSize")
    def title_size(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "titleSize"))

    @title_size.setter
    def title_size(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f6ca66c3830ee8f7bfe57c86565aa2ff2513d2c184208e2db58da81c87a334f1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "titleSize", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[PowerpackWidgetQueryValueDefinition]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryValueDefinition], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetQueryValueDefinition],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__66f9f09b327b17a8460bb177635b883d78a3298fe8325b09e426eba03ea32a10)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequest",
    jsii_struct_bases=[],
    name_mapping={
        "aggregator": "aggregator",
        "apm_query": "apmQuery",
        "audit_query": "auditQuery",
        "conditional_formats": "conditionalFormats",
        "formula": "formula",
        "log_query": "logQuery",
        "process_query": "processQuery",
        "q": "q",
        "query": "query",
        "rum_query": "rumQuery",
        "security_query": "securityQuery",
    },
)
class PowerpackWidgetQueryValueDefinitionRequest:
    def __init__(
        self,
        *,
        aggregator: typing.Optional[builtins.str] = None,
        apm_query: typing.Optional[typing.Union["PowerpackWidgetQueryValueDefinitionRequestApmQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        audit_query: typing.Optional[typing.Union["PowerpackWidgetQueryValueDefinitionRequestAuditQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        conditional_formats: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetQueryValueDefinitionRequestConditionalFormats", typing.Dict[builtins.str, typing.Any]]]]] = None,
        formula: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetQueryValueDefinitionRequestFormula", typing.Dict[builtins.str, typing.Any]]]]] = None,
        log_query: typing.Optional[typing.Union["PowerpackWidgetQueryValueDefinitionRequestLogQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        process_query: typing.Optional[typing.Union["PowerpackWidgetQueryValueDefinitionRequestProcessQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        q: typing.Optional[builtins.str] = None,
        query: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetQueryValueDefinitionRequestQuery", typing.Dict[builtins.str, typing.Any]]]]] = None,
        rum_query: typing.Optional[typing.Union["PowerpackWidgetQueryValueDefinitionRequestRumQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        security_query: typing.Optional[typing.Union["PowerpackWidgetQueryValueDefinitionRequestSecurityQuery", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param aggregator: The aggregator to use for time aggregation. Valid values are ``avg``, ``last``, ``max``, ``min``, ``sum``, ``percentile``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregator Powerpack#aggregator}
        :param apm_query: apm_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#apm_query Powerpack#apm_query}
        :param audit_query: audit_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#audit_query Powerpack#audit_query}
        :param conditional_formats: conditional_formats block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#conditional_formats Powerpack#conditional_formats}
        :param formula: formula block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#formula Powerpack#formula}
        :param log_query: log_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#log_query Powerpack#log_query}
        :param process_query: process_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#process_query Powerpack#process_query}
        :param q: The metric query to use for this widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#q Powerpack#q}
        :param query: query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        :param rum_query: rum_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#rum_query Powerpack#rum_query}
        :param security_query: security_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#security_query Powerpack#security_query}
        '''
        if isinstance(apm_query, dict):
            apm_query = PowerpackWidgetQueryValueDefinitionRequestApmQuery(**apm_query)
        if isinstance(audit_query, dict):
            audit_query = PowerpackWidgetQueryValueDefinitionRequestAuditQuery(**audit_query)
        if isinstance(log_query, dict):
            log_query = PowerpackWidgetQueryValueDefinitionRequestLogQuery(**log_query)
        if isinstance(process_query, dict):
            process_query = PowerpackWidgetQueryValueDefinitionRequestProcessQuery(**process_query)
        if isinstance(rum_query, dict):
            rum_query = PowerpackWidgetQueryValueDefinitionRequestRumQuery(**rum_query)
        if isinstance(security_query, dict):
            security_query = PowerpackWidgetQueryValueDefinitionRequestSecurityQuery(**security_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fddc52cefe13a8b4c739a6ed2aa52fba254d969b416e6914d5d87d78da038dcf)
            check_type(argname="argument aggregator", value=aggregator, expected_type=type_hints["aggregator"])
            check_type(argname="argument apm_query", value=apm_query, expected_type=type_hints["apm_query"])
            check_type(argname="argument audit_query", value=audit_query, expected_type=type_hints["audit_query"])
            check_type(argname="argument conditional_formats", value=conditional_formats, expected_type=type_hints["conditional_formats"])
            check_type(argname="argument formula", value=formula, expected_type=type_hints["formula"])
            check_type(argname="argument log_query", value=log_query, expected_type=type_hints["log_query"])
            check_type(argname="argument process_query", value=process_query, expected_type=type_hints["process_query"])
            check_type(argname="argument q", value=q, expected_type=type_hints["q"])
            check_type(argname="argument query", value=query, expected_type=type_hints["query"])
            check_type(argname="argument rum_query", value=rum_query, expected_type=type_hints["rum_query"])
            check_type(argname="argument security_query", value=security_query, expected_type=type_hints["security_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if aggregator is not None:
            self._values["aggregator"] = aggregator
        if apm_query is not None:
            self._values["apm_query"] = apm_query
        if audit_query is not None:
            self._values["audit_query"] = audit_query
        if conditional_formats is not None:
            self._values["conditional_formats"] = conditional_formats
        if formula is not None:
            self._values["formula"] = formula
        if log_query is not None:
            self._values["log_query"] = log_query
        if process_query is not None:
            self._values["process_query"] = process_query
        if q is not None:
            self._values["q"] = q
        if query is not None:
            self._values["query"] = query
        if rum_query is not None:
            self._values["rum_query"] = rum_query
        if security_query is not None:
            self._values["security_query"] = security_query

    @builtins.property
    def aggregator(self) -> typing.Optional[builtins.str]:
        '''The aggregator to use for time aggregation. Valid values are ``avg``, ``last``, ``max``, ``min``, ``sum``, ``percentile``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregator Powerpack#aggregator}
        '''
        result = self._values.get("aggregator")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def apm_query(
        self,
    ) -> typing.Optional["PowerpackWidgetQueryValueDefinitionRequestApmQuery"]:
        '''apm_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#apm_query Powerpack#apm_query}
        '''
        result = self._values.get("apm_query")
        return typing.cast(typing.Optional["PowerpackWidgetQueryValueDefinitionRequestApmQuery"], result)

    @builtins.property
    def audit_query(
        self,
    ) -> typing.Optional["PowerpackWidgetQueryValueDefinitionRequestAuditQuery"]:
        '''audit_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#audit_query Powerpack#audit_query}
        '''
        result = self._values.get("audit_query")
        return typing.cast(typing.Optional["PowerpackWidgetQueryValueDefinitionRequestAuditQuery"], result)

    @builtins.property
    def conditional_formats(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetQueryValueDefinitionRequestConditionalFormats"]]]:
        '''conditional_formats block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#conditional_formats Powerpack#conditional_formats}
        '''
        result = self._values.get("conditional_formats")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetQueryValueDefinitionRequestConditionalFormats"]]], result)

    @builtins.property
    def formula(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetQueryValueDefinitionRequestFormula"]]]:
        '''formula block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#formula Powerpack#formula}
        '''
        result = self._values.get("formula")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetQueryValueDefinitionRequestFormula"]]], result)

    @builtins.property
    def log_query(
        self,
    ) -> typing.Optional["PowerpackWidgetQueryValueDefinitionRequestLogQuery"]:
        '''log_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#log_query Powerpack#log_query}
        '''
        result = self._values.get("log_query")
        return typing.cast(typing.Optional["PowerpackWidgetQueryValueDefinitionRequestLogQuery"], result)

    @builtins.property
    def process_query(
        self,
    ) -> typing.Optional["PowerpackWidgetQueryValueDefinitionRequestProcessQuery"]:
        '''process_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#process_query Powerpack#process_query}
        '''
        result = self._values.get("process_query")
        return typing.cast(typing.Optional["PowerpackWidgetQueryValueDefinitionRequestProcessQuery"], result)

    @builtins.property
    def q(self) -> typing.Optional[builtins.str]:
        '''The metric query to use for this widget.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#q Powerpack#q}
        '''
        result = self._values.get("q")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def query(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetQueryValueDefinitionRequestQuery"]]]:
        '''query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        '''
        result = self._values.get("query")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetQueryValueDefinitionRequestQuery"]]], result)

    @builtins.property
    def rum_query(
        self,
    ) -> typing.Optional["PowerpackWidgetQueryValueDefinitionRequestRumQuery"]:
        '''rum_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#rum_query Powerpack#rum_query}
        '''
        result = self._values.get("rum_query")
        return typing.cast(typing.Optional["PowerpackWidgetQueryValueDefinitionRequestRumQuery"], result)

    @builtins.property
    def security_query(
        self,
    ) -> typing.Optional["PowerpackWidgetQueryValueDefinitionRequestSecurityQuery"]:
        '''security_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#security_query Powerpack#security_query}
        '''
        result = self._values.get("security_query")
        return typing.cast(typing.Optional["PowerpackWidgetQueryValueDefinitionRequestSecurityQuery"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryValueDefinitionRequest(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestApmQuery",
    jsii_struct_bases=[],
    name_mapping={
        "index": "index",
        "compute_query": "computeQuery",
        "group_by": "groupBy",
        "multi_compute": "multiCompute",
        "search_query": "searchQuery",
    },
)
class PowerpackWidgetQueryValueDefinitionRequestApmQuery:
    def __init__(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union["PowerpackWidgetQueryValueDefinitionRequestApmQueryComputeQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetQueryValueDefinitionRequestApmQueryGroupBy", typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetQueryValueDefinitionRequestApmQueryMultiCompute", typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        if isinstance(compute_query, dict):
            compute_query = PowerpackWidgetQueryValueDefinitionRequestApmQueryComputeQuery(**compute_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e55ad88cf201fb9c09c16dd86b9f0431122268acd798d4604acbd55745e16c93)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
            check_type(argname="argument compute_query", value=compute_query, expected_type=type_hints["compute_query"])
            check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
            check_type(argname="argument multi_compute", value=multi_compute, expected_type=type_hints["multi_compute"])
            check_type(argname="argument search_query", value=search_query, expected_type=type_hints["search_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "index": index,
        }
        if compute_query is not None:
            self._values["compute_query"] = compute_query
        if group_by is not None:
            self._values["group_by"] = group_by
        if multi_compute is not None:
            self._values["multi_compute"] = multi_compute
        if search_query is not None:
            self._values["search_query"] = search_query

    @builtins.property
    def index(self) -> builtins.str:
        '''The name of the index to query.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        '''
        result = self._values.get("index")
        assert result is not None, "Required property 'index' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def compute_query(
        self,
    ) -> typing.Optional["PowerpackWidgetQueryValueDefinitionRequestApmQueryComputeQuery"]:
        '''compute_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        '''
        result = self._values.get("compute_query")
        return typing.cast(typing.Optional["PowerpackWidgetQueryValueDefinitionRequestApmQueryComputeQuery"], result)

    @builtins.property
    def group_by(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetQueryValueDefinitionRequestApmQueryGroupBy"]]]:
        '''group_by block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        '''
        result = self._values.get("group_by")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetQueryValueDefinitionRequestApmQueryGroupBy"]]], result)

    @builtins.property
    def multi_compute(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetQueryValueDefinitionRequestApmQueryMultiCompute"]]]:
        '''multi_compute block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        '''
        result = self._values.get("multi_compute")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetQueryValueDefinitionRequestApmQueryMultiCompute"]]], result)

    @builtins.property
    def search_query(self) -> typing.Optional[builtins.str]:
        '''The search query to use.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        result = self._values.get("search_query")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryValueDefinitionRequestApmQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestApmQueryComputeQuery",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetQueryValueDefinitionRequestApmQueryComputeQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__eccd6fb959607696ab383072f92fb03c3b2e22bf648fa0dac3aed8b6dc562383)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryValueDefinitionRequestApmQueryComputeQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetQueryValueDefinitionRequestApmQueryComputeQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestApmQueryComputeQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0d681a394d8dab48ccff202799bf5f878d441b65c18be39f24ce1f73644c7c84)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__260c6984e79449542c4dde2f068f62498c30a13c60e0682a092ec97978d27e0c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0108d11258489499eed95b03cb0cccb22f0d13ec46a804c00ad9d000459e4f92)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__81f6653abc4e1f03b4f2a15f853eb8c4e2e3a2741f7417a83b9eaa6a095a7525)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetQueryValueDefinitionRequestApmQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryValueDefinitionRequestApmQueryComputeQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetQueryValueDefinitionRequestApmQueryComputeQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ef43875289e4835c33f111d1e79d2174242ea5dd07d367990bed4c68b0a50f5d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestApmQueryGroupBy",
    jsii_struct_bases=[],
    name_mapping={"facet": "facet", "limit": "limit", "sort_query": "sortQuery"},
)
class PowerpackWidgetQueryValueDefinitionRequestApmQueryGroupBy:
    def __init__(
        self,
        *,
        facet: typing.Optional[builtins.str] = None,
        limit: typing.Optional[jsii.Number] = None,
        sort_query: typing.Optional[typing.Union["PowerpackWidgetQueryValueDefinitionRequestApmQueryGroupBySortQuery", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param limit: The maximum number of items in the group. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param sort_query: sort_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        if isinstance(sort_query, dict):
            sort_query = PowerpackWidgetQueryValueDefinitionRequestApmQueryGroupBySortQuery(**sort_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2bf4a5a4d9ca0f24a7895edb47b8a930721d54390137918e01349430df5913c8)
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
            check_type(argname="argument sort_query", value=sort_query, expected_type=type_hints["sort_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if facet is not None:
            self._values["facet"] = facet
        if limit is not None:
            self._values["limit"] = limit
        if sort_query is not None:
            self._values["sort_query"] = sort_query

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def limit(self) -> typing.Optional[jsii.Number]:
        '''The maximum number of items in the group.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        '''
        result = self._values.get("limit")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def sort_query(
        self,
    ) -> typing.Optional["PowerpackWidgetQueryValueDefinitionRequestApmQueryGroupBySortQuery"]:
        '''sort_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        result = self._values.get("sort_query")
        return typing.cast(typing.Optional["PowerpackWidgetQueryValueDefinitionRequestApmQueryGroupBySortQuery"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryValueDefinitionRequestApmQueryGroupBy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetQueryValueDefinitionRequestApmQueryGroupByList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestApmQueryGroupByList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d9813d2d842005d7af9ae265cff7945c1a7829f0a6eec8a8bf35abfae87ba969)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetQueryValueDefinitionRequestApmQueryGroupByOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d311ad8468182fce68f91b5ba2f829eeaef780432b56e2e0715e9ad4d214bbed)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetQueryValueDefinitionRequestApmQueryGroupByOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e8f3c42d30c88d84c3c4680c69973d4ac6f7114879fddb1bac782d3bb7faab67)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__96c71872ff6ead58af6689c906901b0a9a13978770948ad132f2a727b33588af)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f00f0bc44ac75bf6d9a4db470cfdef534e01d4bf9c9882557fd5edc771c5a7a1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionRequestApmQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionRequestApmQueryGroupBy]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionRequestApmQueryGroupBy]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__73ededf572a0cfda03621ba467904fc2da7087d45d70632bfe144126cfba41cf)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetQueryValueDefinitionRequestApmQueryGroupByOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestApmQueryGroupByOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__95e7e8a404608900fa5b5bbcf66609bcfc25de412e60c456772ef129450ace71)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putSortQuery")
    def put_sort_query(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        value = PowerpackWidgetQueryValueDefinitionRequestApmQueryGroupBySortQuery(
            aggregation=aggregation, order=order, facet=facet
        )

        return typing.cast(None, jsii.invoke(self, "putSortQuery", [value]))

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetLimit")
    def reset_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLimit", []))

    @jsii.member(jsii_name="resetSortQuery")
    def reset_sort_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSortQuery", []))

    @builtins.property
    @jsii.member(jsii_name="sortQuery")
    def sort_query(
        self,
    ) -> "PowerpackWidgetQueryValueDefinitionRequestApmQueryGroupBySortQueryOutputReference":
        return typing.cast("PowerpackWidgetQueryValueDefinitionRequestApmQueryGroupBySortQueryOutputReference", jsii.get(self, "sortQuery"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="limitInput")
    def limit_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "limitInput"))

    @builtins.property
    @jsii.member(jsii_name="sortQueryInput")
    def sort_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetQueryValueDefinitionRequestApmQueryGroupBySortQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetQueryValueDefinitionRequestApmQueryGroupBySortQuery"], jsii.get(self, "sortQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__31b171ede32cb397d04b903416451482a3eff36d04605640c18cef2de0a19365)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="limit")
    def limit(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "limit"))

    @limit.setter
    def limit(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e32afe6cda241926730bdc2430cd6b8e8d7b37329b5865ea62be3ff77615dd8c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "limit", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryValueDefinitionRequestApmQueryGroupBy]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryValueDefinitionRequestApmQueryGroupBy]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryValueDefinitionRequestApmQueryGroupBy]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__848f4713f39b3661069b59b3b3dc16b1fc8f42ac0cc22fe14eafd6d1911c393d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestApmQueryGroupBySortQuery",
    jsii_struct_bases=[],
    name_mapping={"aggregation": "aggregation", "order": "order", "facet": "facet"},
)
class PowerpackWidgetQueryValueDefinitionRequestApmQueryGroupBySortQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c0f2a66ccb9846dd0658220a6ee0b067c3e9180e4343b7816a8187966f5f4705)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument order", value=order, expected_type=type_hints["order"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
            "order": order,
        }
        if facet is not None:
            self._values["facet"] = facet

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def order(self) -> builtins.str:
        '''Widget sorting methods. Valid values are ``asc``, ``desc``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        result = self._values.get("order")
        assert result is not None, "Required property 'order' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryValueDefinitionRequestApmQueryGroupBySortQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetQueryValueDefinitionRequestApmQueryGroupBySortQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestApmQueryGroupBySortQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b73141f9ce358d36186f2c096909f65d94c53bb6689d7c89cca05e8ef678f8b1)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="orderInput")
    def order_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "orderInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__99c932ef0086a94b46ec1c09f5614650692625ff37a178598fec5277ce4bb177)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__800277f045d1e39afee8dd95b6461ce0204f23814aa12d224abc437d6803e945)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="order")
    def order(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "order"))

    @order.setter
    def order(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c1286bc993937844746bea6cc8abec03c3d153022c07637f54ba78b7071ce617)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "order", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetQueryValueDefinitionRequestApmQueryGroupBySortQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryValueDefinitionRequestApmQueryGroupBySortQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetQueryValueDefinitionRequestApmQueryGroupBySortQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__74736df49988a16f1f580dcb43123fad397f58b70095af6953526cfdcd5ee36b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestApmQueryMultiCompute",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetQueryValueDefinitionRequestApmQueryMultiCompute:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__45444d64566299889c78988651e3ab1c120c31c45af43f4d0c9cf43e472ef101)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryValueDefinitionRequestApmQueryMultiCompute(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetQueryValueDefinitionRequestApmQueryMultiComputeList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestApmQueryMultiComputeList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ff70f932fcd82b67b0511c8dea942270c9f1ccabaf5cd333214b957cd2ed80bc)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetQueryValueDefinitionRequestApmQueryMultiComputeOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e6689037ef35c6eb6760cbbdcad25b2c837b024cab89e90017473706cd2b4e34)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetQueryValueDefinitionRequestApmQueryMultiComputeOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6a2e578f201472f523043268e34852f4d29efddf74182baf213105c68ef110a2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c85d9aef974623ea6a6e407703764217638d6ad4446500c77427ac19914f6c37)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__19bd356dd9feabf8e454841c7cf6482d49524e9f3a4111d2193866cea982f533)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionRequestApmQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionRequestApmQueryMultiCompute]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionRequestApmQueryMultiCompute]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2e876c0a761ddd08a319c7a2723543172729445bd3194fc70e4af266505d71ef)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetQueryValueDefinitionRequestApmQueryMultiComputeOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestApmQueryMultiComputeOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1ade347b15b6ece80bc83e76ea1f89ea3e8cbe3f6246a33f7c7e781c0224b560)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d814778d629654b15cafc8a430c678798a59127bde3b994198dc7a67feb2fbec)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fe7db11109b413c2db28f6d817059b98b7f72c3e516ac8385c7b5b93104861f0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1ff6a83b24eb8926986d508315b219631d8a8d57f36b28c7eadc4f3550c24892)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryValueDefinitionRequestApmQueryMultiCompute]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryValueDefinitionRequestApmQueryMultiCompute]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryValueDefinitionRequestApmQueryMultiCompute]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a3d7112ce7beaf570b74035420c923de8c8b7aaced9678a5da502c92b9984fe6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetQueryValueDefinitionRequestApmQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestApmQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__762ad782adcf330d39a61124ec6fdf75755c90b353e1b007b257f81e0d46a5d9)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putComputeQuery")
    def put_compute_query(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        value = PowerpackWidgetQueryValueDefinitionRequestApmQueryComputeQuery(
            aggregation=aggregation, facet=facet, interval=interval
        )

        return typing.cast(None, jsii.invoke(self, "putComputeQuery", [value]))

    @jsii.member(jsii_name="putGroupBy")
    def put_group_by(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryValueDefinitionRequestApmQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b02f6f95d7bfd22826e42304cd676a74a6b0ee55dddc4b5c731b84a9f6272dc7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putGroupBy", [value]))

    @jsii.member(jsii_name="putMultiCompute")
    def put_multi_compute(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryValueDefinitionRequestApmQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0c0bc38fa55bdfab7242bf32ebe76b59a3fac2eaefa6dff615f6cfda2e655bf3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putMultiCompute", [value]))

    @jsii.member(jsii_name="resetComputeQuery")
    def reset_compute_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetComputeQuery", []))

    @jsii.member(jsii_name="resetGroupBy")
    def reset_group_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGroupBy", []))

    @jsii.member(jsii_name="resetMultiCompute")
    def reset_multi_compute(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMultiCompute", []))

    @jsii.member(jsii_name="resetSearchQuery")
    def reset_search_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSearchQuery", []))

    @builtins.property
    @jsii.member(jsii_name="computeQuery")
    def compute_query(
        self,
    ) -> PowerpackWidgetQueryValueDefinitionRequestApmQueryComputeQueryOutputReference:
        return typing.cast(PowerpackWidgetQueryValueDefinitionRequestApmQueryComputeQueryOutputReference, jsii.get(self, "computeQuery"))

    @builtins.property
    @jsii.member(jsii_name="groupBy")
    def group_by(self) -> PowerpackWidgetQueryValueDefinitionRequestApmQueryGroupByList:
        return typing.cast(PowerpackWidgetQueryValueDefinitionRequestApmQueryGroupByList, jsii.get(self, "groupBy"))

    @builtins.property
    @jsii.member(jsii_name="multiCompute")
    def multi_compute(
        self,
    ) -> PowerpackWidgetQueryValueDefinitionRequestApmQueryMultiComputeList:
        return typing.cast(PowerpackWidgetQueryValueDefinitionRequestApmQueryMultiComputeList, jsii.get(self, "multiCompute"))

    @builtins.property
    @jsii.member(jsii_name="computeQueryInput")
    def compute_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetQueryValueDefinitionRequestApmQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryValueDefinitionRequestApmQueryComputeQuery], jsii.get(self, "computeQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="groupByInput")
    def group_by_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionRequestApmQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionRequestApmQueryGroupBy]]], jsii.get(self, "groupByInput"))

    @builtins.property
    @jsii.member(jsii_name="indexInput")
    def index_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "indexInput"))

    @builtins.property
    @jsii.member(jsii_name="multiComputeInput")
    def multi_compute_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionRequestApmQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionRequestApmQueryMultiCompute]]], jsii.get(self, "multiComputeInput"))

    @builtins.property
    @jsii.member(jsii_name="searchQueryInput")
    def search_query_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "searchQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="index")
    def index(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "index"))

    @index.setter
    def index(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__54f94ad801ffa794042d17eae53564cad751bd9d2dfaca38126e4be693ebe2fe)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "index", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="searchQuery")
    def search_query(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "searchQuery"))

    @search_query.setter
    def search_query(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7c5962f0d53e20cdede878c60c86a975c474578e0be6ec9e4dfa7d0fc2ba222c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "searchQuery", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetQueryValueDefinitionRequestApmQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryValueDefinitionRequestApmQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetQueryValueDefinitionRequestApmQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__51a122ef77fcfa73fb6007d78aafb6ff74d57d73f8fca455809c17b3e3d2703c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestAuditQuery",
    jsii_struct_bases=[],
    name_mapping={
        "index": "index",
        "compute_query": "computeQuery",
        "group_by": "groupBy",
        "multi_compute": "multiCompute",
        "search_query": "searchQuery",
    },
)
class PowerpackWidgetQueryValueDefinitionRequestAuditQuery:
    def __init__(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union["PowerpackWidgetQueryValueDefinitionRequestAuditQueryComputeQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetQueryValueDefinitionRequestAuditQueryGroupBy", typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetQueryValueDefinitionRequestAuditQueryMultiCompute", typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        if isinstance(compute_query, dict):
            compute_query = PowerpackWidgetQueryValueDefinitionRequestAuditQueryComputeQuery(**compute_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__42881c6d2582490dd46016ee572a05b94a54f8659245e09f51e951beeae461e0)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
            check_type(argname="argument compute_query", value=compute_query, expected_type=type_hints["compute_query"])
            check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
            check_type(argname="argument multi_compute", value=multi_compute, expected_type=type_hints["multi_compute"])
            check_type(argname="argument search_query", value=search_query, expected_type=type_hints["search_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "index": index,
        }
        if compute_query is not None:
            self._values["compute_query"] = compute_query
        if group_by is not None:
            self._values["group_by"] = group_by
        if multi_compute is not None:
            self._values["multi_compute"] = multi_compute
        if search_query is not None:
            self._values["search_query"] = search_query

    @builtins.property
    def index(self) -> builtins.str:
        '''The name of the index to query.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        '''
        result = self._values.get("index")
        assert result is not None, "Required property 'index' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def compute_query(
        self,
    ) -> typing.Optional["PowerpackWidgetQueryValueDefinitionRequestAuditQueryComputeQuery"]:
        '''compute_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        '''
        result = self._values.get("compute_query")
        return typing.cast(typing.Optional["PowerpackWidgetQueryValueDefinitionRequestAuditQueryComputeQuery"], result)

    @builtins.property
    def group_by(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetQueryValueDefinitionRequestAuditQueryGroupBy"]]]:
        '''group_by block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        '''
        result = self._values.get("group_by")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetQueryValueDefinitionRequestAuditQueryGroupBy"]]], result)

    @builtins.property
    def multi_compute(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetQueryValueDefinitionRequestAuditQueryMultiCompute"]]]:
        '''multi_compute block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        '''
        result = self._values.get("multi_compute")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetQueryValueDefinitionRequestAuditQueryMultiCompute"]]], result)

    @builtins.property
    def search_query(self) -> typing.Optional[builtins.str]:
        '''The search query to use.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        result = self._values.get("search_query")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryValueDefinitionRequestAuditQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestAuditQueryComputeQuery",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetQueryValueDefinitionRequestAuditQueryComputeQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__19d0abef19cc0703109a70fa7ab013f1c67acb81875db7e6294cb4a9c0f65285)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryValueDefinitionRequestAuditQueryComputeQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetQueryValueDefinitionRequestAuditQueryComputeQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestAuditQueryComputeQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__38c5b6920f8ad2193d50d679843b976a7a9d10d14a5da18f93d9fa965705f779)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e520ed1cb04cf34c869e6139b17cce58ec354d8ab369f307662b57b7046f1a98)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7977724be04f914668ec400079647c973ee9bd2a6cf808074bfcc87bc71e7c64)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b3b9611e41a79f14677be96993d720e6a34529ac30f43092850cc7ab75f090bd)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetQueryValueDefinitionRequestAuditQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryValueDefinitionRequestAuditQueryComputeQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetQueryValueDefinitionRequestAuditQueryComputeQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__817a78b1c1da43156a735544ff1a9ce6fc8a423eadd3078fbe4a76add443c299)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestAuditQueryGroupBy",
    jsii_struct_bases=[],
    name_mapping={"facet": "facet", "limit": "limit", "sort_query": "sortQuery"},
)
class PowerpackWidgetQueryValueDefinitionRequestAuditQueryGroupBy:
    def __init__(
        self,
        *,
        facet: typing.Optional[builtins.str] = None,
        limit: typing.Optional[jsii.Number] = None,
        sort_query: typing.Optional[typing.Union["PowerpackWidgetQueryValueDefinitionRequestAuditQueryGroupBySortQuery", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param limit: The maximum number of items in the group. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param sort_query: sort_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        if isinstance(sort_query, dict):
            sort_query = PowerpackWidgetQueryValueDefinitionRequestAuditQueryGroupBySortQuery(**sort_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a9a79e042a834bbcecc0851ef3226cdf628c86745b82ca2c7ce9d6f1f0382f05)
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
            check_type(argname="argument sort_query", value=sort_query, expected_type=type_hints["sort_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if facet is not None:
            self._values["facet"] = facet
        if limit is not None:
            self._values["limit"] = limit
        if sort_query is not None:
            self._values["sort_query"] = sort_query

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def limit(self) -> typing.Optional[jsii.Number]:
        '''The maximum number of items in the group.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        '''
        result = self._values.get("limit")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def sort_query(
        self,
    ) -> typing.Optional["PowerpackWidgetQueryValueDefinitionRequestAuditQueryGroupBySortQuery"]:
        '''sort_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        result = self._values.get("sort_query")
        return typing.cast(typing.Optional["PowerpackWidgetQueryValueDefinitionRequestAuditQueryGroupBySortQuery"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryValueDefinitionRequestAuditQueryGroupBy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetQueryValueDefinitionRequestAuditQueryGroupByList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestAuditQueryGroupByList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3d4334a11cd030528edb66d7bf908760cef16cb500672e4a7060eaa48798b166)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetQueryValueDefinitionRequestAuditQueryGroupByOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__adf2b2cace889446479a4accb6ffc14d167588f88afa88404df5e49990d0fe1d)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetQueryValueDefinitionRequestAuditQueryGroupByOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dca5a38ab882e366914e1260e1b494b65270b6ae0e5547abe01e3f11a7e1b400)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__38d82dcd87cc58dd45d1598f534688f514dabbb503420a7a52d93025e3b5dad7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fdc7ba0504927a5a6b9598d7a306ba5010515f9cd0b0df0ebd947e80de479fe3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionRequestAuditQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionRequestAuditQueryGroupBy]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionRequestAuditQueryGroupBy]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ef7678439c08c741e4e9dec2d26677b312ec2c7aedcb3793beb1be2fdb098acc)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetQueryValueDefinitionRequestAuditQueryGroupByOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestAuditQueryGroupByOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fa3358ca23ad2d14ac83b24fc6720d410e209942ec183fe9a40de4b3e5e1c606)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putSortQuery")
    def put_sort_query(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        value = PowerpackWidgetQueryValueDefinitionRequestAuditQueryGroupBySortQuery(
            aggregation=aggregation, order=order, facet=facet
        )

        return typing.cast(None, jsii.invoke(self, "putSortQuery", [value]))

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetLimit")
    def reset_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLimit", []))

    @jsii.member(jsii_name="resetSortQuery")
    def reset_sort_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSortQuery", []))

    @builtins.property
    @jsii.member(jsii_name="sortQuery")
    def sort_query(
        self,
    ) -> "PowerpackWidgetQueryValueDefinitionRequestAuditQueryGroupBySortQueryOutputReference":
        return typing.cast("PowerpackWidgetQueryValueDefinitionRequestAuditQueryGroupBySortQueryOutputReference", jsii.get(self, "sortQuery"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="limitInput")
    def limit_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "limitInput"))

    @builtins.property
    @jsii.member(jsii_name="sortQueryInput")
    def sort_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetQueryValueDefinitionRequestAuditQueryGroupBySortQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetQueryValueDefinitionRequestAuditQueryGroupBySortQuery"], jsii.get(self, "sortQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4ca7cfae616be1bab9131e5e5798431f50098683a90588604e1d1eb570d7e82a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="limit")
    def limit(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "limit"))

    @limit.setter
    def limit(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__58e648ab98eb31722a19fe04a3a7b00d640fc68c43e2bcff9da33133213fe87d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "limit", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryValueDefinitionRequestAuditQueryGroupBy]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryValueDefinitionRequestAuditQueryGroupBy]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryValueDefinitionRequestAuditQueryGroupBy]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__958985440b836c05232f5e64b8c86a74c25c34cc8ebda9698db86b3b6731656b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestAuditQueryGroupBySortQuery",
    jsii_struct_bases=[],
    name_mapping={"aggregation": "aggregation", "order": "order", "facet": "facet"},
)
class PowerpackWidgetQueryValueDefinitionRequestAuditQueryGroupBySortQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__995018ffa1cc6117ff81e54fb8ea8dd9c9334c090812d35d7799cc22d53839d3)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument order", value=order, expected_type=type_hints["order"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
            "order": order,
        }
        if facet is not None:
            self._values["facet"] = facet

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def order(self) -> builtins.str:
        '''Widget sorting methods. Valid values are ``asc``, ``desc``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        result = self._values.get("order")
        assert result is not None, "Required property 'order' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryValueDefinitionRequestAuditQueryGroupBySortQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetQueryValueDefinitionRequestAuditQueryGroupBySortQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestAuditQueryGroupBySortQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7c3b7f46b560782f0991a38def9be256e3eee06a7cd2c98ef903a0f276dbd20f)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="orderInput")
    def order_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "orderInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d63cccfc02de9f24d49b896f36792fee01f10d8dbfd39e2444d1e78e5a35bbb8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9978def8aeb746cab4d6cee3b3cd5b911da37c0407e8a1f7ea4c9d4d30696b84)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="order")
    def order(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "order"))

    @order.setter
    def order(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7ac0bc32c77a48d4e5f9e6db85b61f6ecfb13dec18da0fd1c8fe9593958d99c5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "order", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetQueryValueDefinitionRequestAuditQueryGroupBySortQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryValueDefinitionRequestAuditQueryGroupBySortQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetQueryValueDefinitionRequestAuditQueryGroupBySortQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6f6e575e24d49090088b09b3de213ec91d389efcc49b922d0f6d50743eca3a53)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestAuditQueryMultiCompute",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetQueryValueDefinitionRequestAuditQueryMultiCompute:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ba55ae26d44fd80110d4dc430b87a7fe15a2947033b49022127802d20cfb333d)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryValueDefinitionRequestAuditQueryMultiCompute(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetQueryValueDefinitionRequestAuditQueryMultiComputeList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestAuditQueryMultiComputeList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__902d35499be986461c1bacbb6fdf15d50811a4840b3200f0092ace33156cbfcd)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetQueryValueDefinitionRequestAuditQueryMultiComputeOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__608d70b0dbd6be7f4f1f0dc1bf3d0190af0450c8536c0a6a210ae0633c6b22bd)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetQueryValueDefinitionRequestAuditQueryMultiComputeOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a1f242ef70a3421a0f946c1861e4f78c25863373740dd59e4e2b5d5c5f633693)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d05b0226638953899d28b932d27bf8382f4fc9192499aeee79f46c129390d013)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fc83011cabbbb4ff82b8ca47e29dbd9048cf3fa0344a125f9db579f4027caf3a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionRequestAuditQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionRequestAuditQueryMultiCompute]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionRequestAuditQueryMultiCompute]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6d5864e6dbad51b5ad599e8176c508c551072cb4773fac59617710b696c52da5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetQueryValueDefinitionRequestAuditQueryMultiComputeOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestAuditQueryMultiComputeOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f72d922f9a1dcfaec5b132173bb6b6fc6c4752da64ccca46180dcf3494ffbe27)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0ea6a1a3220a5369526b8694ff0329a2c631fbcb67a5e25aa27172e84f431aad)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d9e653cf049bf8ed1edce9e21abaf40aa243a500f0f253f82a89f113a254f5d4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2952569fbdb093f7216095334a9c236d9fab7ab1d7f852ea29486db6e8343918)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryValueDefinitionRequestAuditQueryMultiCompute]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryValueDefinitionRequestAuditQueryMultiCompute]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryValueDefinitionRequestAuditQueryMultiCompute]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__19f18bfa55a3cce429acf639a62dfa8b694b571c355eda53ef3c9b00c49bf37e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetQueryValueDefinitionRequestAuditQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestAuditQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e659a856f7b18b9313405d8c257bd40d453047740d09ffd0a19af229dc47e734)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putComputeQuery")
    def put_compute_query(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        value = PowerpackWidgetQueryValueDefinitionRequestAuditQueryComputeQuery(
            aggregation=aggregation, facet=facet, interval=interval
        )

        return typing.cast(None, jsii.invoke(self, "putComputeQuery", [value]))

    @jsii.member(jsii_name="putGroupBy")
    def put_group_by(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryValueDefinitionRequestAuditQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__84a421ce05dea1a2ef1f083f6d45c9bdee5552e3efef1adbc0179a9a8b9be30e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putGroupBy", [value]))

    @jsii.member(jsii_name="putMultiCompute")
    def put_multi_compute(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryValueDefinitionRequestAuditQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c0be0d73a313948de3f074341b15bafa4ffacf3613ae94a8ed14918452570d3b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putMultiCompute", [value]))

    @jsii.member(jsii_name="resetComputeQuery")
    def reset_compute_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetComputeQuery", []))

    @jsii.member(jsii_name="resetGroupBy")
    def reset_group_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGroupBy", []))

    @jsii.member(jsii_name="resetMultiCompute")
    def reset_multi_compute(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMultiCompute", []))

    @jsii.member(jsii_name="resetSearchQuery")
    def reset_search_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSearchQuery", []))

    @builtins.property
    @jsii.member(jsii_name="computeQuery")
    def compute_query(
        self,
    ) -> PowerpackWidgetQueryValueDefinitionRequestAuditQueryComputeQueryOutputReference:
        return typing.cast(PowerpackWidgetQueryValueDefinitionRequestAuditQueryComputeQueryOutputReference, jsii.get(self, "computeQuery"))

    @builtins.property
    @jsii.member(jsii_name="groupBy")
    def group_by(
        self,
    ) -> PowerpackWidgetQueryValueDefinitionRequestAuditQueryGroupByList:
        return typing.cast(PowerpackWidgetQueryValueDefinitionRequestAuditQueryGroupByList, jsii.get(self, "groupBy"))

    @builtins.property
    @jsii.member(jsii_name="multiCompute")
    def multi_compute(
        self,
    ) -> PowerpackWidgetQueryValueDefinitionRequestAuditQueryMultiComputeList:
        return typing.cast(PowerpackWidgetQueryValueDefinitionRequestAuditQueryMultiComputeList, jsii.get(self, "multiCompute"))

    @builtins.property
    @jsii.member(jsii_name="computeQueryInput")
    def compute_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetQueryValueDefinitionRequestAuditQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryValueDefinitionRequestAuditQueryComputeQuery], jsii.get(self, "computeQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="groupByInput")
    def group_by_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionRequestAuditQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionRequestAuditQueryGroupBy]]], jsii.get(self, "groupByInput"))

    @builtins.property
    @jsii.member(jsii_name="indexInput")
    def index_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "indexInput"))

    @builtins.property
    @jsii.member(jsii_name="multiComputeInput")
    def multi_compute_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionRequestAuditQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionRequestAuditQueryMultiCompute]]], jsii.get(self, "multiComputeInput"))

    @builtins.property
    @jsii.member(jsii_name="searchQueryInput")
    def search_query_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "searchQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="index")
    def index(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "index"))

    @index.setter
    def index(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fe8ee682469e353514158fc60c3673ffd3f20f32670a981f55fb8cab8d624b7a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "index", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="searchQuery")
    def search_query(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "searchQuery"))

    @search_query.setter
    def search_query(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f5c854ad29ccf27896ad0b604694f1427724dcc88041b808f2c9779b81f94582)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "searchQuery", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetQueryValueDefinitionRequestAuditQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryValueDefinitionRequestAuditQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetQueryValueDefinitionRequestAuditQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__32c457a1f48a71883b0528bfe5fb27b71809f15f757c152ab0c742ed04525003)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestConditionalFormats",
    jsii_struct_bases=[],
    name_mapping={
        "comparator": "comparator",
        "palette": "palette",
        "value": "value",
        "custom_bg_color": "customBgColor",
        "custom_fg_color": "customFgColor",
        "hide_value": "hideValue",
        "image_url": "imageUrl",
        "metric": "metric",
        "timeframe": "timeframe",
    },
)
class PowerpackWidgetQueryValueDefinitionRequestConditionalFormats:
    def __init__(
        self,
        *,
        comparator: builtins.str,
        palette: builtins.str,
        value: jsii.Number,
        custom_bg_color: typing.Optional[builtins.str] = None,
        custom_fg_color: typing.Optional[builtins.str] = None,
        hide_value: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        image_url: typing.Optional[builtins.str] = None,
        metric: typing.Optional[builtins.str] = None,
        timeframe: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param comparator: The comparator to use. Valid values are ``=``, ``>``, ``>=``, ``<``, ``<=``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#comparator Powerpack#comparator}
        :param palette: The color palette to apply. Valid values are ``blue``, ``custom_bg``, ``custom_image``, ``custom_text``, ``gray_on_white``, ``grey``, ``green``, ``orange``, ``red``, ``red_on_white``, ``white_on_gray``, ``white_on_green``, ``green_on_white``, ``white_on_red``, ``white_on_yellow``, ``yellow_on_white``, ``black_on_light_yellow``, ``black_on_light_green``, ``black_on_light_red``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette Powerpack#palette}
        :param value: A value for the comparator. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#value Powerpack#value}
        :param custom_bg_color: The color palette to apply to the background, same values available as palette. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom_bg_color Powerpack#custom_bg_color}
        :param custom_fg_color: The color palette to apply to the foreground, same values available as palette. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom_fg_color Powerpack#custom_fg_color}
        :param hide_value: Setting this to True hides values. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#hide_value Powerpack#hide_value}
        :param image_url: Displays an image as the background. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#image_url Powerpack#image_url}
        :param metric: The metric from the request to correlate with this conditional format. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        :param timeframe: Defines the displayed timeframe. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#timeframe Powerpack#timeframe}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ae816cb54c89b1f5a0bf2b1cea5ee7859957a76960dc0f4940808c420cf38494)
            check_type(argname="argument comparator", value=comparator, expected_type=type_hints["comparator"])
            check_type(argname="argument palette", value=palette, expected_type=type_hints["palette"])
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument custom_bg_color", value=custom_bg_color, expected_type=type_hints["custom_bg_color"])
            check_type(argname="argument custom_fg_color", value=custom_fg_color, expected_type=type_hints["custom_fg_color"])
            check_type(argname="argument hide_value", value=hide_value, expected_type=type_hints["hide_value"])
            check_type(argname="argument image_url", value=image_url, expected_type=type_hints["image_url"])
            check_type(argname="argument metric", value=metric, expected_type=type_hints["metric"])
            check_type(argname="argument timeframe", value=timeframe, expected_type=type_hints["timeframe"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "comparator": comparator,
            "palette": palette,
            "value": value,
        }
        if custom_bg_color is not None:
            self._values["custom_bg_color"] = custom_bg_color
        if custom_fg_color is not None:
            self._values["custom_fg_color"] = custom_fg_color
        if hide_value is not None:
            self._values["hide_value"] = hide_value
        if image_url is not None:
            self._values["image_url"] = image_url
        if metric is not None:
            self._values["metric"] = metric
        if timeframe is not None:
            self._values["timeframe"] = timeframe

    @builtins.property
    def comparator(self) -> builtins.str:
        '''The comparator to use. Valid values are ``=``, ``>``, ``>=``, ``<``, ``<=``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#comparator Powerpack#comparator}
        '''
        result = self._values.get("comparator")
        assert result is not None, "Required property 'comparator' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def palette(self) -> builtins.str:
        '''The color palette to apply.

        Valid values are ``blue``, ``custom_bg``, ``custom_image``, ``custom_text``, ``gray_on_white``, ``grey``, ``green``, ``orange``, ``red``, ``red_on_white``, ``white_on_gray``, ``white_on_green``, ``green_on_white``, ``white_on_red``, ``white_on_yellow``, ``yellow_on_white``, ``black_on_light_yellow``, ``black_on_light_green``, ``black_on_light_red``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette Powerpack#palette}
        '''
        result = self._values.get("palette")
        assert result is not None, "Required property 'palette' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def value(self) -> jsii.Number:
        '''A value for the comparator.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#value Powerpack#value}
        '''
        result = self._values.get("value")
        assert result is not None, "Required property 'value' is missing"
        return typing.cast(jsii.Number, result)

    @builtins.property
    def custom_bg_color(self) -> typing.Optional[builtins.str]:
        '''The color palette to apply to the background, same values available as palette.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom_bg_color Powerpack#custom_bg_color}
        '''
        result = self._values.get("custom_bg_color")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def custom_fg_color(self) -> typing.Optional[builtins.str]:
        '''The color palette to apply to the foreground, same values available as palette.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom_fg_color Powerpack#custom_fg_color}
        '''
        result = self._values.get("custom_fg_color")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def hide_value(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        '''Setting this to True hides values.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#hide_value Powerpack#hide_value}
        '''
        result = self._values.get("hide_value")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)

    @builtins.property
    def image_url(self) -> typing.Optional[builtins.str]:
        '''Displays an image as the background.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#image_url Powerpack#image_url}
        '''
        result = self._values.get("image_url")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def metric(self) -> typing.Optional[builtins.str]:
        '''The metric from the request to correlate with this conditional format.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        '''
        result = self._values.get("metric")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def timeframe(self) -> typing.Optional[builtins.str]:
        '''Defines the displayed timeframe.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#timeframe Powerpack#timeframe}
        '''
        result = self._values.get("timeframe")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryValueDefinitionRequestConditionalFormats(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetQueryValueDefinitionRequestConditionalFormatsList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestConditionalFormatsList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fb779e4408bff83d4839c070b10d486d954af973440e71e5c5eaea6b78cfb1b3)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetQueryValueDefinitionRequestConditionalFormatsOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f480aac56712d1ec8e519a889e9b372332428cde35d114d9c56e84fbfe089510)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetQueryValueDefinitionRequestConditionalFormatsOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__42e5b4d3a0a61c02b64d978595cf848cfa9679f42beca374d6d56059aa6afc1a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e8e97c4c9dd0316be75c97eb49a5f2ed2b8044c4e2d755fae89b8bf19dcaad2e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e5cf716a4962091d2dce156e80c0027436d7d5e465632be59420a47fdc2b5c95)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionRequestConditionalFormats]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionRequestConditionalFormats]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionRequestConditionalFormats]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e50f94bf360afa4ee2fe13e61abbbab22be020c42b8698e44384670e62d5ca74)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetQueryValueDefinitionRequestConditionalFormatsOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestConditionalFormatsOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4d7e912385b6d020af7d3d6a5e0db18a09c1a24623265f72cfb8ed9fb69bec96)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetCustomBgColor")
    def reset_custom_bg_color(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCustomBgColor", []))

    @jsii.member(jsii_name="resetCustomFgColor")
    def reset_custom_fg_color(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCustomFgColor", []))

    @jsii.member(jsii_name="resetHideValue")
    def reset_hide_value(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHideValue", []))

    @jsii.member(jsii_name="resetImageUrl")
    def reset_image_url(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetImageUrl", []))

    @jsii.member(jsii_name="resetMetric")
    def reset_metric(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMetric", []))

    @jsii.member(jsii_name="resetTimeframe")
    def reset_timeframe(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTimeframe", []))

    @builtins.property
    @jsii.member(jsii_name="comparatorInput")
    def comparator_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "comparatorInput"))

    @builtins.property
    @jsii.member(jsii_name="customBgColorInput")
    def custom_bg_color_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "customBgColorInput"))

    @builtins.property
    @jsii.member(jsii_name="customFgColorInput")
    def custom_fg_color_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "customFgColorInput"))

    @builtins.property
    @jsii.member(jsii_name="hideValueInput")
    def hide_value_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "hideValueInput"))

    @builtins.property
    @jsii.member(jsii_name="imageUrlInput")
    def image_url_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "imageUrlInput"))

    @builtins.property
    @jsii.member(jsii_name="metricInput")
    def metric_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "metricInput"))

    @builtins.property
    @jsii.member(jsii_name="paletteInput")
    def palette_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "paletteInput"))

    @builtins.property
    @jsii.member(jsii_name="timeframeInput")
    def timeframe_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "timeframeInput"))

    @builtins.property
    @jsii.member(jsii_name="valueInput")
    def value_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "valueInput"))

    @builtins.property
    @jsii.member(jsii_name="comparator")
    def comparator(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "comparator"))

    @comparator.setter
    def comparator(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__07b071e86737ccbb335f44a0146a4d6f586709ee0927e636ad05ce9bd963007b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "comparator", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="customBgColor")
    def custom_bg_color(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "customBgColor"))

    @custom_bg_color.setter
    def custom_bg_color(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6a71327bee6a2d3753b7da28ad6121bc7e2932e1ebfef92cae8e3805e9993460)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "customBgColor", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="customFgColor")
    def custom_fg_color(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "customFgColor"))

    @custom_fg_color.setter
    def custom_fg_color(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ef142ef759525b5c91fc1da56bed7528b84c28455f99efa95be406c678a9054b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "customFgColor", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="hideValue")
    def hide_value(self) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "hideValue"))

    @hide_value.setter
    def hide_value(
        self,
        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__da939bedb671b383c943b0168ad28ecb795814cc7a8b3eea054dae68b1270b78)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "hideValue", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="imageUrl")
    def image_url(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "imageUrl"))

    @image_url.setter
    def image_url(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2891571f3c8682fc31ea55fec5047d2e8ed36d4ce356e9778436d798ff3d5d70)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "imageUrl", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="metric")
    def metric(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "metric"))

    @metric.setter
    def metric(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bb081f97ecebdbddabca2c0337fd419fa2ecd9deab173aaf62ffe25300c74211)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "metric", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="palette")
    def palette(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "palette"))

    @palette.setter
    def palette(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8f110d8b555624a613fe4d764532c47641981a15d96ee3c6411e21c848ed1a1d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "palette", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="timeframe")
    def timeframe(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "timeframe"))

    @timeframe.setter
    def timeframe(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f26e3d7f9fa98132cccab26f759eb27009cc66f3c845a5cd184557952b51d54a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "timeframe", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="value")
    def value(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "value"))

    @value.setter
    def value(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b9ff9f35e24e0d3afd65090ab74e486046d67a6ec1f01c00fa064c9c72a05dc7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "value", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryValueDefinitionRequestConditionalFormats]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryValueDefinitionRequestConditionalFormats]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryValueDefinitionRequestConditionalFormats]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dd3f99ba66ca04f08e429affb2e551f2444581c3b59264ef7e6d2d9028d96cce)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestFormula",
    jsii_struct_bases=[],
    name_mapping={
        "formula_expression": "formulaExpression",
        "alias": "alias",
        "cell_display_mode": "cellDisplayMode",
        "conditional_formats": "conditionalFormats",
        "limit": "limit",
        "number_format": "numberFormat",
        "style": "style",
    },
)
class PowerpackWidgetQueryValueDefinitionRequestFormula:
    def __init__(
        self,
        *,
        formula_expression: builtins.str,
        alias: typing.Optional[builtins.str] = None,
        cell_display_mode: typing.Optional[builtins.str] = None,
        conditional_formats: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetQueryValueDefinitionRequestFormulaConditionalFormats", typing.Dict[builtins.str, typing.Any]]]]] = None,
        limit: typing.Optional[typing.Union["PowerpackWidgetQueryValueDefinitionRequestFormulaLimit", typing.Dict[builtins.str, typing.Any]]] = None,
        number_format: typing.Optional[typing.Union["PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormat", typing.Dict[builtins.str, typing.Any]]] = None,
        style: typing.Optional[typing.Union["PowerpackWidgetQueryValueDefinitionRequestFormulaStyle", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param formula_expression: A string expression built from queries, formulas, and functions. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#formula_expression Powerpack#formula_expression}
        :param alias: An expression alias. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#alias Powerpack#alias}
        :param cell_display_mode: A list of display modes for each table cell. Valid values are ``number``, ``bar``, ``trend``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cell_display_mode Powerpack#cell_display_mode}
        :param conditional_formats: conditional_formats block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#conditional_formats Powerpack#conditional_formats}
        :param limit: limit block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param number_format: number_format block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#number_format Powerpack#number_format}
        :param style: style block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#style Powerpack#style}
        '''
        if isinstance(limit, dict):
            limit = PowerpackWidgetQueryValueDefinitionRequestFormulaLimit(**limit)
        if isinstance(number_format, dict):
            number_format = PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormat(**number_format)
        if isinstance(style, dict):
            style = PowerpackWidgetQueryValueDefinitionRequestFormulaStyle(**style)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ffd4fdcc94e70aa49a00e5ba6f7b34b69e6fe72515a3c6d6f07c5c99a7360cae)
            check_type(argname="argument formula_expression", value=formula_expression, expected_type=type_hints["formula_expression"])
            check_type(argname="argument alias", value=alias, expected_type=type_hints["alias"])
            check_type(argname="argument cell_display_mode", value=cell_display_mode, expected_type=type_hints["cell_display_mode"])
            check_type(argname="argument conditional_formats", value=conditional_formats, expected_type=type_hints["conditional_formats"])
            check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
            check_type(argname="argument number_format", value=number_format, expected_type=type_hints["number_format"])
            check_type(argname="argument style", value=style, expected_type=type_hints["style"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "formula_expression": formula_expression,
        }
        if alias is not None:
            self._values["alias"] = alias
        if cell_display_mode is not None:
            self._values["cell_display_mode"] = cell_display_mode
        if conditional_formats is not None:
            self._values["conditional_formats"] = conditional_formats
        if limit is not None:
            self._values["limit"] = limit
        if number_format is not None:
            self._values["number_format"] = number_format
        if style is not None:
            self._values["style"] = style

    @builtins.property
    def formula_expression(self) -> builtins.str:
        '''A string expression built from queries, formulas, and functions.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#formula_expression Powerpack#formula_expression}
        '''
        result = self._values.get("formula_expression")
        assert result is not None, "Required property 'formula_expression' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def alias(self) -> typing.Optional[builtins.str]:
        '''An expression alias.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#alias Powerpack#alias}
        '''
        result = self._values.get("alias")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def cell_display_mode(self) -> typing.Optional[builtins.str]:
        '''A list of display modes for each table cell. Valid values are ``number``, ``bar``, ``trend``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cell_display_mode Powerpack#cell_display_mode}
        '''
        result = self._values.get("cell_display_mode")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def conditional_formats(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetQueryValueDefinitionRequestFormulaConditionalFormats"]]]:
        '''conditional_formats block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#conditional_formats Powerpack#conditional_formats}
        '''
        result = self._values.get("conditional_formats")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetQueryValueDefinitionRequestFormulaConditionalFormats"]]], result)

    @builtins.property
    def limit(
        self,
    ) -> typing.Optional["PowerpackWidgetQueryValueDefinitionRequestFormulaLimit"]:
        '''limit block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        '''
        result = self._values.get("limit")
        return typing.cast(typing.Optional["PowerpackWidgetQueryValueDefinitionRequestFormulaLimit"], result)

    @builtins.property
    def number_format(
        self,
    ) -> typing.Optional["PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormat"]:
        '''number_format block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#number_format Powerpack#number_format}
        '''
        result = self._values.get("number_format")
        return typing.cast(typing.Optional["PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormat"], result)

    @builtins.property
    def style(
        self,
    ) -> typing.Optional["PowerpackWidgetQueryValueDefinitionRequestFormulaStyle"]:
        '''style block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#style Powerpack#style}
        '''
        result = self._values.get("style")
        return typing.cast(typing.Optional["PowerpackWidgetQueryValueDefinitionRequestFormulaStyle"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryValueDefinitionRequestFormula(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestFormulaConditionalFormats",
    jsii_struct_bases=[],
    name_mapping={
        "comparator": "comparator",
        "palette": "palette",
        "value": "value",
        "custom_bg_color": "customBgColor",
        "custom_fg_color": "customFgColor",
        "hide_value": "hideValue",
        "image_url": "imageUrl",
        "metric": "metric",
        "timeframe": "timeframe",
    },
)
class PowerpackWidgetQueryValueDefinitionRequestFormulaConditionalFormats:
    def __init__(
        self,
        *,
        comparator: builtins.str,
        palette: builtins.str,
        value: jsii.Number,
        custom_bg_color: typing.Optional[builtins.str] = None,
        custom_fg_color: typing.Optional[builtins.str] = None,
        hide_value: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        image_url: typing.Optional[builtins.str] = None,
        metric: typing.Optional[builtins.str] = None,
        timeframe: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param comparator: The comparator to use. Valid values are ``=``, ``>``, ``>=``, ``<``, ``<=``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#comparator Powerpack#comparator}
        :param palette: The color palette to apply. Valid values are ``blue``, ``custom_bg``, ``custom_image``, ``custom_text``, ``gray_on_white``, ``grey``, ``green``, ``orange``, ``red``, ``red_on_white``, ``white_on_gray``, ``white_on_green``, ``green_on_white``, ``white_on_red``, ``white_on_yellow``, ``yellow_on_white``, ``black_on_light_yellow``, ``black_on_light_green``, ``black_on_light_red``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette Powerpack#palette}
        :param value: A value for the comparator. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#value Powerpack#value}
        :param custom_bg_color: The color palette to apply to the background, same values available as palette. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom_bg_color Powerpack#custom_bg_color}
        :param custom_fg_color: The color palette to apply to the foreground, same values available as palette. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom_fg_color Powerpack#custom_fg_color}
        :param hide_value: Setting this to True hides values. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#hide_value Powerpack#hide_value}
        :param image_url: Displays an image as the background. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#image_url Powerpack#image_url}
        :param metric: The metric from the request to correlate with this conditional format. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        :param timeframe: Defines the displayed timeframe. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#timeframe Powerpack#timeframe}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__80278a6fee8382c22e815b09fe02bd3221bc844f4644215319beff31f3ee47f8)
            check_type(argname="argument comparator", value=comparator, expected_type=type_hints["comparator"])
            check_type(argname="argument palette", value=palette, expected_type=type_hints["palette"])
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument custom_bg_color", value=custom_bg_color, expected_type=type_hints["custom_bg_color"])
            check_type(argname="argument custom_fg_color", value=custom_fg_color, expected_type=type_hints["custom_fg_color"])
            check_type(argname="argument hide_value", value=hide_value, expected_type=type_hints["hide_value"])
            check_type(argname="argument image_url", value=image_url, expected_type=type_hints["image_url"])
            check_type(argname="argument metric", value=metric, expected_type=type_hints["metric"])
            check_type(argname="argument timeframe", value=timeframe, expected_type=type_hints["timeframe"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "comparator": comparator,
            "palette": palette,
            "value": value,
        }
        if custom_bg_color is not None:
            self._values["custom_bg_color"] = custom_bg_color
        if custom_fg_color is not None:
            self._values["custom_fg_color"] = custom_fg_color
        if hide_value is not None:
            self._values["hide_value"] = hide_value
        if image_url is not None:
            self._values["image_url"] = image_url
        if metric is not None:
            self._values["metric"] = metric
        if timeframe is not None:
            self._values["timeframe"] = timeframe

    @builtins.property
    def comparator(self) -> builtins.str:
        '''The comparator to use. Valid values are ``=``, ``>``, ``>=``, ``<``, ``<=``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#comparator Powerpack#comparator}
        '''
        result = self._values.get("comparator")
        assert result is not None, "Required property 'comparator' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def palette(self) -> builtins.str:
        '''The color palette to apply.

        Valid values are ``blue``, ``custom_bg``, ``custom_image``, ``custom_text``, ``gray_on_white``, ``grey``, ``green``, ``orange``, ``red``, ``red_on_white``, ``white_on_gray``, ``white_on_green``, ``green_on_white``, ``white_on_red``, ``white_on_yellow``, ``yellow_on_white``, ``black_on_light_yellow``, ``black_on_light_green``, ``black_on_light_red``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette Powerpack#palette}
        '''
        result = self._values.get("palette")
        assert result is not None, "Required property 'palette' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def value(self) -> jsii.Number:
        '''A value for the comparator.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#value Powerpack#value}
        '''
        result = self._values.get("value")
        assert result is not None, "Required property 'value' is missing"
        return typing.cast(jsii.Number, result)

    @builtins.property
    def custom_bg_color(self) -> typing.Optional[builtins.str]:
        '''The color palette to apply to the background, same values available as palette.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom_bg_color Powerpack#custom_bg_color}
        '''
        result = self._values.get("custom_bg_color")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def custom_fg_color(self) -> typing.Optional[builtins.str]:
        '''The color palette to apply to the foreground, same values available as palette.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom_fg_color Powerpack#custom_fg_color}
        '''
        result = self._values.get("custom_fg_color")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def hide_value(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        '''Setting this to True hides values.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#hide_value Powerpack#hide_value}
        '''
        result = self._values.get("hide_value")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)

    @builtins.property
    def image_url(self) -> typing.Optional[builtins.str]:
        '''Displays an image as the background.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#image_url Powerpack#image_url}
        '''
        result = self._values.get("image_url")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def metric(self) -> typing.Optional[builtins.str]:
        '''The metric from the request to correlate with this conditional format.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        '''
        result = self._values.get("metric")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def timeframe(self) -> typing.Optional[builtins.str]:
        '''Defines the displayed timeframe.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#timeframe Powerpack#timeframe}
        '''
        result = self._values.get("timeframe")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryValueDefinitionRequestFormulaConditionalFormats(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetQueryValueDefinitionRequestFormulaConditionalFormatsList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestFormulaConditionalFormatsList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1f5285ffa03e74340fc0e8c15ad3cfa916dc05d29b4df23bc4c7dcac2a17e9bd)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetQueryValueDefinitionRequestFormulaConditionalFormatsOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__da98d75dd58bd5d15d30cae2244f1c896282322bfbbe74f2191388fb4ede7522)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetQueryValueDefinitionRequestFormulaConditionalFormatsOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__aa7323461678b7b628e23aac97eb8ccb1fe9b71291ad6a152a58aca876c0776b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8ea4730693e627259ddda0c1eeae55438a22f5420fe3518aee3c8f141848d21d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ef499def803d29e933fc30c782c3f827de64a8912644914743b5f7fc4c4911bc)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionRequestFormulaConditionalFormats]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionRequestFormulaConditionalFormats]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionRequestFormulaConditionalFormats]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__01f3408cae5b4912463b5742191b2929e658a1dc8b74a65dea2c3974280d5f5f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetQueryValueDefinitionRequestFormulaConditionalFormatsOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestFormulaConditionalFormatsOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__11e66e422591b94aa474a2b28c8b2ce816c0de32b935e87fa68cd847193ab44c)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetCustomBgColor")
    def reset_custom_bg_color(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCustomBgColor", []))

    @jsii.member(jsii_name="resetCustomFgColor")
    def reset_custom_fg_color(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCustomFgColor", []))

    @jsii.member(jsii_name="resetHideValue")
    def reset_hide_value(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHideValue", []))

    @jsii.member(jsii_name="resetImageUrl")
    def reset_image_url(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetImageUrl", []))

    @jsii.member(jsii_name="resetMetric")
    def reset_metric(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMetric", []))

    @jsii.member(jsii_name="resetTimeframe")
    def reset_timeframe(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTimeframe", []))

    @builtins.property
    @jsii.member(jsii_name="comparatorInput")
    def comparator_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "comparatorInput"))

    @builtins.property
    @jsii.member(jsii_name="customBgColorInput")
    def custom_bg_color_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "customBgColorInput"))

    @builtins.property
    @jsii.member(jsii_name="customFgColorInput")
    def custom_fg_color_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "customFgColorInput"))

    @builtins.property
    @jsii.member(jsii_name="hideValueInput")
    def hide_value_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "hideValueInput"))

    @builtins.property
    @jsii.member(jsii_name="imageUrlInput")
    def image_url_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "imageUrlInput"))

    @builtins.property
    @jsii.member(jsii_name="metricInput")
    def metric_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "metricInput"))

    @builtins.property
    @jsii.member(jsii_name="paletteInput")
    def palette_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "paletteInput"))

    @builtins.property
    @jsii.member(jsii_name="timeframeInput")
    def timeframe_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "timeframeInput"))

    @builtins.property
    @jsii.member(jsii_name="valueInput")
    def value_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "valueInput"))

    @builtins.property
    @jsii.member(jsii_name="comparator")
    def comparator(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "comparator"))

    @comparator.setter
    def comparator(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5ee86f85a3dc01e9fac15a75deafd2f88f77f077e0bd1a3ee895ae2a512e2d16)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "comparator", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="customBgColor")
    def custom_bg_color(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "customBgColor"))

    @custom_bg_color.setter
    def custom_bg_color(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d4511fe123091d67ac62e7877c75b643f18c0411375c7ce79608b7abab180a25)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "customBgColor", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="customFgColor")
    def custom_fg_color(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "customFgColor"))

    @custom_fg_color.setter
    def custom_fg_color(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__38b2798368836b38d734fbba68f928d1d20f4caad2688362f0e28f69955f64ba)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "customFgColor", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="hideValue")
    def hide_value(self) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "hideValue"))

    @hide_value.setter
    def hide_value(
        self,
        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bc3e250b4ebee06b7ce59bfd9623127f7d654a12b98db50cd88e81ec8c0597bc)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "hideValue", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="imageUrl")
    def image_url(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "imageUrl"))

    @image_url.setter
    def image_url(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e7123d568b907847b785d4c1e61d7bf6a419c7cab08af43ca5d9dd4c396e8990)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "imageUrl", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="metric")
    def metric(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "metric"))

    @metric.setter
    def metric(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8bf76cf64229bce3a7d9d365810e8d0945d017db5d621a6577d08bf8a77a429f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "metric", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="palette")
    def palette(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "palette"))

    @palette.setter
    def palette(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__92c73cfd3f79b5e9a798c1a16f448750d80073d9925753c54fa9c43dedbd8453)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "palette", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="timeframe")
    def timeframe(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "timeframe"))

    @timeframe.setter
    def timeframe(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e32664c56a02ee188b3d3c716d3004f97765702a9004c25165dc77ea8a3df553)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "timeframe", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="value")
    def value(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "value"))

    @value.setter
    def value(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3d4089616dcbff2752fc3f030b133acb9677eed3c4dab27b16fb94d4ddef63f9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "value", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryValueDefinitionRequestFormulaConditionalFormats]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryValueDefinitionRequestFormulaConditionalFormats]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryValueDefinitionRequestFormulaConditionalFormats]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3c0076d1b63dbde826da797d25ef0ad81f09a2b5d82d685eccc9492b74250d0d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestFormulaLimit",
    jsii_struct_bases=[],
    name_mapping={"count": "count", "order": "order"},
)
class PowerpackWidgetQueryValueDefinitionRequestFormulaLimit:
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        order: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param count: The number of results to return. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#count Powerpack#count}
        :param order: The direction of the sort. Valid values are ``asc``, ``desc``. Defaults to ``"desc"``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7385639bf39d3854d468b2c26d0af1927dd13ff3aa26305464b95ff4896bb619)
            check_type(argname="argument count", value=count, expected_type=type_hints["count"])
            check_type(argname="argument order", value=order, expected_type=type_hints["order"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if count is not None:
            self._values["count"] = count
        if order is not None:
            self._values["order"] = order

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''The number of results to return.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#count Powerpack#count}
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def order(self) -> typing.Optional[builtins.str]:
        '''The direction of the sort. Valid values are ``asc``, ``desc``. Defaults to ``"desc"``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        result = self._values.get("order")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryValueDefinitionRequestFormulaLimit(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetQueryValueDefinitionRequestFormulaLimitOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestFormulaLimitOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6ec2ec2a8a33a104ba2965e0c852a9593d7c68dcebb73787894f080219d404c3)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetCount")
    def reset_count(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCount", []))

    @jsii.member(jsii_name="resetOrder")
    def reset_order(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetOrder", []))

    @builtins.property
    @jsii.member(jsii_name="countInput")
    def count_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "countInput"))

    @builtins.property
    @jsii.member(jsii_name="orderInput")
    def order_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "orderInput"))

    @builtins.property
    @jsii.member(jsii_name="count")
    def count(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "count"))

    @count.setter
    def count(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e573a167cae6d75c2d7622c54f6437ce58fa33d6154e2652d3b657ed2902bc89)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "count", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="order")
    def order(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "order"))

    @order.setter
    def order(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8dfcebccbd8d2993e8f94798e59d7b31a67a0615ec05e6aa1f56f826802250c1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "order", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetQueryValueDefinitionRequestFormulaLimit]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryValueDefinitionRequestFormulaLimit], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetQueryValueDefinitionRequestFormulaLimit],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3d84d9d47c26ea87c5738c8775dc4f6b29ea942e9305995443643d373154f6be)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetQueryValueDefinitionRequestFormulaList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestFormulaList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__83975d552881908377b62f92318c08b830625ef87ec516b1b7e93f6482972337)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetQueryValueDefinitionRequestFormulaOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__219a1dcf511487566a43075c27fab7d12201136b62c55cd28fc18ea730a87e73)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetQueryValueDefinitionRequestFormulaOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__86d25a1afa576160f2f1e0793c0f59c6690973651020918f7518d1802081ac01)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f538a83d338a8ab4684fe52283392b3a5ab826e3ea75bffe832e0d5072e7a42e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__75f9709183323fcf6bd891e4a8d3563753cd3166f8b463d774ddd56200f86e0c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionRequestFormula]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionRequestFormula]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionRequestFormula]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2430ac1e41cffb132a5102498c0f939bb8601a6ad820811672eff142ba705f13)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormat",
    jsii_struct_bases=[],
    name_mapping={"unit": "unit", "unit_scale": "unitScale"},
)
class PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormat:
    def __init__(
        self,
        *,
        unit: typing.Union["PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormatUnit", typing.Dict[builtins.str, typing.Any]],
        unit_scale: typing.Optional[typing.Union["PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormatUnitScale", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param unit: unit block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit Powerpack#unit}
        :param unit_scale: unit_scale block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit_scale Powerpack#unit_scale}
        '''
        if isinstance(unit, dict):
            unit = PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormatUnit(**unit)
        if isinstance(unit_scale, dict):
            unit_scale = PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormatUnitScale(**unit_scale)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9bef1d69ecf89eaab18a82d8646c48db8a09de25b132811143bf1977d680f21e)
            check_type(argname="argument unit", value=unit, expected_type=type_hints["unit"])
            check_type(argname="argument unit_scale", value=unit_scale, expected_type=type_hints["unit_scale"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "unit": unit,
        }
        if unit_scale is not None:
            self._values["unit_scale"] = unit_scale

    @builtins.property
    def unit(
        self,
    ) -> "PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormatUnit":
        '''unit block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit Powerpack#unit}
        '''
        result = self._values.get("unit")
        assert result is not None, "Required property 'unit' is missing"
        return typing.cast("PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormatUnit", result)

    @builtins.property
    def unit_scale(
        self,
    ) -> typing.Optional["PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormatUnitScale"]:
        '''unit_scale block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit_scale Powerpack#unit_scale}
        '''
        result = self._values.get("unit_scale")
        return typing.cast(typing.Optional["PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormatUnitScale"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormat(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormatOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormatOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__08a2d0c923053cb1ea8670d6da2ef7c0231c40bff5c4473ebcf853d31f45ca09)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putUnit")
    def put_unit(
        self,
        *,
        canonical: typing.Optional[typing.Union["PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormatUnitCanonical", typing.Dict[builtins.str, typing.Any]]] = None,
        custom: typing.Optional[typing.Union["PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormatUnitCustom", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param canonical: canonical block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#canonical Powerpack#canonical}
        :param custom: custom block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom Powerpack#custom}
        '''
        value = PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormatUnit(
            canonical=canonical, custom=custom
        )

        return typing.cast(None, jsii.invoke(self, "putUnit", [value]))

    @jsii.member(jsii_name="putUnitScale")
    def put_unit_scale(self, *, unit_name: builtins.str) -> None:
        '''
        :param unit_name: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit_name Powerpack#unit_name}.
        '''
        value = PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormatUnitScale(
            unit_name=unit_name
        )

        return typing.cast(None, jsii.invoke(self, "putUnitScale", [value]))

    @jsii.member(jsii_name="resetUnitScale")
    def reset_unit_scale(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetUnitScale", []))

    @builtins.property
    @jsii.member(jsii_name="unit")
    def unit(
        self,
    ) -> "PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormatUnitOutputReference":
        return typing.cast("PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormatUnitOutputReference", jsii.get(self, "unit"))

    @builtins.property
    @jsii.member(jsii_name="unitScale")
    def unit_scale(
        self,
    ) -> "PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormatUnitScaleOutputReference":
        return typing.cast("PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormatUnitScaleOutputReference", jsii.get(self, "unitScale"))

    @builtins.property
    @jsii.member(jsii_name="unitInput")
    def unit_input(
        self,
    ) -> typing.Optional["PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormatUnit"]:
        return typing.cast(typing.Optional["PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormatUnit"], jsii.get(self, "unitInput"))

    @builtins.property
    @jsii.member(jsii_name="unitScaleInput")
    def unit_scale_input(
        self,
    ) -> typing.Optional["PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormatUnitScale"]:
        return typing.cast(typing.Optional["PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormatUnitScale"], jsii.get(self, "unitScaleInput"))

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormat]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormat], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormat],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5fea8957766c6bc34fea8bedefbf81083523d4e9c0e769a7447ce087c8668162)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormatUnit",
    jsii_struct_bases=[],
    name_mapping={"canonical": "canonical", "custom": "custom"},
)
class PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormatUnit:
    def __init__(
        self,
        *,
        canonical: typing.Optional[typing.Union["PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormatUnitCanonical", typing.Dict[builtins.str, typing.Any]]] = None,
        custom: typing.Optional[typing.Union["PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormatUnitCustom", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param canonical: canonical block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#canonical Powerpack#canonical}
        :param custom: custom block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom Powerpack#custom}
        '''
        if isinstance(canonical, dict):
            canonical = PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormatUnitCanonical(**canonical)
        if isinstance(custom, dict):
            custom = PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormatUnitCustom(**custom)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3f5ad7a3fb0ec2c85844364e3c00078a7fbb1e0a46c4b33a87a970528e1dcd3e)
            check_type(argname="argument canonical", value=canonical, expected_type=type_hints["canonical"])
            check_type(argname="argument custom", value=custom, expected_type=type_hints["custom"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if canonical is not None:
            self._values["canonical"] = canonical
        if custom is not None:
            self._values["custom"] = custom

    @builtins.property
    def canonical(
        self,
    ) -> typing.Optional["PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormatUnitCanonical"]:
        '''canonical block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#canonical Powerpack#canonical}
        '''
        result = self._values.get("canonical")
        return typing.cast(typing.Optional["PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormatUnitCanonical"], result)

    @builtins.property
    def custom(
        self,
    ) -> typing.Optional["PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormatUnitCustom"]:
        '''custom block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom Powerpack#custom}
        '''
        result = self._values.get("custom")
        return typing.cast(typing.Optional["PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormatUnitCustom"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormatUnit(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormatUnitCanonical",
    jsii_struct_bases=[],
    name_mapping={"unit_name": "unitName", "per_unit_name": "perUnitName"},
)
class PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormatUnitCanonical:
    def __init__(
        self,
        *,
        unit_name: builtins.str,
        per_unit_name: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param unit_name: Unit name. It should be in singular form ('megabyte' and not 'megabytes'). Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit_name Powerpack#unit_name}
        :param per_unit_name: per unit name. If you want to represent megabytes/s, you set 'unit_name' = 'megabyte' and 'per_unit_name = 'second'. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#per_unit_name Powerpack#per_unit_name}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6b01b59e61276a3e589f849af587441e3e67f4bf5f31da254e666a1e01ef52bc)
            check_type(argname="argument unit_name", value=unit_name, expected_type=type_hints["unit_name"])
            check_type(argname="argument per_unit_name", value=per_unit_name, expected_type=type_hints["per_unit_name"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "unit_name": unit_name,
        }
        if per_unit_name is not None:
            self._values["per_unit_name"] = per_unit_name

    @builtins.property
    def unit_name(self) -> builtins.str:
        '''Unit name. It should be in singular form ('megabyte' and not 'megabytes').

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit_name Powerpack#unit_name}
        '''
        result = self._values.get("unit_name")
        assert result is not None, "Required property 'unit_name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def per_unit_name(self) -> typing.Optional[builtins.str]:
        '''per unit name. If you want to represent megabytes/s, you set 'unit_name' = 'megabyte' and 'per_unit_name = 'second'.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#per_unit_name Powerpack#per_unit_name}
        '''
        result = self._values.get("per_unit_name")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormatUnitCanonical(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormatUnitCanonicalOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormatUnitCanonicalOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a77a51cff6879893467eb615b7d43980c390287ca265083c43f088fab4bbb4e6)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetPerUnitName")
    def reset_per_unit_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPerUnitName", []))

    @builtins.property
    @jsii.member(jsii_name="perUnitNameInput")
    def per_unit_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "perUnitNameInput"))

    @builtins.property
    @jsii.member(jsii_name="unitNameInput")
    def unit_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "unitNameInput"))

    @builtins.property
    @jsii.member(jsii_name="perUnitName")
    def per_unit_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "perUnitName"))

    @per_unit_name.setter
    def per_unit_name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4e49e7bae67649e624e8b4574958ac49bb13ae7c1eb62ed684db94e812702989)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "perUnitName", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="unitName")
    def unit_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "unitName"))

    @unit_name.setter
    def unit_name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__eaa5f5e76deaa545024d5cea0eccc439c76d4178f4b64f64315d8883f9fd4dd9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "unitName", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormatUnitCanonical]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormatUnitCanonical], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormatUnitCanonical],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7e4ab2251c6e210ed9ef39c7ffe297327335aad0b26d4d971c561209547a19bc)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormatUnitCustom",
    jsii_struct_bases=[],
    name_mapping={"label": "label"},
)
class PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormatUnitCustom:
    def __init__(self, *, label: builtins.str) -> None:
        '''
        :param label: Unit label. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#label Powerpack#label}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3fd5c93456f8047e6d18eec8523b11abc9a20b22a8242798eedadc029da967ac)
            check_type(argname="argument label", value=label, expected_type=type_hints["label"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "label": label,
        }

    @builtins.property
    def label(self) -> builtins.str:
        '''Unit label.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#label Powerpack#label}
        '''
        result = self._values.get("label")
        assert result is not None, "Required property 'label' is missing"
        return typing.cast(builtins.str, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormatUnitCustom(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormatUnitCustomOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormatUnitCustomOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__eb3747349d7751aaeef2dd5b5e574673a45031da44fef6a555e3fcbf2809e0d5)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @builtins.property
    @jsii.member(jsii_name="labelInput")
    def label_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "labelInput"))

    @builtins.property
    @jsii.member(jsii_name="label")
    def label(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "label"))

    @label.setter
    def label(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__95f35dbb8c72956eeb2be95b764be50e400a6f048a2bfdc98b0728b71217e283)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "label", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormatUnitCustom]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormatUnitCustom], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormatUnitCustom],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1d6eede99fcbb28b5bbc2e9c4ff3279c4fa444aedf71ab3b118cadf0465f23c2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormatUnitOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormatUnitOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f9c76a32172b432dd0a6d0ecdd43c744f4b9359afc639c7b428c06bfef1d0db5)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putCanonical")
    def put_canonical(
        self,
        *,
        unit_name: builtins.str,
        per_unit_name: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param unit_name: Unit name. It should be in singular form ('megabyte' and not 'megabytes'). Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit_name Powerpack#unit_name}
        :param per_unit_name: per unit name. If you want to represent megabytes/s, you set 'unit_name' = 'megabyte' and 'per_unit_name = 'second'. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#per_unit_name Powerpack#per_unit_name}
        '''
        value = PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormatUnitCanonical(
            unit_name=unit_name, per_unit_name=per_unit_name
        )

        return typing.cast(None, jsii.invoke(self, "putCanonical", [value]))

    @jsii.member(jsii_name="putCustom")
    def put_custom(self, *, label: builtins.str) -> None:
        '''
        :param label: Unit label. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#label Powerpack#label}
        '''
        value = PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormatUnitCustom(
            label=label
        )

        return typing.cast(None, jsii.invoke(self, "putCustom", [value]))

    @jsii.member(jsii_name="resetCanonical")
    def reset_canonical(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCanonical", []))

    @jsii.member(jsii_name="resetCustom")
    def reset_custom(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCustom", []))

    @builtins.property
    @jsii.member(jsii_name="canonical")
    def canonical(
        self,
    ) -> PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormatUnitCanonicalOutputReference:
        return typing.cast(PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormatUnitCanonicalOutputReference, jsii.get(self, "canonical"))

    @builtins.property
    @jsii.member(jsii_name="custom")
    def custom(
        self,
    ) -> PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormatUnitCustomOutputReference:
        return typing.cast(PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormatUnitCustomOutputReference, jsii.get(self, "custom"))

    @builtins.property
    @jsii.member(jsii_name="canonicalInput")
    def canonical_input(
        self,
    ) -> typing.Optional[PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormatUnitCanonical]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormatUnitCanonical], jsii.get(self, "canonicalInput"))

    @builtins.property
    @jsii.member(jsii_name="customInput")
    def custom_input(
        self,
    ) -> typing.Optional[PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormatUnitCustom]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormatUnitCustom], jsii.get(self, "customInput"))

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormatUnit]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormatUnit], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormatUnit],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f17ce5536a017770143dff05480d3b5eff308af7d486bff71bf28fba3dc5ea44)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormatUnitScale",
    jsii_struct_bases=[],
    name_mapping={"unit_name": "unitName"},
)
class PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormatUnitScale:
    def __init__(self, *, unit_name: builtins.str) -> None:
        '''
        :param unit_name: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit_name Powerpack#unit_name}.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cc6122788916cb67acd8868e2a3ed06dbbe338ab4fa62733d9b243fd6ecf93e4)
            check_type(argname="argument unit_name", value=unit_name, expected_type=type_hints["unit_name"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "unit_name": unit_name,
        }

    @builtins.property
    def unit_name(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit_name Powerpack#unit_name}.'''
        result = self._values.get("unit_name")
        assert result is not None, "Required property 'unit_name' is missing"
        return typing.cast(builtins.str, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormatUnitScale(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormatUnitScaleOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormatUnitScaleOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fc00126a7702eab2f0a25d39fe25f3696548731a02e537e6f643f5c22bac3480)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @builtins.property
    @jsii.member(jsii_name="unitNameInput")
    def unit_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "unitNameInput"))

    @builtins.property
    @jsii.member(jsii_name="unitName")
    def unit_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "unitName"))

    @unit_name.setter
    def unit_name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__48f931715006d8797ce8b7147a9996fea7c91a16d634c5e7eb5b6d307b7a724d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "unitName", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormatUnitScale]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormatUnitScale], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormatUnitScale],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e6df7f85dcc2db343cd569d9e9ddffe17c160805d01625904cd97e4d93f50480)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetQueryValueDefinitionRequestFormulaOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestFormulaOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3553bd0c186d08f199c97b5e52fd5763f73c3a3fe9f2da0c9770d5b00ffcab70)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putConditionalFormats")
    def put_conditional_formats(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryValueDefinitionRequestFormulaConditionalFormats, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__afca99fe33b24dbc322ea2eaa3f666afa587b0eb9eed61f90205c895197413ef)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putConditionalFormats", [value]))

    @jsii.member(jsii_name="putLimit")
    def put_limit(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        order: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param count: The number of results to return. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#count Powerpack#count}
        :param order: The direction of the sort. Valid values are ``asc``, ``desc``. Defaults to ``"desc"``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        value = PowerpackWidgetQueryValueDefinitionRequestFormulaLimit(
            count=count, order=order
        )

        return typing.cast(None, jsii.invoke(self, "putLimit", [value]))

    @jsii.member(jsii_name="putNumberFormat")
    def put_number_format(
        self,
        *,
        unit: typing.Union[PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormatUnit, typing.Dict[builtins.str, typing.Any]],
        unit_scale: typing.Optional[typing.Union[PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormatUnitScale, typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param unit: unit block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit Powerpack#unit}
        :param unit_scale: unit_scale block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit_scale Powerpack#unit_scale}
        '''
        value = PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormat(
            unit=unit, unit_scale=unit_scale
        )

        return typing.cast(None, jsii.invoke(self, "putNumberFormat", [value]))

    @jsii.member(jsii_name="putStyle")
    def put_style(
        self,
        *,
        palette: typing.Optional[builtins.str] = None,
        palette_index: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param palette: The color palette used to display the formula. A guide to the available color palettes can be found at https://docs.datadoghq.com/dashboards/guide/widget_colors. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette Powerpack#palette}
        :param palette_index: Index specifying which color to use within the palette. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette_index Powerpack#palette_index}
        '''
        value = PowerpackWidgetQueryValueDefinitionRequestFormulaStyle(
            palette=palette, palette_index=palette_index
        )

        return typing.cast(None, jsii.invoke(self, "putStyle", [value]))

    @jsii.member(jsii_name="resetAlias")
    def reset_alias(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAlias", []))

    @jsii.member(jsii_name="resetCellDisplayMode")
    def reset_cell_display_mode(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCellDisplayMode", []))

    @jsii.member(jsii_name="resetConditionalFormats")
    def reset_conditional_formats(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetConditionalFormats", []))

    @jsii.member(jsii_name="resetLimit")
    def reset_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLimit", []))

    @jsii.member(jsii_name="resetNumberFormat")
    def reset_number_format(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetNumberFormat", []))

    @jsii.member(jsii_name="resetStyle")
    def reset_style(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetStyle", []))

    @builtins.property
    @jsii.member(jsii_name="conditionalFormats")
    def conditional_formats(
        self,
    ) -> PowerpackWidgetQueryValueDefinitionRequestFormulaConditionalFormatsList:
        return typing.cast(PowerpackWidgetQueryValueDefinitionRequestFormulaConditionalFormatsList, jsii.get(self, "conditionalFormats"))

    @builtins.property
    @jsii.member(jsii_name="limit")
    def limit(
        self,
    ) -> PowerpackWidgetQueryValueDefinitionRequestFormulaLimitOutputReference:
        return typing.cast(PowerpackWidgetQueryValueDefinitionRequestFormulaLimitOutputReference, jsii.get(self, "limit"))

    @builtins.property
    @jsii.member(jsii_name="numberFormat")
    def number_format(
        self,
    ) -> PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormatOutputReference:
        return typing.cast(PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormatOutputReference, jsii.get(self, "numberFormat"))

    @builtins.property
    @jsii.member(jsii_name="style")
    def style(
        self,
    ) -> "PowerpackWidgetQueryValueDefinitionRequestFormulaStyleOutputReference":
        return typing.cast("PowerpackWidgetQueryValueDefinitionRequestFormulaStyleOutputReference", jsii.get(self, "style"))

    @builtins.property
    @jsii.member(jsii_name="aliasInput")
    def alias_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aliasInput"))

    @builtins.property
    @jsii.member(jsii_name="cellDisplayModeInput")
    def cell_display_mode_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "cellDisplayModeInput"))

    @builtins.property
    @jsii.member(jsii_name="conditionalFormatsInput")
    def conditional_formats_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionRequestFormulaConditionalFormats]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionRequestFormulaConditionalFormats]]], jsii.get(self, "conditionalFormatsInput"))

    @builtins.property
    @jsii.member(jsii_name="formulaExpressionInput")
    def formula_expression_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "formulaExpressionInput"))

    @builtins.property
    @jsii.member(jsii_name="limitInput")
    def limit_input(
        self,
    ) -> typing.Optional[PowerpackWidgetQueryValueDefinitionRequestFormulaLimit]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryValueDefinitionRequestFormulaLimit], jsii.get(self, "limitInput"))

    @builtins.property
    @jsii.member(jsii_name="numberFormatInput")
    def number_format_input(
        self,
    ) -> typing.Optional[PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormat]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormat], jsii.get(self, "numberFormatInput"))

    @builtins.property
    @jsii.member(jsii_name="styleInput")
    def style_input(
        self,
    ) -> typing.Optional["PowerpackWidgetQueryValueDefinitionRequestFormulaStyle"]:
        return typing.cast(typing.Optional["PowerpackWidgetQueryValueDefinitionRequestFormulaStyle"], jsii.get(self, "styleInput"))

    @builtins.property
    @jsii.member(jsii_name="alias")
    def alias(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "alias"))

    @alias.setter
    def alias(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e96ac9f440a4f93ad71db42124b91f651fd66ce33f26de73a3971b8622c72941)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "alias", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="cellDisplayMode")
    def cell_display_mode(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "cellDisplayMode"))

    @cell_display_mode.setter
    def cell_display_mode(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a2452e946051ee60ff6d7d91b6e3df1811d2ac0851d49bc6893fc0224320b267)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "cellDisplayMode", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="formulaExpression")
    def formula_expression(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "formulaExpression"))

    @formula_expression.setter
    def formula_expression(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9dc58abfcdaae46a66758e38517955ec7acd4de4f3003654f3a7fc3faa334854)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "formulaExpression", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryValueDefinitionRequestFormula]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryValueDefinitionRequestFormula]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryValueDefinitionRequestFormula]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__38ff5c9cd6b7fe7e90b862425f7be2651d281615de7840ef245a31ce00ec7b95)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestFormulaStyle",
    jsii_struct_bases=[],
    name_mapping={"palette": "palette", "palette_index": "paletteIndex"},
)
class PowerpackWidgetQueryValueDefinitionRequestFormulaStyle:
    def __init__(
        self,
        *,
        palette: typing.Optional[builtins.str] = None,
        palette_index: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param palette: The color palette used to display the formula. A guide to the available color palettes can be found at https://docs.datadoghq.com/dashboards/guide/widget_colors. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette Powerpack#palette}
        :param palette_index: Index specifying which color to use within the palette. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette_index Powerpack#palette_index}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0086ec2ff84c385925ee2035cd49a081a0b97b7adefd1bd1a4eb55d2b6e4cd82)
            check_type(argname="argument palette", value=palette, expected_type=type_hints["palette"])
            check_type(argname="argument palette_index", value=palette_index, expected_type=type_hints["palette_index"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if palette is not None:
            self._values["palette"] = palette
        if palette_index is not None:
            self._values["palette_index"] = palette_index

    @builtins.property
    def palette(self) -> typing.Optional[builtins.str]:
        '''The color palette used to display the formula.

        A guide to the available color palettes can be found at https://docs.datadoghq.com/dashboards/guide/widget_colors.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette Powerpack#palette}
        '''
        result = self._values.get("palette")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def palette_index(self) -> typing.Optional[jsii.Number]:
        '''Index specifying which color to use within the palette.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette_index Powerpack#palette_index}
        '''
        result = self._values.get("palette_index")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryValueDefinitionRequestFormulaStyle(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetQueryValueDefinitionRequestFormulaStyleOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestFormulaStyleOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1b03adbd8da1369f7db65a8a4173b7e972867d04f0afb0a02b2528e0b6ddc288)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetPalette")
    def reset_palette(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPalette", []))

    @jsii.member(jsii_name="resetPaletteIndex")
    def reset_palette_index(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPaletteIndex", []))

    @builtins.property
    @jsii.member(jsii_name="paletteIndexInput")
    def palette_index_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "paletteIndexInput"))

    @builtins.property
    @jsii.member(jsii_name="paletteInput")
    def palette_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "paletteInput"))

    @builtins.property
    @jsii.member(jsii_name="palette")
    def palette(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "palette"))

    @palette.setter
    def palette(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0abdae024e91e90879d498cffd0eaf40db3767f069712aed820c79abfde6b670)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "palette", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="paletteIndex")
    def palette_index(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "paletteIndex"))

    @palette_index.setter
    def palette_index(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__592fd9515d26cb95e41171cc12461314e8bcf6b05f4b1c6d980b5107d752f0da)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "paletteIndex", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetQueryValueDefinitionRequestFormulaStyle]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryValueDefinitionRequestFormulaStyle], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetQueryValueDefinitionRequestFormulaStyle],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7bc77d30e79c962a5b0d24f7c3ca6ed3599d55cd3b90606840a1bcd5145fc098)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetQueryValueDefinitionRequestList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__358f7ae2316c966b53752efb287a0bcc6899166e4a9ae69b8c5b8b4b3e231cfa)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetQueryValueDefinitionRequestOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f5ff2814cfe6a9514a1603aae194b9219192639bca5c4ff1be3934d0a97840fa)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetQueryValueDefinitionRequestOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c76ab593542a55041e586b7be47a8a92c8569556b0dfd51c2b0c59a497ce76ea)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__42cf929feb833879d3f4261328f9012ad84061befa12c518caee8a99b2da06a2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b539f031649be4fd781884575b17edf6d986020639bd7a4ea7f9c4b918689203)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionRequest]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionRequest]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionRequest]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bd56dee1b87f7c5a7c063ed9348deadd8cc9fa777447304bfe87c884bd67758c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestLogQuery",
    jsii_struct_bases=[],
    name_mapping={
        "index": "index",
        "compute_query": "computeQuery",
        "group_by": "groupBy",
        "multi_compute": "multiCompute",
        "search_query": "searchQuery",
    },
)
class PowerpackWidgetQueryValueDefinitionRequestLogQuery:
    def __init__(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union["PowerpackWidgetQueryValueDefinitionRequestLogQueryComputeQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetQueryValueDefinitionRequestLogQueryGroupBy", typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetQueryValueDefinitionRequestLogQueryMultiCompute", typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        if isinstance(compute_query, dict):
            compute_query = PowerpackWidgetQueryValueDefinitionRequestLogQueryComputeQuery(**compute_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fd362fd3e154284723b4842982936afe6ed64d272012732e10c16ffeac4ec8d2)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
            check_type(argname="argument compute_query", value=compute_query, expected_type=type_hints["compute_query"])
            check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
            check_type(argname="argument multi_compute", value=multi_compute, expected_type=type_hints["multi_compute"])
            check_type(argname="argument search_query", value=search_query, expected_type=type_hints["search_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "index": index,
        }
        if compute_query is not None:
            self._values["compute_query"] = compute_query
        if group_by is not None:
            self._values["group_by"] = group_by
        if multi_compute is not None:
            self._values["multi_compute"] = multi_compute
        if search_query is not None:
            self._values["search_query"] = search_query

    @builtins.property
    def index(self) -> builtins.str:
        '''The name of the index to query.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        '''
        result = self._values.get("index")
        assert result is not None, "Required property 'index' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def compute_query(
        self,
    ) -> typing.Optional["PowerpackWidgetQueryValueDefinitionRequestLogQueryComputeQuery"]:
        '''compute_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        '''
        result = self._values.get("compute_query")
        return typing.cast(typing.Optional["PowerpackWidgetQueryValueDefinitionRequestLogQueryComputeQuery"], result)

    @builtins.property
    def group_by(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetQueryValueDefinitionRequestLogQueryGroupBy"]]]:
        '''group_by block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        '''
        result = self._values.get("group_by")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetQueryValueDefinitionRequestLogQueryGroupBy"]]], result)

    @builtins.property
    def multi_compute(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetQueryValueDefinitionRequestLogQueryMultiCompute"]]]:
        '''multi_compute block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        '''
        result = self._values.get("multi_compute")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetQueryValueDefinitionRequestLogQueryMultiCompute"]]], result)

    @builtins.property
    def search_query(self) -> typing.Optional[builtins.str]:
        '''The search query to use.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        result = self._values.get("search_query")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryValueDefinitionRequestLogQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestLogQueryComputeQuery",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetQueryValueDefinitionRequestLogQueryComputeQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fea818daaa64e8511ce114aafa5bd9cefbb1fc036d215aaaa689f34189a9ca43)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryValueDefinitionRequestLogQueryComputeQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetQueryValueDefinitionRequestLogQueryComputeQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestLogQueryComputeQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__59a269f1477becfebe59a5be62ad9ae1a65ad7a6168f64f9634196e168ea969b)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__88c7045e8a76e36fd050ed5cd2cdd7e2339455322fa010ea0546a81cd4a79a69)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d6e1ec82854cd1f708e01eba68f5f99fee944dc84a3aeaa1c7d17b9e8aeda397)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__982faa7a02a76fe51848990d47f30865fa4cbc5a4dd90891ff5a4eb91c7e9492)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetQueryValueDefinitionRequestLogQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryValueDefinitionRequestLogQueryComputeQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetQueryValueDefinitionRequestLogQueryComputeQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b79a9c446d6656a93b8d0c301d32458af65938cccaaece44b006acd502173cec)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestLogQueryGroupBy",
    jsii_struct_bases=[],
    name_mapping={"facet": "facet", "limit": "limit", "sort_query": "sortQuery"},
)
class PowerpackWidgetQueryValueDefinitionRequestLogQueryGroupBy:
    def __init__(
        self,
        *,
        facet: typing.Optional[builtins.str] = None,
        limit: typing.Optional[jsii.Number] = None,
        sort_query: typing.Optional[typing.Union["PowerpackWidgetQueryValueDefinitionRequestLogQueryGroupBySortQuery", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param limit: The maximum number of items in the group. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param sort_query: sort_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        if isinstance(sort_query, dict):
            sort_query = PowerpackWidgetQueryValueDefinitionRequestLogQueryGroupBySortQuery(**sort_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4ad01ac2217ed3e4cddb53350e6e54931a9941c565e6a26ceec2504df9083682)
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
            check_type(argname="argument sort_query", value=sort_query, expected_type=type_hints["sort_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if facet is not None:
            self._values["facet"] = facet
        if limit is not None:
            self._values["limit"] = limit
        if sort_query is not None:
            self._values["sort_query"] = sort_query

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def limit(self) -> typing.Optional[jsii.Number]:
        '''The maximum number of items in the group.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        '''
        result = self._values.get("limit")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def sort_query(
        self,
    ) -> typing.Optional["PowerpackWidgetQueryValueDefinitionRequestLogQueryGroupBySortQuery"]:
        '''sort_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        result = self._values.get("sort_query")
        return typing.cast(typing.Optional["PowerpackWidgetQueryValueDefinitionRequestLogQueryGroupBySortQuery"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryValueDefinitionRequestLogQueryGroupBy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetQueryValueDefinitionRequestLogQueryGroupByList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestLogQueryGroupByList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__af670b6f45d0a185e61893e46beb9c10562dded20adcc0f92a00b0837471ceee)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetQueryValueDefinitionRequestLogQueryGroupByOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e7c7b9fa818f90c21613d00f77422d2908236b8ef7ac1cff622f3c9a67ba5488)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetQueryValueDefinitionRequestLogQueryGroupByOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ba19b74b8520bf66eed06888f1345f6a50aff2f54bb8875c9097140352c49508)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f33961da8e066ad7f8da1e8fb1e87274cbfe667e0a5f514f6994d8bcefff7bd0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__29fd1ff3b6bb4e2a395d5a9dcbf4158ae8de391b9487f7e4d3c98f50da9e678b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionRequestLogQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionRequestLogQueryGroupBy]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionRequestLogQueryGroupBy]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1b663b6fe7a8af87280f467babf33d5e9c99e3f6b38ed913532e02ce91b9d911)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetQueryValueDefinitionRequestLogQueryGroupByOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestLogQueryGroupByOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5b2081188c9ef3f6d79a5333869971ba73a1a6f955fd0cd430307ae25c47c551)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putSortQuery")
    def put_sort_query(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        value = PowerpackWidgetQueryValueDefinitionRequestLogQueryGroupBySortQuery(
            aggregation=aggregation, order=order, facet=facet
        )

        return typing.cast(None, jsii.invoke(self, "putSortQuery", [value]))

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetLimit")
    def reset_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLimit", []))

    @jsii.member(jsii_name="resetSortQuery")
    def reset_sort_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSortQuery", []))

    @builtins.property
    @jsii.member(jsii_name="sortQuery")
    def sort_query(
        self,
    ) -> "PowerpackWidgetQueryValueDefinitionRequestLogQueryGroupBySortQueryOutputReference":
        return typing.cast("PowerpackWidgetQueryValueDefinitionRequestLogQueryGroupBySortQueryOutputReference", jsii.get(self, "sortQuery"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="limitInput")
    def limit_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "limitInput"))

    @builtins.property
    @jsii.member(jsii_name="sortQueryInput")
    def sort_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetQueryValueDefinitionRequestLogQueryGroupBySortQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetQueryValueDefinitionRequestLogQueryGroupBySortQuery"], jsii.get(self, "sortQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c470795ec665592fe436026ec5c2f7e591d4ac77c2bb4f45c02e0023519eb372)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="limit")
    def limit(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "limit"))

    @limit.setter
    def limit(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b93aaf7985f9f6cb2a538b139899252ee53e18eee56210a54dfeade9d8a711ad)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "limit", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryValueDefinitionRequestLogQueryGroupBy]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryValueDefinitionRequestLogQueryGroupBy]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryValueDefinitionRequestLogQueryGroupBy]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__93634c7775477a096a72a968bd4f63dc6a28fccd2e4306e036bdd32c33246d6a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestLogQueryGroupBySortQuery",
    jsii_struct_bases=[],
    name_mapping={"aggregation": "aggregation", "order": "order", "facet": "facet"},
)
class PowerpackWidgetQueryValueDefinitionRequestLogQueryGroupBySortQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f986ef97740dfae5769f36336632573b51072fc94d8e3fba491dbe3bbe859565)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument order", value=order, expected_type=type_hints["order"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
            "order": order,
        }
        if facet is not None:
            self._values["facet"] = facet

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def order(self) -> builtins.str:
        '''Widget sorting methods. Valid values are ``asc``, ``desc``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        result = self._values.get("order")
        assert result is not None, "Required property 'order' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryValueDefinitionRequestLogQueryGroupBySortQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetQueryValueDefinitionRequestLogQueryGroupBySortQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestLogQueryGroupBySortQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5c7f5cae54c55cb502af9543118a24aedcc98397bfb4e4f306006d7278e0b0d5)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="orderInput")
    def order_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "orderInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3b5ae501b0cd22e157a909af749a0c0b35cda1645b2afe8f5c64a773e30a4eaa)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b3b3eb8829bc3b779e09dcf4bb737157b095e29eeed0b3b417b052a33912e1ab)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="order")
    def order(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "order"))

    @order.setter
    def order(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b226773c961d7054916169a9e0e4d4fbef2225d6d5b4f6330ab6e82773816f49)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "order", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetQueryValueDefinitionRequestLogQueryGroupBySortQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryValueDefinitionRequestLogQueryGroupBySortQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetQueryValueDefinitionRequestLogQueryGroupBySortQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__51561904f883528870dba0dba8ba914db2358bd77fbc159349bdaf04d810b4c6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestLogQueryMultiCompute",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetQueryValueDefinitionRequestLogQueryMultiCompute:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4bf9c24b0f81d700e666f46f4a91a9f8797ff3e837e0f609428c88ffa4dab394)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryValueDefinitionRequestLogQueryMultiCompute(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetQueryValueDefinitionRequestLogQueryMultiComputeList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestLogQueryMultiComputeList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5ab33761a7230269860d2aad30618a4bdbeb506c255f339a32046556e88f02a1)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetQueryValueDefinitionRequestLogQueryMultiComputeOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__35eaa7d7b6bf41c47441c8f7e2b205b036977f94bc421970a12b7c75737bf8a6)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetQueryValueDefinitionRequestLogQueryMultiComputeOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__74771a684c96dd8d268308a84c70f4a26fd392f3653ba12cbc132f3228a70e70)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dcae3b14a3b405abcac440161e346e4c4312886a1c069de5343f3020349e6e99)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2c5e368f4ea30c56e34f3dd4a4c5ddf31592182e98c79adc5301d5c85c012313)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionRequestLogQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionRequestLogQueryMultiCompute]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionRequestLogQueryMultiCompute]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__78da300d651eafb163be58d5cd3743b45b4eb3a55241984f3691a4704841e9d9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetQueryValueDefinitionRequestLogQueryMultiComputeOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestLogQueryMultiComputeOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cae330ce8ea2b4ed443f9e01c2fe7e99c953948b5e736d33204a3ce2f1504483)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d24832601fcf718fd9eff1466471da05a675988671935bf6dd165b9f34d142d5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f7bcc9d1aed54a3593f130f1fb967bd83136f92bdfe849d1f82b6c36e3e933f1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__552fe5114be2aa99b9b93d18a1aeaf27b924ea07bb7349ef7011260e77619760)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryValueDefinitionRequestLogQueryMultiCompute]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryValueDefinitionRequestLogQueryMultiCompute]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryValueDefinitionRequestLogQueryMultiCompute]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c671c88e3da5e7c79f169cc2c568777baf7b51d669460da8c5848beb4df391a3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetQueryValueDefinitionRequestLogQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestLogQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b59f93ad1cd06fcc288b19135664b4c005e6c548313fc683d8cbfa102c62555d)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putComputeQuery")
    def put_compute_query(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        value = PowerpackWidgetQueryValueDefinitionRequestLogQueryComputeQuery(
            aggregation=aggregation, facet=facet, interval=interval
        )

        return typing.cast(None, jsii.invoke(self, "putComputeQuery", [value]))

    @jsii.member(jsii_name="putGroupBy")
    def put_group_by(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryValueDefinitionRequestLogQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__47a9cfb9d211a80a6dc75a7b83613d6287126e17e7c1bdb640126d1bd08d1806)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putGroupBy", [value]))

    @jsii.member(jsii_name="putMultiCompute")
    def put_multi_compute(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryValueDefinitionRequestLogQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b5a3235a55cd48a26dca25620ad298dfd8a9179a22a4fb1ba0424bfc1485d44a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putMultiCompute", [value]))

    @jsii.member(jsii_name="resetComputeQuery")
    def reset_compute_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetComputeQuery", []))

    @jsii.member(jsii_name="resetGroupBy")
    def reset_group_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGroupBy", []))

    @jsii.member(jsii_name="resetMultiCompute")
    def reset_multi_compute(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMultiCompute", []))

    @jsii.member(jsii_name="resetSearchQuery")
    def reset_search_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSearchQuery", []))

    @builtins.property
    @jsii.member(jsii_name="computeQuery")
    def compute_query(
        self,
    ) -> PowerpackWidgetQueryValueDefinitionRequestLogQueryComputeQueryOutputReference:
        return typing.cast(PowerpackWidgetQueryValueDefinitionRequestLogQueryComputeQueryOutputReference, jsii.get(self, "computeQuery"))

    @builtins.property
    @jsii.member(jsii_name="groupBy")
    def group_by(self) -> PowerpackWidgetQueryValueDefinitionRequestLogQueryGroupByList:
        return typing.cast(PowerpackWidgetQueryValueDefinitionRequestLogQueryGroupByList, jsii.get(self, "groupBy"))

    @builtins.property
    @jsii.member(jsii_name="multiCompute")
    def multi_compute(
        self,
    ) -> PowerpackWidgetQueryValueDefinitionRequestLogQueryMultiComputeList:
        return typing.cast(PowerpackWidgetQueryValueDefinitionRequestLogQueryMultiComputeList, jsii.get(self, "multiCompute"))

    @builtins.property
    @jsii.member(jsii_name="computeQueryInput")
    def compute_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetQueryValueDefinitionRequestLogQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryValueDefinitionRequestLogQueryComputeQuery], jsii.get(self, "computeQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="groupByInput")
    def group_by_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionRequestLogQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionRequestLogQueryGroupBy]]], jsii.get(self, "groupByInput"))

    @builtins.property
    @jsii.member(jsii_name="indexInput")
    def index_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "indexInput"))

    @builtins.property
    @jsii.member(jsii_name="multiComputeInput")
    def multi_compute_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionRequestLogQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionRequestLogQueryMultiCompute]]], jsii.get(self, "multiComputeInput"))

    @builtins.property
    @jsii.member(jsii_name="searchQueryInput")
    def search_query_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "searchQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="index")
    def index(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "index"))

    @index.setter
    def index(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b99bd4a450e91d114e7201f7826064027ed213161cc93b294346cd6621a7467a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "index", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="searchQuery")
    def search_query(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "searchQuery"))

    @search_query.setter
    def search_query(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0ba71bb88a7e35cefde15bb7dd524468968fe221fdec262c55b192d0c1557920)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "searchQuery", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetQueryValueDefinitionRequestLogQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryValueDefinitionRequestLogQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetQueryValueDefinitionRequestLogQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__329e6209c18a2089fcfe9d047f70ef40f035fdc3a709609a1b085ed49f30d764)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetQueryValueDefinitionRequestOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__baf2f70a7753aa3ffa3a9ccb92bc79d1e4115a55d2f32da427aca68a943b7e93)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putApmQuery")
    def put_apm_query(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union[PowerpackWidgetQueryValueDefinitionRequestApmQueryComputeQuery, typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryValueDefinitionRequestApmQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryValueDefinitionRequestApmQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        value = PowerpackWidgetQueryValueDefinitionRequestApmQuery(
            index=index,
            compute_query=compute_query,
            group_by=group_by,
            multi_compute=multi_compute,
            search_query=search_query,
        )

        return typing.cast(None, jsii.invoke(self, "putApmQuery", [value]))

    @jsii.member(jsii_name="putAuditQuery")
    def put_audit_query(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union[PowerpackWidgetQueryValueDefinitionRequestAuditQueryComputeQuery, typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryValueDefinitionRequestAuditQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryValueDefinitionRequestAuditQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        value = PowerpackWidgetQueryValueDefinitionRequestAuditQuery(
            index=index,
            compute_query=compute_query,
            group_by=group_by,
            multi_compute=multi_compute,
            search_query=search_query,
        )

        return typing.cast(None, jsii.invoke(self, "putAuditQuery", [value]))

    @jsii.member(jsii_name="putConditionalFormats")
    def put_conditional_formats(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryValueDefinitionRequestConditionalFormats, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9f157bdc70236b9f5f572be1bc01ca178138ccac0acacef31fe2ecfa68490386)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putConditionalFormats", [value]))

    @jsii.member(jsii_name="putFormula")
    def put_formula(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryValueDefinitionRequestFormula, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7091afd47e05449f0698bec6549cf6f7e896f3591f85342f783c683a6b007523)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putFormula", [value]))

    @jsii.member(jsii_name="putLogQuery")
    def put_log_query(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union[PowerpackWidgetQueryValueDefinitionRequestLogQueryComputeQuery, typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryValueDefinitionRequestLogQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryValueDefinitionRequestLogQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        value = PowerpackWidgetQueryValueDefinitionRequestLogQuery(
            index=index,
            compute_query=compute_query,
            group_by=group_by,
            multi_compute=multi_compute,
            search_query=search_query,
        )

        return typing.cast(None, jsii.invoke(self, "putLogQuery", [value]))

    @jsii.member(jsii_name="putProcessQuery")
    def put_process_query(
        self,
        *,
        metric: builtins.str,
        filter_by: typing.Optional[typing.Sequence[builtins.str]] = None,
        limit: typing.Optional[jsii.Number] = None,
        search_by: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param metric: Your chosen metric. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        :param filter_by: A list of processes. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#filter_by Powerpack#filter_by}
        :param limit: The max number of items in the filter list. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param search_by: Your chosen search term. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_by Powerpack#search_by}
        '''
        value = PowerpackWidgetQueryValueDefinitionRequestProcessQuery(
            metric=metric, filter_by=filter_by, limit=limit, search_by=search_by
        )

        return typing.cast(None, jsii.invoke(self, "putProcessQuery", [value]))

    @jsii.member(jsii_name="putQuery")
    def put_query(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetQueryValueDefinitionRequestQuery", typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__063d0ec151118dacc0d9edfc26d9631c25b6f640cd6118d9f755a73d5cb12ae6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putQuery", [value]))

    @jsii.member(jsii_name="putRumQuery")
    def put_rum_query(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union["PowerpackWidgetQueryValueDefinitionRequestRumQueryComputeQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetQueryValueDefinitionRequestRumQueryGroupBy", typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetQueryValueDefinitionRequestRumQueryMultiCompute", typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        value = PowerpackWidgetQueryValueDefinitionRequestRumQuery(
            index=index,
            compute_query=compute_query,
            group_by=group_by,
            multi_compute=multi_compute,
            search_query=search_query,
        )

        return typing.cast(None, jsii.invoke(self, "putRumQuery", [value]))

    @jsii.member(jsii_name="putSecurityQuery")
    def put_security_query(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union["PowerpackWidgetQueryValueDefinitionRequestSecurityQueryComputeQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetQueryValueDefinitionRequestSecurityQueryGroupBy", typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetQueryValueDefinitionRequestSecurityQueryMultiCompute", typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        value = PowerpackWidgetQueryValueDefinitionRequestSecurityQuery(
            index=index,
            compute_query=compute_query,
            group_by=group_by,
            multi_compute=multi_compute,
            search_query=search_query,
        )

        return typing.cast(None, jsii.invoke(self, "putSecurityQuery", [value]))

    @jsii.member(jsii_name="resetAggregator")
    def reset_aggregator(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAggregator", []))

    @jsii.member(jsii_name="resetApmQuery")
    def reset_apm_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetApmQuery", []))

    @jsii.member(jsii_name="resetAuditQuery")
    def reset_audit_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAuditQuery", []))

    @jsii.member(jsii_name="resetConditionalFormats")
    def reset_conditional_formats(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetConditionalFormats", []))

    @jsii.member(jsii_name="resetFormula")
    def reset_formula(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFormula", []))

    @jsii.member(jsii_name="resetLogQuery")
    def reset_log_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLogQuery", []))

    @jsii.member(jsii_name="resetProcessQuery")
    def reset_process_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetProcessQuery", []))

    @jsii.member(jsii_name="resetQ")
    def reset_q(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetQ", []))

    @jsii.member(jsii_name="resetQuery")
    def reset_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetQuery", []))

    @jsii.member(jsii_name="resetRumQuery")
    def reset_rum_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetRumQuery", []))

    @jsii.member(jsii_name="resetSecurityQuery")
    def reset_security_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSecurityQuery", []))

    @builtins.property
    @jsii.member(jsii_name="apmQuery")
    def apm_query(
        self,
    ) -> PowerpackWidgetQueryValueDefinitionRequestApmQueryOutputReference:
        return typing.cast(PowerpackWidgetQueryValueDefinitionRequestApmQueryOutputReference, jsii.get(self, "apmQuery"))

    @builtins.property
    @jsii.member(jsii_name="auditQuery")
    def audit_query(
        self,
    ) -> PowerpackWidgetQueryValueDefinitionRequestAuditQueryOutputReference:
        return typing.cast(PowerpackWidgetQueryValueDefinitionRequestAuditQueryOutputReference, jsii.get(self, "auditQuery"))

    @builtins.property
    @jsii.member(jsii_name="conditionalFormats")
    def conditional_formats(
        self,
    ) -> PowerpackWidgetQueryValueDefinitionRequestConditionalFormatsList:
        return typing.cast(PowerpackWidgetQueryValueDefinitionRequestConditionalFormatsList, jsii.get(self, "conditionalFormats"))

    @builtins.property
    @jsii.member(jsii_name="formula")
    def formula(self) -> PowerpackWidgetQueryValueDefinitionRequestFormulaList:
        return typing.cast(PowerpackWidgetQueryValueDefinitionRequestFormulaList, jsii.get(self, "formula"))

    @builtins.property
    @jsii.member(jsii_name="logQuery")
    def log_query(
        self,
    ) -> PowerpackWidgetQueryValueDefinitionRequestLogQueryOutputReference:
        return typing.cast(PowerpackWidgetQueryValueDefinitionRequestLogQueryOutputReference, jsii.get(self, "logQuery"))

    @builtins.property
    @jsii.member(jsii_name="processQuery")
    def process_query(
        self,
    ) -> "PowerpackWidgetQueryValueDefinitionRequestProcessQueryOutputReference":
        return typing.cast("PowerpackWidgetQueryValueDefinitionRequestProcessQueryOutputReference", jsii.get(self, "processQuery"))

    @builtins.property
    @jsii.member(jsii_name="query")
    def query(self) -> "PowerpackWidgetQueryValueDefinitionRequestQueryList":
        return typing.cast("PowerpackWidgetQueryValueDefinitionRequestQueryList", jsii.get(self, "query"))

    @builtins.property
    @jsii.member(jsii_name="rumQuery")
    def rum_query(
        self,
    ) -> "PowerpackWidgetQueryValueDefinitionRequestRumQueryOutputReference":
        return typing.cast("PowerpackWidgetQueryValueDefinitionRequestRumQueryOutputReference", jsii.get(self, "rumQuery"))

    @builtins.property
    @jsii.member(jsii_name="securityQuery")
    def security_query(
        self,
    ) -> "PowerpackWidgetQueryValueDefinitionRequestSecurityQueryOutputReference":
        return typing.cast("PowerpackWidgetQueryValueDefinitionRequestSecurityQueryOutputReference", jsii.get(self, "securityQuery"))

    @builtins.property
    @jsii.member(jsii_name="aggregatorInput")
    def aggregator_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregatorInput"))

    @builtins.property
    @jsii.member(jsii_name="apmQueryInput")
    def apm_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetQueryValueDefinitionRequestApmQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryValueDefinitionRequestApmQuery], jsii.get(self, "apmQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="auditQueryInput")
    def audit_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetQueryValueDefinitionRequestAuditQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryValueDefinitionRequestAuditQuery], jsii.get(self, "auditQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="conditionalFormatsInput")
    def conditional_formats_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionRequestConditionalFormats]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionRequestConditionalFormats]]], jsii.get(self, "conditionalFormatsInput"))

    @builtins.property
    @jsii.member(jsii_name="formulaInput")
    def formula_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionRequestFormula]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionRequestFormula]]], jsii.get(self, "formulaInput"))

    @builtins.property
    @jsii.member(jsii_name="logQueryInput")
    def log_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetQueryValueDefinitionRequestLogQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryValueDefinitionRequestLogQuery], jsii.get(self, "logQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="processQueryInput")
    def process_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetQueryValueDefinitionRequestProcessQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetQueryValueDefinitionRequestProcessQuery"], jsii.get(self, "processQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="qInput")
    def q_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "qInput"))

    @builtins.property
    @jsii.member(jsii_name="queryInput")
    def query_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetQueryValueDefinitionRequestQuery"]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetQueryValueDefinitionRequestQuery"]]], jsii.get(self, "queryInput"))

    @builtins.property
    @jsii.member(jsii_name="rumQueryInput")
    def rum_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetQueryValueDefinitionRequestRumQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetQueryValueDefinitionRequestRumQuery"], jsii.get(self, "rumQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="securityQueryInput")
    def security_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetQueryValueDefinitionRequestSecurityQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetQueryValueDefinitionRequestSecurityQuery"], jsii.get(self, "securityQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregator")
    def aggregator(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregator"))

    @aggregator.setter
    def aggregator(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1d3026e14612ae3f1a7fdba9edee3e4c3bc59b00f1eec5530d5bcc739dbac3f4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregator", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="q")
    def q(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "q"))

    @q.setter
    def q(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__251cdd3a1c49a2ffd3c0985dedba7651194a31d0307e7aa2f56d7d64a8cf88b8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "q", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryValueDefinitionRequest]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryValueDefinitionRequest]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryValueDefinitionRequest]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__19a28eeb8c159582159dec3845eb5c99dd9a8790ef78b366a0aad8a3e51bfebe)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestProcessQuery",
    jsii_struct_bases=[],
    name_mapping={
        "metric": "metric",
        "filter_by": "filterBy",
        "limit": "limit",
        "search_by": "searchBy",
    },
)
class PowerpackWidgetQueryValueDefinitionRequestProcessQuery:
    def __init__(
        self,
        *,
        metric: builtins.str,
        filter_by: typing.Optional[typing.Sequence[builtins.str]] = None,
        limit: typing.Optional[jsii.Number] = None,
        search_by: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param metric: Your chosen metric. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        :param filter_by: A list of processes. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#filter_by Powerpack#filter_by}
        :param limit: The max number of items in the filter list. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param search_by: Your chosen search term. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_by Powerpack#search_by}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__da78e5f15b0a9a00f767b554ed565a420edc5f5a730d7f660e9aecac03918be1)
            check_type(argname="argument metric", value=metric, expected_type=type_hints["metric"])
            check_type(argname="argument filter_by", value=filter_by, expected_type=type_hints["filter_by"])
            check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
            check_type(argname="argument search_by", value=search_by, expected_type=type_hints["search_by"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "metric": metric,
        }
        if filter_by is not None:
            self._values["filter_by"] = filter_by
        if limit is not None:
            self._values["limit"] = limit
        if search_by is not None:
            self._values["search_by"] = search_by

    @builtins.property
    def metric(self) -> builtins.str:
        '''Your chosen metric.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        '''
        result = self._values.get("metric")
        assert result is not None, "Required property 'metric' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def filter_by(self) -> typing.Optional[typing.List[builtins.str]]:
        '''A list of processes.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#filter_by Powerpack#filter_by}
        '''
        result = self._values.get("filter_by")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def limit(self) -> typing.Optional[jsii.Number]:
        '''The max number of items in the filter list.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        '''
        result = self._values.get("limit")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def search_by(self) -> typing.Optional[builtins.str]:
        '''Your chosen search term.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_by Powerpack#search_by}
        '''
        result = self._values.get("search_by")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryValueDefinitionRequestProcessQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetQueryValueDefinitionRequestProcessQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestProcessQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__003b968039c9c9fccc29dddbd4095c7e71c599c46163656bc13a25fbe49b1093)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFilterBy")
    def reset_filter_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFilterBy", []))

    @jsii.member(jsii_name="resetLimit")
    def reset_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLimit", []))

    @jsii.member(jsii_name="resetSearchBy")
    def reset_search_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSearchBy", []))

    @builtins.property
    @jsii.member(jsii_name="filterByInput")
    def filter_by_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "filterByInput"))

    @builtins.property
    @jsii.member(jsii_name="limitInput")
    def limit_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "limitInput"))

    @builtins.property
    @jsii.member(jsii_name="metricInput")
    def metric_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "metricInput"))

    @builtins.property
    @jsii.member(jsii_name="searchByInput")
    def search_by_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "searchByInput"))

    @builtins.property
    @jsii.member(jsii_name="filterBy")
    def filter_by(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "filterBy"))

    @filter_by.setter
    def filter_by(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__56ebc3900a1b832e13773e7404120ac5baebbbaf8ff4a14643c4003f53e797c4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "filterBy", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="limit")
    def limit(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "limit"))

    @limit.setter
    def limit(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cda97fe2b44ae4fc097b5fcf75e5ef13ae2ab2c34c51f099f84c65a67df1760c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "limit", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="metric")
    def metric(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "metric"))

    @metric.setter
    def metric(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__03772cc757681e389960493432d2b8875c203e74322ce733abd37c5911e08d1f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "metric", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="searchBy")
    def search_by(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "searchBy"))

    @search_by.setter
    def search_by(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3d8d37a0b53a943e01ca227fc22925bafefd28d28543c499267aafa555e84bda)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "searchBy", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetQueryValueDefinitionRequestProcessQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryValueDefinitionRequestProcessQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetQueryValueDefinitionRequestProcessQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c252ca5e1f1327686f51ebda5e4ae3bbf2ac4ddbbd6ab90053f1fbf83ae76f60)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestQuery",
    jsii_struct_bases=[],
    name_mapping={
        "apm_dependency_stats_query": "apmDependencyStatsQuery",
        "apm_resource_stats_query": "apmResourceStatsQuery",
        "cloud_cost_query": "cloudCostQuery",
        "event_query": "eventQuery",
        "metric_query": "metricQuery",
        "process_query": "processQuery",
        "slo_query": "sloQuery",
    },
)
class PowerpackWidgetQueryValueDefinitionRequestQuery:
    def __init__(
        self,
        *,
        apm_dependency_stats_query: typing.Optional[typing.Union["PowerpackWidgetQueryValueDefinitionRequestQueryApmDependencyStatsQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        apm_resource_stats_query: typing.Optional[typing.Union["PowerpackWidgetQueryValueDefinitionRequestQueryApmResourceStatsQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        cloud_cost_query: typing.Optional[typing.Union["PowerpackWidgetQueryValueDefinitionRequestQueryCloudCostQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        event_query: typing.Optional[typing.Union["PowerpackWidgetQueryValueDefinitionRequestQueryEventQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        metric_query: typing.Optional[typing.Union["PowerpackWidgetQueryValueDefinitionRequestQueryMetricQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        process_query: typing.Optional[typing.Union["PowerpackWidgetQueryValueDefinitionRequestQueryProcessQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        slo_query: typing.Optional[typing.Union["PowerpackWidgetQueryValueDefinitionRequestQuerySloQuery", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param apm_dependency_stats_query: apm_dependency_stats_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#apm_dependency_stats_query Powerpack#apm_dependency_stats_query}
        :param apm_resource_stats_query: apm_resource_stats_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#apm_resource_stats_query Powerpack#apm_resource_stats_query}
        :param cloud_cost_query: cloud_cost_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cloud_cost_query Powerpack#cloud_cost_query}
        :param event_query: event_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#event_query Powerpack#event_query}
        :param metric_query: metric_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric_query Powerpack#metric_query}
        :param process_query: process_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#process_query Powerpack#process_query}
        :param slo_query: slo_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#slo_query Powerpack#slo_query}
        '''
        if isinstance(apm_dependency_stats_query, dict):
            apm_dependency_stats_query = PowerpackWidgetQueryValueDefinitionRequestQueryApmDependencyStatsQuery(**apm_dependency_stats_query)
        if isinstance(apm_resource_stats_query, dict):
            apm_resource_stats_query = PowerpackWidgetQueryValueDefinitionRequestQueryApmResourceStatsQuery(**apm_resource_stats_query)
        if isinstance(cloud_cost_query, dict):
            cloud_cost_query = PowerpackWidgetQueryValueDefinitionRequestQueryCloudCostQuery(**cloud_cost_query)
        if isinstance(event_query, dict):
            event_query = PowerpackWidgetQueryValueDefinitionRequestQueryEventQuery(**event_query)
        if isinstance(metric_query, dict):
            metric_query = PowerpackWidgetQueryValueDefinitionRequestQueryMetricQuery(**metric_query)
        if isinstance(process_query, dict):
            process_query = PowerpackWidgetQueryValueDefinitionRequestQueryProcessQuery(**process_query)
        if isinstance(slo_query, dict):
            slo_query = PowerpackWidgetQueryValueDefinitionRequestQuerySloQuery(**slo_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__250f35a40f348f03c42936227025012e29664e3bd5c334ad56030f751d8d46c4)
            check_type(argname="argument apm_dependency_stats_query", value=apm_dependency_stats_query, expected_type=type_hints["apm_dependency_stats_query"])
            check_type(argname="argument apm_resource_stats_query", value=apm_resource_stats_query, expected_type=type_hints["apm_resource_stats_query"])
            check_type(argname="argument cloud_cost_query", value=cloud_cost_query, expected_type=type_hints["cloud_cost_query"])
            check_type(argname="argument event_query", value=event_query, expected_type=type_hints["event_query"])
            check_type(argname="argument metric_query", value=metric_query, expected_type=type_hints["metric_query"])
            check_type(argname="argument process_query", value=process_query, expected_type=type_hints["process_query"])
            check_type(argname="argument slo_query", value=slo_query, expected_type=type_hints["slo_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if apm_dependency_stats_query is not None:
            self._values["apm_dependency_stats_query"] = apm_dependency_stats_query
        if apm_resource_stats_query is not None:
            self._values["apm_resource_stats_query"] = apm_resource_stats_query
        if cloud_cost_query is not None:
            self._values["cloud_cost_query"] = cloud_cost_query
        if event_query is not None:
            self._values["event_query"] = event_query
        if metric_query is not None:
            self._values["metric_query"] = metric_query
        if process_query is not None:
            self._values["process_query"] = process_query
        if slo_query is not None:
            self._values["slo_query"] = slo_query

    @builtins.property
    def apm_dependency_stats_query(
        self,
    ) -> typing.Optional["PowerpackWidgetQueryValueDefinitionRequestQueryApmDependencyStatsQuery"]:
        '''apm_dependency_stats_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#apm_dependency_stats_query Powerpack#apm_dependency_stats_query}
        '''
        result = self._values.get("apm_dependency_stats_query")
        return typing.cast(typing.Optional["PowerpackWidgetQueryValueDefinitionRequestQueryApmDependencyStatsQuery"], result)

    @builtins.property
    def apm_resource_stats_query(
        self,
    ) -> typing.Optional["PowerpackWidgetQueryValueDefinitionRequestQueryApmResourceStatsQuery"]:
        '''apm_resource_stats_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#apm_resource_stats_query Powerpack#apm_resource_stats_query}
        '''
        result = self._values.get("apm_resource_stats_query")
        return typing.cast(typing.Optional["PowerpackWidgetQueryValueDefinitionRequestQueryApmResourceStatsQuery"], result)

    @builtins.property
    def cloud_cost_query(
        self,
    ) -> typing.Optional["PowerpackWidgetQueryValueDefinitionRequestQueryCloudCostQuery"]:
        '''cloud_cost_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cloud_cost_query Powerpack#cloud_cost_query}
        '''
        result = self._values.get("cloud_cost_query")
        return typing.cast(typing.Optional["PowerpackWidgetQueryValueDefinitionRequestQueryCloudCostQuery"], result)

    @builtins.property
    def event_query(
        self,
    ) -> typing.Optional["PowerpackWidgetQueryValueDefinitionRequestQueryEventQuery"]:
        '''event_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#event_query Powerpack#event_query}
        '''
        result = self._values.get("event_query")
        return typing.cast(typing.Optional["PowerpackWidgetQueryValueDefinitionRequestQueryEventQuery"], result)

    @builtins.property
    def metric_query(
        self,
    ) -> typing.Optional["PowerpackWidgetQueryValueDefinitionRequestQueryMetricQuery"]:
        '''metric_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric_query Powerpack#metric_query}
        '''
        result = self._values.get("metric_query")
        return typing.cast(typing.Optional["PowerpackWidgetQueryValueDefinitionRequestQueryMetricQuery"], result)

    @builtins.property
    def process_query(
        self,
    ) -> typing.Optional["PowerpackWidgetQueryValueDefinitionRequestQueryProcessQuery"]:
        '''process_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#process_query Powerpack#process_query}
        '''
        result = self._values.get("process_query")
        return typing.cast(typing.Optional["PowerpackWidgetQueryValueDefinitionRequestQueryProcessQuery"], result)

    @builtins.property
    def slo_query(
        self,
    ) -> typing.Optional["PowerpackWidgetQueryValueDefinitionRequestQuerySloQuery"]:
        '''slo_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#slo_query Powerpack#slo_query}
        '''
        result = self._values.get("slo_query")
        return typing.cast(typing.Optional["PowerpackWidgetQueryValueDefinitionRequestQuerySloQuery"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryValueDefinitionRequestQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestQueryApmDependencyStatsQuery",
    jsii_struct_bases=[],
    name_mapping={
        "data_source": "dataSource",
        "env": "env",
        "name": "name",
        "operation_name": "operationName",
        "resource_name": "resourceName",
        "service": "service",
        "stat": "stat",
        "cross_org_uuids": "crossOrgUuids",
        "is_upstream": "isUpstream",
        "primary_tag_name": "primaryTagName",
        "primary_tag_value": "primaryTagValue",
    },
)
class PowerpackWidgetQueryValueDefinitionRequestQueryApmDependencyStatsQuery:
    def __init__(
        self,
        *,
        data_source: builtins.str,
        env: builtins.str,
        name: builtins.str,
        operation_name: builtins.str,
        resource_name: builtins.str,
        service: builtins.str,
        stat: builtins.str,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        is_upstream: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        primary_tag_name: typing.Optional[builtins.str] = None,
        primary_tag_value: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param data_source: The data source for APM Dependency Stats queries. Valid values are ``apm_dependency_stats``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param env: APM environment. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#env Powerpack#env}
        :param name: The name of query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param operation_name: Name of operation on service. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#operation_name Powerpack#operation_name}
        :param resource_name: APM resource. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#resource_name Powerpack#resource_name}
        :param service: APM service. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#service Powerpack#service}
        :param stat: APM statistic. Valid values are ``avg_duration``, ``avg_root_duration``, ``avg_spans_per_trace``, ``error_rate``, ``pct_exec_time``, ``pct_of_traces``, ``total_traces_count``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#stat Powerpack#stat}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param is_upstream: Determines whether stats for upstream or downstream dependencies should be queried. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#is_upstream Powerpack#is_upstream}
        :param primary_tag_name: The name of the second primary tag used within APM; required when ``primary_tag_value`` is specified. See https://docs.datadoghq.com/tracing/guide/setting_primary_tags_to_scope/#add-a-second-primary-tag-in-datadog. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_name Powerpack#primary_tag_name}
        :param primary_tag_value: Filter APM data by the second primary tag. ``primary_tag_name`` must also be specified. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_value Powerpack#primary_tag_value}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9bd0517699144f92edbb9ecdbe13e18f3a3deb7ba455d259cc782dd9f37133b7)
            check_type(argname="argument data_source", value=data_source, expected_type=type_hints["data_source"])
            check_type(argname="argument env", value=env, expected_type=type_hints["env"])
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument operation_name", value=operation_name, expected_type=type_hints["operation_name"])
            check_type(argname="argument resource_name", value=resource_name, expected_type=type_hints["resource_name"])
            check_type(argname="argument service", value=service, expected_type=type_hints["service"])
            check_type(argname="argument stat", value=stat, expected_type=type_hints["stat"])
            check_type(argname="argument cross_org_uuids", value=cross_org_uuids, expected_type=type_hints["cross_org_uuids"])
            check_type(argname="argument is_upstream", value=is_upstream, expected_type=type_hints["is_upstream"])
            check_type(argname="argument primary_tag_name", value=primary_tag_name, expected_type=type_hints["primary_tag_name"])
            check_type(argname="argument primary_tag_value", value=primary_tag_value, expected_type=type_hints["primary_tag_value"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "data_source": data_source,
            "env": env,
            "name": name,
            "operation_name": operation_name,
            "resource_name": resource_name,
            "service": service,
            "stat": stat,
        }
        if cross_org_uuids is not None:
            self._values["cross_org_uuids"] = cross_org_uuids
        if is_upstream is not None:
            self._values["is_upstream"] = is_upstream
        if primary_tag_name is not None:
            self._values["primary_tag_name"] = primary_tag_name
        if primary_tag_value is not None:
            self._values["primary_tag_value"] = primary_tag_value

    @builtins.property
    def data_source(self) -> builtins.str:
        '''The data source for APM Dependency Stats queries. Valid values are ``apm_dependency_stats``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        '''
        result = self._values.get("data_source")
        assert result is not None, "Required property 'data_source' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def env(self) -> builtins.str:
        '''APM environment.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#env Powerpack#env}
        '''
        result = self._values.get("env")
        assert result is not None, "Required property 'env' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def name(self) -> builtins.str:
        '''The name of query for use in formulas.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        '''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def operation_name(self) -> builtins.str:
        '''Name of operation on service.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#operation_name Powerpack#operation_name}
        '''
        result = self._values.get("operation_name")
        assert result is not None, "Required property 'operation_name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def resource_name(self) -> builtins.str:
        '''APM resource.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#resource_name Powerpack#resource_name}
        '''
        result = self._values.get("resource_name")
        assert result is not None, "Required property 'resource_name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def service(self) -> builtins.str:
        '''APM service.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#service Powerpack#service}
        '''
        result = self._values.get("service")
        assert result is not None, "Required property 'service' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def stat(self) -> builtins.str:
        '''APM statistic. Valid values are ``avg_duration``, ``avg_root_duration``, ``avg_spans_per_trace``, ``error_rate``, ``pct_exec_time``, ``pct_of_traces``, ``total_traces_count``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#stat Powerpack#stat}
        '''
        result = self._values.get("stat")
        assert result is not None, "Required property 'stat' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def cross_org_uuids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''The source organization UUID for cross organization queries. Feature in Private Beta.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        '''
        result = self._values.get("cross_org_uuids")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def is_upstream(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        '''Determines whether stats for upstream or downstream dependencies should be queried.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#is_upstream Powerpack#is_upstream}
        '''
        result = self._values.get("is_upstream")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)

    @builtins.property
    def primary_tag_name(self) -> typing.Optional[builtins.str]:
        '''The name of the second primary tag used within APM; required when ``primary_tag_value`` is specified. See https://docs.datadoghq.com/tracing/guide/setting_primary_tags_to_scope/#add-a-second-primary-tag-in-datadog.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_name Powerpack#primary_tag_name}
        '''
        result = self._values.get("primary_tag_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def primary_tag_value(self) -> typing.Optional[builtins.str]:
        '''Filter APM data by the second primary tag. ``primary_tag_name`` must also be specified.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_value Powerpack#primary_tag_value}
        '''
        result = self._values.get("primary_tag_value")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryValueDefinitionRequestQueryApmDependencyStatsQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetQueryValueDefinitionRequestQueryApmDependencyStatsQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestQueryApmDependencyStatsQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8c2663255d9437b58af786ffb55c295ff7de21e32bbb6dc76ebcafa28a1fc0a3)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetCrossOrgUuids")
    def reset_cross_org_uuids(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCrossOrgUuids", []))

    @jsii.member(jsii_name="resetIsUpstream")
    def reset_is_upstream(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetIsUpstream", []))

    @jsii.member(jsii_name="resetPrimaryTagName")
    def reset_primary_tag_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPrimaryTagName", []))

    @jsii.member(jsii_name="resetPrimaryTagValue")
    def reset_primary_tag_value(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPrimaryTagValue", []))

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuidsInput")
    def cross_org_uuids_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "crossOrgUuidsInput"))

    @builtins.property
    @jsii.member(jsii_name="dataSourceInput")
    def data_source_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "dataSourceInput"))

    @builtins.property
    @jsii.member(jsii_name="envInput")
    def env_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "envInput"))

    @builtins.property
    @jsii.member(jsii_name="isUpstreamInput")
    def is_upstream_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "isUpstreamInput"))

    @builtins.property
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property
    @jsii.member(jsii_name="operationNameInput")
    def operation_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "operationNameInput"))

    @builtins.property
    @jsii.member(jsii_name="primaryTagNameInput")
    def primary_tag_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "primaryTagNameInput"))

    @builtins.property
    @jsii.member(jsii_name="primaryTagValueInput")
    def primary_tag_value_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "primaryTagValueInput"))

    @builtins.property
    @jsii.member(jsii_name="resourceNameInput")
    def resource_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "resourceNameInput"))

    @builtins.property
    @jsii.member(jsii_name="serviceInput")
    def service_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "serviceInput"))

    @builtins.property
    @jsii.member(jsii_name="statInput")
    def stat_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "statInput"))

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuids")
    def cross_org_uuids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "crossOrgUuids"))

    @cross_org_uuids.setter
    def cross_org_uuids(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2fd02f8b494f9f1474173afc3303789913d02507df75b7ffe622dc5439acdf44)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "crossOrgUuids", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="dataSource")
    def data_source(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "dataSource"))

    @data_source.setter
    def data_source(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e057b6344e1d643b5af4945b845683e2cddac1610b5626523ca35f1ffc37b1f1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "dataSource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="env")
    def env(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "env"))

    @env.setter
    def env(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a9157f5616c07b0b9984ec374e967d763a2c4c02e651bea236da26814c1404ca)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "env", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="isUpstream")
    def is_upstream(self) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "isUpstream"))

    @is_upstream.setter
    def is_upstream(
        self,
        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__22f79736bf602137f769c92cb0a6c4e26168dc6223a35efa371ddb86a85b5829)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "isUpstream", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__87cd96f9da9a6f491d377befbf3144fb6989f2be59357e1ea4e4ad7cb48eb7fd)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "name", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="operationName")
    def operation_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "operationName"))

    @operation_name.setter
    def operation_name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__059b05d0bbe320f75038316d07162741492fc3a3ed2e6a03ac108a6ff1f06d0f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "operationName", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="primaryTagName")
    def primary_tag_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "primaryTagName"))

    @primary_tag_name.setter
    def primary_tag_name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__82ee39d01c73d2ebcdc1061a2b4d3419eecc18aa55b178e5ae6a8d71ba4eac48)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "primaryTagName", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="primaryTagValue")
    def primary_tag_value(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "primaryTagValue"))

    @primary_tag_value.setter
    def primary_tag_value(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__de4bb62f637216f20bec1944194070806c42f9f18c396c17b49a33c2b9e66aa0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "primaryTagValue", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="resourceName")
    def resource_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "resourceName"))

    @resource_name.setter
    def resource_name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d4f8f11e29b6e2bc969df84955280f294905de563d5f7d40a4f12b1d1e6f6370)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "resourceName", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="service")
    def service(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "service"))

    @service.setter
    def service(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__321ce53a3b1be89b458fb378979d00a032dbb9f4bcda6f3d6b5e64b8a5656e1f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "service", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="stat")
    def stat(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "stat"))

    @stat.setter
    def stat(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c0ab40cb3b007efac2e37b5674684af19ff2b4b073976c8502a94980138e2b37)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "stat", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetQueryValueDefinitionRequestQueryApmDependencyStatsQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryValueDefinitionRequestQueryApmDependencyStatsQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetQueryValueDefinitionRequestQueryApmDependencyStatsQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b027b88294ce59ed53334e2d6be99a6df9fdc8cf2b093cf043f1763bbf18595b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestQueryApmResourceStatsQuery",
    jsii_struct_bases=[],
    name_mapping={
        "data_source": "dataSource",
        "env": "env",
        "name": "name",
        "service": "service",
        "stat": "stat",
        "cross_org_uuids": "crossOrgUuids",
        "group_by": "groupBy",
        "operation_name": "operationName",
        "primary_tag_name": "primaryTagName",
        "primary_tag_value": "primaryTagValue",
        "resource_name": "resourceName",
    },
)
class PowerpackWidgetQueryValueDefinitionRequestQueryApmResourceStatsQuery:
    def __init__(
        self,
        *,
        data_source: builtins.str,
        env: builtins.str,
        name: builtins.str,
        service: builtins.str,
        stat: builtins.str,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        group_by: typing.Optional[typing.Sequence[builtins.str]] = None,
        operation_name: typing.Optional[builtins.str] = None,
        primary_tag_name: typing.Optional[builtins.str] = None,
        primary_tag_value: typing.Optional[builtins.str] = None,
        resource_name: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param data_source: The data source for APM Resource Stats queries. Valid values are ``apm_resource_stats``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param env: APM environment. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#env Powerpack#env}
        :param name: The name of query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param service: APM service. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#service Powerpack#service}
        :param stat: APM statistic. Valid values are ``errors``, ``error_rate``, ``hits``, ``latency_avg``, ``latency_distribution``, ``latency_max``, ``latency_p50``, ``latency_p75``, ``latency_p90``, ``latency_p95``, ``latency_p99``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#stat Powerpack#stat}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param group_by: Array of fields to group results by. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param operation_name: Name of operation on service. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#operation_name Powerpack#operation_name}
        :param primary_tag_name: The name of the second primary tag used within APM; required when ``primary_tag_value`` is specified. See https://docs.datadoghq.com/tracing/guide/setting_primary_tags_to_scope/#add-a-second-primary-tag-in-datadog. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_name Powerpack#primary_tag_name}
        :param primary_tag_value: Filter APM data by the second primary tag. ``primary_tag_name`` must also be specified. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_value Powerpack#primary_tag_value}
        :param resource_name: APM resource. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#resource_name Powerpack#resource_name}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3d29fe224d3adb955d571654dadeb54bd4f22bfd5c105982accb8a491406be8a)
            check_type(argname="argument data_source", value=data_source, expected_type=type_hints["data_source"])
            check_type(argname="argument env", value=env, expected_type=type_hints["env"])
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument service", value=service, expected_type=type_hints["service"])
            check_type(argname="argument stat", value=stat, expected_type=type_hints["stat"])
            check_type(argname="argument cross_org_uuids", value=cross_org_uuids, expected_type=type_hints["cross_org_uuids"])
            check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
            check_type(argname="argument operation_name", value=operation_name, expected_type=type_hints["operation_name"])
            check_type(argname="argument primary_tag_name", value=primary_tag_name, expected_type=type_hints["primary_tag_name"])
            check_type(argname="argument primary_tag_value", value=primary_tag_value, expected_type=type_hints["primary_tag_value"])
            check_type(argname="argument resource_name", value=resource_name, expected_type=type_hints["resource_name"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "data_source": data_source,
            "env": env,
            "name": name,
            "service": service,
            "stat": stat,
        }
        if cross_org_uuids is not None:
            self._values["cross_org_uuids"] = cross_org_uuids
        if group_by is not None:
            self._values["group_by"] = group_by
        if operation_name is not None:
            self._values["operation_name"] = operation_name
        if primary_tag_name is not None:
            self._values["primary_tag_name"] = primary_tag_name
        if primary_tag_value is not None:
            self._values["primary_tag_value"] = primary_tag_value
        if resource_name is not None:
            self._values["resource_name"] = resource_name

    @builtins.property
    def data_source(self) -> builtins.str:
        '''The data source for APM Resource Stats queries. Valid values are ``apm_resource_stats``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        '''
        result = self._values.get("data_source")
        assert result is not None, "Required property 'data_source' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def env(self) -> builtins.str:
        '''APM environment.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#env Powerpack#env}
        '''
        result = self._values.get("env")
        assert result is not None, "Required property 'env' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def name(self) -> builtins.str:
        '''The name of query for use in formulas.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        '''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def service(self) -> builtins.str:
        '''APM service.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#service Powerpack#service}
        '''
        result = self._values.get("service")
        assert result is not None, "Required property 'service' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def stat(self) -> builtins.str:
        '''APM statistic. Valid values are ``errors``, ``error_rate``, ``hits``, ``latency_avg``, ``latency_distribution``, ``latency_max``, ``latency_p50``, ``latency_p75``, ``latency_p90``, ``latency_p95``, ``latency_p99``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#stat Powerpack#stat}
        '''
        result = self._values.get("stat")
        assert result is not None, "Required property 'stat' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def cross_org_uuids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''The source organization UUID for cross organization queries. Feature in Private Beta.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        '''
        result = self._values.get("cross_org_uuids")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def group_by(self) -> typing.Optional[typing.List[builtins.str]]:
        '''Array of fields to group results by.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        '''
        result = self._values.get("group_by")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def operation_name(self) -> typing.Optional[builtins.str]:
        '''Name of operation on service.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#operation_name Powerpack#operation_name}
        '''
        result = self._values.get("operation_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def primary_tag_name(self) -> typing.Optional[builtins.str]:
        '''The name of the second primary tag used within APM; required when ``primary_tag_value`` is specified. See https://docs.datadoghq.com/tracing/guide/setting_primary_tags_to_scope/#add-a-second-primary-tag-in-datadog.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_name Powerpack#primary_tag_name}
        '''
        result = self._values.get("primary_tag_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def primary_tag_value(self) -> typing.Optional[builtins.str]:
        '''Filter APM data by the second primary tag. ``primary_tag_name`` must also be specified.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_value Powerpack#primary_tag_value}
        '''
        result = self._values.get("primary_tag_value")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def resource_name(self) -> typing.Optional[builtins.str]:
        '''APM resource.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#resource_name Powerpack#resource_name}
        '''
        result = self._values.get("resource_name")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryValueDefinitionRequestQueryApmResourceStatsQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetQueryValueDefinitionRequestQueryApmResourceStatsQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestQueryApmResourceStatsQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e1ffe0d36398af52d2500864571b1746a91e3d9a92756b4d2ce98984124ef206)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetCrossOrgUuids")
    def reset_cross_org_uuids(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCrossOrgUuids", []))

    @jsii.member(jsii_name="resetGroupBy")
    def reset_group_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGroupBy", []))

    @jsii.member(jsii_name="resetOperationName")
    def reset_operation_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetOperationName", []))

    @jsii.member(jsii_name="resetPrimaryTagName")
    def reset_primary_tag_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPrimaryTagName", []))

    @jsii.member(jsii_name="resetPrimaryTagValue")
    def reset_primary_tag_value(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPrimaryTagValue", []))

    @jsii.member(jsii_name="resetResourceName")
    def reset_resource_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetResourceName", []))

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuidsInput")
    def cross_org_uuids_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "crossOrgUuidsInput"))

    @builtins.property
    @jsii.member(jsii_name="dataSourceInput")
    def data_source_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "dataSourceInput"))

    @builtins.property
    @jsii.member(jsii_name="envInput")
    def env_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "envInput"))

    @builtins.property
    @jsii.member(jsii_name="groupByInput")
    def group_by_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "groupByInput"))

    @builtins.property
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property
    @jsii.member(jsii_name="operationNameInput")
    def operation_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "operationNameInput"))

    @builtins.property
    @jsii.member(jsii_name="primaryTagNameInput")
    def primary_tag_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "primaryTagNameInput"))

    @builtins.property
    @jsii.member(jsii_name="primaryTagValueInput")
    def primary_tag_value_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "primaryTagValueInput"))

    @builtins.property
    @jsii.member(jsii_name="resourceNameInput")
    def resource_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "resourceNameInput"))

    @builtins.property
    @jsii.member(jsii_name="serviceInput")
    def service_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "serviceInput"))

    @builtins.property
    @jsii.member(jsii_name="statInput")
    def stat_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "statInput"))

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuids")
    def cross_org_uuids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "crossOrgUuids"))

    @cross_org_uuids.setter
    def cross_org_uuids(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a4369fc5fcd1593e41a59d9a879cc0a4b920d441aad9ec452bf0cd12108649aa)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "crossOrgUuids", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="dataSource")
    def data_source(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "dataSource"))

    @data_source.setter
    def data_source(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__070997f57b4296919237845d3c0283eb528f0da5afdc9c5e474b132520970c7b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "dataSource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="env")
    def env(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "env"))

    @env.setter
    def env(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8a8244c2f3669e5f8546de1cc3b0a5c930b34390e97797cbf16ba64243fab625)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "env", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="groupBy")
    def group_by(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "groupBy"))

    @group_by.setter
    def group_by(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5d11c492320b1edab1ae365df54c6a157aa39612e6112ee8f4829e7b6376493b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "groupBy", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bf0e2c20951462a185985c723bb68c9bc1161ecd0add436bb48afa7182a9b854)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "name", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="operationName")
    def operation_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "operationName"))

    @operation_name.setter
    def operation_name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__077c1f15374dc4f8e10a9670b4432131354091b4a481c1d3554f2dafd3a530a0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "operationName", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="primaryTagName")
    def primary_tag_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "primaryTagName"))

    @primary_tag_name.setter
    def primary_tag_name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9342bed67c3d93f18c6664ae7d60b286ba3f9ab59be8604a97aed15d2f1325d4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "primaryTagName", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="primaryTagValue")
    def primary_tag_value(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "primaryTagValue"))

    @primary_tag_value.setter
    def primary_tag_value(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c04e037fd9c74ec71c136cc621ff29e08bea96c409e8b4ece0a3b9d963780287)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "primaryTagValue", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="resourceName")
    def resource_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "resourceName"))

    @resource_name.setter
    def resource_name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6f2149f48e349b478d6a46fe27eefaa91f48829b2f614973ad8fdab14f1b685f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "resourceName", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="service")
    def service(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "service"))

    @service.setter
    def service(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4c01814ff896733fc59afae92eb460f1ac00d8b5756e65e0b3aaab79af0eec8c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "service", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="stat")
    def stat(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "stat"))

    @stat.setter
    def stat(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__061bacdc3592f2e26cd0bea0017eec9c740cabfa2649c3860e203877151135ff)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "stat", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetQueryValueDefinitionRequestQueryApmResourceStatsQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryValueDefinitionRequestQueryApmResourceStatsQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetQueryValueDefinitionRequestQueryApmResourceStatsQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__359861c816bf6890c846260aa6d2cd5f761ff1572b9cbd902521eeeedfebb90f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestQueryCloudCostQuery",
    jsii_struct_bases=[],
    name_mapping={
        "data_source": "dataSource",
        "name": "name",
        "query": "query",
        "aggregator": "aggregator",
        "cross_org_uuids": "crossOrgUuids",
    },
)
class PowerpackWidgetQueryValueDefinitionRequestQueryCloudCostQuery:
    def __init__(
        self,
        *,
        data_source: builtins.str,
        name: builtins.str,
        query: builtins.str,
        aggregator: typing.Optional[builtins.str] = None,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
    ) -> None:
        '''
        :param data_source: The data source for cloud cost queries. Valid values are ``cloud_cost``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param name: The name of the query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param query: The cloud cost query definition. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        :param aggregator: The aggregation methods available for cloud cost queries. Valid values are ``avg``, ``last``, ``max``, ``min``, ``sum``, ``percentile``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregator Powerpack#aggregator}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__eaea6e22e1858616523822d874f21483870815d9bc44db5e56ef7ba05f3998f2)
            check_type(argname="argument data_source", value=data_source, expected_type=type_hints["data_source"])
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument query", value=query, expected_type=type_hints["query"])
            check_type(argname="argument aggregator", value=aggregator, expected_type=type_hints["aggregator"])
            check_type(argname="argument cross_org_uuids", value=cross_org_uuids, expected_type=type_hints["cross_org_uuids"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "data_source": data_source,
            "name": name,
            "query": query,
        }
        if aggregator is not None:
            self._values["aggregator"] = aggregator
        if cross_org_uuids is not None:
            self._values["cross_org_uuids"] = cross_org_uuids

    @builtins.property
    def data_source(self) -> builtins.str:
        '''The data source for cloud cost queries. Valid values are ``cloud_cost``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        '''
        result = self._values.get("data_source")
        assert result is not None, "Required property 'data_source' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def name(self) -> builtins.str:
        '''The name of the query for use in formulas.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        '''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def query(self) -> builtins.str:
        '''The cloud cost query definition.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        '''
        result = self._values.get("query")
        assert result is not None, "Required property 'query' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def aggregator(self) -> typing.Optional[builtins.str]:
        '''The aggregation methods available for cloud cost queries. Valid values are ``avg``, ``last``, ``max``, ``min``, ``sum``, ``percentile``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregator Powerpack#aggregator}
        '''
        result = self._values.get("aggregator")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def cross_org_uuids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''The source organization UUID for cross organization queries. Feature in Private Beta.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        '''
        result = self._values.get("cross_org_uuids")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryValueDefinitionRequestQueryCloudCostQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetQueryValueDefinitionRequestQueryCloudCostQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestQueryCloudCostQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c09368a02827f8304f4458d6b475fdd669fac73ce20b20305ef5a28b96847557)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetAggregator")
    def reset_aggregator(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAggregator", []))

    @jsii.member(jsii_name="resetCrossOrgUuids")
    def reset_cross_org_uuids(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCrossOrgUuids", []))

    @builtins.property
    @jsii.member(jsii_name="aggregatorInput")
    def aggregator_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregatorInput"))

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuidsInput")
    def cross_org_uuids_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "crossOrgUuidsInput"))

    @builtins.property
    @jsii.member(jsii_name="dataSourceInput")
    def data_source_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "dataSourceInput"))

    @builtins.property
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property
    @jsii.member(jsii_name="queryInput")
    def query_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "queryInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregator")
    def aggregator(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregator"))

    @aggregator.setter
    def aggregator(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__35190afc09abfdb5a63f82bf510b68df1353baf5861cdc628ae3d51d13319d1d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregator", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuids")
    def cross_org_uuids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "crossOrgUuids"))

    @cross_org_uuids.setter
    def cross_org_uuids(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3b57d03537f1a6fb7f717173e165b11ef8ee91701074b2f31afb2fb435176952)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "crossOrgUuids", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="dataSource")
    def data_source(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "dataSource"))

    @data_source.setter
    def data_source(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1acab92244954bf354798abf6e9772e463a660e2bd44bebfbb122cfaa0f9b545)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "dataSource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5f8b41e28ebe5314437bc8a540a6ae8bdcdae54239af4863a16c6738cff93029)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "name", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="query")
    def query(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "query"))

    @query.setter
    def query(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__23cb7408cfa360d4aa16d1b7968fa21320d039723cd5c9bc4ffb2f1940001818)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "query", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetQueryValueDefinitionRequestQueryCloudCostQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryValueDefinitionRequestQueryCloudCostQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetQueryValueDefinitionRequestQueryCloudCostQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__26dedfb249892fdbe3ff6d9008e61c9d06fb0a561aca6f5980609283310bcdbc)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestQueryEventQuery",
    jsii_struct_bases=[],
    name_mapping={
        "compute": "compute",
        "data_source": "dataSource",
        "name": "name",
        "cross_org_uuids": "crossOrgUuids",
        "group_by": "groupBy",
        "indexes": "indexes",
        "search": "search",
        "storage": "storage",
    },
)
class PowerpackWidgetQueryValueDefinitionRequestQueryEventQuery:
    def __init__(
        self,
        *,
        compute: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetQueryValueDefinitionRequestQueryEventQueryCompute", typing.Dict[builtins.str, typing.Any]]]],
        data_source: builtins.str,
        name: builtins.str,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetQueryValueDefinitionRequestQueryEventQueryGroupBy", typing.Dict[builtins.str, typing.Any]]]]] = None,
        indexes: typing.Optional[typing.Sequence[builtins.str]] = None,
        search: typing.Optional[typing.Union["PowerpackWidgetQueryValueDefinitionRequestQueryEventQuerySearch", typing.Dict[builtins.str, typing.Any]]] = None,
        storage: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param compute: compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute Powerpack#compute}
        :param data_source: The data source for event platform-based queries. Valid values are ``logs``, ``spans``, ``network``, ``rum``, ``security_signals``, ``profiles``, ``audit``, ``events``, ``ci_tests``, ``ci_pipelines``, ``incident_analytics``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param name: The name of query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param indexes: An array of index names to query in the stream. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#indexes Powerpack#indexes}
        :param search: search block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search Powerpack#search}
        :param storage: Storage location (private beta). Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#storage Powerpack#storage}
        '''
        if isinstance(search, dict):
            search = PowerpackWidgetQueryValueDefinitionRequestQueryEventQuerySearch(**search)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8797ea815a7555e5aa07dd86707224e68fbebadb1e7f2cc36ce6d3cda843bfaf)
            check_type(argname="argument compute", value=compute, expected_type=type_hints["compute"])
            check_type(argname="argument data_source", value=data_source, expected_type=type_hints["data_source"])
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument cross_org_uuids", value=cross_org_uuids, expected_type=type_hints["cross_org_uuids"])
            check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
            check_type(argname="argument indexes", value=indexes, expected_type=type_hints["indexes"])
            check_type(argname="argument search", value=search, expected_type=type_hints["search"])
            check_type(argname="argument storage", value=storage, expected_type=type_hints["storage"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "compute": compute,
            "data_source": data_source,
            "name": name,
        }
        if cross_org_uuids is not None:
            self._values["cross_org_uuids"] = cross_org_uuids
        if group_by is not None:
            self._values["group_by"] = group_by
        if indexes is not None:
            self._values["indexes"] = indexes
        if search is not None:
            self._values["search"] = search
        if storage is not None:
            self._values["storage"] = storage

    @builtins.property
    def compute(
        self,
    ) -> typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetQueryValueDefinitionRequestQueryEventQueryCompute"]]:
        '''compute block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute Powerpack#compute}
        '''
        result = self._values.get("compute")
        assert result is not None, "Required property 'compute' is missing"
        return typing.cast(typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetQueryValueDefinitionRequestQueryEventQueryCompute"]], result)

    @builtins.property
    def data_source(self) -> builtins.str:
        '''The data source for event platform-based queries.

        Valid values are ``logs``, ``spans``, ``network``, ``rum``, ``security_signals``, ``profiles``, ``audit``, ``events``, ``ci_tests``, ``ci_pipelines``, ``incident_analytics``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        '''
        result = self._values.get("data_source")
        assert result is not None, "Required property 'data_source' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def name(self) -> builtins.str:
        '''The name of query for use in formulas.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        '''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def cross_org_uuids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''The source organization UUID for cross organization queries. Feature in Private Beta.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        '''
        result = self._values.get("cross_org_uuids")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def group_by(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetQueryValueDefinitionRequestQueryEventQueryGroupBy"]]]:
        '''group_by block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        '''
        result = self._values.get("group_by")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetQueryValueDefinitionRequestQueryEventQueryGroupBy"]]], result)

    @builtins.property
    def indexes(self) -> typing.Optional[typing.List[builtins.str]]:
        '''An array of index names to query in the stream.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#indexes Powerpack#indexes}
        '''
        result = self._values.get("indexes")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def search(
        self,
    ) -> typing.Optional["PowerpackWidgetQueryValueDefinitionRequestQueryEventQuerySearch"]:
        '''search block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search Powerpack#search}
        '''
        result = self._values.get("search")
        return typing.cast(typing.Optional["PowerpackWidgetQueryValueDefinitionRequestQueryEventQuerySearch"], result)

    @builtins.property
    def storage(self) -> typing.Optional[builtins.str]:
        '''Storage location (private beta).

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#storage Powerpack#storage}
        '''
        result = self._values.get("storage")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryValueDefinitionRequestQueryEventQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestQueryEventQueryCompute",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "interval": "interval",
        "metric": "metric",
    },
)
class PowerpackWidgetQueryValueDefinitionRequestQueryEventQueryCompute:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        interval: typing.Optional[jsii.Number] = None,
        metric: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation methods for event platform queries. Valid values are ``count``, ``cardinality``, ``median``, ``pc75``, ``pc90``, ``pc95``, ``pc98``, ``pc99``, ``sum``, ``min``, ``max``, ``avg``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param interval: A time interval in milliseconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        :param metric: The measurable attribute to compute. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__97825189bbb5cd51bed45058bdd0c8c6a104ee3e9525da17a45060e1ebc33bed)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
            check_type(argname="argument metric", value=metric, expected_type=type_hints["metric"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if interval is not None:
            self._values["interval"] = interval
        if metric is not None:
            self._values["metric"] = metric

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation methods for event platform queries.

        Valid values are ``count``, ``cardinality``, ``median``, ``pc75``, ``pc90``, ``pc95``, ``pc98``, ``pc99``, ``sum``, ``min``, ``max``, ``avg``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''A time interval in milliseconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def metric(self) -> typing.Optional[builtins.str]:
        '''The measurable attribute to compute.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        '''
        result = self._values.get("metric")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryValueDefinitionRequestQueryEventQueryCompute(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetQueryValueDefinitionRequestQueryEventQueryComputeList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestQueryEventQueryComputeList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6ab515ffcd2a98040e5cf4e403efbfc7d0995a696c423f5e61aed95cb1a40b00)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetQueryValueDefinitionRequestQueryEventQueryComputeOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f69da1266ff85408552c7909037842a3297c4327b5fb8fe059e4ab27b994bd23)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetQueryValueDefinitionRequestQueryEventQueryComputeOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b1aad7233a9d813039be863faf9d943300bb532811c1ac2d7de90dfc23f566d6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c9fe80ffaf62e03ba4a1c3f317fd6cabd572aa6ba9e99bbd0cf908b905c8810d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b27a582d9b25c52ddc45a1226ceaf75001c3ceab94e8e3e1cb44bf7f5de35c14)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionRequestQueryEventQueryCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionRequestQueryEventQueryCompute]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionRequestQueryEventQueryCompute]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ff4caf54c4c5f600ef1ea1808de66a2f6ca74697969458616e66d0e28672e785)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetQueryValueDefinitionRequestQueryEventQueryComputeOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestQueryEventQueryComputeOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__acf960a500096f7f983a2ad69d6a0aa42c8a2e2f98cb4c8c4cd4bbcc09c5d0dc)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @jsii.member(jsii_name="resetMetric")
    def reset_metric(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMetric", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="metricInput")
    def metric_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "metricInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__982abf2f1efa638c51d71afd44d35e7c6ac4658cdc7be865bfde23b426a6c81b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__75847addb6ed0449d9ca9bc3854cd373e32a6f59ce18207870670ac2bc4ed432)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="metric")
    def metric(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "metric"))

    @metric.setter
    def metric(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__314f1c6ed74e7211eabf24ad9fbd5dc592f909c0c62f611aaf02c561f326784f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "metric", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryValueDefinitionRequestQueryEventQueryCompute]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryValueDefinitionRequestQueryEventQueryCompute]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryValueDefinitionRequestQueryEventQueryCompute]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b4be1ec4c06d3408fc4f948aca4efdf82e3356a38b7256d1347c1dda3aeee627)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestQueryEventQueryGroupBy",
    jsii_struct_bases=[],
    name_mapping={"facet": "facet", "limit": "limit", "sort": "sort"},
)
class PowerpackWidgetQueryValueDefinitionRequestQueryEventQueryGroupBy:
    def __init__(
        self,
        *,
        facet: builtins.str,
        limit: typing.Optional[jsii.Number] = None,
        sort: typing.Optional[typing.Union["PowerpackWidgetQueryValueDefinitionRequestQueryEventQueryGroupBySort", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param facet: The event facet. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param limit: The number of groups to return. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param sort: sort block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort Powerpack#sort}
        '''
        if isinstance(sort, dict):
            sort = PowerpackWidgetQueryValueDefinitionRequestQueryEventQueryGroupBySort(**sort)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__58ee3dd36e95d50403a202e8a1e1638b8e355995ade9557252123793607fc6d8)
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
            check_type(argname="argument sort", value=sort, expected_type=type_hints["sort"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "facet": facet,
        }
        if limit is not None:
            self._values["limit"] = limit
        if sort is not None:
            self._values["sort"] = sort

    @builtins.property
    def facet(self) -> builtins.str:
        '''The event facet.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        assert result is not None, "Required property 'facet' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def limit(self) -> typing.Optional[jsii.Number]:
        '''The number of groups to return.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        '''
        result = self._values.get("limit")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def sort(
        self,
    ) -> typing.Optional["PowerpackWidgetQueryValueDefinitionRequestQueryEventQueryGroupBySort"]:
        '''sort block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort Powerpack#sort}
        '''
        result = self._values.get("sort")
        return typing.cast(typing.Optional["PowerpackWidgetQueryValueDefinitionRequestQueryEventQueryGroupBySort"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryValueDefinitionRequestQueryEventQueryGroupBy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetQueryValueDefinitionRequestQueryEventQueryGroupByList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestQueryEventQueryGroupByList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d5c33e646903e080bbed8ec6220928bb6ebb8eb428a43df783c5576358d2d35f)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetQueryValueDefinitionRequestQueryEventQueryGroupByOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0c9c2846b2bc855fabceb883eca3eb01ac787afdb4f2dd526fb8ebd3d6a888a3)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetQueryValueDefinitionRequestQueryEventQueryGroupByOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c868f2ecf58e83c31f7d0e882ff0cdb9cf4650f28a48a413a66e2e0a6a47a656)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b29a5e4b4e111bd4ef438ab292a2d8045ff9a78cbccb4ef1655039e90dee4eb7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2452fec94b710c498e7ce73483a8a8404aa283d4be49f2d4e2b4ad01b63c574f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionRequestQueryEventQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionRequestQueryEventQueryGroupBy]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionRequestQueryEventQueryGroupBy]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c6f04a17b02963ea290fbc30f2e7768c46edf555c4e915356f727e00dd4cb84e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetQueryValueDefinitionRequestQueryEventQueryGroupByOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestQueryEventQueryGroupByOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ca929fdf8ffbf0dc575b2111f528d23295c26872dd36969c9ee0cc68ff2d0635)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putSort")
    def put_sort(
        self,
        *,
        aggregation: builtins.str,
        metric: typing.Optional[builtins.str] = None,
        order: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation methods for the event platform queries. Valid values are ``count``, ``cardinality``, ``median``, ``pc75``, ``pc90``, ``pc95``, ``pc98``, ``pc99``, ``sum``, ``min``, ``max``, ``avg``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param metric: The metric used for sorting group by results. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        :param order: Direction of sort. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        value = PowerpackWidgetQueryValueDefinitionRequestQueryEventQueryGroupBySort(
            aggregation=aggregation, metric=metric, order=order
        )

        return typing.cast(None, jsii.invoke(self, "putSort", [value]))

    @jsii.member(jsii_name="resetLimit")
    def reset_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLimit", []))

    @jsii.member(jsii_name="resetSort")
    def reset_sort(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSort", []))

    @builtins.property
    @jsii.member(jsii_name="sort")
    def sort(
        self,
    ) -> "PowerpackWidgetQueryValueDefinitionRequestQueryEventQueryGroupBySortOutputReference":
        return typing.cast("PowerpackWidgetQueryValueDefinitionRequestQueryEventQueryGroupBySortOutputReference", jsii.get(self, "sort"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="limitInput")
    def limit_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "limitInput"))

    @builtins.property
    @jsii.member(jsii_name="sortInput")
    def sort_input(
        self,
    ) -> typing.Optional["PowerpackWidgetQueryValueDefinitionRequestQueryEventQueryGroupBySort"]:
        return typing.cast(typing.Optional["PowerpackWidgetQueryValueDefinitionRequestQueryEventQueryGroupBySort"], jsii.get(self, "sortInput"))

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ca079fa93e2289f5be4b1d063fa14fc1ec39f9c959a8b6b053be432f7ff8a0f2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="limit")
    def limit(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "limit"))

    @limit.setter
    def limit(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__633062a5197543d8c4c6ee2f72c092256d0ff62b5ba13e6b10f81373db42826f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "limit", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryValueDefinitionRequestQueryEventQueryGroupBy]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryValueDefinitionRequestQueryEventQueryGroupBy]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryValueDefinitionRequestQueryEventQueryGroupBy]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__611e4c4469a3deeb58e3f252bd13aebf34db695d50fca9b3b22b4df3da9d927e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestQueryEventQueryGroupBySort",
    jsii_struct_bases=[],
    name_mapping={"aggregation": "aggregation", "metric": "metric", "order": "order"},
)
class PowerpackWidgetQueryValueDefinitionRequestQueryEventQueryGroupBySort:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        metric: typing.Optional[builtins.str] = None,
        order: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation methods for the event platform queries. Valid values are ``count``, ``cardinality``, ``median``, ``pc75``, ``pc90``, ``pc95``, ``pc98``, ``pc99``, ``sum``, ``min``, ``max``, ``avg``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param metric: The metric used for sorting group by results. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        :param order: Direction of sort. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a79e099fc4e7379a6239cf0b786f8ba16cb0f200595c3f8f6470f91c95d09dc6)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument metric", value=metric, expected_type=type_hints["metric"])
            check_type(argname="argument order", value=order, expected_type=type_hints["order"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if metric is not None:
            self._values["metric"] = metric
        if order is not None:
            self._values["order"] = order

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation methods for the event platform queries.

        Valid values are ``count``, ``cardinality``, ``median``, ``pc75``, ``pc90``, ``pc95``, ``pc98``, ``pc99``, ``sum``, ``min``, ``max``, ``avg``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def metric(self) -> typing.Optional[builtins.str]:
        '''The metric used for sorting group by results.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        '''
        result = self._values.get("metric")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def order(self) -> typing.Optional[builtins.str]:
        '''Direction of sort. Valid values are ``asc``, ``desc``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        result = self._values.get("order")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryValueDefinitionRequestQueryEventQueryGroupBySort(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetQueryValueDefinitionRequestQueryEventQueryGroupBySortOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestQueryEventQueryGroupBySortOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__312dd0c2d55e2f69130652e4b1eb146bbbf10d26e0b3e28581f5f1ae25905a2f)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetMetric")
    def reset_metric(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMetric", []))

    @jsii.member(jsii_name="resetOrder")
    def reset_order(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetOrder", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="metricInput")
    def metric_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "metricInput"))

    @builtins.property
    @jsii.member(jsii_name="orderInput")
    def order_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "orderInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4f4d66aabf5424b67c7e850fd32a97f28b5858c0164412864131930184174891)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="metric")
    def metric(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "metric"))

    @metric.setter
    def metric(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__496960a3962933d635f674dcc791ac6fade49881e1851179467fb404f3bd9f5e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "metric", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="order")
    def order(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "order"))

    @order.setter
    def order(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ec828f832f6ca9e84b4a0a0dcc1ef07ac2bc4d1481cd6967541eab05b6b463ed)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "order", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetQueryValueDefinitionRequestQueryEventQueryGroupBySort]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryValueDefinitionRequestQueryEventQueryGroupBySort], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetQueryValueDefinitionRequestQueryEventQueryGroupBySort],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__05bb1e0f46521f62dff4752848d780a5f1159058e0fbbc76ee0b5d2097538486)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetQueryValueDefinitionRequestQueryEventQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestQueryEventQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__032ba2aa8dec0a82441e01646dfb8c28788a1bab2fae4ec2e2c18b25b6ee8078)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putCompute")
    def put_compute(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryValueDefinitionRequestQueryEventQueryCompute, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d58badd9eb9a6b6c6b5195ba55098cff224ba1ff63a6646e302c4e3be7473ee1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putCompute", [value]))

    @jsii.member(jsii_name="putGroupBy")
    def put_group_by(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryValueDefinitionRequestQueryEventQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5bc302625831387dcfdae5485c3f4bfcabe43b60a102155b4d90c74320d0c98c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putGroupBy", [value]))

    @jsii.member(jsii_name="putSearch")
    def put_search(self, *, query: builtins.str) -> None:
        '''
        :param query: The events search string. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        '''
        value = PowerpackWidgetQueryValueDefinitionRequestQueryEventQuerySearch(
            query=query
        )

        return typing.cast(None, jsii.invoke(self, "putSearch", [value]))

    @jsii.member(jsii_name="resetCrossOrgUuids")
    def reset_cross_org_uuids(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCrossOrgUuids", []))

    @jsii.member(jsii_name="resetGroupBy")
    def reset_group_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGroupBy", []))

    @jsii.member(jsii_name="resetIndexes")
    def reset_indexes(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetIndexes", []))

    @jsii.member(jsii_name="resetSearch")
    def reset_search(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSearch", []))

    @jsii.member(jsii_name="resetStorage")
    def reset_storage(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetStorage", []))

    @builtins.property
    @jsii.member(jsii_name="compute")
    def compute(
        self,
    ) -> PowerpackWidgetQueryValueDefinitionRequestQueryEventQueryComputeList:
        return typing.cast(PowerpackWidgetQueryValueDefinitionRequestQueryEventQueryComputeList, jsii.get(self, "compute"))

    @builtins.property
    @jsii.member(jsii_name="groupBy")
    def group_by(
        self,
    ) -> PowerpackWidgetQueryValueDefinitionRequestQueryEventQueryGroupByList:
        return typing.cast(PowerpackWidgetQueryValueDefinitionRequestQueryEventQueryGroupByList, jsii.get(self, "groupBy"))

    @builtins.property
    @jsii.member(jsii_name="search")
    def search(
        self,
    ) -> "PowerpackWidgetQueryValueDefinitionRequestQueryEventQuerySearchOutputReference":
        return typing.cast("PowerpackWidgetQueryValueDefinitionRequestQueryEventQuerySearchOutputReference", jsii.get(self, "search"))

    @builtins.property
    @jsii.member(jsii_name="computeInput")
    def compute_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionRequestQueryEventQueryCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionRequestQueryEventQueryCompute]]], jsii.get(self, "computeInput"))

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuidsInput")
    def cross_org_uuids_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "crossOrgUuidsInput"))

    @builtins.property
    @jsii.member(jsii_name="dataSourceInput")
    def data_source_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "dataSourceInput"))

    @builtins.property
    @jsii.member(jsii_name="groupByInput")
    def group_by_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionRequestQueryEventQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionRequestQueryEventQueryGroupBy]]], jsii.get(self, "groupByInput"))

    @builtins.property
    @jsii.member(jsii_name="indexesInput")
    def indexes_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "indexesInput"))

    @builtins.property
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property
    @jsii.member(jsii_name="searchInput")
    def search_input(
        self,
    ) -> typing.Optional["PowerpackWidgetQueryValueDefinitionRequestQueryEventQuerySearch"]:
        return typing.cast(typing.Optional["PowerpackWidgetQueryValueDefinitionRequestQueryEventQuerySearch"], jsii.get(self, "searchInput"))

    @builtins.property
    @jsii.member(jsii_name="storageInput")
    def storage_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "storageInput"))

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuids")
    def cross_org_uuids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "crossOrgUuids"))

    @cross_org_uuids.setter
    def cross_org_uuids(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b65787a59f9759dd8e991232c5fb9703d185470f131d8ab535a936688b368fcf)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "crossOrgUuids", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="dataSource")
    def data_source(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "dataSource"))

    @data_source.setter
    def data_source(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b258cdcf2a3c34e67d79e95cac21b2e54a2d9a55f752d91c888a8225195f2b36)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "dataSource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="indexes")
    def indexes(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "indexes"))

    @indexes.setter
    def indexes(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9b28f6ee8a2924ba1010100204b957be43f5f35fa4251b0184f8ac9bbf8031f6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "indexes", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b586fa874956e6fb44259c06a2b74fbcc0bc16880e99318dbd933bfbfa4ae128)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "name", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="storage")
    def storage(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "storage"))

    @storage.setter
    def storage(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6bf52432a36ed66535a89632afa846aa9dbe5bee752695644af32cb4b469cb86)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "storage", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetQueryValueDefinitionRequestQueryEventQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryValueDefinitionRequestQueryEventQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetQueryValueDefinitionRequestQueryEventQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1be0e98448a80b3b9d84294cfbb3f6da89704f0e09ba91560337e20b826c4f29)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestQueryEventQuerySearch",
    jsii_struct_bases=[],
    name_mapping={"query": "query"},
)
class PowerpackWidgetQueryValueDefinitionRequestQueryEventQuerySearch:
    def __init__(self, *, query: builtins.str) -> None:
        '''
        :param query: The events search string. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__88b2c5ce7bb3e4067126f4536a69c15c4f6370e57efb64436f289a325bb4cea1)
            check_type(argname="argument query", value=query, expected_type=type_hints["query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "query": query,
        }

    @builtins.property
    def query(self) -> builtins.str:
        '''The events search string.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        '''
        result = self._values.get("query")
        assert result is not None, "Required property 'query' is missing"
        return typing.cast(builtins.str, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryValueDefinitionRequestQueryEventQuerySearch(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetQueryValueDefinitionRequestQueryEventQuerySearchOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestQueryEventQuerySearchOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2e51a05a776e70dfadf05a728c4e2e3a606c6f3336612d9f616c174ff1b6b584)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @builtins.property
    @jsii.member(jsii_name="queryInput")
    def query_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "queryInput"))

    @builtins.property
    @jsii.member(jsii_name="query")
    def query(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "query"))

    @query.setter
    def query(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__313a991252b0c4f57a29016640d4ee7888cfe8c6503893931f850e0101a17cba)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "query", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetQueryValueDefinitionRequestQueryEventQuerySearch]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryValueDefinitionRequestQueryEventQuerySearch], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetQueryValueDefinitionRequestQueryEventQuerySearch],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__20fcfc66dc9dea273e2f08f3c8679ff279b58492a5596a2da0f8d2e1a44965dd)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetQueryValueDefinitionRequestQueryList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestQueryList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9d1c3717e547871c6fb83980068d0853905596ba8410689998086ceee729960a)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetQueryValueDefinitionRequestQueryOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__821bb32e518f00b1baf3fd746da6547fdedeb3cfb4d7696cd33cf15551deaa24)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetQueryValueDefinitionRequestQueryOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__725f9ded0b15a1de75907eceb329ebc0fbed229b6cb12ac9c220a8ad5ed6d62b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2db87fcaba818e2134e99fd3957b1eb285c5abcc62a228f89b48e24322470835)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__29bd1a24a95af600d9db77eeb5beba7ad67540e5c04323ee679d1424251697b1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionRequestQuery]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionRequestQuery]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionRequestQuery]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__015a78fc5249bbf6368b194bfcb017964d10d1c30827f5128dd60abb4da640b8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestQueryMetricQuery",
    jsii_struct_bases=[],
    name_mapping={
        "name": "name",
        "query": "query",
        "aggregator": "aggregator",
        "cross_org_uuids": "crossOrgUuids",
        "data_source": "dataSource",
    },
)
class PowerpackWidgetQueryValueDefinitionRequestQueryMetricQuery:
    def __init__(
        self,
        *,
        name: builtins.str,
        query: builtins.str,
        aggregator: typing.Optional[builtins.str] = None,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        data_source: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param name: The name of the query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param query: The metrics query definition. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        :param aggregator: The aggregation methods available for metrics queries. Valid values are ``avg``, ``min``, ``max``, ``sum``, ``last``, ``area``, ``l2norm``, ``percentile``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregator Powerpack#aggregator}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param data_source: The data source for metrics queries. Defaults to ``"metrics"``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d5516dd97814a52aa30d4087502367d1a7327599c720f20eae2350946d475dda)
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument query", value=query, expected_type=type_hints["query"])
            check_type(argname="argument aggregator", value=aggregator, expected_type=type_hints["aggregator"])
            check_type(argname="argument cross_org_uuids", value=cross_org_uuids, expected_type=type_hints["cross_org_uuids"])
            check_type(argname="argument data_source", value=data_source, expected_type=type_hints["data_source"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "name": name,
            "query": query,
        }
        if aggregator is not None:
            self._values["aggregator"] = aggregator
        if cross_org_uuids is not None:
            self._values["cross_org_uuids"] = cross_org_uuids
        if data_source is not None:
            self._values["data_source"] = data_source

    @builtins.property
    def name(self) -> builtins.str:
        '''The name of the query for use in formulas.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        '''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def query(self) -> builtins.str:
        '''The metrics query definition.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        '''
        result = self._values.get("query")
        assert result is not None, "Required property 'query' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def aggregator(self) -> typing.Optional[builtins.str]:
        '''The aggregation methods available for metrics queries. Valid values are ``avg``, ``min``, ``max``, ``sum``, ``last``, ``area``, ``l2norm``, ``percentile``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregator Powerpack#aggregator}
        '''
        result = self._values.get("aggregator")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def cross_org_uuids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''The source organization UUID for cross organization queries. Feature in Private Beta.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        '''
        result = self._values.get("cross_org_uuids")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def data_source(self) -> typing.Optional[builtins.str]:
        '''The data source for metrics queries. Defaults to ``"metrics"``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        '''
        result = self._values.get("data_source")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryValueDefinitionRequestQueryMetricQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetQueryValueDefinitionRequestQueryMetricQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestQueryMetricQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__38a661dea927b3ca6ce82799655c7fab4ead44f4fefffcb7d6c5caaba3af84c7)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetAggregator")
    def reset_aggregator(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAggregator", []))

    @jsii.member(jsii_name="resetCrossOrgUuids")
    def reset_cross_org_uuids(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCrossOrgUuids", []))

    @jsii.member(jsii_name="resetDataSource")
    def reset_data_source(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDataSource", []))

    @builtins.property
    @jsii.member(jsii_name="aggregatorInput")
    def aggregator_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregatorInput"))

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuidsInput")
    def cross_org_uuids_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "crossOrgUuidsInput"))

    @builtins.property
    @jsii.member(jsii_name="dataSourceInput")
    def data_source_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "dataSourceInput"))

    @builtins.property
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property
    @jsii.member(jsii_name="queryInput")
    def query_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "queryInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregator")
    def aggregator(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregator"))

    @aggregator.setter
    def aggregator(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__73f913845107f208a0eb7c688728aee4fd1a44cba5e25db1558f009a17136d52)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregator", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuids")
    def cross_org_uuids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "crossOrgUuids"))

    @cross_org_uuids.setter
    def cross_org_uuids(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c922281d6a268339d3f39f7b127d58c5bdd490ff5f38c38bffb3d01c2d73c24d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "crossOrgUuids", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="dataSource")
    def data_source(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "dataSource"))

    @data_source.setter
    def data_source(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__31ce03d8283c3f9d7409840447d6326ec6605f570baf97c8b9f3d6423c333283)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "dataSource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1789e80164f0ea0dc847ac5bed44a05c129732f6be114875cbd04f75f9d0cb0d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "name", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="query")
    def query(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "query"))

    @query.setter
    def query(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7a308688c2866ff89723c60058f97fad667fd11bbc2aa72cc614315d379bd015)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "query", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetQueryValueDefinitionRequestQueryMetricQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryValueDefinitionRequestQueryMetricQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetQueryValueDefinitionRequestQueryMetricQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d842cb52ed6a4bd5a076c9b020aceb1a8206c894a2c5dc2db95de51d9edbb03e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetQueryValueDefinitionRequestQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__76864561a84e0130c5ed7c320dbb8f5ac6f0f59e9d6b2a7ad514139aba1c33f7)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putApmDependencyStatsQuery")
    def put_apm_dependency_stats_query(
        self,
        *,
        data_source: builtins.str,
        env: builtins.str,
        name: builtins.str,
        operation_name: builtins.str,
        resource_name: builtins.str,
        service: builtins.str,
        stat: builtins.str,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        is_upstream: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        primary_tag_name: typing.Optional[builtins.str] = None,
        primary_tag_value: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param data_source: The data source for APM Dependency Stats queries. Valid values are ``apm_dependency_stats``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param env: APM environment. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#env Powerpack#env}
        :param name: The name of query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param operation_name: Name of operation on service. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#operation_name Powerpack#operation_name}
        :param resource_name: APM resource. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#resource_name Powerpack#resource_name}
        :param service: APM service. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#service Powerpack#service}
        :param stat: APM statistic. Valid values are ``avg_duration``, ``avg_root_duration``, ``avg_spans_per_trace``, ``error_rate``, ``pct_exec_time``, ``pct_of_traces``, ``total_traces_count``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#stat Powerpack#stat}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param is_upstream: Determines whether stats for upstream or downstream dependencies should be queried. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#is_upstream Powerpack#is_upstream}
        :param primary_tag_name: The name of the second primary tag used within APM; required when ``primary_tag_value`` is specified. See https://docs.datadoghq.com/tracing/guide/setting_primary_tags_to_scope/#add-a-second-primary-tag-in-datadog. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_name Powerpack#primary_tag_name}
        :param primary_tag_value: Filter APM data by the second primary tag. ``primary_tag_name`` must also be specified. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_value Powerpack#primary_tag_value}
        '''
        value = PowerpackWidgetQueryValueDefinitionRequestQueryApmDependencyStatsQuery(
            data_source=data_source,
            env=env,
            name=name,
            operation_name=operation_name,
            resource_name=resource_name,
            service=service,
            stat=stat,
            cross_org_uuids=cross_org_uuids,
            is_upstream=is_upstream,
            primary_tag_name=primary_tag_name,
            primary_tag_value=primary_tag_value,
        )

        return typing.cast(None, jsii.invoke(self, "putApmDependencyStatsQuery", [value]))

    @jsii.member(jsii_name="putApmResourceStatsQuery")
    def put_apm_resource_stats_query(
        self,
        *,
        data_source: builtins.str,
        env: builtins.str,
        name: builtins.str,
        service: builtins.str,
        stat: builtins.str,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        group_by: typing.Optional[typing.Sequence[builtins.str]] = None,
        operation_name: typing.Optional[builtins.str] = None,
        primary_tag_name: typing.Optional[builtins.str] = None,
        primary_tag_value: typing.Optional[builtins.str] = None,
        resource_name: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param data_source: The data source for APM Resource Stats queries. Valid values are ``apm_resource_stats``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param env: APM environment. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#env Powerpack#env}
        :param name: The name of query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param service: APM service. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#service Powerpack#service}
        :param stat: APM statistic. Valid values are ``errors``, ``error_rate``, ``hits``, ``latency_avg``, ``latency_distribution``, ``latency_max``, ``latency_p50``, ``latency_p75``, ``latency_p90``, ``latency_p95``, ``latency_p99``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#stat Powerpack#stat}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param group_by: Array of fields to group results by. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param operation_name: Name of operation on service. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#operation_name Powerpack#operation_name}
        :param primary_tag_name: The name of the second primary tag used within APM; required when ``primary_tag_value`` is specified. See https://docs.datadoghq.com/tracing/guide/setting_primary_tags_to_scope/#add-a-second-primary-tag-in-datadog. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_name Powerpack#primary_tag_name}
        :param primary_tag_value: Filter APM data by the second primary tag. ``primary_tag_name`` must also be specified. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_value Powerpack#primary_tag_value}
        :param resource_name: APM resource. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#resource_name Powerpack#resource_name}
        '''
        value = PowerpackWidgetQueryValueDefinitionRequestQueryApmResourceStatsQuery(
            data_source=data_source,
            env=env,
            name=name,
            service=service,
            stat=stat,
            cross_org_uuids=cross_org_uuids,
            group_by=group_by,
            operation_name=operation_name,
            primary_tag_name=primary_tag_name,
            primary_tag_value=primary_tag_value,
            resource_name=resource_name,
        )

        return typing.cast(None, jsii.invoke(self, "putApmResourceStatsQuery", [value]))

    @jsii.member(jsii_name="putCloudCostQuery")
    def put_cloud_cost_query(
        self,
        *,
        data_source: builtins.str,
        name: builtins.str,
        query: builtins.str,
        aggregator: typing.Optional[builtins.str] = None,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
    ) -> None:
        '''
        :param data_source: The data source for cloud cost queries. Valid values are ``cloud_cost``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param name: The name of the query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param query: The cloud cost query definition. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        :param aggregator: The aggregation methods available for cloud cost queries. Valid values are ``avg``, ``last``, ``max``, ``min``, ``sum``, ``percentile``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregator Powerpack#aggregator}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        '''
        value = PowerpackWidgetQueryValueDefinitionRequestQueryCloudCostQuery(
            data_source=data_source,
            name=name,
            query=query,
            aggregator=aggregator,
            cross_org_uuids=cross_org_uuids,
        )

        return typing.cast(None, jsii.invoke(self, "putCloudCostQuery", [value]))

    @jsii.member(jsii_name="putEventQuery")
    def put_event_query(
        self,
        *,
        compute: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryValueDefinitionRequestQueryEventQueryCompute, typing.Dict[builtins.str, typing.Any]]]],
        data_source: builtins.str,
        name: builtins.str,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryValueDefinitionRequestQueryEventQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
        indexes: typing.Optional[typing.Sequence[builtins.str]] = None,
        search: typing.Optional[typing.Union[PowerpackWidgetQueryValueDefinitionRequestQueryEventQuerySearch, typing.Dict[builtins.str, typing.Any]]] = None,
        storage: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param compute: compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute Powerpack#compute}
        :param data_source: The data source for event platform-based queries. Valid values are ``logs``, ``spans``, ``network``, ``rum``, ``security_signals``, ``profiles``, ``audit``, ``events``, ``ci_tests``, ``ci_pipelines``, ``incident_analytics``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param name: The name of query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param indexes: An array of index names to query in the stream. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#indexes Powerpack#indexes}
        :param search: search block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search Powerpack#search}
        :param storage: Storage location (private beta). Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#storage Powerpack#storage}
        '''
        value = PowerpackWidgetQueryValueDefinitionRequestQueryEventQuery(
            compute=compute,
            data_source=data_source,
            name=name,
            cross_org_uuids=cross_org_uuids,
            group_by=group_by,
            indexes=indexes,
            search=search,
            storage=storage,
        )

        return typing.cast(None, jsii.invoke(self, "putEventQuery", [value]))

    @jsii.member(jsii_name="putMetricQuery")
    def put_metric_query(
        self,
        *,
        name: builtins.str,
        query: builtins.str,
        aggregator: typing.Optional[builtins.str] = None,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        data_source: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param name: The name of the query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param query: The metrics query definition. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        :param aggregator: The aggregation methods available for metrics queries. Valid values are ``avg``, ``min``, ``max``, ``sum``, ``last``, ``area``, ``l2norm``, ``percentile``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregator Powerpack#aggregator}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param data_source: The data source for metrics queries. Defaults to ``"metrics"``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        '''
        value = PowerpackWidgetQueryValueDefinitionRequestQueryMetricQuery(
            name=name,
            query=query,
            aggregator=aggregator,
            cross_org_uuids=cross_org_uuids,
            data_source=data_source,
        )

        return typing.cast(None, jsii.invoke(self, "putMetricQuery", [value]))

    @jsii.member(jsii_name="putProcessQuery")
    def put_process_query(
        self,
        *,
        data_source: builtins.str,
        metric: builtins.str,
        name: builtins.str,
        aggregator: typing.Optional[builtins.str] = None,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        is_normalized_cpu: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        limit: typing.Optional[jsii.Number] = None,
        sort: typing.Optional[builtins.str] = None,
        tag_filters: typing.Optional[typing.Sequence[builtins.str]] = None,
        text_filter: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param data_source: The data source for process queries. Valid values are ``process``, ``container``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param metric: The process metric name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        :param name: The name of query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param aggregator: The aggregation methods available for metrics queries. Valid values are ``avg``, ``min``, ``max``, ``sum``, ``last``, ``area``, ``l2norm``, ``percentile``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregator Powerpack#aggregator}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param is_normalized_cpu: Whether to normalize the CPU percentages. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#is_normalized_cpu Powerpack#is_normalized_cpu}
        :param limit: The number of hits to return. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param sort: The direction of the sort. Valid values are ``asc``, ``desc``. Defaults to ``"desc"``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort Powerpack#sort}
        :param tag_filters: An array of tags to filter by. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#tag_filters Powerpack#tag_filters}
        :param text_filter: The text to use as a filter. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#text_filter Powerpack#text_filter}
        '''
        value = PowerpackWidgetQueryValueDefinitionRequestQueryProcessQuery(
            data_source=data_source,
            metric=metric,
            name=name,
            aggregator=aggregator,
            cross_org_uuids=cross_org_uuids,
            is_normalized_cpu=is_normalized_cpu,
            limit=limit,
            sort=sort,
            tag_filters=tag_filters,
            text_filter=text_filter,
        )

        return typing.cast(None, jsii.invoke(self, "putProcessQuery", [value]))

    @jsii.member(jsii_name="putSloQuery")
    def put_slo_query(
        self,
        *,
        data_source: builtins.str,
        measure: builtins.str,
        slo_id: builtins.str,
        additional_query_filters: typing.Optional[builtins.str] = None,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        group_mode: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
        slo_query_type: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param data_source: The data source for SLO queries. Valid values are ``slo``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param measure: SLO measures queries. Valid values are ``good_events``, ``bad_events``, ``good_minutes``, ``bad_minutes``, ``slo_status``, ``error_budget_remaining``, ``burn_rate``, ``error_budget_burndown``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#measure Powerpack#measure}
        :param slo_id: ID of an SLO to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#slo_id Powerpack#slo_id}
        :param additional_query_filters: Additional filters applied to the SLO query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#additional_query_filters Powerpack#additional_query_filters}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param group_mode: Group mode to query measures. Valid values are ``overall``, ``components``. Defaults to ``"overall"``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_mode Powerpack#group_mode}
        :param name: The name of query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param slo_query_type: type of the SLO to query. Valid values are ``metric``, ``monitor``, ``time_slice``. Defaults to ``"metric"``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#slo_query_type Powerpack#slo_query_type}
        '''
        value = PowerpackWidgetQueryValueDefinitionRequestQuerySloQuery(
            data_source=data_source,
            measure=measure,
            slo_id=slo_id,
            additional_query_filters=additional_query_filters,
            cross_org_uuids=cross_org_uuids,
            group_mode=group_mode,
            name=name,
            slo_query_type=slo_query_type,
        )

        return typing.cast(None, jsii.invoke(self, "putSloQuery", [value]))

    @jsii.member(jsii_name="resetApmDependencyStatsQuery")
    def reset_apm_dependency_stats_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetApmDependencyStatsQuery", []))

    @jsii.member(jsii_name="resetApmResourceStatsQuery")
    def reset_apm_resource_stats_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetApmResourceStatsQuery", []))

    @jsii.member(jsii_name="resetCloudCostQuery")
    def reset_cloud_cost_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCloudCostQuery", []))

    @jsii.member(jsii_name="resetEventQuery")
    def reset_event_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetEventQuery", []))

    @jsii.member(jsii_name="resetMetricQuery")
    def reset_metric_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMetricQuery", []))

    @jsii.member(jsii_name="resetProcessQuery")
    def reset_process_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetProcessQuery", []))

    @jsii.member(jsii_name="resetSloQuery")
    def reset_slo_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSloQuery", []))

    @builtins.property
    @jsii.member(jsii_name="apmDependencyStatsQuery")
    def apm_dependency_stats_query(
        self,
    ) -> PowerpackWidgetQueryValueDefinitionRequestQueryApmDependencyStatsQueryOutputReference:
        return typing.cast(PowerpackWidgetQueryValueDefinitionRequestQueryApmDependencyStatsQueryOutputReference, jsii.get(self, "apmDependencyStatsQuery"))

    @builtins.property
    @jsii.member(jsii_name="apmResourceStatsQuery")
    def apm_resource_stats_query(
        self,
    ) -> PowerpackWidgetQueryValueDefinitionRequestQueryApmResourceStatsQueryOutputReference:
        return typing.cast(PowerpackWidgetQueryValueDefinitionRequestQueryApmResourceStatsQueryOutputReference, jsii.get(self, "apmResourceStatsQuery"))

    @builtins.property
    @jsii.member(jsii_name="cloudCostQuery")
    def cloud_cost_query(
        self,
    ) -> PowerpackWidgetQueryValueDefinitionRequestQueryCloudCostQueryOutputReference:
        return typing.cast(PowerpackWidgetQueryValueDefinitionRequestQueryCloudCostQueryOutputReference, jsii.get(self, "cloudCostQuery"))

    @builtins.property
    @jsii.member(jsii_name="eventQuery")
    def event_query(
        self,
    ) -> PowerpackWidgetQueryValueDefinitionRequestQueryEventQueryOutputReference:
        return typing.cast(PowerpackWidgetQueryValueDefinitionRequestQueryEventQueryOutputReference, jsii.get(self, "eventQuery"))

    @builtins.property
    @jsii.member(jsii_name="metricQuery")
    def metric_query(
        self,
    ) -> PowerpackWidgetQueryValueDefinitionRequestQueryMetricQueryOutputReference:
        return typing.cast(PowerpackWidgetQueryValueDefinitionRequestQueryMetricQueryOutputReference, jsii.get(self, "metricQuery"))

    @builtins.property
    @jsii.member(jsii_name="processQuery")
    def process_query(
        self,
    ) -> "PowerpackWidgetQueryValueDefinitionRequestQueryProcessQueryOutputReference":
        return typing.cast("PowerpackWidgetQueryValueDefinitionRequestQueryProcessQueryOutputReference", jsii.get(self, "processQuery"))

    @builtins.property
    @jsii.member(jsii_name="sloQuery")
    def slo_query(
        self,
    ) -> "PowerpackWidgetQueryValueDefinitionRequestQuerySloQueryOutputReference":
        return typing.cast("PowerpackWidgetQueryValueDefinitionRequestQuerySloQueryOutputReference", jsii.get(self, "sloQuery"))

    @builtins.property
    @jsii.member(jsii_name="apmDependencyStatsQueryInput")
    def apm_dependency_stats_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetQueryValueDefinitionRequestQueryApmDependencyStatsQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryValueDefinitionRequestQueryApmDependencyStatsQuery], jsii.get(self, "apmDependencyStatsQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="apmResourceStatsQueryInput")
    def apm_resource_stats_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetQueryValueDefinitionRequestQueryApmResourceStatsQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryValueDefinitionRequestQueryApmResourceStatsQuery], jsii.get(self, "apmResourceStatsQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="cloudCostQueryInput")
    def cloud_cost_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetQueryValueDefinitionRequestQueryCloudCostQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryValueDefinitionRequestQueryCloudCostQuery], jsii.get(self, "cloudCostQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="eventQueryInput")
    def event_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetQueryValueDefinitionRequestQueryEventQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryValueDefinitionRequestQueryEventQuery], jsii.get(self, "eventQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="metricQueryInput")
    def metric_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetQueryValueDefinitionRequestQueryMetricQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryValueDefinitionRequestQueryMetricQuery], jsii.get(self, "metricQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="processQueryInput")
    def process_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetQueryValueDefinitionRequestQueryProcessQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetQueryValueDefinitionRequestQueryProcessQuery"], jsii.get(self, "processQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="sloQueryInput")
    def slo_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetQueryValueDefinitionRequestQuerySloQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetQueryValueDefinitionRequestQuerySloQuery"], jsii.get(self, "sloQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryValueDefinitionRequestQuery]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryValueDefinitionRequestQuery]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryValueDefinitionRequestQuery]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3f6365fd5cff139361e4c3fe79b870c497e088fe39bdff2330bda7ea38ecbfbd)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestQueryProcessQuery",
    jsii_struct_bases=[],
    name_mapping={
        "data_source": "dataSource",
        "metric": "metric",
        "name": "name",
        "aggregator": "aggregator",
        "cross_org_uuids": "crossOrgUuids",
        "is_normalized_cpu": "isNormalizedCpu",
        "limit": "limit",
        "sort": "sort",
        "tag_filters": "tagFilters",
        "text_filter": "textFilter",
    },
)
class PowerpackWidgetQueryValueDefinitionRequestQueryProcessQuery:
    def __init__(
        self,
        *,
        data_source: builtins.str,
        metric: builtins.str,
        name: builtins.str,
        aggregator: typing.Optional[builtins.str] = None,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        is_normalized_cpu: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        limit: typing.Optional[jsii.Number] = None,
        sort: typing.Optional[builtins.str] = None,
        tag_filters: typing.Optional[typing.Sequence[builtins.str]] = None,
        text_filter: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param data_source: The data source for process queries. Valid values are ``process``, ``container``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param metric: The process metric name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        :param name: The name of query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param aggregator: The aggregation methods available for metrics queries. Valid values are ``avg``, ``min``, ``max``, ``sum``, ``last``, ``area``, ``l2norm``, ``percentile``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregator Powerpack#aggregator}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param is_normalized_cpu: Whether to normalize the CPU percentages. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#is_normalized_cpu Powerpack#is_normalized_cpu}
        :param limit: The number of hits to return. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param sort: The direction of the sort. Valid values are ``asc``, ``desc``. Defaults to ``"desc"``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort Powerpack#sort}
        :param tag_filters: An array of tags to filter by. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#tag_filters Powerpack#tag_filters}
        :param text_filter: The text to use as a filter. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#text_filter Powerpack#text_filter}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b5b6f1c78d195e4bfe7e8f56fe5ea1632820ac68a63b6c2028f403e7d382f126)
            check_type(argname="argument data_source", value=data_source, expected_type=type_hints["data_source"])
            check_type(argname="argument metric", value=metric, expected_type=type_hints["metric"])
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument aggregator", value=aggregator, expected_type=type_hints["aggregator"])
            check_type(argname="argument cross_org_uuids", value=cross_org_uuids, expected_type=type_hints["cross_org_uuids"])
            check_type(argname="argument is_normalized_cpu", value=is_normalized_cpu, expected_type=type_hints["is_normalized_cpu"])
            check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
            check_type(argname="argument sort", value=sort, expected_type=type_hints["sort"])
            check_type(argname="argument tag_filters", value=tag_filters, expected_type=type_hints["tag_filters"])
            check_type(argname="argument text_filter", value=text_filter, expected_type=type_hints["text_filter"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "data_source": data_source,
            "metric": metric,
            "name": name,
        }
        if aggregator is not None:
            self._values["aggregator"] = aggregator
        if cross_org_uuids is not None:
            self._values["cross_org_uuids"] = cross_org_uuids
        if is_normalized_cpu is not None:
            self._values["is_normalized_cpu"] = is_normalized_cpu
        if limit is not None:
            self._values["limit"] = limit
        if sort is not None:
            self._values["sort"] = sort
        if tag_filters is not None:
            self._values["tag_filters"] = tag_filters
        if text_filter is not None:
            self._values["text_filter"] = text_filter

    @builtins.property
    def data_source(self) -> builtins.str:
        '''The data source for process queries. Valid values are ``process``, ``container``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        '''
        result = self._values.get("data_source")
        assert result is not None, "Required property 'data_source' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def metric(self) -> builtins.str:
        '''The process metric name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        '''
        result = self._values.get("metric")
        assert result is not None, "Required property 'metric' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def name(self) -> builtins.str:
        '''The name of query for use in formulas.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        '''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def aggregator(self) -> typing.Optional[builtins.str]:
        '''The aggregation methods available for metrics queries. Valid values are ``avg``, ``min``, ``max``, ``sum``, ``last``, ``area``, ``l2norm``, ``percentile``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregator Powerpack#aggregator}
        '''
        result = self._values.get("aggregator")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def cross_org_uuids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''The source organization UUID for cross organization queries. Feature in Private Beta.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        '''
        result = self._values.get("cross_org_uuids")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def is_normalized_cpu(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        '''Whether to normalize the CPU percentages.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#is_normalized_cpu Powerpack#is_normalized_cpu}
        '''
        result = self._values.get("is_normalized_cpu")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)

    @builtins.property
    def limit(self) -> typing.Optional[jsii.Number]:
        '''The number of hits to return.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        '''
        result = self._values.get("limit")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def sort(self) -> typing.Optional[builtins.str]:
        '''The direction of the sort. Valid values are ``asc``, ``desc``. Defaults to ``"desc"``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort Powerpack#sort}
        '''
        result = self._values.get("sort")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def tag_filters(self) -> typing.Optional[typing.List[builtins.str]]:
        '''An array of tags to filter by.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#tag_filters Powerpack#tag_filters}
        '''
        result = self._values.get("tag_filters")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def text_filter(self) -> typing.Optional[builtins.str]:
        '''The text to use as a filter.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#text_filter Powerpack#text_filter}
        '''
        result = self._values.get("text_filter")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryValueDefinitionRequestQueryProcessQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetQueryValueDefinitionRequestQueryProcessQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestQueryProcessQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d9941fa8a6c3da3d4f4b6eadd4662d076c7f83ee89ec2a9346b883452091621d)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetAggregator")
    def reset_aggregator(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAggregator", []))

    @jsii.member(jsii_name="resetCrossOrgUuids")
    def reset_cross_org_uuids(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCrossOrgUuids", []))

    @jsii.member(jsii_name="resetIsNormalizedCpu")
    def reset_is_normalized_cpu(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetIsNormalizedCpu", []))

    @jsii.member(jsii_name="resetLimit")
    def reset_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLimit", []))

    @jsii.member(jsii_name="resetSort")
    def reset_sort(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSort", []))

    @jsii.member(jsii_name="resetTagFilters")
    def reset_tag_filters(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTagFilters", []))

    @jsii.member(jsii_name="resetTextFilter")
    def reset_text_filter(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTextFilter", []))

    @builtins.property
    @jsii.member(jsii_name="aggregatorInput")
    def aggregator_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregatorInput"))

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuidsInput")
    def cross_org_uuids_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "crossOrgUuidsInput"))

    @builtins.property
    @jsii.member(jsii_name="dataSourceInput")
    def data_source_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "dataSourceInput"))

    @builtins.property
    @jsii.member(jsii_name="isNormalizedCpuInput")
    def is_normalized_cpu_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "isNormalizedCpuInput"))

    @builtins.property
    @jsii.member(jsii_name="limitInput")
    def limit_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "limitInput"))

    @builtins.property
    @jsii.member(jsii_name="metricInput")
    def metric_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "metricInput"))

    @builtins.property
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property
    @jsii.member(jsii_name="sortInput")
    def sort_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "sortInput"))

    @builtins.property
    @jsii.member(jsii_name="tagFiltersInput")
    def tag_filters_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "tagFiltersInput"))

    @builtins.property
    @jsii.member(jsii_name="textFilterInput")
    def text_filter_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "textFilterInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregator")
    def aggregator(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregator"))

    @aggregator.setter
    def aggregator(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__911d852ad7a6eda7ffd5247066638a89b9e3d4e61ee78d41d9402762e6c4e6c4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregator", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuids")
    def cross_org_uuids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "crossOrgUuids"))

    @cross_org_uuids.setter
    def cross_org_uuids(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6e5a2c74a0ab3a21fbca7e2c4e0091e30df1c1434e99ef84a016330b46d96ded)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "crossOrgUuids", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="dataSource")
    def data_source(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "dataSource"))

    @data_source.setter
    def data_source(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fb353a32976a337a040bc7b358d7fac80dbdb3a183ddd2cdde57540912dfe4d1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "dataSource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="isNormalizedCpu")
    def is_normalized_cpu(
        self,
    ) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "isNormalizedCpu"))

    @is_normalized_cpu.setter
    def is_normalized_cpu(
        self,
        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__58ce44771290a974378fb362c0740d3bd585d02e240ea1db01f34e26eae1ce1a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "isNormalizedCpu", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="limit")
    def limit(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "limit"))

    @limit.setter
    def limit(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__76b6e9a82925bda7f32f51c7f76390e196327d9ef1da56cf54b97e51c9ac182e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "limit", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="metric")
    def metric(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "metric"))

    @metric.setter
    def metric(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d05814c23ff553bdd64f2685100cef9bef660004124c55303e5ddb2d51da3071)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "metric", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__47a54fe36350942ab0068c071ac12e7fb09ac336118abb8d3fa55a28468fe49f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "name", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="sort")
    def sort(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "sort"))

    @sort.setter
    def sort(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d37d95ee208bdbfc3df3f5ce719e5a02b26891251c580c1740a57c35bc93a88d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "sort", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="tagFilters")
    def tag_filters(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "tagFilters"))

    @tag_filters.setter
    def tag_filters(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b148190f7dc1b9995b9c84f43df127b45a581a48741e164cb28f87ea55ace1eb)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "tagFilters", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="textFilter")
    def text_filter(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "textFilter"))

    @text_filter.setter
    def text_filter(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ce2f06c98fb36cf8daed84ad2e5f99ce196056d557fd60b6271bac973c3c9b53)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "textFilter", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetQueryValueDefinitionRequestQueryProcessQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryValueDefinitionRequestQueryProcessQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetQueryValueDefinitionRequestQueryProcessQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0a9ef981c1a0c81259e150ee9c9547a6679bb71d11898f0ea093bc2a292ea1d8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestQuerySloQuery",
    jsii_struct_bases=[],
    name_mapping={
        "data_source": "dataSource",
        "measure": "measure",
        "slo_id": "sloId",
        "additional_query_filters": "additionalQueryFilters",
        "cross_org_uuids": "crossOrgUuids",
        "group_mode": "groupMode",
        "name": "name",
        "slo_query_type": "sloQueryType",
    },
)
class PowerpackWidgetQueryValueDefinitionRequestQuerySloQuery:
    def __init__(
        self,
        *,
        data_source: builtins.str,
        measure: builtins.str,
        slo_id: builtins.str,
        additional_query_filters: typing.Optional[builtins.str] = None,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        group_mode: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
        slo_query_type: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param data_source: The data source for SLO queries. Valid values are ``slo``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param measure: SLO measures queries. Valid values are ``good_events``, ``bad_events``, ``good_minutes``, ``bad_minutes``, ``slo_status``, ``error_budget_remaining``, ``burn_rate``, ``error_budget_burndown``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#measure Powerpack#measure}
        :param slo_id: ID of an SLO to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#slo_id Powerpack#slo_id}
        :param additional_query_filters: Additional filters applied to the SLO query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#additional_query_filters Powerpack#additional_query_filters}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param group_mode: Group mode to query measures. Valid values are ``overall``, ``components``. Defaults to ``"overall"``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_mode Powerpack#group_mode}
        :param name: The name of query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param slo_query_type: type of the SLO to query. Valid values are ``metric``, ``monitor``, ``time_slice``. Defaults to ``"metric"``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#slo_query_type Powerpack#slo_query_type}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7e8ac8125fb20380f1860f4a5a0f7e93961142f43141ecd24c1256f55009ccc2)
            check_type(argname="argument data_source", value=data_source, expected_type=type_hints["data_source"])
            check_type(argname="argument measure", value=measure, expected_type=type_hints["measure"])
            check_type(argname="argument slo_id", value=slo_id, expected_type=type_hints["slo_id"])
            check_type(argname="argument additional_query_filters", value=additional_query_filters, expected_type=type_hints["additional_query_filters"])
            check_type(argname="argument cross_org_uuids", value=cross_org_uuids, expected_type=type_hints["cross_org_uuids"])
            check_type(argname="argument group_mode", value=group_mode, expected_type=type_hints["group_mode"])
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument slo_query_type", value=slo_query_type, expected_type=type_hints["slo_query_type"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "data_source": data_source,
            "measure": measure,
            "slo_id": slo_id,
        }
        if additional_query_filters is not None:
            self._values["additional_query_filters"] = additional_query_filters
        if cross_org_uuids is not None:
            self._values["cross_org_uuids"] = cross_org_uuids
        if group_mode is not None:
            self._values["group_mode"] = group_mode
        if name is not None:
            self._values["name"] = name
        if slo_query_type is not None:
            self._values["slo_query_type"] = slo_query_type

    @builtins.property
    def data_source(self) -> builtins.str:
        '''The data source for SLO queries. Valid values are ``slo``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        '''
        result = self._values.get("data_source")
        assert result is not None, "Required property 'data_source' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def measure(self) -> builtins.str:
        '''SLO measures queries. Valid values are ``good_events``, ``bad_events``, ``good_minutes``, ``bad_minutes``, ``slo_status``, ``error_budget_remaining``, ``burn_rate``, ``error_budget_burndown``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#measure Powerpack#measure}
        '''
        result = self._values.get("measure")
        assert result is not None, "Required property 'measure' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def slo_id(self) -> builtins.str:
        '''ID of an SLO to query.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#slo_id Powerpack#slo_id}
        '''
        result = self._values.get("slo_id")
        assert result is not None, "Required property 'slo_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def additional_query_filters(self) -> typing.Optional[builtins.str]:
        '''Additional filters applied to the SLO query.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#additional_query_filters Powerpack#additional_query_filters}
        '''
        result = self._values.get("additional_query_filters")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def cross_org_uuids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''The source organization UUID for cross organization queries. Feature in Private Beta.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        '''
        result = self._values.get("cross_org_uuids")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def group_mode(self) -> typing.Optional[builtins.str]:
        '''Group mode to query measures. Valid values are ``overall``, ``components``. Defaults to ``"overall"``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_mode Powerpack#group_mode}
        '''
        result = self._values.get("group_mode")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''The name of query for use in formulas.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        '''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def slo_query_type(self) -> typing.Optional[builtins.str]:
        '''type of the SLO to query. Valid values are ``metric``, ``monitor``, ``time_slice``. Defaults to ``"metric"``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#slo_query_type Powerpack#slo_query_type}
        '''
        result = self._values.get("slo_query_type")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryValueDefinitionRequestQuerySloQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetQueryValueDefinitionRequestQuerySloQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestQuerySloQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bca184e64bc61cf509f30660ee5c695024889ad04670ae984a450d731fe733f1)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetAdditionalQueryFilters")
    def reset_additional_query_filters(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAdditionalQueryFilters", []))

    @jsii.member(jsii_name="resetCrossOrgUuids")
    def reset_cross_org_uuids(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCrossOrgUuids", []))

    @jsii.member(jsii_name="resetGroupMode")
    def reset_group_mode(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGroupMode", []))

    @jsii.member(jsii_name="resetName")
    def reset_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetName", []))

    @jsii.member(jsii_name="resetSloQueryType")
    def reset_slo_query_type(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSloQueryType", []))

    @builtins.property
    @jsii.member(jsii_name="additionalQueryFiltersInput")
    def additional_query_filters_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "additionalQueryFiltersInput"))

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuidsInput")
    def cross_org_uuids_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "crossOrgUuidsInput"))

    @builtins.property
    @jsii.member(jsii_name="dataSourceInput")
    def data_source_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "dataSourceInput"))

    @builtins.property
    @jsii.member(jsii_name="groupModeInput")
    def group_mode_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "groupModeInput"))

    @builtins.property
    @jsii.member(jsii_name="measureInput")
    def measure_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "measureInput"))

    @builtins.property
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property
    @jsii.member(jsii_name="sloIdInput")
    def slo_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "sloIdInput"))

    @builtins.property
    @jsii.member(jsii_name="sloQueryTypeInput")
    def slo_query_type_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "sloQueryTypeInput"))

    @builtins.property
    @jsii.member(jsii_name="additionalQueryFilters")
    def additional_query_filters(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "additionalQueryFilters"))

    @additional_query_filters.setter
    def additional_query_filters(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__61c1ff364c824656065f4a1b62767d817ae473a10131b273a49d305776815f17)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "additionalQueryFilters", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuids")
    def cross_org_uuids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "crossOrgUuids"))

    @cross_org_uuids.setter
    def cross_org_uuids(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e8d6148e2b5c15b5bce68f100309ee9d0d7d8de65f60fd74538a0ba018e8b5ed)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "crossOrgUuids", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="dataSource")
    def data_source(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "dataSource"))

    @data_source.setter
    def data_source(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f59d641fde0457a298a0c6acc1f08a61e33229015d4c673ecb99dbb347efb29b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "dataSource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="groupMode")
    def group_mode(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "groupMode"))

    @group_mode.setter
    def group_mode(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__492eb2ef04e8470fb452b90eafb5acfb6f0358bc7a574c31c9be513b3f300e13)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "groupMode", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="measure")
    def measure(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "measure"))

    @measure.setter
    def measure(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a3ab408a128fc16b9693ea9c23e224ae27df3fd0f877286071259c2803962460)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "measure", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__91e453d484c4c21dbdf027b4ce284a044283479ad8548a0102d9f0a04eaa2f67)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "name", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="sloId")
    def slo_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "sloId"))

    @slo_id.setter
    def slo_id(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3866101c0175b8965d61d377776f4b5035272e2120a12563e0b119346c55e59a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "sloId", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="sloQueryType")
    def slo_query_type(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "sloQueryType"))

    @slo_query_type.setter
    def slo_query_type(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8ba178222b38a5524295737519d24a1af6f1c47f4daea45a5901cbe5619ccd63)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "sloQueryType", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetQueryValueDefinitionRequestQuerySloQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryValueDefinitionRequestQuerySloQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetQueryValueDefinitionRequestQuerySloQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3e95d82f2a7d93ced31c1e87e79e569acac43fc0ac7b41a68404fdbf4bab031d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestRumQuery",
    jsii_struct_bases=[],
    name_mapping={
        "index": "index",
        "compute_query": "computeQuery",
        "group_by": "groupBy",
        "multi_compute": "multiCompute",
        "search_query": "searchQuery",
    },
)
class PowerpackWidgetQueryValueDefinitionRequestRumQuery:
    def __init__(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union["PowerpackWidgetQueryValueDefinitionRequestRumQueryComputeQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetQueryValueDefinitionRequestRumQueryGroupBy", typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetQueryValueDefinitionRequestRumQueryMultiCompute", typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        if isinstance(compute_query, dict):
            compute_query = PowerpackWidgetQueryValueDefinitionRequestRumQueryComputeQuery(**compute_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a2f05e0062e9d5027803d93abe6f450dd7d3f7df322cde557c58eaeb5c4f2bd6)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
            check_type(argname="argument compute_query", value=compute_query, expected_type=type_hints["compute_query"])
            check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
            check_type(argname="argument multi_compute", value=multi_compute, expected_type=type_hints["multi_compute"])
            check_type(argname="argument search_query", value=search_query, expected_type=type_hints["search_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "index": index,
        }
        if compute_query is not None:
            self._values["compute_query"] = compute_query
        if group_by is not None:
            self._values["group_by"] = group_by
        if multi_compute is not None:
            self._values["multi_compute"] = multi_compute
        if search_query is not None:
            self._values["search_query"] = search_query

    @builtins.property
    def index(self) -> builtins.str:
        '''The name of the index to query.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        '''
        result = self._values.get("index")
        assert result is not None, "Required property 'index' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def compute_query(
        self,
    ) -> typing.Optional["PowerpackWidgetQueryValueDefinitionRequestRumQueryComputeQuery"]:
        '''compute_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        '''
        result = self._values.get("compute_query")
        return typing.cast(typing.Optional["PowerpackWidgetQueryValueDefinitionRequestRumQueryComputeQuery"], result)

    @builtins.property
    def group_by(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetQueryValueDefinitionRequestRumQueryGroupBy"]]]:
        '''group_by block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        '''
        result = self._values.get("group_by")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetQueryValueDefinitionRequestRumQueryGroupBy"]]], result)

    @builtins.property
    def multi_compute(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetQueryValueDefinitionRequestRumQueryMultiCompute"]]]:
        '''multi_compute block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        '''
        result = self._values.get("multi_compute")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetQueryValueDefinitionRequestRumQueryMultiCompute"]]], result)

    @builtins.property
    def search_query(self) -> typing.Optional[builtins.str]:
        '''The search query to use.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        result = self._values.get("search_query")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryValueDefinitionRequestRumQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestRumQueryComputeQuery",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetQueryValueDefinitionRequestRumQueryComputeQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b11a5dc8808be7d7b4084d0c460143ac7670e97800287c049ae42763964f9115)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryValueDefinitionRequestRumQueryComputeQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetQueryValueDefinitionRequestRumQueryComputeQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestRumQueryComputeQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9a59c66ea74e556b240f5735b76219970cea655ac9d7b1c6b972d76a7330767e)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c29829addd78221cd8eb42287c588721b5f4a498b33071d4534bf0450b032016)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bedc4f1a44f1c4ac957f40de264243f213c518ddb8720dd5b1923d24e3ec781b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9734c50954fb64fbebc661d7b42557e25fe6cb9b9b4908f19085a6e3938fe012)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetQueryValueDefinitionRequestRumQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryValueDefinitionRequestRumQueryComputeQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetQueryValueDefinitionRequestRumQueryComputeQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1b0e3c9283ada1bb9fa8e22570872cfe737f00b8bf3db7870ee544be81327c0c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestRumQueryGroupBy",
    jsii_struct_bases=[],
    name_mapping={"facet": "facet", "limit": "limit", "sort_query": "sortQuery"},
)
class PowerpackWidgetQueryValueDefinitionRequestRumQueryGroupBy:
    def __init__(
        self,
        *,
        facet: typing.Optional[builtins.str] = None,
        limit: typing.Optional[jsii.Number] = None,
        sort_query: typing.Optional[typing.Union["PowerpackWidgetQueryValueDefinitionRequestRumQueryGroupBySortQuery", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param limit: The maximum number of items in the group. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param sort_query: sort_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        if isinstance(sort_query, dict):
            sort_query = PowerpackWidgetQueryValueDefinitionRequestRumQueryGroupBySortQuery(**sort_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5fb884831a39675b65f894580b8f436a3487ffb4b24c7b58144f23765d234172)
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
            check_type(argname="argument sort_query", value=sort_query, expected_type=type_hints["sort_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if facet is not None:
            self._values["facet"] = facet
        if limit is not None:
            self._values["limit"] = limit
        if sort_query is not None:
            self._values["sort_query"] = sort_query

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def limit(self) -> typing.Optional[jsii.Number]:
        '''The maximum number of items in the group.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        '''
        result = self._values.get("limit")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def sort_query(
        self,
    ) -> typing.Optional["PowerpackWidgetQueryValueDefinitionRequestRumQueryGroupBySortQuery"]:
        '''sort_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        result = self._values.get("sort_query")
        return typing.cast(typing.Optional["PowerpackWidgetQueryValueDefinitionRequestRumQueryGroupBySortQuery"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryValueDefinitionRequestRumQueryGroupBy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetQueryValueDefinitionRequestRumQueryGroupByList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestRumQueryGroupByList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__efead7a16c6e9d5eae9797b3735a7592fd8a8d9a444ac598912012d2c0f43743)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetQueryValueDefinitionRequestRumQueryGroupByOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1bf270630cc3c0d6c3163d8d407d6fe00ab5e47d85b11800373a01b2cfc9c08c)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetQueryValueDefinitionRequestRumQueryGroupByOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9fc18a77104e398e207fda291cae9ed254586137bb57f6149692fb235b4b6590)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a3b3bdce9aff057700af86f423d85e7c2226a5d08f8918a7ae60ef32c6a57ab8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4cef083d561903285113d66f607c17c1c40c8d393eef328805e30b0f19811a72)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionRequestRumQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionRequestRumQueryGroupBy]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionRequestRumQueryGroupBy]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2080aba88fa2418969ee31197a53fa3d7cec4f19a7e1b13d812e81ff9458d849)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetQueryValueDefinitionRequestRumQueryGroupByOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestRumQueryGroupByOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__41f04e80a751bcdf9dd3b193c9fd3f0b744d995b43df726cf1caec23ec02bfce)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putSortQuery")
    def put_sort_query(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        value = PowerpackWidgetQueryValueDefinitionRequestRumQueryGroupBySortQuery(
            aggregation=aggregation, order=order, facet=facet
        )

        return typing.cast(None, jsii.invoke(self, "putSortQuery", [value]))

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetLimit")
    def reset_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLimit", []))

    @jsii.member(jsii_name="resetSortQuery")
    def reset_sort_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSortQuery", []))

    @builtins.property
    @jsii.member(jsii_name="sortQuery")
    def sort_query(
        self,
    ) -> "PowerpackWidgetQueryValueDefinitionRequestRumQueryGroupBySortQueryOutputReference":
        return typing.cast("PowerpackWidgetQueryValueDefinitionRequestRumQueryGroupBySortQueryOutputReference", jsii.get(self, "sortQuery"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="limitInput")
    def limit_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "limitInput"))

    @builtins.property
    @jsii.member(jsii_name="sortQueryInput")
    def sort_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetQueryValueDefinitionRequestRumQueryGroupBySortQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetQueryValueDefinitionRequestRumQueryGroupBySortQuery"], jsii.get(self, "sortQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5642af0eb5bbbee384f9ad02beac309f34072cf9762c8069d58eb020c261f2c4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="limit")
    def limit(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "limit"))

    @limit.setter
    def limit(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__07210c0d3b2b6001ab94012e733da904722a8fbc4045fa218e9ae5a53e35359d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "limit", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryValueDefinitionRequestRumQueryGroupBy]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryValueDefinitionRequestRumQueryGroupBy]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryValueDefinitionRequestRumQueryGroupBy]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8f3472765585136e3281178632fd5f12bdd1a1bbad37d5a6f80d8001b209b9e1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestRumQueryGroupBySortQuery",
    jsii_struct_bases=[],
    name_mapping={"aggregation": "aggregation", "order": "order", "facet": "facet"},
)
class PowerpackWidgetQueryValueDefinitionRequestRumQueryGroupBySortQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cc51cfe33fd866b587a6540d85d55a078ae895347a2ebada3df46cccc3e8559b)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument order", value=order, expected_type=type_hints["order"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
            "order": order,
        }
        if facet is not None:
            self._values["facet"] = facet

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def order(self) -> builtins.str:
        '''Widget sorting methods. Valid values are ``asc``, ``desc``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        result = self._values.get("order")
        assert result is not None, "Required property 'order' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryValueDefinitionRequestRumQueryGroupBySortQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetQueryValueDefinitionRequestRumQueryGroupBySortQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestRumQueryGroupBySortQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__974c54782208a7495a1cd48d4c4614c7da680f1dd3c1b095a690e4b2da45721f)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="orderInput")
    def order_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "orderInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e3e3e4c3fadf90643e33337c31e6db5c780abe1b03435669dda5fe4b22af600e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__09785c1fcc2cfa778d0a34543d3a5545f7b83f41f9b20e2437af00aeee7d9559)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="order")
    def order(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "order"))

    @order.setter
    def order(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9a1ed1f9f8b9bab160b72fd4d5952766e3df00acbc1e10dbda6d7d82b70d5616)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "order", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetQueryValueDefinitionRequestRumQueryGroupBySortQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryValueDefinitionRequestRumQueryGroupBySortQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetQueryValueDefinitionRequestRumQueryGroupBySortQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b8856cd8ef330d3f5d2b1e07baa35d7b866ad127642f3f8cb0515f87e711054e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestRumQueryMultiCompute",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetQueryValueDefinitionRequestRumQueryMultiCompute:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__545679c8a91a63346e1f5804aca3fcd8325234617a183320e8faded413862609)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryValueDefinitionRequestRumQueryMultiCompute(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetQueryValueDefinitionRequestRumQueryMultiComputeList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestRumQueryMultiComputeList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f131465cf167124ca0c133289a4f177483952612fceaadcae9f77badfcf74b0b)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetQueryValueDefinitionRequestRumQueryMultiComputeOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6871a370f33117787dbda4eb05e91405f0b3352c12cc3ae18da1d4a3d0cd4c88)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetQueryValueDefinitionRequestRumQueryMultiComputeOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__72106daeadb7e3249e9b21de9c48cbd7e57a9998eb643f94077a9af5c4b00a7d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__146ec8b91af6be8179b33272dc1ad1c0b2d39efadbb5a4c627c009eaa99c74f3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8000c3f90fcd39ca69bcbddb2b7bf155b0b0c8d9f6104b92d32c885b0cab43c3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionRequestRumQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionRequestRumQueryMultiCompute]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionRequestRumQueryMultiCompute]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__38701e00a4b6ed9cd990605bb9a5fa2dc362172047e48a5715fe444f0304a5be)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetQueryValueDefinitionRequestRumQueryMultiComputeOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestRumQueryMultiComputeOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6f7e6f414f8b85137428446283e066d7679f917e34ff29016ce92e07762f1b9e)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9d97bbb05a28b28f08248d3443d300a597be0bc21b271278288da6081a23579e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2771da955efc56f966fd1556aab7803796d0c508a3fc4b68d42697d8e06cdb98)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__efa9ba626689c9cd702655afee12d11d499edbee6ac8faf3e2abdd39ecfc709f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryValueDefinitionRequestRumQueryMultiCompute]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryValueDefinitionRequestRumQueryMultiCompute]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryValueDefinitionRequestRumQueryMultiCompute]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a52e185ff0f4204a7e6ae8939bbcff28169371b2a63171f269f501831f699713)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetQueryValueDefinitionRequestRumQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestRumQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__aa44c59cee0d757d4124a1118fa68d599c5a184293be876644b5f311771b3061)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putComputeQuery")
    def put_compute_query(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        value = PowerpackWidgetQueryValueDefinitionRequestRumQueryComputeQuery(
            aggregation=aggregation, facet=facet, interval=interval
        )

        return typing.cast(None, jsii.invoke(self, "putComputeQuery", [value]))

    @jsii.member(jsii_name="putGroupBy")
    def put_group_by(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryValueDefinitionRequestRumQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ea68325b6a1b4b266ad7ee3a12a6228d992d42a3b444f46787ab28e0edf66051)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putGroupBy", [value]))

    @jsii.member(jsii_name="putMultiCompute")
    def put_multi_compute(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryValueDefinitionRequestRumQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dad2cfacd5bd14362a606318985e504d5018c3ac48871e7d59be771e547e72fb)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putMultiCompute", [value]))

    @jsii.member(jsii_name="resetComputeQuery")
    def reset_compute_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetComputeQuery", []))

    @jsii.member(jsii_name="resetGroupBy")
    def reset_group_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGroupBy", []))

    @jsii.member(jsii_name="resetMultiCompute")
    def reset_multi_compute(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMultiCompute", []))

    @jsii.member(jsii_name="resetSearchQuery")
    def reset_search_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSearchQuery", []))

    @builtins.property
    @jsii.member(jsii_name="computeQuery")
    def compute_query(
        self,
    ) -> PowerpackWidgetQueryValueDefinitionRequestRumQueryComputeQueryOutputReference:
        return typing.cast(PowerpackWidgetQueryValueDefinitionRequestRumQueryComputeQueryOutputReference, jsii.get(self, "computeQuery"))

    @builtins.property
    @jsii.member(jsii_name="groupBy")
    def group_by(self) -> PowerpackWidgetQueryValueDefinitionRequestRumQueryGroupByList:
        return typing.cast(PowerpackWidgetQueryValueDefinitionRequestRumQueryGroupByList, jsii.get(self, "groupBy"))

    @builtins.property
    @jsii.member(jsii_name="multiCompute")
    def multi_compute(
        self,
    ) -> PowerpackWidgetQueryValueDefinitionRequestRumQueryMultiComputeList:
        return typing.cast(PowerpackWidgetQueryValueDefinitionRequestRumQueryMultiComputeList, jsii.get(self, "multiCompute"))

    @builtins.property
    @jsii.member(jsii_name="computeQueryInput")
    def compute_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetQueryValueDefinitionRequestRumQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryValueDefinitionRequestRumQueryComputeQuery], jsii.get(self, "computeQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="groupByInput")
    def group_by_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionRequestRumQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionRequestRumQueryGroupBy]]], jsii.get(self, "groupByInput"))

    @builtins.property
    @jsii.member(jsii_name="indexInput")
    def index_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "indexInput"))

    @builtins.property
    @jsii.member(jsii_name="multiComputeInput")
    def multi_compute_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionRequestRumQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionRequestRumQueryMultiCompute]]], jsii.get(self, "multiComputeInput"))

    @builtins.property
    @jsii.member(jsii_name="searchQueryInput")
    def search_query_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "searchQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="index")
    def index(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "index"))

    @index.setter
    def index(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__594f322ec92b34e5c99b5f08eb685b263ccb42abbe874cbbf43bd84e585d6017)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "index", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="searchQuery")
    def search_query(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "searchQuery"))

    @search_query.setter
    def search_query(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f47ddab18c6b3180ea5d5628afb92603d829173ec2006db18ab44fa7a9664f17)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "searchQuery", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetQueryValueDefinitionRequestRumQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryValueDefinitionRequestRumQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetQueryValueDefinitionRequestRumQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4c0813d7568c758982c0577444df0bcf777582532400cce26e330500b746ebb3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestSecurityQuery",
    jsii_struct_bases=[],
    name_mapping={
        "index": "index",
        "compute_query": "computeQuery",
        "group_by": "groupBy",
        "multi_compute": "multiCompute",
        "search_query": "searchQuery",
    },
)
class PowerpackWidgetQueryValueDefinitionRequestSecurityQuery:
    def __init__(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union["PowerpackWidgetQueryValueDefinitionRequestSecurityQueryComputeQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetQueryValueDefinitionRequestSecurityQueryGroupBy", typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetQueryValueDefinitionRequestSecurityQueryMultiCompute", typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        if isinstance(compute_query, dict):
            compute_query = PowerpackWidgetQueryValueDefinitionRequestSecurityQueryComputeQuery(**compute_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b2d0e9236761f8712b6d4e1ee03b2774af0c5a4cfeffe87eefbe00025cdfb450)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
            check_type(argname="argument compute_query", value=compute_query, expected_type=type_hints["compute_query"])
            check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
            check_type(argname="argument multi_compute", value=multi_compute, expected_type=type_hints["multi_compute"])
            check_type(argname="argument search_query", value=search_query, expected_type=type_hints["search_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "index": index,
        }
        if compute_query is not None:
            self._values["compute_query"] = compute_query
        if group_by is not None:
            self._values["group_by"] = group_by
        if multi_compute is not None:
            self._values["multi_compute"] = multi_compute
        if search_query is not None:
            self._values["search_query"] = search_query

    @builtins.property
    def index(self) -> builtins.str:
        '''The name of the index to query.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        '''
        result = self._values.get("index")
        assert result is not None, "Required property 'index' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def compute_query(
        self,
    ) -> typing.Optional["PowerpackWidgetQueryValueDefinitionRequestSecurityQueryComputeQuery"]:
        '''compute_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        '''
        result = self._values.get("compute_query")
        return typing.cast(typing.Optional["PowerpackWidgetQueryValueDefinitionRequestSecurityQueryComputeQuery"], result)

    @builtins.property
    def group_by(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetQueryValueDefinitionRequestSecurityQueryGroupBy"]]]:
        '''group_by block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        '''
        result = self._values.get("group_by")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetQueryValueDefinitionRequestSecurityQueryGroupBy"]]], result)

    @builtins.property
    def multi_compute(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetQueryValueDefinitionRequestSecurityQueryMultiCompute"]]]:
        '''multi_compute block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        '''
        result = self._values.get("multi_compute")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetQueryValueDefinitionRequestSecurityQueryMultiCompute"]]], result)

    @builtins.property
    def search_query(self) -> typing.Optional[builtins.str]:
        '''The search query to use.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        result = self._values.get("search_query")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryValueDefinitionRequestSecurityQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestSecurityQueryComputeQuery",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetQueryValueDefinitionRequestSecurityQueryComputeQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__34253fb2198fae930eecea4c83e15984e514e534fe574abb429f94a6d4789dad)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryValueDefinitionRequestSecurityQueryComputeQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetQueryValueDefinitionRequestSecurityQueryComputeQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestSecurityQueryComputeQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7538f667f134aebc56dc788a15175285dd756f414c17a81e5eadb0c1ccbd7efb)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__67caf903fa7cd0eccb4a88d18893d66bbabd6b9196ff36e0c2808e8ba7141f9d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__02aa9c11240953fbc1558a66376a8423ea6212b42e2181a12d26b35a01495db1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__308379c2be08cf384c9194c27227ea2073509b11cd8e32a17b0b102e9f1381a8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetQueryValueDefinitionRequestSecurityQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryValueDefinitionRequestSecurityQueryComputeQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetQueryValueDefinitionRequestSecurityQueryComputeQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__31c475dddd7b80f62653490b2846f654d7a14d4b021595ea45eb6fbea06647ff)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestSecurityQueryGroupBy",
    jsii_struct_bases=[],
    name_mapping={"facet": "facet", "limit": "limit", "sort_query": "sortQuery"},
)
class PowerpackWidgetQueryValueDefinitionRequestSecurityQueryGroupBy:
    def __init__(
        self,
        *,
        facet: typing.Optional[builtins.str] = None,
        limit: typing.Optional[jsii.Number] = None,
        sort_query: typing.Optional[typing.Union["PowerpackWidgetQueryValueDefinitionRequestSecurityQueryGroupBySortQuery", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param limit: The maximum number of items in the group. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param sort_query: sort_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        if isinstance(sort_query, dict):
            sort_query = PowerpackWidgetQueryValueDefinitionRequestSecurityQueryGroupBySortQuery(**sort_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__88174f669e16c140f59517cf9ef6248f96e5ff15203827f79d2ea70fa20a4df6)
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
            check_type(argname="argument sort_query", value=sort_query, expected_type=type_hints["sort_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if facet is not None:
            self._values["facet"] = facet
        if limit is not None:
            self._values["limit"] = limit
        if sort_query is not None:
            self._values["sort_query"] = sort_query

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def limit(self) -> typing.Optional[jsii.Number]:
        '''The maximum number of items in the group.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        '''
        result = self._values.get("limit")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def sort_query(
        self,
    ) -> typing.Optional["PowerpackWidgetQueryValueDefinitionRequestSecurityQueryGroupBySortQuery"]:
        '''sort_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        result = self._values.get("sort_query")
        return typing.cast(typing.Optional["PowerpackWidgetQueryValueDefinitionRequestSecurityQueryGroupBySortQuery"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryValueDefinitionRequestSecurityQueryGroupBy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetQueryValueDefinitionRequestSecurityQueryGroupByList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestSecurityQueryGroupByList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b4f88af8c40e5c05e31d7dda99c21764b157ff723b176398c04e4dc1b6911317)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetQueryValueDefinitionRequestSecurityQueryGroupByOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b2b6a170b6cc34720907f41f84598a3ef5c9bc96afce6d986adeaa52f40f2184)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetQueryValueDefinitionRequestSecurityQueryGroupByOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f3092dde51cce3359bf6bf185774accb91f561d2a331007d05bf61666106b91e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f8d002e29398ebdcaf2e07536e179050218bb94298e148aee6996322cfd376a1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__74ec8fbd06810dad9deebef00b5464439d7323d2dc15cefd9349a09af651e812)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionRequestSecurityQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionRequestSecurityQueryGroupBy]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionRequestSecurityQueryGroupBy]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b473556bfba5929bbd4263e5ea066b68f168f642d83a6405b118603da915da49)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetQueryValueDefinitionRequestSecurityQueryGroupByOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestSecurityQueryGroupByOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__426d29516ceb51f3740171bc17e77b1ac389c25e6f1a39eb2e05802c2a585c47)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putSortQuery")
    def put_sort_query(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        value = PowerpackWidgetQueryValueDefinitionRequestSecurityQueryGroupBySortQuery(
            aggregation=aggregation, order=order, facet=facet
        )

        return typing.cast(None, jsii.invoke(self, "putSortQuery", [value]))

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetLimit")
    def reset_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLimit", []))

    @jsii.member(jsii_name="resetSortQuery")
    def reset_sort_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSortQuery", []))

    @builtins.property
    @jsii.member(jsii_name="sortQuery")
    def sort_query(
        self,
    ) -> "PowerpackWidgetQueryValueDefinitionRequestSecurityQueryGroupBySortQueryOutputReference":
        return typing.cast("PowerpackWidgetQueryValueDefinitionRequestSecurityQueryGroupBySortQueryOutputReference", jsii.get(self, "sortQuery"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="limitInput")
    def limit_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "limitInput"))

    @builtins.property
    @jsii.member(jsii_name="sortQueryInput")
    def sort_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetQueryValueDefinitionRequestSecurityQueryGroupBySortQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetQueryValueDefinitionRequestSecurityQueryGroupBySortQuery"], jsii.get(self, "sortQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c661a11e3a831635426dd92e83fccdf9683802473c2acab06681b67ed7ad6642)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="limit")
    def limit(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "limit"))

    @limit.setter
    def limit(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3bd1a728b11ce3d130789b487408c3eb32822fae53a1cc729ea497eeb9beeef5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "limit", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryValueDefinitionRequestSecurityQueryGroupBy]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryValueDefinitionRequestSecurityQueryGroupBy]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryValueDefinitionRequestSecurityQueryGroupBy]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4d793a119b51986fe36a1c33b79f34448bd8230ae9a8840ebb20f93b41f27c6d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestSecurityQueryGroupBySortQuery",
    jsii_struct_bases=[],
    name_mapping={"aggregation": "aggregation", "order": "order", "facet": "facet"},
)
class PowerpackWidgetQueryValueDefinitionRequestSecurityQueryGroupBySortQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f27fd8da6e7dcdf099c858b74ad9c5dc4244419a9d9018d2ce75563c11308fe8)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument order", value=order, expected_type=type_hints["order"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
            "order": order,
        }
        if facet is not None:
            self._values["facet"] = facet

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def order(self) -> builtins.str:
        '''Widget sorting methods. Valid values are ``asc``, ``desc``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        result = self._values.get("order")
        assert result is not None, "Required property 'order' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryValueDefinitionRequestSecurityQueryGroupBySortQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetQueryValueDefinitionRequestSecurityQueryGroupBySortQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestSecurityQueryGroupBySortQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__99920275b613216b49f95c940e0508bec5eadecec93714528db1b3d174ce7b3f)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="orderInput")
    def order_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "orderInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5a36678d2a144e3a04b7daec203ac61b09470c963adf5819f68c3cc84fcc00cd)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ebe73c7b024c0f04abce1dc8e33c8c1e33b05cc0dcf4cf482b9686faa972c650)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="order")
    def order(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "order"))

    @order.setter
    def order(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c25ca72636fddc071b3748e989c99cb2acd00abeef9074fd040aa6ad61c2ce88)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "order", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetQueryValueDefinitionRequestSecurityQueryGroupBySortQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryValueDefinitionRequestSecurityQueryGroupBySortQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetQueryValueDefinitionRequestSecurityQueryGroupBySortQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8b0a48b76fe907abc17decbb84ac3bb98bffdfa2dbdd8bf395e72540e3936bde)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestSecurityQueryMultiCompute",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetQueryValueDefinitionRequestSecurityQueryMultiCompute:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8668a910d4d62a71d16cd4e3d696c39cd3333a40fe4f8081e8837753e0a8e1bb)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryValueDefinitionRequestSecurityQueryMultiCompute(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetQueryValueDefinitionRequestSecurityQueryMultiComputeList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestSecurityQueryMultiComputeList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__58a9b0dee9ba85a4c4b73c79b1de6e038359bf1f583e8b59c6e8bce8db583451)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetQueryValueDefinitionRequestSecurityQueryMultiComputeOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__37e688d1a844ea73caeb3c4e0c5d5152edbd5d6e02c150876762e9c88bfde407)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetQueryValueDefinitionRequestSecurityQueryMultiComputeOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fa0b92281d8b55b35835bafd1851ff291faa7cd07ad0b5d76bfccad92fc5fe14)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1a2e1e187520ececfe9b015f195414c46de071b29a1108cb4eed2be23e00b51b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2396afa5f93fcf767abfb2d542450f1026d5d389a4cdb1661402e63ada0acc4f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionRequestSecurityQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionRequestSecurityQueryMultiCompute]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionRequestSecurityQueryMultiCompute]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__99aff0597e2948fc8543abb4949ec09aeda1606a02994820fefd847b592c1916)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetQueryValueDefinitionRequestSecurityQueryMultiComputeOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestSecurityQueryMultiComputeOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6980835a4f0c89e629c757aacb3182fb8cc6a471d7d8f92f88127d02e91b8d11)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ee7ea4264f49ad4ff6037203d0b6d747539c115d64d98bd657c720faf2df99f2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ca61c59ae7d42649af520e3c2ac9b72e588d9e6defc7e5bac450345485339639)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3b62bef07f7e3746e6e43d09f77b48c9dc5b3d78a818dcba1fa6be8c9a69a0f6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryValueDefinitionRequestSecurityQueryMultiCompute]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryValueDefinitionRequestSecurityQueryMultiCompute]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryValueDefinitionRequestSecurityQueryMultiCompute]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__20b35d9468077f96722388ba46e3b2dfa185ea571f314309480b1aaf2a8c0f16)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetQueryValueDefinitionRequestSecurityQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionRequestSecurityQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ebee6fe858dc874c486e725a122aa6cc68d071e73628f26d677caa2f4d3f4921)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putComputeQuery")
    def put_compute_query(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        value = PowerpackWidgetQueryValueDefinitionRequestSecurityQueryComputeQuery(
            aggregation=aggregation, facet=facet, interval=interval
        )

        return typing.cast(None, jsii.invoke(self, "putComputeQuery", [value]))

    @jsii.member(jsii_name="putGroupBy")
    def put_group_by(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryValueDefinitionRequestSecurityQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__372fa5a65810eebd9b8b465f65bbb798a0cf2a7b7b18f96fadf8905c009890c9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putGroupBy", [value]))

    @jsii.member(jsii_name="putMultiCompute")
    def put_multi_compute(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryValueDefinitionRequestSecurityQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a7f160171783e74cc215dfbb2f5bd428f9d2ed92d251c4a233cb86a711d957d8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putMultiCompute", [value]))

    @jsii.member(jsii_name="resetComputeQuery")
    def reset_compute_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetComputeQuery", []))

    @jsii.member(jsii_name="resetGroupBy")
    def reset_group_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGroupBy", []))

    @jsii.member(jsii_name="resetMultiCompute")
    def reset_multi_compute(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMultiCompute", []))

    @jsii.member(jsii_name="resetSearchQuery")
    def reset_search_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSearchQuery", []))

    @builtins.property
    @jsii.member(jsii_name="computeQuery")
    def compute_query(
        self,
    ) -> PowerpackWidgetQueryValueDefinitionRequestSecurityQueryComputeQueryOutputReference:
        return typing.cast(PowerpackWidgetQueryValueDefinitionRequestSecurityQueryComputeQueryOutputReference, jsii.get(self, "computeQuery"))

    @builtins.property
    @jsii.member(jsii_name="groupBy")
    def group_by(
        self,
    ) -> PowerpackWidgetQueryValueDefinitionRequestSecurityQueryGroupByList:
        return typing.cast(PowerpackWidgetQueryValueDefinitionRequestSecurityQueryGroupByList, jsii.get(self, "groupBy"))

    @builtins.property
    @jsii.member(jsii_name="multiCompute")
    def multi_compute(
        self,
    ) -> PowerpackWidgetQueryValueDefinitionRequestSecurityQueryMultiComputeList:
        return typing.cast(PowerpackWidgetQueryValueDefinitionRequestSecurityQueryMultiComputeList, jsii.get(self, "multiCompute"))

    @builtins.property
    @jsii.member(jsii_name="computeQueryInput")
    def compute_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetQueryValueDefinitionRequestSecurityQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryValueDefinitionRequestSecurityQueryComputeQuery], jsii.get(self, "computeQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="groupByInput")
    def group_by_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionRequestSecurityQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionRequestSecurityQueryGroupBy]]], jsii.get(self, "groupByInput"))

    @builtins.property
    @jsii.member(jsii_name="indexInput")
    def index_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "indexInput"))

    @builtins.property
    @jsii.member(jsii_name="multiComputeInput")
    def multi_compute_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionRequestSecurityQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionRequestSecurityQueryMultiCompute]]], jsii.get(self, "multiComputeInput"))

    @builtins.property
    @jsii.member(jsii_name="searchQueryInput")
    def search_query_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "searchQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="index")
    def index(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "index"))

    @index.setter
    def index(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7889864c3497d793f0eabd61095230433d43d4eb55e28f48cc9711ec198fd861)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "index", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="searchQuery")
    def search_query(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "searchQuery"))

    @search_query.setter
    def search_query(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4698e48afc82842a9b8f2e547201653dc9b68e534c2db30ba4ceb393500813fa)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "searchQuery", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetQueryValueDefinitionRequestSecurityQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryValueDefinitionRequestSecurityQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetQueryValueDefinitionRequestSecurityQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__89bef1a552de2227d64fc47bb85341bc60c4b8c51ef260e91e41634f2c7a68f5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionTimeseriesBackground",
    jsii_struct_bases=[],
    name_mapping={"type": "type", "yaxis": "yaxis"},
)
class PowerpackWidgetQueryValueDefinitionTimeseriesBackground:
    def __init__(
        self,
        *,
        type: builtins.str,
        yaxis: typing.Optional[typing.Union["PowerpackWidgetQueryValueDefinitionTimeseriesBackgroundYaxis", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param type: Whether the Timeseries is made using an area or bars. Valid values are ``bars``, ``area``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#type Powerpack#type}
        :param yaxis: yaxis block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#yaxis Powerpack#yaxis}
        '''
        if isinstance(yaxis, dict):
            yaxis = PowerpackWidgetQueryValueDefinitionTimeseriesBackgroundYaxis(**yaxis)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ac1b198b91ab539ce18a8f621182c864b9d492e13d4df6a4f26a2d0b9fb2eac5)
            check_type(argname="argument type", value=type, expected_type=type_hints["type"])
            check_type(argname="argument yaxis", value=yaxis, expected_type=type_hints["yaxis"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "type": type,
        }
        if yaxis is not None:
            self._values["yaxis"] = yaxis

    @builtins.property
    def type(self) -> builtins.str:
        '''Whether the Timeseries is made using an area or bars. Valid values are ``bars``, ``area``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#type Powerpack#type}
        '''
        result = self._values.get("type")
        assert result is not None, "Required property 'type' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def yaxis(
        self,
    ) -> typing.Optional["PowerpackWidgetQueryValueDefinitionTimeseriesBackgroundYaxis"]:
        '''yaxis block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#yaxis Powerpack#yaxis}
        '''
        result = self._values.get("yaxis")
        return typing.cast(typing.Optional["PowerpackWidgetQueryValueDefinitionTimeseriesBackgroundYaxis"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryValueDefinitionTimeseriesBackground(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetQueryValueDefinitionTimeseriesBackgroundOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionTimeseriesBackgroundOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9a1baf9c23ca4cad8428d1310d4657e82c85bc0546739c34ae9d38a3b59972a6)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putYaxis")
    def put_yaxis(
        self,
        *,
        include_zero: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        label: typing.Optional[builtins.str] = None,
        max: typing.Optional[builtins.str] = None,
        min: typing.Optional[builtins.str] = None,
        scale: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param include_zero: Always include zero or fit the axis to the data range. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#include_zero Powerpack#include_zero}
        :param label: The label of the axis to display on the graph. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#label Powerpack#label}
        :param max: Specify the maximum value to show on the Y-axis. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#max Powerpack#max}
        :param min: Specify the minimum value to show on the Y-axis. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#min Powerpack#min}
        :param scale: Specify the scale type, options: ``linear``, ``log``, ``pow``, ``sqrt``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#scale Powerpack#scale}
        '''
        value = PowerpackWidgetQueryValueDefinitionTimeseriesBackgroundYaxis(
            include_zero=include_zero, label=label, max=max, min=min, scale=scale
        )

        return typing.cast(None, jsii.invoke(self, "putYaxis", [value]))

    @jsii.member(jsii_name="resetYaxis")
    def reset_yaxis(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetYaxis", []))

    @builtins.property
    @jsii.member(jsii_name="yaxis")
    def yaxis(
        self,
    ) -> "PowerpackWidgetQueryValueDefinitionTimeseriesBackgroundYaxisOutputReference":
        return typing.cast("PowerpackWidgetQueryValueDefinitionTimeseriesBackgroundYaxisOutputReference", jsii.get(self, "yaxis"))

    @builtins.property
    @jsii.member(jsii_name="typeInput")
    def type_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "typeInput"))

    @builtins.property
    @jsii.member(jsii_name="yaxisInput")
    def yaxis_input(
        self,
    ) -> typing.Optional["PowerpackWidgetQueryValueDefinitionTimeseriesBackgroundYaxis"]:
        return typing.cast(typing.Optional["PowerpackWidgetQueryValueDefinitionTimeseriesBackgroundYaxis"], jsii.get(self, "yaxisInput"))

    @builtins.property
    @jsii.member(jsii_name="type")
    def type(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "type"))

    @type.setter
    def type(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a1a61aa512ae153f10a1ed8f15f8cf317d9ca2d2e88c5265014c9315e4a5737b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "type", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetQueryValueDefinitionTimeseriesBackground]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryValueDefinitionTimeseriesBackground], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetQueryValueDefinitionTimeseriesBackground],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c16aad3eb0f425da8e2c5644430bf90b0f5a57a8f37801e2af0cd3b94b55149c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionTimeseriesBackgroundYaxis",
    jsii_struct_bases=[],
    name_mapping={
        "include_zero": "includeZero",
        "label": "label",
        "max": "max",
        "min": "min",
        "scale": "scale",
    },
)
class PowerpackWidgetQueryValueDefinitionTimeseriesBackgroundYaxis:
    def __init__(
        self,
        *,
        include_zero: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        label: typing.Optional[builtins.str] = None,
        max: typing.Optional[builtins.str] = None,
        min: typing.Optional[builtins.str] = None,
        scale: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param include_zero: Always include zero or fit the axis to the data range. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#include_zero Powerpack#include_zero}
        :param label: The label of the axis to display on the graph. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#label Powerpack#label}
        :param max: Specify the maximum value to show on the Y-axis. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#max Powerpack#max}
        :param min: Specify the minimum value to show on the Y-axis. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#min Powerpack#min}
        :param scale: Specify the scale type, options: ``linear``, ``log``, ``pow``, ``sqrt``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#scale Powerpack#scale}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__852972f5c521e090a44acc49f2c72f9a1f9be8c3b853393caa51f1354026bed1)
            check_type(argname="argument include_zero", value=include_zero, expected_type=type_hints["include_zero"])
            check_type(argname="argument label", value=label, expected_type=type_hints["label"])
            check_type(argname="argument max", value=max, expected_type=type_hints["max"])
            check_type(argname="argument min", value=min, expected_type=type_hints["min"])
            check_type(argname="argument scale", value=scale, expected_type=type_hints["scale"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if include_zero is not None:
            self._values["include_zero"] = include_zero
        if label is not None:
            self._values["label"] = label
        if max is not None:
            self._values["max"] = max
        if min is not None:
            self._values["min"] = min
        if scale is not None:
            self._values["scale"] = scale

    @builtins.property
    def include_zero(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        '''Always include zero or fit the axis to the data range.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#include_zero Powerpack#include_zero}
        '''
        result = self._values.get("include_zero")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)

    @builtins.property
    def label(self) -> typing.Optional[builtins.str]:
        '''The label of the axis to display on the graph.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#label Powerpack#label}
        '''
        result = self._values.get("label")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def max(self) -> typing.Optional[builtins.str]:
        '''Specify the maximum value to show on the Y-axis.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#max Powerpack#max}
        '''
        result = self._values.get("max")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def min(self) -> typing.Optional[builtins.str]:
        '''Specify the minimum value to show on the Y-axis.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#min Powerpack#min}
        '''
        result = self._values.get("min")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def scale(self) -> typing.Optional[builtins.str]:
        '''Specify the scale type, options: ``linear``, ``log``, ``pow``, ``sqrt``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#scale Powerpack#scale}
        '''
        result = self._values.get("scale")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetQueryValueDefinitionTimeseriesBackgroundYaxis(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetQueryValueDefinitionTimeseriesBackgroundYaxisOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetQueryValueDefinitionTimeseriesBackgroundYaxisOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6b055dec7b59ebc42f83ec38b54ef9d14d2e6a14d59e60b1bc749f0ad5513b22)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetIncludeZero")
    def reset_include_zero(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetIncludeZero", []))

    @jsii.member(jsii_name="resetLabel")
    def reset_label(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLabel", []))

    @jsii.member(jsii_name="resetMax")
    def reset_max(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMax", []))

    @jsii.member(jsii_name="resetMin")
    def reset_min(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMin", []))

    @jsii.member(jsii_name="resetScale")
    def reset_scale(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetScale", []))

    @builtins.property
    @jsii.member(jsii_name="includeZeroInput")
    def include_zero_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "includeZeroInput"))

    @builtins.property
    @jsii.member(jsii_name="labelInput")
    def label_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "labelInput"))

    @builtins.property
    @jsii.member(jsii_name="maxInput")
    def max_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "maxInput"))

    @builtins.property
    @jsii.member(jsii_name="minInput")
    def min_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "minInput"))

    @builtins.property
    @jsii.member(jsii_name="scaleInput")
    def scale_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "scaleInput"))

    @builtins.property
    @jsii.member(jsii_name="includeZero")
    def include_zero(self) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "includeZero"))

    @include_zero.setter
    def include_zero(
        self,
        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5a08781fcda5bc0b7bbf719b560ce6931a308e0d3f357dc09a1a54f051eecd9c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "includeZero", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="label")
    def label(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "label"))

    @label.setter
    def label(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__93eb9434e1a85792b301339647014164c3a899f51b254b64c9e1ebd12716c4d3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "label", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="max")
    def max(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "max"))

    @max.setter
    def max(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2523e4d92dc921607486e3198063cfab7523996430cd709fbc2500fe1bd9b700)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "max", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="min")
    def min(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "min"))

    @min.setter
    def min(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e6051355f65bfff507a8b7277bf88288ac37c8d76a560cf1befd267548adf62b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "min", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="scale")
    def scale(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "scale"))

    @scale.setter
    def scale(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dcebe61a1d5456c39b0448e12d3dba6da36dc8af7fcc1dc6a5ef13114b140a54)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "scale", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetQueryValueDefinitionTimeseriesBackgroundYaxis]:
        return typing.cast(typing.Optional[PowerpackWidgetQueryValueDefinitionTimeseriesBackgroundYaxis], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetQueryValueDefinitionTimeseriesBackgroundYaxis],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__106caa13a0c71fda2182b323aeb91470cf400cc5ee55210545e2d43486e679e6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetRunWorkflowDefinition",
    jsii_struct_bases=[],
    name_mapping={
        "workflow_id": "workflowId",
        "custom_link": "customLink",
        "input": "input",
        "live_span": "liveSpan",
        "title": "title",
        "title_align": "titleAlign",
        "title_size": "titleSize",
    },
)
class PowerpackWidgetRunWorkflowDefinition:
    def __init__(
        self,
        *,
        workflow_id: builtins.str,
        custom_link: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetRunWorkflowDefinitionCustomLink", typing.Dict[builtins.str, typing.Any]]]]] = None,
        input: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetRunWorkflowDefinitionInput", typing.Dict[builtins.str, typing.Any]]]]] = None,
        live_span: typing.Optional[builtins.str] = None,
        title: typing.Optional[builtins.str] = None,
        title_align: typing.Optional[builtins.str] = None,
        title_size: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param workflow_id: Workflow ID. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#workflow_id Powerpack#workflow_id}
        :param custom_link: custom_link block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom_link Powerpack#custom_link}
        :param input: input block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#input Powerpack#input}
        :param live_span: The timeframe to use when displaying the widget. Valid values are ``1m``, ``5m``, ``10m``, ``15m``, ``30m``, ``1h``, ``4h``, ``1d``, ``2d``, ``1w``, ``1mo``, ``3mo``, ``6mo``, ``week_to_date``, ``month_to_date``, ``1y``, ``alert``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#live_span Powerpack#live_span}
        :param title: The title of the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title Powerpack#title}
        :param title_align: The alignment of the widget's title. Valid values are ``center``, ``left``, ``right``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_align Powerpack#title_align}
        :param title_size: The size of the widget's title (defaults to 16). Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_size Powerpack#title_size}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0b2183c46bcf174022f542964cc7b2c27fd3fa610c14faa75f0edae30483d6ff)
            check_type(argname="argument workflow_id", value=workflow_id, expected_type=type_hints["workflow_id"])
            check_type(argname="argument custom_link", value=custom_link, expected_type=type_hints["custom_link"])
            check_type(argname="argument input", value=input, expected_type=type_hints["input"])
            check_type(argname="argument live_span", value=live_span, expected_type=type_hints["live_span"])
            check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            check_type(argname="argument title_align", value=title_align, expected_type=type_hints["title_align"])
            check_type(argname="argument title_size", value=title_size, expected_type=type_hints["title_size"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "workflow_id": workflow_id,
        }
        if custom_link is not None:
            self._values["custom_link"] = custom_link
        if input is not None:
            self._values["input"] = input
        if live_span is not None:
            self._values["live_span"] = live_span
        if title is not None:
            self._values["title"] = title
        if title_align is not None:
            self._values["title_align"] = title_align
        if title_size is not None:
            self._values["title_size"] = title_size

    @builtins.property
    def workflow_id(self) -> builtins.str:
        '''Workflow ID.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#workflow_id Powerpack#workflow_id}
        '''
        result = self._values.get("workflow_id")
        assert result is not None, "Required property 'workflow_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def custom_link(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetRunWorkflowDefinitionCustomLink"]]]:
        '''custom_link block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom_link Powerpack#custom_link}
        '''
        result = self._values.get("custom_link")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetRunWorkflowDefinitionCustomLink"]]], result)

    @builtins.property
    def input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetRunWorkflowDefinitionInput"]]]:
        '''input block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#input Powerpack#input}
        '''
        result = self._values.get("input")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetRunWorkflowDefinitionInput"]]], result)

    @builtins.property
    def live_span(self) -> typing.Optional[builtins.str]:
        '''The timeframe to use when displaying the widget.

        Valid values are ``1m``, ``5m``, ``10m``, ``15m``, ``30m``, ``1h``, ``4h``, ``1d``, ``2d``, ``1w``, ``1mo``, ``3mo``, ``6mo``, ``week_to_date``, ``month_to_date``, ``1y``, ``alert``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#live_span Powerpack#live_span}
        '''
        result = self._values.get("live_span")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def title(self) -> typing.Optional[builtins.str]:
        '''The title of the widget.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title Powerpack#title}
        '''
        result = self._values.get("title")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def title_align(self) -> typing.Optional[builtins.str]:
        '''The alignment of the widget's title. Valid values are ``center``, ``left``, ``right``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_align Powerpack#title_align}
        '''
        result = self._values.get("title_align")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def title_size(self) -> typing.Optional[builtins.str]:
        '''The size of the widget's title (defaults to 16).

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_size Powerpack#title_size}
        '''
        result = self._values.get("title_size")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetRunWorkflowDefinition(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetRunWorkflowDefinitionCustomLink",
    jsii_struct_bases=[],
    name_mapping={
        "is_hidden": "isHidden",
        "label": "label",
        "link": "link",
        "override_label": "overrideLabel",
    },
)
class PowerpackWidgetRunWorkflowDefinitionCustomLink:
    def __init__(
        self,
        *,
        is_hidden: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        label: typing.Optional[builtins.str] = None,
        link: typing.Optional[builtins.str] = None,
        override_label: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param is_hidden: The flag for toggling context menu link visibility. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#is_hidden Powerpack#is_hidden}
        :param label: The label for the custom link URL. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#label Powerpack#label}
        :param link: The URL of the custom link. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#link Powerpack#link}
        :param override_label: The label ID that refers to a context menu link item. When ``override_label`` is provided, the client request omits the label field. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#override_label Powerpack#override_label}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c14523faa2ae9d753a58060c0311cc07110cf439c61847795b6cf95e8fe4b344)
            check_type(argname="argument is_hidden", value=is_hidden, expected_type=type_hints["is_hidden"])
            check_type(argname="argument label", value=label, expected_type=type_hints["label"])
            check_type(argname="argument link", value=link, expected_type=type_hints["link"])
            check_type(argname="argument override_label", value=override_label, expected_type=type_hints["override_label"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if is_hidden is not None:
            self._values["is_hidden"] = is_hidden
        if label is not None:
            self._values["label"] = label
        if link is not None:
            self._values["link"] = link
        if override_label is not None:
            self._values["override_label"] = override_label

    @builtins.property
    def is_hidden(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        '''The flag for toggling context menu link visibility.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#is_hidden Powerpack#is_hidden}
        '''
        result = self._values.get("is_hidden")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)

    @builtins.property
    def label(self) -> typing.Optional[builtins.str]:
        '''The label for the custom link URL.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#label Powerpack#label}
        '''
        result = self._values.get("label")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def link(self) -> typing.Optional[builtins.str]:
        '''The URL of the custom link.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#link Powerpack#link}
        '''
        result = self._values.get("link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def override_label(self) -> typing.Optional[builtins.str]:
        '''The label ID that refers to a context menu link item.

        When ``override_label`` is provided, the client request omits the label field.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#override_label Powerpack#override_label}
        '''
        result = self._values.get("override_label")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetRunWorkflowDefinitionCustomLink(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetRunWorkflowDefinitionCustomLinkList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetRunWorkflowDefinitionCustomLinkList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b3324cd84cc7a60d676cac235f75f5ca2b5d415f5d69526105f8478e22713bfe)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetRunWorkflowDefinitionCustomLinkOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2ebe154c0687ec92c8097ea8ca74d8dded2120bf3014f0e5f3f5a1083d0f825d)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetRunWorkflowDefinitionCustomLinkOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1a1a8d0c27259853444f29f41f767e15560006d2ada86870f3c144feaea75242)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6de7923bf414cd270d42e82000ef0db3d63d32beea77cadf478fceaf126276ee)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6a8fab212edf0f70cdc1b3adac26f198cdd2b32ebdaa96ab428aaacbcf0c2f23)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetRunWorkflowDefinitionCustomLink]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetRunWorkflowDefinitionCustomLink]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetRunWorkflowDefinitionCustomLink]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5f154ecb27d71ba20fcbfe170eb619ab13805e5c25b97277023aed9c48642491)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetRunWorkflowDefinitionCustomLinkOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetRunWorkflowDefinitionCustomLinkOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f2579bb5d66005c403c93cd629d5ea76d4cf42dd392c4fbc92c30b45aa3c8a8e)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetIsHidden")
    def reset_is_hidden(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetIsHidden", []))

    @jsii.member(jsii_name="resetLabel")
    def reset_label(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLabel", []))

    @jsii.member(jsii_name="resetLink")
    def reset_link(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLink", []))

    @jsii.member(jsii_name="resetOverrideLabel")
    def reset_override_label(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetOverrideLabel", []))

    @builtins.property
    @jsii.member(jsii_name="isHiddenInput")
    def is_hidden_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "isHiddenInput"))

    @builtins.property
    @jsii.member(jsii_name="labelInput")
    def label_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "labelInput"))

    @builtins.property
    @jsii.member(jsii_name="linkInput")
    def link_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "linkInput"))

    @builtins.property
    @jsii.member(jsii_name="overrideLabelInput")
    def override_label_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "overrideLabelInput"))

    @builtins.property
    @jsii.member(jsii_name="isHidden")
    def is_hidden(self) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "isHidden"))

    @is_hidden.setter
    def is_hidden(
        self,
        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__75a8c8821bfea5eaf578fc552b34b1d72a7a51a7cafce5a49715fd7dd6db0ff8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "isHidden", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="label")
    def label(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "label"))

    @label.setter
    def label(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b76af170e62f2aaa27eed067cdf4eaf2b4f405e44d7c34c9a7c9b37283610e7a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "label", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="link")
    def link(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "link"))

    @link.setter
    def link(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__abca52d30b001d32ab297782c02f338f9760986a74bf01b3ee38c4cdfc45eec5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "link", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="overrideLabel")
    def override_label(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "overrideLabel"))

    @override_label.setter
    def override_label(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__56774a92383eba548ed72019af4ead8c0772a1379b2e81069ded7324748ae1aa)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "overrideLabel", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetRunWorkflowDefinitionCustomLink]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetRunWorkflowDefinitionCustomLink]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetRunWorkflowDefinitionCustomLink]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bbceb8ad91c0f9dc4ce6442f81f26ea554b1738f62e8dc3627fe446962058396)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetRunWorkflowDefinitionInput",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "value": "value"},
)
class PowerpackWidgetRunWorkflowDefinitionInput:
    def __init__(self, *, name: builtins.str, value: builtins.str) -> None:
        '''
        :param name: Name of the workflow input. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param value: Dashboard template variable. Can be suffixed with ``.value`` or ``.key``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#value Powerpack#value}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__42ee91cd974955698dc0abf7eb15032499c2f653812cda80992d6149a5b2e2d3)
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "name": name,
            "value": value,
        }

    @builtins.property
    def name(self) -> builtins.str:
        '''Name of the workflow input.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        '''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def value(self) -> builtins.str:
        '''Dashboard template variable. Can be suffixed with ``.value`` or ``.key``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#value Powerpack#value}
        '''
        result = self._values.get("value")
        assert result is not None, "Required property 'value' is missing"
        return typing.cast(builtins.str, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetRunWorkflowDefinitionInput(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetRunWorkflowDefinitionInputList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetRunWorkflowDefinitionInputList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__14e3831ed5d51c1b1b364cc71e2a3181c4bcf11de08076f0967a37f862ef523b)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetRunWorkflowDefinitionInputOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ebd67744559a8789860126a738a658f60ba44da928ff6abb33ef516cdab83df5)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetRunWorkflowDefinitionInputOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__16891624eb04e56094f3dbf57f772a3f49ab02073c4741a41e8de9ba11ab8319)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9548f6b50edb69c686b190f5cf1114c39dbd98d8c1e87067f64d0ef3bd1729b8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0f1fc65030e049defaaa223e439910ee924b583f65a8217c4e46677a530fcfd1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetRunWorkflowDefinitionInput]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetRunWorkflowDefinitionInput]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetRunWorkflowDefinitionInput]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fc5cd306fc0631dcffc2878afbef50093b973ce65dc684647e474d2f8cc1a319)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetRunWorkflowDefinitionInputOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetRunWorkflowDefinitionInputOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__de532a03cfe8bbe80278b5849031b33a500b425c05a46e67d89f23671eacb5e9)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property
    @jsii.member(jsii_name="valueInput")
    def value_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "valueInput"))

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a6fb9b55cd202b5562b72d04c314d9000091814ba63115036debd8457514f92b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "name", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="value")
    def value(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "value"))

    @value.setter
    def value(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5ef93059596f21429e3b3d57d66e6d007d29093406b574055deab4a6cc3e46d2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "value", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetRunWorkflowDefinitionInput]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetRunWorkflowDefinitionInput]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetRunWorkflowDefinitionInput]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7f677dd2d33726c5de799b5236105367ea8a079e95d0fb0f243605e2f36ffc1e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetRunWorkflowDefinitionOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetRunWorkflowDefinitionOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c60b912b9fe6f85e1bd9c2f83853c42c2700387efb28d8ba2c05ebcea447410a)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putCustomLink")
    def put_custom_link(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetRunWorkflowDefinitionCustomLink, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__014454659bb506c2a482cdbfeb629912be6907780d37694bace1c8bd9256a8aa)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putCustomLink", [value]))

    @jsii.member(jsii_name="putInput")
    def put_input(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetRunWorkflowDefinitionInput, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e7df5d1f2b754a4e173504aed0265b30e6cfc0fa96eca9aaa9e2f89c22782def)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putInput", [value]))

    @jsii.member(jsii_name="resetCustomLink")
    def reset_custom_link(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCustomLink", []))

    @jsii.member(jsii_name="resetInput")
    def reset_input(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInput", []))

    @jsii.member(jsii_name="resetLiveSpan")
    def reset_live_span(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLiveSpan", []))

    @jsii.member(jsii_name="resetTitle")
    def reset_title(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTitle", []))

    @jsii.member(jsii_name="resetTitleAlign")
    def reset_title_align(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTitleAlign", []))

    @jsii.member(jsii_name="resetTitleSize")
    def reset_title_size(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTitleSize", []))

    @builtins.property
    @jsii.member(jsii_name="customLink")
    def custom_link(self) -> PowerpackWidgetRunWorkflowDefinitionCustomLinkList:
        return typing.cast(PowerpackWidgetRunWorkflowDefinitionCustomLinkList, jsii.get(self, "customLink"))

    @builtins.property
    @jsii.member(jsii_name="input")
    def input(self) -> PowerpackWidgetRunWorkflowDefinitionInputList:
        return typing.cast(PowerpackWidgetRunWorkflowDefinitionInputList, jsii.get(self, "input"))

    @builtins.property
    @jsii.member(jsii_name="customLinkInput")
    def custom_link_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetRunWorkflowDefinitionCustomLink]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetRunWorkflowDefinitionCustomLink]]], jsii.get(self, "customLinkInput"))

    @builtins.property
    @jsii.member(jsii_name="inputInput")
    def input_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetRunWorkflowDefinitionInput]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetRunWorkflowDefinitionInput]]], jsii.get(self, "inputInput"))

    @builtins.property
    @jsii.member(jsii_name="liveSpanInput")
    def live_span_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "liveSpanInput"))

    @builtins.property
    @jsii.member(jsii_name="titleAlignInput")
    def title_align_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "titleAlignInput"))

    @builtins.property
    @jsii.member(jsii_name="titleInput")
    def title_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "titleInput"))

    @builtins.property
    @jsii.member(jsii_name="titleSizeInput")
    def title_size_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "titleSizeInput"))

    @builtins.property
    @jsii.member(jsii_name="workflowIdInput")
    def workflow_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "workflowIdInput"))

    @builtins.property
    @jsii.member(jsii_name="liveSpan")
    def live_span(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "liveSpan"))

    @live_span.setter
    def live_span(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cda7c32b898d8b14b38545dca20d6c3f7eef46b00158b73d7bb7708125b49de8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "liveSpan", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="title")
    def title(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "title"))

    @title.setter
    def title(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__73546b845c7c16bdab6713dacc2a6e0309f7a37b9bcbbb9f51d28d38129cd109)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "title", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="titleAlign")
    def title_align(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "titleAlign"))

    @title_align.setter
    def title_align(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fd3218cc0a021791b6bd50323fdef193bf4da661e7976d5c6cf37a7358a4e1fa)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "titleAlign", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="titleSize")
    def title_size(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "titleSize"))

    @title_size.setter
    def title_size(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f121e37fa3106c172991a02400b5134c8ba03bbeb768ecff60bb96ce8010e313)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "titleSize", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="workflowId")
    def workflow_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "workflowId"))

    @workflow_id.setter
    def workflow_id(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e8b9770932916e2b0bcf91e9473e5ad80bf486c53384da3783e7a9b34dfdb58e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "workflowId", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[PowerpackWidgetRunWorkflowDefinition]:
        return typing.cast(typing.Optional[PowerpackWidgetRunWorkflowDefinition], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetRunWorkflowDefinition],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6000f737817b4c908c0f88fbc45ba0d5c797f1e7a4ed3c0c8799619d36f9bc7f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinition",
    jsii_struct_bases=[],
    name_mapping={
        "color_by_groups": "colorByGroups",
        "custom_link": "customLink",
        "live_span": "liveSpan",
        "request": "request",
        "title": "title",
        "title_align": "titleAlign",
        "title_size": "titleSize",
        "xaxis": "xaxis",
        "yaxis": "yaxis",
    },
)
class PowerpackWidgetScatterplotDefinition:
    def __init__(
        self,
        *,
        color_by_groups: typing.Optional[typing.Sequence[builtins.str]] = None,
        custom_link: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetScatterplotDefinitionCustomLink", typing.Dict[builtins.str, typing.Any]]]]] = None,
        live_span: typing.Optional[builtins.str] = None,
        request: typing.Optional[typing.Union["PowerpackWidgetScatterplotDefinitionRequest", typing.Dict[builtins.str, typing.Any]]] = None,
        title: typing.Optional[builtins.str] = None,
        title_align: typing.Optional[builtins.str] = None,
        title_size: typing.Optional[builtins.str] = None,
        xaxis: typing.Optional[typing.Union["PowerpackWidgetScatterplotDefinitionXaxis", typing.Dict[builtins.str, typing.Any]]] = None,
        yaxis: typing.Optional[typing.Union["PowerpackWidgetScatterplotDefinitionYaxis", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param color_by_groups: List of groups used for colors. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#color_by_groups Powerpack#color_by_groups}
        :param custom_link: custom_link block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom_link Powerpack#custom_link}
        :param live_span: The timeframe to use when displaying the widget. Valid values are ``1m``, ``5m``, ``10m``, ``15m``, ``30m``, ``1h``, ``4h``, ``1d``, ``2d``, ``1w``, ``1mo``, ``3mo``, ``6mo``, ``week_to_date``, ``month_to_date``, ``1y``, ``alert``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#live_span Powerpack#live_span}
        :param request: request block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#request Powerpack#request}
        :param title: The title of the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title Powerpack#title}
        :param title_align: The alignment of the widget's title. Valid values are ``center``, ``left``, ``right``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_align Powerpack#title_align}
        :param title_size: The size of the widget's title (defaults to 16). Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_size Powerpack#title_size}
        :param xaxis: xaxis block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#xaxis Powerpack#xaxis}
        :param yaxis: yaxis block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#yaxis Powerpack#yaxis}
        '''
        if isinstance(request, dict):
            request = PowerpackWidgetScatterplotDefinitionRequest(**request)
        if isinstance(xaxis, dict):
            xaxis = PowerpackWidgetScatterplotDefinitionXaxis(**xaxis)
        if isinstance(yaxis, dict):
            yaxis = PowerpackWidgetScatterplotDefinitionYaxis(**yaxis)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d10709bfa15bb2e27015dd5dd582d1b74862a9f4a789d7349965d37fdf3f1e66)
            check_type(argname="argument color_by_groups", value=color_by_groups, expected_type=type_hints["color_by_groups"])
            check_type(argname="argument custom_link", value=custom_link, expected_type=type_hints["custom_link"])
            check_type(argname="argument live_span", value=live_span, expected_type=type_hints["live_span"])
            check_type(argname="argument request", value=request, expected_type=type_hints["request"])
            check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            check_type(argname="argument title_align", value=title_align, expected_type=type_hints["title_align"])
            check_type(argname="argument title_size", value=title_size, expected_type=type_hints["title_size"])
            check_type(argname="argument xaxis", value=xaxis, expected_type=type_hints["xaxis"])
            check_type(argname="argument yaxis", value=yaxis, expected_type=type_hints["yaxis"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if color_by_groups is not None:
            self._values["color_by_groups"] = color_by_groups
        if custom_link is not None:
            self._values["custom_link"] = custom_link
        if live_span is not None:
            self._values["live_span"] = live_span
        if request is not None:
            self._values["request"] = request
        if title is not None:
            self._values["title"] = title
        if title_align is not None:
            self._values["title_align"] = title_align
        if title_size is not None:
            self._values["title_size"] = title_size
        if xaxis is not None:
            self._values["xaxis"] = xaxis
        if yaxis is not None:
            self._values["yaxis"] = yaxis

    @builtins.property
    def color_by_groups(self) -> typing.Optional[typing.List[builtins.str]]:
        '''List of groups used for colors.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#color_by_groups Powerpack#color_by_groups}
        '''
        result = self._values.get("color_by_groups")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def custom_link(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetScatterplotDefinitionCustomLink"]]]:
        '''custom_link block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom_link Powerpack#custom_link}
        '''
        result = self._values.get("custom_link")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetScatterplotDefinitionCustomLink"]]], result)

    @builtins.property
    def live_span(self) -> typing.Optional[builtins.str]:
        '''The timeframe to use when displaying the widget.

        Valid values are ``1m``, ``5m``, ``10m``, ``15m``, ``30m``, ``1h``, ``4h``, ``1d``, ``2d``, ``1w``, ``1mo``, ``3mo``, ``6mo``, ``week_to_date``, ``month_to_date``, ``1y``, ``alert``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#live_span Powerpack#live_span}
        '''
        result = self._values.get("live_span")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def request(self) -> typing.Optional["PowerpackWidgetScatterplotDefinitionRequest"]:
        '''request block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#request Powerpack#request}
        '''
        result = self._values.get("request")
        return typing.cast(typing.Optional["PowerpackWidgetScatterplotDefinitionRequest"], result)

    @builtins.property
    def title(self) -> typing.Optional[builtins.str]:
        '''The title of the widget.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title Powerpack#title}
        '''
        result = self._values.get("title")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def title_align(self) -> typing.Optional[builtins.str]:
        '''The alignment of the widget's title. Valid values are ``center``, ``left``, ``right``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_align Powerpack#title_align}
        '''
        result = self._values.get("title_align")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def title_size(self) -> typing.Optional[builtins.str]:
        '''The size of the widget's title (defaults to 16).

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_size Powerpack#title_size}
        '''
        result = self._values.get("title_size")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def xaxis(self) -> typing.Optional["PowerpackWidgetScatterplotDefinitionXaxis"]:
        '''xaxis block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#xaxis Powerpack#xaxis}
        '''
        result = self._values.get("xaxis")
        return typing.cast(typing.Optional["PowerpackWidgetScatterplotDefinitionXaxis"], result)

    @builtins.property
    def yaxis(self) -> typing.Optional["PowerpackWidgetScatterplotDefinitionYaxis"]:
        '''yaxis block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#yaxis Powerpack#yaxis}
        '''
        result = self._values.get("yaxis")
        return typing.cast(typing.Optional["PowerpackWidgetScatterplotDefinitionYaxis"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetScatterplotDefinition(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionCustomLink",
    jsii_struct_bases=[],
    name_mapping={
        "is_hidden": "isHidden",
        "label": "label",
        "link": "link",
        "override_label": "overrideLabel",
    },
)
class PowerpackWidgetScatterplotDefinitionCustomLink:
    def __init__(
        self,
        *,
        is_hidden: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        label: typing.Optional[builtins.str] = None,
        link: typing.Optional[builtins.str] = None,
        override_label: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param is_hidden: The flag for toggling context menu link visibility. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#is_hidden Powerpack#is_hidden}
        :param label: The label for the custom link URL. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#label Powerpack#label}
        :param link: The URL of the custom link. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#link Powerpack#link}
        :param override_label: The label ID that refers to a context menu link item. When ``override_label`` is provided, the client request omits the label field. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#override_label Powerpack#override_label}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__84af1d7fd896478dbf0b36051bad0d112aff33563650b04f746523e2a32ebd05)
            check_type(argname="argument is_hidden", value=is_hidden, expected_type=type_hints["is_hidden"])
            check_type(argname="argument label", value=label, expected_type=type_hints["label"])
            check_type(argname="argument link", value=link, expected_type=type_hints["link"])
            check_type(argname="argument override_label", value=override_label, expected_type=type_hints["override_label"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if is_hidden is not None:
            self._values["is_hidden"] = is_hidden
        if label is not None:
            self._values["label"] = label
        if link is not None:
            self._values["link"] = link
        if override_label is not None:
            self._values["override_label"] = override_label

    @builtins.property
    def is_hidden(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        '''The flag for toggling context menu link visibility.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#is_hidden Powerpack#is_hidden}
        '''
        result = self._values.get("is_hidden")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)

    @builtins.property
    def label(self) -> typing.Optional[builtins.str]:
        '''The label for the custom link URL.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#label Powerpack#label}
        '''
        result = self._values.get("label")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def link(self) -> typing.Optional[builtins.str]:
        '''The URL of the custom link.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#link Powerpack#link}
        '''
        result = self._values.get("link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def override_label(self) -> typing.Optional[builtins.str]:
        '''The label ID that refers to a context menu link item.

        When ``override_label`` is provided, the client request omits the label field.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#override_label Powerpack#override_label}
        '''
        result = self._values.get("override_label")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetScatterplotDefinitionCustomLink(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetScatterplotDefinitionCustomLinkList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionCustomLinkList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8418c12d81e2ad8dd254765c293ff50c93e2abad0bfbbe8f6d492fdc0cd68b4d)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetScatterplotDefinitionCustomLinkOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8ddce7337c79d011c488366f10de5155f43ae0f267c557955cddce332913de6b)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetScatterplotDefinitionCustomLinkOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5be37c69a8fb5f07cf497d5d3b3730f86ffa42bc85bcdbf4e137fdea20449b29)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d00d85c941af48cffc32dca800808189cc34b611070190dacfbf2aedd6f2a15b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__84c85c331bc2cdbfc4566314160d0c92fcd78f871e5b72c054376af2f3be5a2c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionCustomLink]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionCustomLink]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionCustomLink]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__215e6276070abef97595e66ea798e0729e3926d058c6c991bfe0f9f1ecc7533f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetScatterplotDefinitionCustomLinkOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionCustomLinkOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bfa43a7e31db9615cbc4030ca7a822842c426f7d6ca356afad842e08ede829cb)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetIsHidden")
    def reset_is_hidden(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetIsHidden", []))

    @jsii.member(jsii_name="resetLabel")
    def reset_label(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLabel", []))

    @jsii.member(jsii_name="resetLink")
    def reset_link(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLink", []))

    @jsii.member(jsii_name="resetOverrideLabel")
    def reset_override_label(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetOverrideLabel", []))

    @builtins.property
    @jsii.member(jsii_name="isHiddenInput")
    def is_hidden_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "isHiddenInput"))

    @builtins.property
    @jsii.member(jsii_name="labelInput")
    def label_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "labelInput"))

    @builtins.property
    @jsii.member(jsii_name="linkInput")
    def link_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "linkInput"))

    @builtins.property
    @jsii.member(jsii_name="overrideLabelInput")
    def override_label_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "overrideLabelInput"))

    @builtins.property
    @jsii.member(jsii_name="isHidden")
    def is_hidden(self) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "isHidden"))

    @is_hidden.setter
    def is_hidden(
        self,
        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5d7045cabedf7fc4af3fcc3bb0c91f8976345a6192b8f4b595b30358fd4a6b19)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "isHidden", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="label")
    def label(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "label"))

    @label.setter
    def label(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__04bb9805c1d8d8e7add9481bc0e7c0857149e80c74b1fbff25f79cdedae19c7c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "label", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="link")
    def link(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "link"))

    @link.setter
    def link(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dd28f1e27f32351621e6e71789652ebbcd73c10082dbf7cfd2eaadcab9e06379)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "link", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="overrideLabel")
    def override_label(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "overrideLabel"))

    @override_label.setter
    def override_label(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7875940ab5022aa32f6c8a4743c77c0c73fe57726dc3d9cd8edf2b1b39138157)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "overrideLabel", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetScatterplotDefinitionCustomLink]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetScatterplotDefinitionCustomLink]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetScatterplotDefinitionCustomLink]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9b79d855faad8904895c4775c3ee3cea72a94b36508d3632c307c74381ba752c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetScatterplotDefinitionOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__968b207547b2369ef4499c4129b05fc24fd859eea848ee1d1328f882d0fd3a15)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putCustomLink")
    def put_custom_link(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetScatterplotDefinitionCustomLink, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5f563893315b24fd1f7c21c7db409971fcc5cb7c66869b3245033cf6921cf7b9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putCustomLink", [value]))

    @jsii.member(jsii_name="putRequest")
    def put_request(
        self,
        *,
        scatterplot_table: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetScatterplotDefinitionRequestScatterplotTable", typing.Dict[builtins.str, typing.Any]]]]] = None,
        x: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetScatterplotDefinitionRequestX", typing.Dict[builtins.str, typing.Any]]]]] = None,
        y: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetScatterplotDefinitionRequestY", typing.Dict[builtins.str, typing.Any]]]]] = None,
    ) -> None:
        '''
        :param scatterplot_table: scatterplot_table block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#scatterplot_table Powerpack#scatterplot_table}
        :param x: x block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#x Powerpack#x}
        :param y: y block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#y Powerpack#y}
        '''
        value = PowerpackWidgetScatterplotDefinitionRequest(
            scatterplot_table=scatterplot_table, x=x, y=y
        )

        return typing.cast(None, jsii.invoke(self, "putRequest", [value]))

    @jsii.member(jsii_name="putXaxis")
    def put_xaxis(
        self,
        *,
        include_zero: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        label: typing.Optional[builtins.str] = None,
        max: typing.Optional[builtins.str] = None,
        min: typing.Optional[builtins.str] = None,
        scale: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param include_zero: Always include zero or fit the axis to the data range. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#include_zero Powerpack#include_zero}
        :param label: The label of the axis to display on the graph. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#label Powerpack#label}
        :param max: Specify the maximum value to show on the Y-axis. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#max Powerpack#max}
        :param min: Specify the minimum value to show on the Y-axis. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#min Powerpack#min}
        :param scale: Specify the scale type, options: ``linear``, ``log``, ``pow``, ``sqrt``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#scale Powerpack#scale}
        '''
        value = PowerpackWidgetScatterplotDefinitionXaxis(
            include_zero=include_zero, label=label, max=max, min=min, scale=scale
        )

        return typing.cast(None, jsii.invoke(self, "putXaxis", [value]))

    @jsii.member(jsii_name="putYaxis")
    def put_yaxis(
        self,
        *,
        include_zero: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        label: typing.Optional[builtins.str] = None,
        max: typing.Optional[builtins.str] = None,
        min: typing.Optional[builtins.str] = None,
        scale: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param include_zero: Always include zero or fit the axis to the data range. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#include_zero Powerpack#include_zero}
        :param label: The label of the axis to display on the graph. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#label Powerpack#label}
        :param max: Specify the maximum value to show on the Y-axis. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#max Powerpack#max}
        :param min: Specify the minimum value to show on the Y-axis. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#min Powerpack#min}
        :param scale: Specify the scale type, options: ``linear``, ``log``, ``pow``, ``sqrt``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#scale Powerpack#scale}
        '''
        value = PowerpackWidgetScatterplotDefinitionYaxis(
            include_zero=include_zero, label=label, max=max, min=min, scale=scale
        )

        return typing.cast(None, jsii.invoke(self, "putYaxis", [value]))

    @jsii.member(jsii_name="resetColorByGroups")
    def reset_color_by_groups(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetColorByGroups", []))

    @jsii.member(jsii_name="resetCustomLink")
    def reset_custom_link(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCustomLink", []))

    @jsii.member(jsii_name="resetLiveSpan")
    def reset_live_span(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLiveSpan", []))

    @jsii.member(jsii_name="resetRequest")
    def reset_request(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetRequest", []))

    @jsii.member(jsii_name="resetTitle")
    def reset_title(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTitle", []))

    @jsii.member(jsii_name="resetTitleAlign")
    def reset_title_align(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTitleAlign", []))

    @jsii.member(jsii_name="resetTitleSize")
    def reset_title_size(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTitleSize", []))

    @jsii.member(jsii_name="resetXaxis")
    def reset_xaxis(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetXaxis", []))

    @jsii.member(jsii_name="resetYaxis")
    def reset_yaxis(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetYaxis", []))

    @builtins.property
    @jsii.member(jsii_name="customLink")
    def custom_link(self) -> PowerpackWidgetScatterplotDefinitionCustomLinkList:
        return typing.cast(PowerpackWidgetScatterplotDefinitionCustomLinkList, jsii.get(self, "customLink"))

    @builtins.property
    @jsii.member(jsii_name="request")
    def request(self) -> "PowerpackWidgetScatterplotDefinitionRequestOutputReference":
        return typing.cast("PowerpackWidgetScatterplotDefinitionRequestOutputReference", jsii.get(self, "request"))

    @builtins.property
    @jsii.member(jsii_name="xaxis")
    def xaxis(self) -> "PowerpackWidgetScatterplotDefinitionXaxisOutputReference":
        return typing.cast("PowerpackWidgetScatterplotDefinitionXaxisOutputReference", jsii.get(self, "xaxis"))

    @builtins.property
    @jsii.member(jsii_name="yaxis")
    def yaxis(self) -> "PowerpackWidgetScatterplotDefinitionYaxisOutputReference":
        return typing.cast("PowerpackWidgetScatterplotDefinitionYaxisOutputReference", jsii.get(self, "yaxis"))

    @builtins.property
    @jsii.member(jsii_name="colorByGroupsInput")
    def color_by_groups_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "colorByGroupsInput"))

    @builtins.property
    @jsii.member(jsii_name="customLinkInput")
    def custom_link_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionCustomLink]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionCustomLink]]], jsii.get(self, "customLinkInput"))

    @builtins.property
    @jsii.member(jsii_name="liveSpanInput")
    def live_span_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "liveSpanInput"))

    @builtins.property
    @jsii.member(jsii_name="requestInput")
    def request_input(
        self,
    ) -> typing.Optional["PowerpackWidgetScatterplotDefinitionRequest"]:
        return typing.cast(typing.Optional["PowerpackWidgetScatterplotDefinitionRequest"], jsii.get(self, "requestInput"))

    @builtins.property
    @jsii.member(jsii_name="titleAlignInput")
    def title_align_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "titleAlignInput"))

    @builtins.property
    @jsii.member(jsii_name="titleInput")
    def title_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "titleInput"))

    @builtins.property
    @jsii.member(jsii_name="titleSizeInput")
    def title_size_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "titleSizeInput"))

    @builtins.property
    @jsii.member(jsii_name="xaxisInput")
    def xaxis_input(
        self,
    ) -> typing.Optional["PowerpackWidgetScatterplotDefinitionXaxis"]:
        return typing.cast(typing.Optional["PowerpackWidgetScatterplotDefinitionXaxis"], jsii.get(self, "xaxisInput"))

    @builtins.property
    @jsii.member(jsii_name="yaxisInput")
    def yaxis_input(
        self,
    ) -> typing.Optional["PowerpackWidgetScatterplotDefinitionYaxis"]:
        return typing.cast(typing.Optional["PowerpackWidgetScatterplotDefinitionYaxis"], jsii.get(self, "yaxisInput"))

    @builtins.property
    @jsii.member(jsii_name="colorByGroups")
    def color_by_groups(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "colorByGroups"))

    @color_by_groups.setter
    def color_by_groups(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5ce260b7bdbe7057535626839bfe60d7cd4b13e00b16bb2d8cf2d1142979be84)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "colorByGroups", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="liveSpan")
    def live_span(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "liveSpan"))

    @live_span.setter
    def live_span(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__daa1e81a7d8e7e6cf2494bd4ad38ef0b5fb7643615cf1c6b222e8e918cdf65b3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "liveSpan", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="title")
    def title(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "title"))

    @title.setter
    def title(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5e3b4bfd398a2cbd80900856bf140df975a8063525dbedc0e63a4fb75511266c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "title", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="titleAlign")
    def title_align(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "titleAlign"))

    @title_align.setter
    def title_align(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1197190948e41eed4abfe1ab79515a7ea77d21140ad318899a7cd6a073ae0417)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "titleAlign", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="titleSize")
    def title_size(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "titleSize"))

    @title_size.setter
    def title_size(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f278d6689bd8aadcc6abc191094dd4735a7bb951bff7b4683453545e87da4b30)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "titleSize", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[PowerpackWidgetScatterplotDefinition]:
        return typing.cast(typing.Optional[PowerpackWidgetScatterplotDefinition], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetScatterplotDefinition],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7ce195bdeff5c86c78c00debcf6cdfa13dd9ed7e50b60d5432246d8419fd8548)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequest",
    jsii_struct_bases=[],
    name_mapping={"scatterplot_table": "scatterplotTable", "x": "x", "y": "y"},
)
class PowerpackWidgetScatterplotDefinitionRequest:
    def __init__(
        self,
        *,
        scatterplot_table: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetScatterplotDefinitionRequestScatterplotTable", typing.Dict[builtins.str, typing.Any]]]]] = None,
        x: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetScatterplotDefinitionRequestX", typing.Dict[builtins.str, typing.Any]]]]] = None,
        y: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetScatterplotDefinitionRequestY", typing.Dict[builtins.str, typing.Any]]]]] = None,
    ) -> None:
        '''
        :param scatterplot_table: scatterplot_table block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#scatterplot_table Powerpack#scatterplot_table}
        :param x: x block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#x Powerpack#x}
        :param y: y block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#y Powerpack#y}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__057f8c8bc1cbcd5d113f1076f35e6dc9ca3446ea94dcf16869ece5bcb91d5969)
            check_type(argname="argument scatterplot_table", value=scatterplot_table, expected_type=type_hints["scatterplot_table"])
            check_type(argname="argument x", value=x, expected_type=type_hints["x"])
            check_type(argname="argument y", value=y, expected_type=type_hints["y"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if scatterplot_table is not None:
            self._values["scatterplot_table"] = scatterplot_table
        if x is not None:
            self._values["x"] = x
        if y is not None:
            self._values["y"] = y

    @builtins.property
    def scatterplot_table(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetScatterplotDefinitionRequestScatterplotTable"]]]:
        '''scatterplot_table block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#scatterplot_table Powerpack#scatterplot_table}
        '''
        result = self._values.get("scatterplot_table")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetScatterplotDefinitionRequestScatterplotTable"]]], result)

    @builtins.property
    def x(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetScatterplotDefinitionRequestX"]]]:
        '''x block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#x Powerpack#x}
        '''
        result = self._values.get("x")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetScatterplotDefinitionRequestX"]]], result)

    @builtins.property
    def y(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetScatterplotDefinitionRequestY"]]]:
        '''y block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#y Powerpack#y}
        '''
        result = self._values.get("y")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetScatterplotDefinitionRequestY"]]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetScatterplotDefinitionRequest(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetScatterplotDefinitionRequestOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c329698088f12915cbdee68467f85fc5d59fa46047dfcf9eb9fde55e78924995)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putScatterplotTable")
    def put_scatterplot_table(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetScatterplotDefinitionRequestScatterplotTable", typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__628e691c46f289a0adb7e9be538bbae14c08e0b9237bdbfe470533d661089a33)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putScatterplotTable", [value]))

    @jsii.member(jsii_name="putX")
    def put_x(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetScatterplotDefinitionRequestX", typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__460e6b4f5433d15b22ff503c6e64a9dc5a82445b6da4d8d7c75e9bdbaf594f97)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putX", [value]))

    @jsii.member(jsii_name="putY")
    def put_y(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetScatterplotDefinitionRequestY", typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f9008d37060b22d0cab5c6c309ca6760ecfb075fc2277d0dfc5fb9b4ef613a93)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putY", [value]))

    @jsii.member(jsii_name="resetScatterplotTable")
    def reset_scatterplot_table(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetScatterplotTable", []))

    @jsii.member(jsii_name="resetX")
    def reset_x(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetX", []))

    @jsii.member(jsii_name="resetY")
    def reset_y(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetY", []))

    @builtins.property
    @jsii.member(jsii_name="scatterplotTable")
    def scatterplot_table(
        self,
    ) -> "PowerpackWidgetScatterplotDefinitionRequestScatterplotTableList":
        return typing.cast("PowerpackWidgetScatterplotDefinitionRequestScatterplotTableList", jsii.get(self, "scatterplotTable"))

    @builtins.property
    @jsii.member(jsii_name="x")
    def x(self) -> "PowerpackWidgetScatterplotDefinitionRequestXList":
        return typing.cast("PowerpackWidgetScatterplotDefinitionRequestXList", jsii.get(self, "x"))

    @builtins.property
    @jsii.member(jsii_name="y")
    def y(self) -> "PowerpackWidgetScatterplotDefinitionRequestYList":
        return typing.cast("PowerpackWidgetScatterplotDefinitionRequestYList", jsii.get(self, "y"))

    @builtins.property
    @jsii.member(jsii_name="scatterplotTableInput")
    def scatterplot_table_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetScatterplotDefinitionRequestScatterplotTable"]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetScatterplotDefinitionRequestScatterplotTable"]]], jsii.get(self, "scatterplotTableInput"))

    @builtins.property
    @jsii.member(jsii_name="xInput")
    def x_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetScatterplotDefinitionRequestX"]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetScatterplotDefinitionRequestX"]]], jsii.get(self, "xInput"))

    @builtins.property
    @jsii.member(jsii_name="yInput")
    def y_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetScatterplotDefinitionRequestY"]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetScatterplotDefinitionRequestY"]]], jsii.get(self, "yInput"))

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetScatterplotDefinitionRequest]:
        return typing.cast(typing.Optional[PowerpackWidgetScatterplotDefinitionRequest], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetScatterplotDefinitionRequest],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bb023c50594df625dee6ee876dae952f149c20c8bd06ec559e12faa340697311)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestScatterplotTable",
    jsii_struct_bases=[],
    name_mapping={"formula": "formula", "query": "query"},
)
class PowerpackWidgetScatterplotDefinitionRequestScatterplotTable:
    def __init__(
        self,
        *,
        formula: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetScatterplotDefinitionRequestScatterplotTableFormula", typing.Dict[builtins.str, typing.Any]]]]] = None,
        query: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQuery", typing.Dict[builtins.str, typing.Any]]]]] = None,
    ) -> None:
        '''
        :param formula: formula block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#formula Powerpack#formula}
        :param query: query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8cd1c75f805da40e078db02810f38122cf221f034f7141a843cbe2437e319b6a)
            check_type(argname="argument formula", value=formula, expected_type=type_hints["formula"])
            check_type(argname="argument query", value=query, expected_type=type_hints["query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if formula is not None:
            self._values["formula"] = formula
        if query is not None:
            self._values["query"] = query

    @builtins.property
    def formula(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetScatterplotDefinitionRequestScatterplotTableFormula"]]]:
        '''formula block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#formula Powerpack#formula}
        '''
        result = self._values.get("formula")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetScatterplotDefinitionRequestScatterplotTableFormula"]]], result)

    @builtins.property
    def query(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQuery"]]]:
        '''query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        '''
        result = self._values.get("query")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQuery"]]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetScatterplotDefinitionRequestScatterplotTable(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestScatterplotTableFormula",
    jsii_struct_bases=[],
    name_mapping={
        "dimension": "dimension",
        "formula_expression": "formulaExpression",
        "alias": "alias",
    },
)
class PowerpackWidgetScatterplotDefinitionRequestScatterplotTableFormula:
    def __init__(
        self,
        *,
        dimension: builtins.str,
        formula_expression: builtins.str,
        alias: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param dimension: Dimension of the Scatterplot. Valid values are ``x``, ``y``, ``radius``, ``color``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#dimension Powerpack#dimension}
        :param formula_expression: A string expression built from queries, formulas, and functions. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#formula_expression Powerpack#formula_expression}
        :param alias: An expression alias. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#alias Powerpack#alias}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b5f96303bdee6ae64e8a6959e9f4d933a8c30d27b124333543f865ad9e17f2d0)
            check_type(argname="argument dimension", value=dimension, expected_type=type_hints["dimension"])
            check_type(argname="argument formula_expression", value=formula_expression, expected_type=type_hints["formula_expression"])
            check_type(argname="argument alias", value=alias, expected_type=type_hints["alias"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "dimension": dimension,
            "formula_expression": formula_expression,
        }
        if alias is not None:
            self._values["alias"] = alias

    @builtins.property
    def dimension(self) -> builtins.str:
        '''Dimension of the Scatterplot. Valid values are ``x``, ``y``, ``radius``, ``color``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#dimension Powerpack#dimension}
        '''
        result = self._values.get("dimension")
        assert result is not None, "Required property 'dimension' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def formula_expression(self) -> builtins.str:
        '''A string expression built from queries, formulas, and functions.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#formula_expression Powerpack#formula_expression}
        '''
        result = self._values.get("formula_expression")
        assert result is not None, "Required property 'formula_expression' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def alias(self) -> typing.Optional[builtins.str]:
        '''An expression alias.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#alias Powerpack#alias}
        '''
        result = self._values.get("alias")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetScatterplotDefinitionRequestScatterplotTableFormula(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetScatterplotDefinitionRequestScatterplotTableFormulaList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestScatterplotTableFormulaList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__531377c71d303ea15803fc0a10d0ba5a1064f1150bf457c07b7e0d220a8136e6)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetScatterplotDefinitionRequestScatterplotTableFormulaOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f432a5ed4970afa8ff50408bf529addb8e421bc2a894256f92a27a1c051020f5)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetScatterplotDefinitionRequestScatterplotTableFormulaOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5f702194a7b9d4d648024940f7fc4c85c9531ff7459c05cf6f707d1e873ff241)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ed26edc1af84ddb4e1ec73929cdeda8669c847a57e4a2e91832f38812cee6586)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b70195b0c28292123f404a906d5662a7ef9cb0195c1324339aa29a9f611d032c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestScatterplotTableFormula]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestScatterplotTableFormula]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestScatterplotTableFormula]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__665abcdd6c40cc73cf465b67bba9b291445c8d919d0b8e764677303612c85a4e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetScatterplotDefinitionRequestScatterplotTableFormulaOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestScatterplotTableFormulaOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9e4a1d48730aba2d6c4504a1e024c9889ba20dea4f5113164868eff3e87d8573)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetAlias")
    def reset_alias(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAlias", []))

    @builtins.property
    @jsii.member(jsii_name="aliasInput")
    def alias_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aliasInput"))

    @builtins.property
    @jsii.member(jsii_name="dimensionInput")
    def dimension_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "dimensionInput"))

    @builtins.property
    @jsii.member(jsii_name="formulaExpressionInput")
    def formula_expression_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "formulaExpressionInput"))

    @builtins.property
    @jsii.member(jsii_name="alias")
    def alias(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "alias"))

    @alias.setter
    def alias(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__385baeb7163fdb577c33ac4dc7a70499b3fd061c56d190ad72ae3e5961634580)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "alias", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="dimension")
    def dimension(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "dimension"))

    @dimension.setter
    def dimension(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9e352f85d686fae27a580a97c0df7a9efe7cb90061fdc50c8705829d26a73619)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "dimension", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="formulaExpression")
    def formula_expression(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "formulaExpression"))

    @formula_expression.setter
    def formula_expression(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a2cff983cedf8cc111ceeb58e4031fe5bc82702666104804f9f2587a7f2c6fc3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "formulaExpression", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetScatterplotDefinitionRequestScatterplotTableFormula]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetScatterplotDefinitionRequestScatterplotTableFormula]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetScatterplotDefinitionRequestScatterplotTableFormula]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__477738b3cdc74a55daf41245eeb738120fdc7db1a899c3f7ef8e46debf990436)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetScatterplotDefinitionRequestScatterplotTableList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestScatterplotTableList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__aa143f93020e40e008b28dad3ecd44efed17d7713261ed7d6cee5807f2d23e96)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetScatterplotDefinitionRequestScatterplotTableOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e5d60c8fe8b97a2e5553a4cd85e8776a94149f708b29fe4b9a19d05491bbd93d)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetScatterplotDefinitionRequestScatterplotTableOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6e48bd220be7e52c67dd69d4729d5e6d481246a83a796205d9b922fb01060cde)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6d3a3800433ce66b57cff95da7724682e693fe0a45605e0780051f02c614f513)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9763e9a7ba5ef7aa2bd6d103aca95a3909f9d870e55374d57f18601bd21fcdf2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestScatterplotTable]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestScatterplotTable]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestScatterplotTable]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__942d907cb7b66214cb5d3e91ec530fe77cd42ec3f5572848b40ebc40c00b5e9a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetScatterplotDefinitionRequestScatterplotTableOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestScatterplotTableOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bdd870d354a8b790198fc5d435c3840d8d968957daf70748ce0f1a9811e8729e)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putFormula")
    def put_formula(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetScatterplotDefinitionRequestScatterplotTableFormula, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b8bd2ec6a9d5f035e6ffccbd0e74c05403291935b554ec6a2b8f3b7dbcbcde55)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putFormula", [value]))

    @jsii.member(jsii_name="putQuery")
    def put_query(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQuery", typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fe1e68179e4be18ed6a4c52ab4c0b38f1d088998ef8f1a81cb89a1cbba4f10b2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putQuery", [value]))

    @jsii.member(jsii_name="resetFormula")
    def reset_formula(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFormula", []))

    @jsii.member(jsii_name="resetQuery")
    def reset_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetQuery", []))

    @builtins.property
    @jsii.member(jsii_name="formula")
    def formula(
        self,
    ) -> PowerpackWidgetScatterplotDefinitionRequestScatterplotTableFormulaList:
        return typing.cast(PowerpackWidgetScatterplotDefinitionRequestScatterplotTableFormulaList, jsii.get(self, "formula"))

    @builtins.property
    @jsii.member(jsii_name="query")
    def query(
        self,
    ) -> "PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryList":
        return typing.cast("PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryList", jsii.get(self, "query"))

    @builtins.property
    @jsii.member(jsii_name="formulaInput")
    def formula_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestScatterplotTableFormula]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestScatterplotTableFormula]]], jsii.get(self, "formulaInput"))

    @builtins.property
    @jsii.member(jsii_name="queryInput")
    def query_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQuery"]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQuery"]]], jsii.get(self, "queryInput"))

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetScatterplotDefinitionRequestScatterplotTable]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetScatterplotDefinitionRequestScatterplotTable]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetScatterplotDefinitionRequestScatterplotTable]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e0e7c432f2bd03e8e1366c8871e1a2ce628ddcece51b0eb7945a323ea532a889)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQuery",
    jsii_struct_bases=[],
    name_mapping={
        "apm_dependency_stats_query": "apmDependencyStatsQuery",
        "apm_resource_stats_query": "apmResourceStatsQuery",
        "cloud_cost_query": "cloudCostQuery",
        "event_query": "eventQuery",
        "metric_query": "metricQuery",
        "process_query": "processQuery",
        "slo_query": "sloQuery",
    },
)
class PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQuery:
    def __init__(
        self,
        *,
        apm_dependency_stats_query: typing.Optional[typing.Union["PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryApmDependencyStatsQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        apm_resource_stats_query: typing.Optional[typing.Union["PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryApmResourceStatsQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        cloud_cost_query: typing.Optional[typing.Union["PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryCloudCostQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        event_query: typing.Optional[typing.Union["PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        metric_query: typing.Optional[typing.Union["PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryMetricQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        process_query: typing.Optional[typing.Union["PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryProcessQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        slo_query: typing.Optional[typing.Union["PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQuerySloQuery", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param apm_dependency_stats_query: apm_dependency_stats_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#apm_dependency_stats_query Powerpack#apm_dependency_stats_query}
        :param apm_resource_stats_query: apm_resource_stats_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#apm_resource_stats_query Powerpack#apm_resource_stats_query}
        :param cloud_cost_query: cloud_cost_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cloud_cost_query Powerpack#cloud_cost_query}
        :param event_query: event_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#event_query Powerpack#event_query}
        :param metric_query: metric_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric_query Powerpack#metric_query}
        :param process_query: process_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#process_query Powerpack#process_query}
        :param slo_query: slo_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#slo_query Powerpack#slo_query}
        '''
        if isinstance(apm_dependency_stats_query, dict):
            apm_dependency_stats_query = PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryApmDependencyStatsQuery(**apm_dependency_stats_query)
        if isinstance(apm_resource_stats_query, dict):
            apm_resource_stats_query = PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryApmResourceStatsQuery(**apm_resource_stats_query)
        if isinstance(cloud_cost_query, dict):
            cloud_cost_query = PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryCloudCostQuery(**cloud_cost_query)
        if isinstance(event_query, dict):
            event_query = PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQuery(**event_query)
        if isinstance(metric_query, dict):
            metric_query = PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryMetricQuery(**metric_query)
        if isinstance(process_query, dict):
            process_query = PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryProcessQuery(**process_query)
        if isinstance(slo_query, dict):
            slo_query = PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQuerySloQuery(**slo_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2e694451ee73e1f6150093d10263a1883ba6521527062c39c4c6f3e31cf2749e)
            check_type(argname="argument apm_dependency_stats_query", value=apm_dependency_stats_query, expected_type=type_hints["apm_dependency_stats_query"])
            check_type(argname="argument apm_resource_stats_query", value=apm_resource_stats_query, expected_type=type_hints["apm_resource_stats_query"])
            check_type(argname="argument cloud_cost_query", value=cloud_cost_query, expected_type=type_hints["cloud_cost_query"])
            check_type(argname="argument event_query", value=event_query, expected_type=type_hints["event_query"])
            check_type(argname="argument metric_query", value=metric_query, expected_type=type_hints["metric_query"])
            check_type(argname="argument process_query", value=process_query, expected_type=type_hints["process_query"])
            check_type(argname="argument slo_query", value=slo_query, expected_type=type_hints["slo_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if apm_dependency_stats_query is not None:
            self._values["apm_dependency_stats_query"] = apm_dependency_stats_query
        if apm_resource_stats_query is not None:
            self._values["apm_resource_stats_query"] = apm_resource_stats_query
        if cloud_cost_query is not None:
            self._values["cloud_cost_query"] = cloud_cost_query
        if event_query is not None:
            self._values["event_query"] = event_query
        if metric_query is not None:
            self._values["metric_query"] = metric_query
        if process_query is not None:
            self._values["process_query"] = process_query
        if slo_query is not None:
            self._values["slo_query"] = slo_query

    @builtins.property
    def apm_dependency_stats_query(
        self,
    ) -> typing.Optional["PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryApmDependencyStatsQuery"]:
        '''apm_dependency_stats_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#apm_dependency_stats_query Powerpack#apm_dependency_stats_query}
        '''
        result = self._values.get("apm_dependency_stats_query")
        return typing.cast(typing.Optional["PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryApmDependencyStatsQuery"], result)

    @builtins.property
    def apm_resource_stats_query(
        self,
    ) -> typing.Optional["PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryApmResourceStatsQuery"]:
        '''apm_resource_stats_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#apm_resource_stats_query Powerpack#apm_resource_stats_query}
        '''
        result = self._values.get("apm_resource_stats_query")
        return typing.cast(typing.Optional["PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryApmResourceStatsQuery"], result)

    @builtins.property
    def cloud_cost_query(
        self,
    ) -> typing.Optional["PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryCloudCostQuery"]:
        '''cloud_cost_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cloud_cost_query Powerpack#cloud_cost_query}
        '''
        result = self._values.get("cloud_cost_query")
        return typing.cast(typing.Optional["PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryCloudCostQuery"], result)

    @builtins.property
    def event_query(
        self,
    ) -> typing.Optional["PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQuery"]:
        '''event_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#event_query Powerpack#event_query}
        '''
        result = self._values.get("event_query")
        return typing.cast(typing.Optional["PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQuery"], result)

    @builtins.property
    def metric_query(
        self,
    ) -> typing.Optional["PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryMetricQuery"]:
        '''metric_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric_query Powerpack#metric_query}
        '''
        result = self._values.get("metric_query")
        return typing.cast(typing.Optional["PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryMetricQuery"], result)

    @builtins.property
    def process_query(
        self,
    ) -> typing.Optional["PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryProcessQuery"]:
        '''process_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#process_query Powerpack#process_query}
        '''
        result = self._values.get("process_query")
        return typing.cast(typing.Optional["PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryProcessQuery"], result)

    @builtins.property
    def slo_query(
        self,
    ) -> typing.Optional["PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQuerySloQuery"]:
        '''slo_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#slo_query Powerpack#slo_query}
        '''
        result = self._values.get("slo_query")
        return typing.cast(typing.Optional["PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQuerySloQuery"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryApmDependencyStatsQuery",
    jsii_struct_bases=[],
    name_mapping={
        "data_source": "dataSource",
        "env": "env",
        "name": "name",
        "operation_name": "operationName",
        "resource_name": "resourceName",
        "service": "service",
        "stat": "stat",
        "cross_org_uuids": "crossOrgUuids",
        "is_upstream": "isUpstream",
        "primary_tag_name": "primaryTagName",
        "primary_tag_value": "primaryTagValue",
    },
)
class PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryApmDependencyStatsQuery:
    def __init__(
        self,
        *,
        data_source: builtins.str,
        env: builtins.str,
        name: builtins.str,
        operation_name: builtins.str,
        resource_name: builtins.str,
        service: builtins.str,
        stat: builtins.str,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        is_upstream: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        primary_tag_name: typing.Optional[builtins.str] = None,
        primary_tag_value: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param data_source: The data source for APM Dependency Stats queries. Valid values are ``apm_dependency_stats``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param env: APM environment. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#env Powerpack#env}
        :param name: The name of query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param operation_name: Name of operation on service. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#operation_name Powerpack#operation_name}
        :param resource_name: APM resource. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#resource_name Powerpack#resource_name}
        :param service: APM service. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#service Powerpack#service}
        :param stat: APM statistic. Valid values are ``avg_duration``, ``avg_root_duration``, ``avg_spans_per_trace``, ``error_rate``, ``pct_exec_time``, ``pct_of_traces``, ``total_traces_count``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#stat Powerpack#stat}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param is_upstream: Determines whether stats for upstream or downstream dependencies should be queried. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#is_upstream Powerpack#is_upstream}
        :param primary_tag_name: The name of the second primary tag used within APM; required when ``primary_tag_value`` is specified. See https://docs.datadoghq.com/tracing/guide/setting_primary_tags_to_scope/#add-a-second-primary-tag-in-datadog. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_name Powerpack#primary_tag_name}
        :param primary_tag_value: Filter APM data by the second primary tag. ``primary_tag_name`` must also be specified. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_value Powerpack#primary_tag_value}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cf113f4730868b12458e02706ef914c06cfbe2e677683a5678b40ffa57b6beb9)
            check_type(argname="argument data_source", value=data_source, expected_type=type_hints["data_source"])
            check_type(argname="argument env", value=env, expected_type=type_hints["env"])
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument operation_name", value=operation_name, expected_type=type_hints["operation_name"])
            check_type(argname="argument resource_name", value=resource_name, expected_type=type_hints["resource_name"])
            check_type(argname="argument service", value=service, expected_type=type_hints["service"])
            check_type(argname="argument stat", value=stat, expected_type=type_hints["stat"])
            check_type(argname="argument cross_org_uuids", value=cross_org_uuids, expected_type=type_hints["cross_org_uuids"])
            check_type(argname="argument is_upstream", value=is_upstream, expected_type=type_hints["is_upstream"])
            check_type(argname="argument primary_tag_name", value=primary_tag_name, expected_type=type_hints["primary_tag_name"])
            check_type(argname="argument primary_tag_value", value=primary_tag_value, expected_type=type_hints["primary_tag_value"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "data_source": data_source,
            "env": env,
            "name": name,
            "operation_name": operation_name,
            "resource_name": resource_name,
            "service": service,
            "stat": stat,
        }
        if cross_org_uuids is not None:
            self._values["cross_org_uuids"] = cross_org_uuids
        if is_upstream is not None:
            self._values["is_upstream"] = is_upstream
        if primary_tag_name is not None:
            self._values["primary_tag_name"] = primary_tag_name
        if primary_tag_value is not None:
            self._values["primary_tag_value"] = primary_tag_value

    @builtins.property
    def data_source(self) -> builtins.str:
        '''The data source for APM Dependency Stats queries. Valid values are ``apm_dependency_stats``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        '''
        result = self._values.get("data_source")
        assert result is not None, "Required property 'data_source' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def env(self) -> builtins.str:
        '''APM environment.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#env Powerpack#env}
        '''
        result = self._values.get("env")
        assert result is not None, "Required property 'env' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def name(self) -> builtins.str:
        '''The name of query for use in formulas.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        '''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def operation_name(self) -> builtins.str:
        '''Name of operation on service.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#operation_name Powerpack#operation_name}
        '''
        result = self._values.get("operation_name")
        assert result is not None, "Required property 'operation_name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def resource_name(self) -> builtins.str:
        '''APM resource.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#resource_name Powerpack#resource_name}
        '''
        result = self._values.get("resource_name")
        assert result is not None, "Required property 'resource_name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def service(self) -> builtins.str:
        '''APM service.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#service Powerpack#service}
        '''
        result = self._values.get("service")
        assert result is not None, "Required property 'service' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def stat(self) -> builtins.str:
        '''APM statistic. Valid values are ``avg_duration``, ``avg_root_duration``, ``avg_spans_per_trace``, ``error_rate``, ``pct_exec_time``, ``pct_of_traces``, ``total_traces_count``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#stat Powerpack#stat}
        '''
        result = self._values.get("stat")
        assert result is not None, "Required property 'stat' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def cross_org_uuids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''The source organization UUID for cross organization queries. Feature in Private Beta.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        '''
        result = self._values.get("cross_org_uuids")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def is_upstream(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        '''Determines whether stats for upstream or downstream dependencies should be queried.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#is_upstream Powerpack#is_upstream}
        '''
        result = self._values.get("is_upstream")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)

    @builtins.property
    def primary_tag_name(self) -> typing.Optional[builtins.str]:
        '''The name of the second primary tag used within APM; required when ``primary_tag_value`` is specified. See https://docs.datadoghq.com/tracing/guide/setting_primary_tags_to_scope/#add-a-second-primary-tag-in-datadog.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_name Powerpack#primary_tag_name}
        '''
        result = self._values.get("primary_tag_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def primary_tag_value(self) -> typing.Optional[builtins.str]:
        '''Filter APM data by the second primary tag. ``primary_tag_name`` must also be specified.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_value Powerpack#primary_tag_value}
        '''
        result = self._values.get("primary_tag_value")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryApmDependencyStatsQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryApmDependencyStatsQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryApmDependencyStatsQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4bac5d2c4e4054bf817bb0072bb595a1900ea95dea84c7e5966165d35a4d922d)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetCrossOrgUuids")
    def reset_cross_org_uuids(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCrossOrgUuids", []))

    @jsii.member(jsii_name="resetIsUpstream")
    def reset_is_upstream(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetIsUpstream", []))

    @jsii.member(jsii_name="resetPrimaryTagName")
    def reset_primary_tag_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPrimaryTagName", []))

    @jsii.member(jsii_name="resetPrimaryTagValue")
    def reset_primary_tag_value(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPrimaryTagValue", []))

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuidsInput")
    def cross_org_uuids_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "crossOrgUuidsInput"))

    @builtins.property
    @jsii.member(jsii_name="dataSourceInput")
    def data_source_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "dataSourceInput"))

    @builtins.property
    @jsii.member(jsii_name="envInput")
    def env_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "envInput"))

    @builtins.property
    @jsii.member(jsii_name="isUpstreamInput")
    def is_upstream_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "isUpstreamInput"))

    @builtins.property
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property
    @jsii.member(jsii_name="operationNameInput")
    def operation_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "operationNameInput"))

    @builtins.property
    @jsii.member(jsii_name="primaryTagNameInput")
    def primary_tag_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "primaryTagNameInput"))

    @builtins.property
    @jsii.member(jsii_name="primaryTagValueInput")
    def primary_tag_value_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "primaryTagValueInput"))

    @builtins.property
    @jsii.member(jsii_name="resourceNameInput")
    def resource_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "resourceNameInput"))

    @builtins.property
    @jsii.member(jsii_name="serviceInput")
    def service_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "serviceInput"))

    @builtins.property
    @jsii.member(jsii_name="statInput")
    def stat_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "statInput"))

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuids")
    def cross_org_uuids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "crossOrgUuids"))

    @cross_org_uuids.setter
    def cross_org_uuids(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__51b34c1937bd33e97ed44442e5542e871705f719b3a2d83d7bfcfc37d9384ebf)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "crossOrgUuids", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="dataSource")
    def data_source(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "dataSource"))

    @data_source.setter
    def data_source(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__12f6f0338d31d29e748b36593760334c916e547ef9058cd1873479ddf4427138)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "dataSource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="env")
    def env(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "env"))

    @env.setter
    def env(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4da22da386bad2884f3b8b6bf2d85565cc0353820a09b66e19482abb2064e6b3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "env", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="isUpstream")
    def is_upstream(self) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "isUpstream"))

    @is_upstream.setter
    def is_upstream(
        self,
        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8ce0e554f151e87187a11f27bff350868357e598a95b0546eddf3f3108dcafc0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "isUpstream", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__093a6964e810e710536b2da4d7408e90432fee2fd21d2ddbf7d03981ae8d74c4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "name", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="operationName")
    def operation_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "operationName"))

    @operation_name.setter
    def operation_name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f56140eab51822bdc0897d6456f2fca9a4240f2d238a625c5248f2976faddfa6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "operationName", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="primaryTagName")
    def primary_tag_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "primaryTagName"))

    @primary_tag_name.setter
    def primary_tag_name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7b89ffe0f91ead35cdab02230791a88f4b1157091d36256920d66594dc9b77e9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "primaryTagName", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="primaryTagValue")
    def primary_tag_value(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "primaryTagValue"))

    @primary_tag_value.setter
    def primary_tag_value(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6bb2c4c186e480717172aa4cbc2a115b82ed3460da90dd01ad670c79d4fa52f3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "primaryTagValue", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="resourceName")
    def resource_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "resourceName"))

    @resource_name.setter
    def resource_name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5fbdea236e6d46a775122c4928e29448858243193d7d625585d92c886aac6751)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "resourceName", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="service")
    def service(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "service"))

    @service.setter
    def service(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__84265b70e9db05d2f568dd1f4bd87649a023270213bf886b53d3c2d6da262965)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "service", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="stat")
    def stat(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "stat"))

    @stat.setter
    def stat(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6a608dbd4d59406c706036a74f6123973eceef60681c8cdd44e846f2d94f7916)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "stat", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryApmDependencyStatsQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryApmDependencyStatsQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryApmDependencyStatsQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9d5a6efed4ac688fe156abfae36c8186782c116cafc2b47672d765aaa07c26f0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryApmResourceStatsQuery",
    jsii_struct_bases=[],
    name_mapping={
        "data_source": "dataSource",
        "env": "env",
        "name": "name",
        "service": "service",
        "stat": "stat",
        "cross_org_uuids": "crossOrgUuids",
        "group_by": "groupBy",
        "operation_name": "operationName",
        "primary_tag_name": "primaryTagName",
        "primary_tag_value": "primaryTagValue",
        "resource_name": "resourceName",
    },
)
class PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryApmResourceStatsQuery:
    def __init__(
        self,
        *,
        data_source: builtins.str,
        env: builtins.str,
        name: builtins.str,
        service: builtins.str,
        stat: builtins.str,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        group_by: typing.Optional[typing.Sequence[builtins.str]] = None,
        operation_name: typing.Optional[builtins.str] = None,
        primary_tag_name: typing.Optional[builtins.str] = None,
        primary_tag_value: typing.Optional[builtins.str] = None,
        resource_name: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param data_source: The data source for APM Resource Stats queries. Valid values are ``apm_resource_stats``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param env: APM environment. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#env Powerpack#env}
        :param name: The name of query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param service: APM service. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#service Powerpack#service}
        :param stat: APM statistic. Valid values are ``errors``, ``error_rate``, ``hits``, ``latency_avg``, ``latency_distribution``, ``latency_max``, ``latency_p50``, ``latency_p75``, ``latency_p90``, ``latency_p95``, ``latency_p99``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#stat Powerpack#stat}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param group_by: Array of fields to group results by. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param operation_name: Name of operation on service. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#operation_name Powerpack#operation_name}
        :param primary_tag_name: The name of the second primary tag used within APM; required when ``primary_tag_value`` is specified. See https://docs.datadoghq.com/tracing/guide/setting_primary_tags_to_scope/#add-a-second-primary-tag-in-datadog. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_name Powerpack#primary_tag_name}
        :param primary_tag_value: Filter APM data by the second primary tag. ``primary_tag_name`` must also be specified. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_value Powerpack#primary_tag_value}
        :param resource_name: APM resource. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#resource_name Powerpack#resource_name}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c2ee3e6cc80e8c82c9eb508c4ce4b16351ba597efef48393ea960c709a8daed5)
            check_type(argname="argument data_source", value=data_source, expected_type=type_hints["data_source"])
            check_type(argname="argument env", value=env, expected_type=type_hints["env"])
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument service", value=service, expected_type=type_hints["service"])
            check_type(argname="argument stat", value=stat, expected_type=type_hints["stat"])
            check_type(argname="argument cross_org_uuids", value=cross_org_uuids, expected_type=type_hints["cross_org_uuids"])
            check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
            check_type(argname="argument operation_name", value=operation_name, expected_type=type_hints["operation_name"])
            check_type(argname="argument primary_tag_name", value=primary_tag_name, expected_type=type_hints["primary_tag_name"])
            check_type(argname="argument primary_tag_value", value=primary_tag_value, expected_type=type_hints["primary_tag_value"])
            check_type(argname="argument resource_name", value=resource_name, expected_type=type_hints["resource_name"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "data_source": data_source,
            "env": env,
            "name": name,
            "service": service,
            "stat": stat,
        }
        if cross_org_uuids is not None:
            self._values["cross_org_uuids"] = cross_org_uuids
        if group_by is not None:
            self._values["group_by"] = group_by
        if operation_name is not None:
            self._values["operation_name"] = operation_name
        if primary_tag_name is not None:
            self._values["primary_tag_name"] = primary_tag_name
        if primary_tag_value is not None:
            self._values["primary_tag_value"] = primary_tag_value
        if resource_name is not None:
            self._values["resource_name"] = resource_name

    @builtins.property
    def data_source(self) -> builtins.str:
        '''The data source for APM Resource Stats queries. Valid values are ``apm_resource_stats``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        '''
        result = self._values.get("data_source")
        assert result is not None, "Required property 'data_source' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def env(self) -> builtins.str:
        '''APM environment.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#env Powerpack#env}
        '''
        result = self._values.get("env")
        assert result is not None, "Required property 'env' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def name(self) -> builtins.str:
        '''The name of query for use in formulas.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        '''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def service(self) -> builtins.str:
        '''APM service.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#service Powerpack#service}
        '''
        result = self._values.get("service")
        assert result is not None, "Required property 'service' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def stat(self) -> builtins.str:
        '''APM statistic. Valid values are ``errors``, ``error_rate``, ``hits``, ``latency_avg``, ``latency_distribution``, ``latency_max``, ``latency_p50``, ``latency_p75``, ``latency_p90``, ``latency_p95``, ``latency_p99``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#stat Powerpack#stat}
        '''
        result = self._values.get("stat")
        assert result is not None, "Required property 'stat' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def cross_org_uuids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''The source organization UUID for cross organization queries. Feature in Private Beta.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        '''
        result = self._values.get("cross_org_uuids")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def group_by(self) -> typing.Optional[typing.List[builtins.str]]:
        '''Array of fields to group results by.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        '''
        result = self._values.get("group_by")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def operation_name(self) -> typing.Optional[builtins.str]:
        '''Name of operation on service.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#operation_name Powerpack#operation_name}
        '''
        result = self._values.get("operation_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def primary_tag_name(self) -> typing.Optional[builtins.str]:
        '''The name of the second primary tag used within APM; required when ``primary_tag_value`` is specified. See https://docs.datadoghq.com/tracing/guide/setting_primary_tags_to_scope/#add-a-second-primary-tag-in-datadog.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_name Powerpack#primary_tag_name}
        '''
        result = self._values.get("primary_tag_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def primary_tag_value(self) -> typing.Optional[builtins.str]:
        '''Filter APM data by the second primary tag. ``primary_tag_name`` must also be specified.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_value Powerpack#primary_tag_value}
        '''
        result = self._values.get("primary_tag_value")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def resource_name(self) -> typing.Optional[builtins.str]:
        '''APM resource.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#resource_name Powerpack#resource_name}
        '''
        result = self._values.get("resource_name")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryApmResourceStatsQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryApmResourceStatsQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryApmResourceStatsQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a4f4f4b57995a670469811233f12c4bff874c2398551b8e56c8524341f0049db)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetCrossOrgUuids")
    def reset_cross_org_uuids(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCrossOrgUuids", []))

    @jsii.member(jsii_name="resetGroupBy")
    def reset_group_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGroupBy", []))

    @jsii.member(jsii_name="resetOperationName")
    def reset_operation_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetOperationName", []))

    @jsii.member(jsii_name="resetPrimaryTagName")
    def reset_primary_tag_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPrimaryTagName", []))

    @jsii.member(jsii_name="resetPrimaryTagValue")
    def reset_primary_tag_value(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPrimaryTagValue", []))

    @jsii.member(jsii_name="resetResourceName")
    def reset_resource_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetResourceName", []))

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuidsInput")
    def cross_org_uuids_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "crossOrgUuidsInput"))

    @builtins.property
    @jsii.member(jsii_name="dataSourceInput")
    def data_source_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "dataSourceInput"))

    @builtins.property
    @jsii.member(jsii_name="envInput")
    def env_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "envInput"))

    @builtins.property
    @jsii.member(jsii_name="groupByInput")
    def group_by_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "groupByInput"))

    @builtins.property
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property
    @jsii.member(jsii_name="operationNameInput")
    def operation_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "operationNameInput"))

    @builtins.property
    @jsii.member(jsii_name="primaryTagNameInput")
    def primary_tag_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "primaryTagNameInput"))

    @builtins.property
    @jsii.member(jsii_name="primaryTagValueInput")
    def primary_tag_value_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "primaryTagValueInput"))

    @builtins.property
    @jsii.member(jsii_name="resourceNameInput")
    def resource_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "resourceNameInput"))

    @builtins.property
    @jsii.member(jsii_name="serviceInput")
    def service_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "serviceInput"))

    @builtins.property
    @jsii.member(jsii_name="statInput")
    def stat_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "statInput"))

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuids")
    def cross_org_uuids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "crossOrgUuids"))

    @cross_org_uuids.setter
    def cross_org_uuids(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__918f4d5cb32eb6a6e5fa0d0c9ebfea05de79ddc1f6a0477aa289d1a4513cee7b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "crossOrgUuids", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="dataSource")
    def data_source(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "dataSource"))

    @data_source.setter
    def data_source(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2837f1a61142bc63c6d810f5bc6a996ec28e1ef5962ded84966c05abb50ecb09)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "dataSource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="env")
    def env(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "env"))

    @env.setter
    def env(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__42c23ad3f86cae9fce3c416a09507253d7e16cf678c701b7381946b6bd0607a5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "env", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="groupBy")
    def group_by(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "groupBy"))

    @group_by.setter
    def group_by(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5f108722ff7835f2079f6b88e3e302489316e6d8aad6a1c2b38635fc3dfcfe94)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "groupBy", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5b6bd7fb4c4936c077085fb2cb38117c80505dabf6dec0fb2f80cf58fd0236cb)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "name", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="operationName")
    def operation_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "operationName"))

    @operation_name.setter
    def operation_name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__52155c80905bc6087fea1e76c390a46567e22970d93f7e4c9c4464c4618714fe)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "operationName", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="primaryTagName")
    def primary_tag_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "primaryTagName"))

    @primary_tag_name.setter
    def primary_tag_name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7fc09d73d420a7c3e785a396ba08615ec289f1ee63efe7854f007697a5e75a47)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "primaryTagName", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="primaryTagValue")
    def primary_tag_value(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "primaryTagValue"))

    @primary_tag_value.setter
    def primary_tag_value(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6149fd817f84cf668afbacc73a2b91f6673d971b439e738f124c3f580b497349)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "primaryTagValue", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="resourceName")
    def resource_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "resourceName"))

    @resource_name.setter
    def resource_name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8d8ae8603641d57031426c5ea9fd97a5fd0e3c3206836bff68867a104b2d4ad9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "resourceName", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="service")
    def service(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "service"))

    @service.setter
    def service(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ae55d67f6d0e7d18162135c50e405e81c0f6e61ac03f45ec29360c5a50f63ae2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "service", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="stat")
    def stat(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "stat"))

    @stat.setter
    def stat(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e36977653df495a6674a62fa930e1d9d80c6a3a73152e6254bd79ad8da5dd688)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "stat", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryApmResourceStatsQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryApmResourceStatsQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryApmResourceStatsQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5bc03de1db0ef5ef9a3ff47ea2d32a960a4f2cbcfde60ec1f4307b0bea11a914)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryCloudCostQuery",
    jsii_struct_bases=[],
    name_mapping={
        "data_source": "dataSource",
        "name": "name",
        "query": "query",
        "aggregator": "aggregator",
        "cross_org_uuids": "crossOrgUuids",
    },
)
class PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryCloudCostQuery:
    def __init__(
        self,
        *,
        data_source: builtins.str,
        name: builtins.str,
        query: builtins.str,
        aggregator: typing.Optional[builtins.str] = None,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
    ) -> None:
        '''
        :param data_source: The data source for cloud cost queries. Valid values are ``cloud_cost``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param name: The name of the query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param query: The cloud cost query definition. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        :param aggregator: The aggregation methods available for cloud cost queries. Valid values are ``avg``, ``last``, ``max``, ``min``, ``sum``, ``percentile``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregator Powerpack#aggregator}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__783eeed3cdb04ac238804cba42f93e01d1a5d50364785b6929507ea1ef3af3b7)
            check_type(argname="argument data_source", value=data_source, expected_type=type_hints["data_source"])
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument query", value=query, expected_type=type_hints["query"])
            check_type(argname="argument aggregator", value=aggregator, expected_type=type_hints["aggregator"])
            check_type(argname="argument cross_org_uuids", value=cross_org_uuids, expected_type=type_hints["cross_org_uuids"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "data_source": data_source,
            "name": name,
            "query": query,
        }
        if aggregator is not None:
            self._values["aggregator"] = aggregator
        if cross_org_uuids is not None:
            self._values["cross_org_uuids"] = cross_org_uuids

    @builtins.property
    def data_source(self) -> builtins.str:
        '''The data source for cloud cost queries. Valid values are ``cloud_cost``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        '''
        result = self._values.get("data_source")
        assert result is not None, "Required property 'data_source' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def name(self) -> builtins.str:
        '''The name of the query for use in formulas.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        '''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def query(self) -> builtins.str:
        '''The cloud cost query definition.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        '''
        result = self._values.get("query")
        assert result is not None, "Required property 'query' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def aggregator(self) -> typing.Optional[builtins.str]:
        '''The aggregation methods available for cloud cost queries. Valid values are ``avg``, ``last``, ``max``, ``min``, ``sum``, ``percentile``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregator Powerpack#aggregator}
        '''
        result = self._values.get("aggregator")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def cross_org_uuids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''The source organization UUID for cross organization queries. Feature in Private Beta.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        '''
        result = self._values.get("cross_org_uuids")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryCloudCostQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryCloudCostQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryCloudCostQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b87bc5a937f989fb604f584d2a514cd1a0e94da1375af5ba23576841c5b56275)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetAggregator")
    def reset_aggregator(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAggregator", []))

    @jsii.member(jsii_name="resetCrossOrgUuids")
    def reset_cross_org_uuids(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCrossOrgUuids", []))

    @builtins.property
    @jsii.member(jsii_name="aggregatorInput")
    def aggregator_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregatorInput"))

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuidsInput")
    def cross_org_uuids_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "crossOrgUuidsInput"))

    @builtins.property
    @jsii.member(jsii_name="dataSourceInput")
    def data_source_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "dataSourceInput"))

    @builtins.property
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property
    @jsii.member(jsii_name="queryInput")
    def query_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "queryInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregator")
    def aggregator(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregator"))

    @aggregator.setter
    def aggregator(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ca4d78e2e7dcf40b874b2820ec67d315e1fe8a93f2bddbcffa1693503b28a6de)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregator", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuids")
    def cross_org_uuids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "crossOrgUuids"))

    @cross_org_uuids.setter
    def cross_org_uuids(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8bf1dd44f68ac5c16faa8737ab92e77b33cc5f4a674215120f02cfd5840050a3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "crossOrgUuids", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="dataSource")
    def data_source(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "dataSource"))

    @data_source.setter
    def data_source(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__03c4ad34d034abb1c1b31484292db144673dd3e06c14905cc6cc056f2d093e41)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "dataSource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7b4f50b8d449ef1e44cd7a20d8859fe8fdf5fd99ef381686183803e82a364e55)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "name", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="query")
    def query(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "query"))

    @query.setter
    def query(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f2deb15e1299c0657e6e0383bf1ff878040906662602fa729f0c7003a60ab0ce)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "query", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryCloudCostQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryCloudCostQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryCloudCostQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0c5156d6a8698448958ca5fbf0691b9df90d35a732e0481427be15a64e35e06d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQuery",
    jsii_struct_bases=[],
    name_mapping={
        "compute": "compute",
        "data_source": "dataSource",
        "name": "name",
        "cross_org_uuids": "crossOrgUuids",
        "group_by": "groupBy",
        "indexes": "indexes",
        "search": "search",
        "storage": "storage",
    },
)
class PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQuery:
    def __init__(
        self,
        *,
        compute: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQueryCompute", typing.Dict[builtins.str, typing.Any]]]],
        data_source: builtins.str,
        name: builtins.str,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQueryGroupBy", typing.Dict[builtins.str, typing.Any]]]]] = None,
        indexes: typing.Optional[typing.Sequence[builtins.str]] = None,
        search: typing.Optional[typing.Union["PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQuerySearch", typing.Dict[builtins.str, typing.Any]]] = None,
        storage: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param compute: compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute Powerpack#compute}
        :param data_source: The data source for event platform-based queries. Valid values are ``logs``, ``spans``, ``network``, ``rum``, ``security_signals``, ``profiles``, ``audit``, ``events``, ``ci_tests``, ``ci_pipelines``, ``incident_analytics``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param name: The name of query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param indexes: An array of index names to query in the stream. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#indexes Powerpack#indexes}
        :param search: search block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search Powerpack#search}
        :param storage: Storage location (private beta). Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#storage Powerpack#storage}
        '''
        if isinstance(search, dict):
            search = PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQuerySearch(**search)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__44c65c685f014b0dd9944555e2180e9a699ebe687396104df5b8be45972ae41e)
            check_type(argname="argument compute", value=compute, expected_type=type_hints["compute"])
            check_type(argname="argument data_source", value=data_source, expected_type=type_hints["data_source"])
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument cross_org_uuids", value=cross_org_uuids, expected_type=type_hints["cross_org_uuids"])
            check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
            check_type(argname="argument indexes", value=indexes, expected_type=type_hints["indexes"])
            check_type(argname="argument search", value=search, expected_type=type_hints["search"])
            check_type(argname="argument storage", value=storage, expected_type=type_hints["storage"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "compute": compute,
            "data_source": data_source,
            "name": name,
        }
        if cross_org_uuids is not None:
            self._values["cross_org_uuids"] = cross_org_uuids
        if group_by is not None:
            self._values["group_by"] = group_by
        if indexes is not None:
            self._values["indexes"] = indexes
        if search is not None:
            self._values["search"] = search
        if storage is not None:
            self._values["storage"] = storage

    @builtins.property
    def compute(
        self,
    ) -> typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQueryCompute"]]:
        '''compute block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute Powerpack#compute}
        '''
        result = self._values.get("compute")
        assert result is not None, "Required property 'compute' is missing"
        return typing.cast(typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQueryCompute"]], result)

    @builtins.property
    def data_source(self) -> builtins.str:
        '''The data source for event platform-based queries.

        Valid values are ``logs``, ``spans``, ``network``, ``rum``, ``security_signals``, ``profiles``, ``audit``, ``events``, ``ci_tests``, ``ci_pipelines``, ``incident_analytics``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        '''
        result = self._values.get("data_source")
        assert result is not None, "Required property 'data_source' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def name(self) -> builtins.str:
        '''The name of query for use in formulas.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        '''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def cross_org_uuids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''The source organization UUID for cross organization queries. Feature in Private Beta.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        '''
        result = self._values.get("cross_org_uuids")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def group_by(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQueryGroupBy"]]]:
        '''group_by block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        '''
        result = self._values.get("group_by")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQueryGroupBy"]]], result)

    @builtins.property
    def indexes(self) -> typing.Optional[typing.List[builtins.str]]:
        '''An array of index names to query in the stream.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#indexes Powerpack#indexes}
        '''
        result = self._values.get("indexes")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def search(
        self,
    ) -> typing.Optional["PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQuerySearch"]:
        '''search block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search Powerpack#search}
        '''
        result = self._values.get("search")
        return typing.cast(typing.Optional["PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQuerySearch"], result)

    @builtins.property
    def storage(self) -> typing.Optional[builtins.str]:
        '''Storage location (private beta).

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#storage Powerpack#storage}
        '''
        result = self._values.get("storage")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQueryCompute",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "interval": "interval",
        "metric": "metric",
    },
)
class PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQueryCompute:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        interval: typing.Optional[jsii.Number] = None,
        metric: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation methods for event platform queries. Valid values are ``count``, ``cardinality``, ``median``, ``pc75``, ``pc90``, ``pc95``, ``pc98``, ``pc99``, ``sum``, ``min``, ``max``, ``avg``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param interval: A time interval in milliseconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        :param metric: The measurable attribute to compute. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__146a1f4463beb3172e4b3a4473b4611a613e8d669549573806315165e6b5abf5)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
            check_type(argname="argument metric", value=metric, expected_type=type_hints["metric"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if interval is not None:
            self._values["interval"] = interval
        if metric is not None:
            self._values["metric"] = metric

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation methods for event platform queries.

        Valid values are ``count``, ``cardinality``, ``median``, ``pc75``, ``pc90``, ``pc95``, ``pc98``, ``pc99``, ``sum``, ``min``, ``max``, ``avg``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''A time interval in milliseconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def metric(self) -> typing.Optional[builtins.str]:
        '''The measurable attribute to compute.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        '''
        result = self._values.get("metric")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQueryCompute(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQueryComputeList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQueryComputeList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ffd141e4cb4e8124d8bc9e6178ef60ea9248489bb5eb29a583ece2505a3e040a)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQueryComputeOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5e9388319e8b6b00ee0c542abbf4bab7c41bde6e7d895aac322fb263b8b9c75f)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQueryComputeOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__04d13cfee0cb778be66c4f0aa376ef7d5994d6cc932fe4e8745616eb6b923d57)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__918dda8e52c13ca3129ebb50eb0700ab49ea857a9d49e213313800d78f326ab7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d8f1d9d0b0e7befaf76992f2808b4fd7c35b0a606f1c8c9833ff6f08d3408c0c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQueryCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQueryCompute]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQueryCompute]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4f9295f4ae7842792d7179809cc44ed8824eedf5c7b8f5d6392e5736c7244654)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQueryComputeOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQueryComputeOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__184d80cd5b4e72cd86d4a4dbaaa2560dde28926aa227637519b54d5e1d2b2e06)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @jsii.member(jsii_name="resetMetric")
    def reset_metric(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMetric", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="metricInput")
    def metric_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "metricInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b6a2ff0c294a6e71b6166081db1c60c4df1f2b727eee86f122de122947df5733)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__08a61c6cc879aaa7f50fc14fa486e02f343ea6f8c691d39e796a653ac72ac347)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="metric")
    def metric(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "metric"))

    @metric.setter
    def metric(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f63b48afdb972e1a67368f582f9873ee2fb7c437bc9a666c36611726d351bbd6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "metric", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQueryCompute]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQueryCompute]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQueryCompute]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__776c1ecd54001a63955205a5baaee4e579e21ae5fabba892bd21edf5bf12de8b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQueryGroupBy",
    jsii_struct_bases=[],
    name_mapping={"facet": "facet", "limit": "limit", "sort": "sort"},
)
class PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQueryGroupBy:
    def __init__(
        self,
        *,
        facet: builtins.str,
        limit: typing.Optional[jsii.Number] = None,
        sort: typing.Optional[typing.Union["PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQueryGroupBySort", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param facet: The event facet. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param limit: The number of groups to return. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param sort: sort block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort Powerpack#sort}
        '''
        if isinstance(sort, dict):
            sort = PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQueryGroupBySort(**sort)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c8a0740fe4dd93d44daee94b54e1e5746aff66ddae3840225cecf5767f98ac93)
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
            check_type(argname="argument sort", value=sort, expected_type=type_hints["sort"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "facet": facet,
        }
        if limit is not None:
            self._values["limit"] = limit
        if sort is not None:
            self._values["sort"] = sort

    @builtins.property
    def facet(self) -> builtins.str:
        '''The event facet.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        assert result is not None, "Required property 'facet' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def limit(self) -> typing.Optional[jsii.Number]:
        '''The number of groups to return.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        '''
        result = self._values.get("limit")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def sort(
        self,
    ) -> typing.Optional["PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQueryGroupBySort"]:
        '''sort block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort Powerpack#sort}
        '''
        result = self._values.get("sort")
        return typing.cast(typing.Optional["PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQueryGroupBySort"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQueryGroupBy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQueryGroupByList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQueryGroupByList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ba668dad112e83b366d90c692585aadf5d4bbfcef3ed63fd2dcd27f77be6e5f2)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQueryGroupByOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2b74d10c5142d19cd736ed9a0c563e594b02b87730fbd3d1a3c84993c745f4bc)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQueryGroupByOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c876c67a3e1d309f1264f3b34f0f46fb16d56eadd68edf856aaf6a4e1db180b3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9e57629e9803138ee2504650c34ce6fb1f6190124b26805d5ee1e1c9eb1caaed)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__db30cf3278a15c9e8e5d94f7c53259d3ea16dab8debbd364d3e8a8450472f854)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQueryGroupBy]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQueryGroupBy]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__93b56d97b21ddb2d41e0aaaaf75c71ed7a39281d0f9219d6c292acdb6c0a747a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQueryGroupByOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQueryGroupByOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__848ac0f9f68d2de4b9360882cb8c5850088b79ec3802064b773ff208a8fb91ed)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putSort")
    def put_sort(
        self,
        *,
        aggregation: builtins.str,
        metric: typing.Optional[builtins.str] = None,
        order: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation methods for the event platform queries. Valid values are ``count``, ``cardinality``, ``median``, ``pc75``, ``pc90``, ``pc95``, ``pc98``, ``pc99``, ``sum``, ``min``, ``max``, ``avg``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param metric: The metric used for sorting group by results. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        :param order: Direction of sort. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        value = PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQueryGroupBySort(
            aggregation=aggregation, metric=metric, order=order
        )

        return typing.cast(None, jsii.invoke(self, "putSort", [value]))

    @jsii.member(jsii_name="resetLimit")
    def reset_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLimit", []))

    @jsii.member(jsii_name="resetSort")
    def reset_sort(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSort", []))

    @builtins.property
    @jsii.member(jsii_name="sort")
    def sort(
        self,
    ) -> "PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQueryGroupBySortOutputReference":
        return typing.cast("PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQueryGroupBySortOutputReference", jsii.get(self, "sort"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="limitInput")
    def limit_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "limitInput"))

    @builtins.property
    @jsii.member(jsii_name="sortInput")
    def sort_input(
        self,
    ) -> typing.Optional["PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQueryGroupBySort"]:
        return typing.cast(typing.Optional["PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQueryGroupBySort"], jsii.get(self, "sortInput"))

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__02210ef287bcb70efb0be067a6f816f641cb91135a0e67b0dc74bdc3ffedbd03)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="limit")
    def limit(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "limit"))

    @limit.setter
    def limit(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ed85c985e4f615832c010e13b023f7c5b93d94145b542ab13b4deaa17d04a32c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "limit", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQueryGroupBy]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQueryGroupBy]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQueryGroupBy]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c431275bdd17f254638c20e585a6d68d1b72fb491ac2efd6bac3c82ae19853f5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQueryGroupBySort",
    jsii_struct_bases=[],
    name_mapping={"aggregation": "aggregation", "metric": "metric", "order": "order"},
)
class PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQueryGroupBySort:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        metric: typing.Optional[builtins.str] = None,
        order: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation methods for the event platform queries. Valid values are ``count``, ``cardinality``, ``median``, ``pc75``, ``pc90``, ``pc95``, ``pc98``, ``pc99``, ``sum``, ``min``, ``max``, ``avg``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param metric: The metric used for sorting group by results. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        :param order: Direction of sort. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2f4ba271bd12c230e07e59a303c4a43534af928022385705bdc60831ac64d2dc)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument metric", value=metric, expected_type=type_hints["metric"])
            check_type(argname="argument order", value=order, expected_type=type_hints["order"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if metric is not None:
            self._values["metric"] = metric
        if order is not None:
            self._values["order"] = order

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation methods for the event platform queries.

        Valid values are ``count``, ``cardinality``, ``median``, ``pc75``, ``pc90``, ``pc95``, ``pc98``, ``pc99``, ``sum``, ``min``, ``max``, ``avg``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def metric(self) -> typing.Optional[builtins.str]:
        '''The metric used for sorting group by results.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        '''
        result = self._values.get("metric")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def order(self) -> typing.Optional[builtins.str]:
        '''Direction of sort. Valid values are ``asc``, ``desc``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        result = self._values.get("order")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQueryGroupBySort(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQueryGroupBySortOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQueryGroupBySortOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4f8eed02a8c4bc79de0653b74f6a2057aadcab29beafe71296bb217bc51a0574)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetMetric")
    def reset_metric(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMetric", []))

    @jsii.member(jsii_name="resetOrder")
    def reset_order(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetOrder", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="metricInput")
    def metric_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "metricInput"))

    @builtins.property
    @jsii.member(jsii_name="orderInput")
    def order_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "orderInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__125673fa346cd88b2dde2d5d6f7de0ec4a5f36a93905ae7fb89010b402f729dc)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="metric")
    def metric(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "metric"))

    @metric.setter
    def metric(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__17528f5c58190490d23ab9a4e3cf583e2b2987924c5a1cd6795fdc742b1d933e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "metric", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="order")
    def order(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "order"))

    @order.setter
    def order(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__48e77286c34a378f4bfb7b7c849389000041b4b756f9de268f5445c8d2ba1248)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "order", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQueryGroupBySort]:
        return typing.cast(typing.Optional[PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQueryGroupBySort], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQueryGroupBySort],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9531b830afcfee490588274edc69c62911245d4ba222448cc28fae18d29fc353)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7df8e457ac20acb5dfbcc35b2b2f96c7ab6d641bba9a67d67dca197d7a3aa278)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putCompute")
    def put_compute(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQueryCompute, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5a431b4009e2f0f388598198dc339e04ea126e570ed3e80522bd49e3fa1b962b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putCompute", [value]))

    @jsii.member(jsii_name="putGroupBy")
    def put_group_by(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__604f2bc3957ae86358c7b6384a337437426ab94023d10a386243a2eae734baac)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putGroupBy", [value]))

    @jsii.member(jsii_name="putSearch")
    def put_search(self, *, query: builtins.str) -> None:
        '''
        :param query: The events search string. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        '''
        value = PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQuerySearch(
            query=query
        )

        return typing.cast(None, jsii.invoke(self, "putSearch", [value]))

    @jsii.member(jsii_name="resetCrossOrgUuids")
    def reset_cross_org_uuids(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCrossOrgUuids", []))

    @jsii.member(jsii_name="resetGroupBy")
    def reset_group_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGroupBy", []))

    @jsii.member(jsii_name="resetIndexes")
    def reset_indexes(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetIndexes", []))

    @jsii.member(jsii_name="resetSearch")
    def reset_search(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSearch", []))

    @jsii.member(jsii_name="resetStorage")
    def reset_storage(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetStorage", []))

    @builtins.property
    @jsii.member(jsii_name="compute")
    def compute(
        self,
    ) -> PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQueryComputeList:
        return typing.cast(PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQueryComputeList, jsii.get(self, "compute"))

    @builtins.property
    @jsii.member(jsii_name="groupBy")
    def group_by(
        self,
    ) -> PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQueryGroupByList:
        return typing.cast(PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQueryGroupByList, jsii.get(self, "groupBy"))

    @builtins.property
    @jsii.member(jsii_name="search")
    def search(
        self,
    ) -> "PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQuerySearchOutputReference":
        return typing.cast("PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQuerySearchOutputReference", jsii.get(self, "search"))

    @builtins.property
    @jsii.member(jsii_name="computeInput")
    def compute_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQueryCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQueryCompute]]], jsii.get(self, "computeInput"))

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuidsInput")
    def cross_org_uuids_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "crossOrgUuidsInput"))

    @builtins.property
    @jsii.member(jsii_name="dataSourceInput")
    def data_source_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "dataSourceInput"))

    @builtins.property
    @jsii.member(jsii_name="groupByInput")
    def group_by_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQueryGroupBy]]], jsii.get(self, "groupByInput"))

    @builtins.property
    @jsii.member(jsii_name="indexesInput")
    def indexes_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "indexesInput"))

    @builtins.property
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property
    @jsii.member(jsii_name="searchInput")
    def search_input(
        self,
    ) -> typing.Optional["PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQuerySearch"]:
        return typing.cast(typing.Optional["PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQuerySearch"], jsii.get(self, "searchInput"))

    @builtins.property
    @jsii.member(jsii_name="storageInput")
    def storage_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "storageInput"))

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuids")
    def cross_org_uuids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "crossOrgUuids"))

    @cross_org_uuids.setter
    def cross_org_uuids(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4985862c72b9b0f00a131bb9c141feb3040d91216e048e03aabf4f868ca7b2b7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "crossOrgUuids", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="dataSource")
    def data_source(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "dataSource"))

    @data_source.setter
    def data_source(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4d70016994255e2fe812ca5a81dd7b50b593d0957524caa683cf77689340390f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "dataSource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="indexes")
    def indexes(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "indexes"))

    @indexes.setter
    def indexes(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fd70e4a6fb36f5399974f8e9808949b8f4a2ce30b7be13efeefd32d06d8374f2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "indexes", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ca3610f29019b72e160bc00142b595a9dea7920862926c560b1f4251ccee619a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "name", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="storage")
    def storage(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "storage"))

    @storage.setter
    def storage(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f1a90d8b3e06cc1b2a8928a38a9d3dde23d4b13f7bb28bdb0e1d04059d47f507)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "storage", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c07d00a257dac45333530089a9992c271f771ee850fe53dde06b088f34b7a5a1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQuerySearch",
    jsii_struct_bases=[],
    name_mapping={"query": "query"},
)
class PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQuerySearch:
    def __init__(self, *, query: builtins.str) -> None:
        '''
        :param query: The events search string. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__73f8f865b05d7a55d6c792ec95f0ecceb1d5f8f3b1b8817858f3898bc745ae26)
            check_type(argname="argument query", value=query, expected_type=type_hints["query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "query": query,
        }

    @builtins.property
    def query(self) -> builtins.str:
        '''The events search string.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        '''
        result = self._values.get("query")
        assert result is not None, "Required property 'query' is missing"
        return typing.cast(builtins.str, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQuerySearch(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQuerySearchOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQuerySearchOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d72cc844f0c1d4e0e0a167f7a1412de1480fc2c697ceaaaee09c2d487c6a04ca)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @builtins.property
    @jsii.member(jsii_name="queryInput")
    def query_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "queryInput"))

    @builtins.property
    @jsii.member(jsii_name="query")
    def query(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "query"))

    @query.setter
    def query(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5c2bff2a32dfd68cc87ca9f6998c4bf421c384b44868a6c16d4cad1ab6feb868)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "query", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQuerySearch]:
        return typing.cast(typing.Optional[PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQuerySearch], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQuerySearch],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4440503bdfc10acfa1c7ad8fb120a895d0f5b7e481846e2fc06d8ab3901c39b4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__abfb2ff2234f38c827f5fa9a65f7e8caef9aefaa66dc3af97dee09e0027853c9)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e2b009a35c4bcb1741992e04cd4e17eb251d1b1da1a961be6a1eced2b6836897)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__46472bf420b8a74939f88a145e295c1f1581496ab0d7703ed9b0447c1cc8fe8b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__187a4dc9cfc44b0bbd31fb12acf754b40090b7d4aa01861c010f33940c865504)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__db70a2fa7b099c3782c304cc51017a756c55dcf33bb96ebd8ec473a8052fa7b9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQuery]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQuery]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQuery]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__33a53d9e0645ab38ec8a73214fae1e0094464e39f905da924d091413c59598ba)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryMetricQuery",
    jsii_struct_bases=[],
    name_mapping={
        "name": "name",
        "query": "query",
        "aggregator": "aggregator",
        "cross_org_uuids": "crossOrgUuids",
        "data_source": "dataSource",
    },
)
class PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryMetricQuery:
    def __init__(
        self,
        *,
        name: builtins.str,
        query: builtins.str,
        aggregator: typing.Optional[builtins.str] = None,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        data_source: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param name: The name of the query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param query: The metrics query definition. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        :param aggregator: The aggregation methods available for metrics queries. Valid values are ``avg``, ``min``, ``max``, ``sum``, ``last``, ``area``, ``l2norm``, ``percentile``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregator Powerpack#aggregator}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param data_source: The data source for metrics queries. Defaults to ``"metrics"``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f3d4650483b8798b6bfc4959aef53a5c5686cee12e0c6b679a38a76b6a0331a8)
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument query", value=query, expected_type=type_hints["query"])
            check_type(argname="argument aggregator", value=aggregator, expected_type=type_hints["aggregator"])
            check_type(argname="argument cross_org_uuids", value=cross_org_uuids, expected_type=type_hints["cross_org_uuids"])
            check_type(argname="argument data_source", value=data_source, expected_type=type_hints["data_source"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "name": name,
            "query": query,
        }
        if aggregator is not None:
            self._values["aggregator"] = aggregator
        if cross_org_uuids is not None:
            self._values["cross_org_uuids"] = cross_org_uuids
        if data_source is not None:
            self._values["data_source"] = data_source

    @builtins.property
    def name(self) -> builtins.str:
        '''The name of the query for use in formulas.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        '''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def query(self) -> builtins.str:
        '''The metrics query definition.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        '''
        result = self._values.get("query")
        assert result is not None, "Required property 'query' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def aggregator(self) -> typing.Optional[builtins.str]:
        '''The aggregation methods available for metrics queries. Valid values are ``avg``, ``min``, ``max``, ``sum``, ``last``, ``area``, ``l2norm``, ``percentile``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregator Powerpack#aggregator}
        '''
        result = self._values.get("aggregator")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def cross_org_uuids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''The source organization UUID for cross organization queries. Feature in Private Beta.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        '''
        result = self._values.get("cross_org_uuids")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def data_source(self) -> typing.Optional[builtins.str]:
        '''The data source for metrics queries. Defaults to ``"metrics"``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        '''
        result = self._values.get("data_source")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryMetricQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryMetricQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryMetricQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0790b2cc53254f5db4955ec30851b8239ab9a15f29af96bf6b15801398e0e2b3)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetAggregator")
    def reset_aggregator(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAggregator", []))

    @jsii.member(jsii_name="resetCrossOrgUuids")
    def reset_cross_org_uuids(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCrossOrgUuids", []))

    @jsii.member(jsii_name="resetDataSource")
    def reset_data_source(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDataSource", []))

    @builtins.property
    @jsii.member(jsii_name="aggregatorInput")
    def aggregator_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregatorInput"))

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuidsInput")
    def cross_org_uuids_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "crossOrgUuidsInput"))

    @builtins.property
    @jsii.member(jsii_name="dataSourceInput")
    def data_source_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "dataSourceInput"))

    @builtins.property
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property
    @jsii.member(jsii_name="queryInput")
    def query_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "queryInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregator")
    def aggregator(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregator"))

    @aggregator.setter
    def aggregator(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7a9fb005467ad30eb9724011e7b1fce0ad63bb5a9a5e1606911f3711bfee08ef)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregator", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuids")
    def cross_org_uuids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "crossOrgUuids"))

    @cross_org_uuids.setter
    def cross_org_uuids(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7383c3b092e3bfe5de7c7d2184e60992438860f637ae7bea288116eae58f2123)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "crossOrgUuids", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="dataSource")
    def data_source(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "dataSource"))

    @data_source.setter
    def data_source(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6e559c26bb7b3b79023461d457aa13ead3d8bbf5dcf254491f45abfc6a71ee85)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "dataSource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c64a0a54a9f4c37689a4fa3b7b9effadc74372185ef4a7e746d7db029b5f95e9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "name", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="query")
    def query(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "query"))

    @query.setter
    def query(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7182274fd4705df52af754b44a860b9475188ce04ec5fdc418bc3315e0049f61)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "query", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryMetricQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryMetricQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryMetricQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ad24ec609b004e931b30bb2e28dfc6c342e5b16c5e97f7b89e0782ae12e35059)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__207fecbf81003d543a119cbac42fa205b0d67cb60b1931e5684e1c5d070ea4ca)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putApmDependencyStatsQuery")
    def put_apm_dependency_stats_query(
        self,
        *,
        data_source: builtins.str,
        env: builtins.str,
        name: builtins.str,
        operation_name: builtins.str,
        resource_name: builtins.str,
        service: builtins.str,
        stat: builtins.str,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        is_upstream: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        primary_tag_name: typing.Optional[builtins.str] = None,
        primary_tag_value: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param data_source: The data source for APM Dependency Stats queries. Valid values are ``apm_dependency_stats``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param env: APM environment. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#env Powerpack#env}
        :param name: The name of query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param operation_name: Name of operation on service. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#operation_name Powerpack#operation_name}
        :param resource_name: APM resource. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#resource_name Powerpack#resource_name}
        :param service: APM service. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#service Powerpack#service}
        :param stat: APM statistic. Valid values are ``avg_duration``, ``avg_root_duration``, ``avg_spans_per_trace``, ``error_rate``, ``pct_exec_time``, ``pct_of_traces``, ``total_traces_count``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#stat Powerpack#stat}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param is_upstream: Determines whether stats for upstream or downstream dependencies should be queried. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#is_upstream Powerpack#is_upstream}
        :param primary_tag_name: The name of the second primary tag used within APM; required when ``primary_tag_value`` is specified. See https://docs.datadoghq.com/tracing/guide/setting_primary_tags_to_scope/#add-a-second-primary-tag-in-datadog. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_name Powerpack#primary_tag_name}
        :param primary_tag_value: Filter APM data by the second primary tag. ``primary_tag_name`` must also be specified. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_value Powerpack#primary_tag_value}
        '''
        value = PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryApmDependencyStatsQuery(
            data_source=data_source,
            env=env,
            name=name,
            operation_name=operation_name,
            resource_name=resource_name,
            service=service,
            stat=stat,
            cross_org_uuids=cross_org_uuids,
            is_upstream=is_upstream,
            primary_tag_name=primary_tag_name,
            primary_tag_value=primary_tag_value,
        )

        return typing.cast(None, jsii.invoke(self, "putApmDependencyStatsQuery", [value]))

    @jsii.member(jsii_name="putApmResourceStatsQuery")
    def put_apm_resource_stats_query(
        self,
        *,
        data_source: builtins.str,
        env: builtins.str,
        name: builtins.str,
        service: builtins.str,
        stat: builtins.str,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        group_by: typing.Optional[typing.Sequence[builtins.str]] = None,
        operation_name: typing.Optional[builtins.str] = None,
        primary_tag_name: typing.Optional[builtins.str] = None,
        primary_tag_value: typing.Optional[builtins.str] = None,
        resource_name: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param data_source: The data source for APM Resource Stats queries. Valid values are ``apm_resource_stats``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param env: APM environment. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#env Powerpack#env}
        :param name: The name of query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param service: APM service. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#service Powerpack#service}
        :param stat: APM statistic. Valid values are ``errors``, ``error_rate``, ``hits``, ``latency_avg``, ``latency_distribution``, ``latency_max``, ``latency_p50``, ``latency_p75``, ``latency_p90``, ``latency_p95``, ``latency_p99``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#stat Powerpack#stat}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param group_by: Array of fields to group results by. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param operation_name: Name of operation on service. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#operation_name Powerpack#operation_name}
        :param primary_tag_name: The name of the second primary tag used within APM; required when ``primary_tag_value`` is specified. See https://docs.datadoghq.com/tracing/guide/setting_primary_tags_to_scope/#add-a-second-primary-tag-in-datadog. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_name Powerpack#primary_tag_name}
        :param primary_tag_value: Filter APM data by the second primary tag. ``primary_tag_name`` must also be specified. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_value Powerpack#primary_tag_value}
        :param resource_name: APM resource. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#resource_name Powerpack#resource_name}
        '''
        value = PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryApmResourceStatsQuery(
            data_source=data_source,
            env=env,
            name=name,
            service=service,
            stat=stat,
            cross_org_uuids=cross_org_uuids,
            group_by=group_by,
            operation_name=operation_name,
            primary_tag_name=primary_tag_name,
            primary_tag_value=primary_tag_value,
            resource_name=resource_name,
        )

        return typing.cast(None, jsii.invoke(self, "putApmResourceStatsQuery", [value]))

    @jsii.member(jsii_name="putCloudCostQuery")
    def put_cloud_cost_query(
        self,
        *,
        data_source: builtins.str,
        name: builtins.str,
        query: builtins.str,
        aggregator: typing.Optional[builtins.str] = None,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
    ) -> None:
        '''
        :param data_source: The data source for cloud cost queries. Valid values are ``cloud_cost``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param name: The name of the query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param query: The cloud cost query definition. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        :param aggregator: The aggregation methods available for cloud cost queries. Valid values are ``avg``, ``last``, ``max``, ``min``, ``sum``, ``percentile``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregator Powerpack#aggregator}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        '''
        value = PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryCloudCostQuery(
            data_source=data_source,
            name=name,
            query=query,
            aggregator=aggregator,
            cross_org_uuids=cross_org_uuids,
        )

        return typing.cast(None, jsii.invoke(self, "putCloudCostQuery", [value]))

    @jsii.member(jsii_name="putEventQuery")
    def put_event_query(
        self,
        *,
        compute: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQueryCompute, typing.Dict[builtins.str, typing.Any]]]],
        data_source: builtins.str,
        name: builtins.str,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
        indexes: typing.Optional[typing.Sequence[builtins.str]] = None,
        search: typing.Optional[typing.Union[PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQuerySearch, typing.Dict[builtins.str, typing.Any]]] = None,
        storage: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param compute: compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute Powerpack#compute}
        :param data_source: The data source for event platform-based queries. Valid values are ``logs``, ``spans``, ``network``, ``rum``, ``security_signals``, ``profiles``, ``audit``, ``events``, ``ci_tests``, ``ci_pipelines``, ``incident_analytics``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param name: The name of query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param indexes: An array of index names to query in the stream. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#indexes Powerpack#indexes}
        :param search: search block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search Powerpack#search}
        :param storage: Storage location (private beta). Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#storage Powerpack#storage}
        '''
        value = PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQuery(
            compute=compute,
            data_source=data_source,
            name=name,
            cross_org_uuids=cross_org_uuids,
            group_by=group_by,
            indexes=indexes,
            search=search,
            storage=storage,
        )

        return typing.cast(None, jsii.invoke(self, "putEventQuery", [value]))

    @jsii.member(jsii_name="putMetricQuery")
    def put_metric_query(
        self,
        *,
        name: builtins.str,
        query: builtins.str,
        aggregator: typing.Optional[builtins.str] = None,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        data_source: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param name: The name of the query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param query: The metrics query definition. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        :param aggregator: The aggregation methods available for metrics queries. Valid values are ``avg``, ``min``, ``max``, ``sum``, ``last``, ``area``, ``l2norm``, ``percentile``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregator Powerpack#aggregator}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param data_source: The data source for metrics queries. Defaults to ``"metrics"``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        '''
        value = PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryMetricQuery(
            name=name,
            query=query,
            aggregator=aggregator,
            cross_org_uuids=cross_org_uuids,
            data_source=data_source,
        )

        return typing.cast(None, jsii.invoke(self, "putMetricQuery", [value]))

    @jsii.member(jsii_name="putProcessQuery")
    def put_process_query(
        self,
        *,
        data_source: builtins.str,
        metric: builtins.str,
        name: builtins.str,
        aggregator: typing.Optional[builtins.str] = None,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        is_normalized_cpu: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        limit: typing.Optional[jsii.Number] = None,
        sort: typing.Optional[builtins.str] = None,
        tag_filters: typing.Optional[typing.Sequence[builtins.str]] = None,
        text_filter: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param data_source: The data source for process queries. Valid values are ``process``, ``container``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param metric: The process metric name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        :param name: The name of query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param aggregator: The aggregation methods available for metrics queries. Valid values are ``avg``, ``min``, ``max``, ``sum``, ``last``, ``area``, ``l2norm``, ``percentile``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregator Powerpack#aggregator}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param is_normalized_cpu: Whether to normalize the CPU percentages. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#is_normalized_cpu Powerpack#is_normalized_cpu}
        :param limit: The number of hits to return. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param sort: The direction of the sort. Valid values are ``asc``, ``desc``. Defaults to ``"desc"``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort Powerpack#sort}
        :param tag_filters: An array of tags to filter by. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#tag_filters Powerpack#tag_filters}
        :param text_filter: The text to use as a filter. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#text_filter Powerpack#text_filter}
        '''
        value = PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryProcessQuery(
            data_source=data_source,
            metric=metric,
            name=name,
            aggregator=aggregator,
            cross_org_uuids=cross_org_uuids,
            is_normalized_cpu=is_normalized_cpu,
            limit=limit,
            sort=sort,
            tag_filters=tag_filters,
            text_filter=text_filter,
        )

        return typing.cast(None, jsii.invoke(self, "putProcessQuery", [value]))

    @jsii.member(jsii_name="putSloQuery")
    def put_slo_query(
        self,
        *,
        data_source: builtins.str,
        measure: builtins.str,
        slo_id: builtins.str,
        additional_query_filters: typing.Optional[builtins.str] = None,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        group_mode: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
        slo_query_type: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param data_source: The data source for SLO queries. Valid values are ``slo``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param measure: SLO measures queries. Valid values are ``good_events``, ``bad_events``, ``good_minutes``, ``bad_minutes``, ``slo_status``, ``error_budget_remaining``, ``burn_rate``, ``error_budget_burndown``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#measure Powerpack#measure}
        :param slo_id: ID of an SLO to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#slo_id Powerpack#slo_id}
        :param additional_query_filters: Additional filters applied to the SLO query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#additional_query_filters Powerpack#additional_query_filters}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param group_mode: Group mode to query measures. Valid values are ``overall``, ``components``. Defaults to ``"overall"``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_mode Powerpack#group_mode}
        :param name: The name of query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param slo_query_type: type of the SLO to query. Valid values are ``metric``, ``monitor``, ``time_slice``. Defaults to ``"metric"``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#slo_query_type Powerpack#slo_query_type}
        '''
        value = PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQuerySloQuery(
            data_source=data_source,
            measure=measure,
            slo_id=slo_id,
            additional_query_filters=additional_query_filters,
            cross_org_uuids=cross_org_uuids,
            group_mode=group_mode,
            name=name,
            slo_query_type=slo_query_type,
        )

        return typing.cast(None, jsii.invoke(self, "putSloQuery", [value]))

    @jsii.member(jsii_name="resetApmDependencyStatsQuery")
    def reset_apm_dependency_stats_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetApmDependencyStatsQuery", []))

    @jsii.member(jsii_name="resetApmResourceStatsQuery")
    def reset_apm_resource_stats_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetApmResourceStatsQuery", []))

    @jsii.member(jsii_name="resetCloudCostQuery")
    def reset_cloud_cost_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCloudCostQuery", []))

    @jsii.member(jsii_name="resetEventQuery")
    def reset_event_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetEventQuery", []))

    @jsii.member(jsii_name="resetMetricQuery")
    def reset_metric_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMetricQuery", []))

    @jsii.member(jsii_name="resetProcessQuery")
    def reset_process_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetProcessQuery", []))

    @jsii.member(jsii_name="resetSloQuery")
    def reset_slo_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSloQuery", []))

    @builtins.property
    @jsii.member(jsii_name="apmDependencyStatsQuery")
    def apm_dependency_stats_query(
        self,
    ) -> PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryApmDependencyStatsQueryOutputReference:
        return typing.cast(PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryApmDependencyStatsQueryOutputReference, jsii.get(self, "apmDependencyStatsQuery"))

    @builtins.property
    @jsii.member(jsii_name="apmResourceStatsQuery")
    def apm_resource_stats_query(
        self,
    ) -> PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryApmResourceStatsQueryOutputReference:
        return typing.cast(PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryApmResourceStatsQueryOutputReference, jsii.get(self, "apmResourceStatsQuery"))

    @builtins.property
    @jsii.member(jsii_name="cloudCostQuery")
    def cloud_cost_query(
        self,
    ) -> PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryCloudCostQueryOutputReference:
        return typing.cast(PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryCloudCostQueryOutputReference, jsii.get(self, "cloudCostQuery"))

    @builtins.property
    @jsii.member(jsii_name="eventQuery")
    def event_query(
        self,
    ) -> PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQueryOutputReference:
        return typing.cast(PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQueryOutputReference, jsii.get(self, "eventQuery"))

    @builtins.property
    @jsii.member(jsii_name="metricQuery")
    def metric_query(
        self,
    ) -> PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryMetricQueryOutputReference:
        return typing.cast(PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryMetricQueryOutputReference, jsii.get(self, "metricQuery"))

    @builtins.property
    @jsii.member(jsii_name="processQuery")
    def process_query(
        self,
    ) -> "PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryProcessQueryOutputReference":
        return typing.cast("PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryProcessQueryOutputReference", jsii.get(self, "processQuery"))

    @builtins.property
    @jsii.member(jsii_name="sloQuery")
    def slo_query(
        self,
    ) -> "PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQuerySloQueryOutputReference":
        return typing.cast("PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQuerySloQueryOutputReference", jsii.get(self, "sloQuery"))

    @builtins.property
    @jsii.member(jsii_name="apmDependencyStatsQueryInput")
    def apm_dependency_stats_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryApmDependencyStatsQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryApmDependencyStatsQuery], jsii.get(self, "apmDependencyStatsQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="apmResourceStatsQueryInput")
    def apm_resource_stats_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryApmResourceStatsQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryApmResourceStatsQuery], jsii.get(self, "apmResourceStatsQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="cloudCostQueryInput")
    def cloud_cost_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryCloudCostQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryCloudCostQuery], jsii.get(self, "cloudCostQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="eventQueryInput")
    def event_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQuery], jsii.get(self, "eventQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="metricQueryInput")
    def metric_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryMetricQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryMetricQuery], jsii.get(self, "metricQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="processQueryInput")
    def process_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryProcessQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryProcessQuery"], jsii.get(self, "processQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="sloQueryInput")
    def slo_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQuerySloQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQuerySloQuery"], jsii.get(self, "sloQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQuery]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQuery]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQuery]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__25b4605017feba5c172a268ba824398981cdf41faedff368b0993b28609f802c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryProcessQuery",
    jsii_struct_bases=[],
    name_mapping={
        "data_source": "dataSource",
        "metric": "metric",
        "name": "name",
        "aggregator": "aggregator",
        "cross_org_uuids": "crossOrgUuids",
        "is_normalized_cpu": "isNormalizedCpu",
        "limit": "limit",
        "sort": "sort",
        "tag_filters": "tagFilters",
        "text_filter": "textFilter",
    },
)
class PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryProcessQuery:
    def __init__(
        self,
        *,
        data_source: builtins.str,
        metric: builtins.str,
        name: builtins.str,
        aggregator: typing.Optional[builtins.str] = None,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        is_normalized_cpu: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        limit: typing.Optional[jsii.Number] = None,
        sort: typing.Optional[builtins.str] = None,
        tag_filters: typing.Optional[typing.Sequence[builtins.str]] = None,
        text_filter: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param data_source: The data source for process queries. Valid values are ``process``, ``container``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param metric: The process metric name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        :param name: The name of query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param aggregator: The aggregation methods available for metrics queries. Valid values are ``avg``, ``min``, ``max``, ``sum``, ``last``, ``area``, ``l2norm``, ``percentile``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregator Powerpack#aggregator}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param is_normalized_cpu: Whether to normalize the CPU percentages. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#is_normalized_cpu Powerpack#is_normalized_cpu}
        :param limit: The number of hits to return. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param sort: The direction of the sort. Valid values are ``asc``, ``desc``. Defaults to ``"desc"``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort Powerpack#sort}
        :param tag_filters: An array of tags to filter by. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#tag_filters Powerpack#tag_filters}
        :param text_filter: The text to use as a filter. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#text_filter Powerpack#text_filter}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__348cbf82c6637be8ce295feda6d8817f8228d0cca7c5d309e5ec920449dad04e)
            check_type(argname="argument data_source", value=data_source, expected_type=type_hints["data_source"])
            check_type(argname="argument metric", value=metric, expected_type=type_hints["metric"])
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument aggregator", value=aggregator, expected_type=type_hints["aggregator"])
            check_type(argname="argument cross_org_uuids", value=cross_org_uuids, expected_type=type_hints["cross_org_uuids"])
            check_type(argname="argument is_normalized_cpu", value=is_normalized_cpu, expected_type=type_hints["is_normalized_cpu"])
            check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
            check_type(argname="argument sort", value=sort, expected_type=type_hints["sort"])
            check_type(argname="argument tag_filters", value=tag_filters, expected_type=type_hints["tag_filters"])
            check_type(argname="argument text_filter", value=text_filter, expected_type=type_hints["text_filter"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "data_source": data_source,
            "metric": metric,
            "name": name,
        }
        if aggregator is not None:
            self._values["aggregator"] = aggregator
        if cross_org_uuids is not None:
            self._values["cross_org_uuids"] = cross_org_uuids
        if is_normalized_cpu is not None:
            self._values["is_normalized_cpu"] = is_normalized_cpu
        if limit is not None:
            self._values["limit"] = limit
        if sort is not None:
            self._values["sort"] = sort
        if tag_filters is not None:
            self._values["tag_filters"] = tag_filters
        if text_filter is not None:
            self._values["text_filter"] = text_filter

    @builtins.property
    def data_source(self) -> builtins.str:
        '''The data source for process queries. Valid values are ``process``, ``container``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        '''
        result = self._values.get("data_source")
        assert result is not None, "Required property 'data_source' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def metric(self) -> builtins.str:
        '''The process metric name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        '''
        result = self._values.get("metric")
        assert result is not None, "Required property 'metric' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def name(self) -> builtins.str:
        '''The name of query for use in formulas.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        '''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def aggregator(self) -> typing.Optional[builtins.str]:
        '''The aggregation methods available for metrics queries. Valid values are ``avg``, ``min``, ``max``, ``sum``, ``last``, ``area``, ``l2norm``, ``percentile``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregator Powerpack#aggregator}
        '''
        result = self._values.get("aggregator")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def cross_org_uuids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''The source organization UUID for cross organization queries. Feature in Private Beta.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        '''
        result = self._values.get("cross_org_uuids")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def is_normalized_cpu(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        '''Whether to normalize the CPU percentages.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#is_normalized_cpu Powerpack#is_normalized_cpu}
        '''
        result = self._values.get("is_normalized_cpu")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)

    @builtins.property
    def limit(self) -> typing.Optional[jsii.Number]:
        '''The number of hits to return.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        '''
        result = self._values.get("limit")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def sort(self) -> typing.Optional[builtins.str]:
        '''The direction of the sort. Valid values are ``asc``, ``desc``. Defaults to ``"desc"``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort Powerpack#sort}
        '''
        result = self._values.get("sort")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def tag_filters(self) -> typing.Optional[typing.List[builtins.str]]:
        '''An array of tags to filter by.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#tag_filters Powerpack#tag_filters}
        '''
        result = self._values.get("tag_filters")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def text_filter(self) -> typing.Optional[builtins.str]:
        '''The text to use as a filter.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#text_filter Powerpack#text_filter}
        '''
        result = self._values.get("text_filter")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryProcessQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryProcessQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryProcessQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__180617b100d1563310fb4cb2bad6cc587202365691ba72ff46e17e14fc8b1457)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetAggregator")
    def reset_aggregator(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAggregator", []))

    @jsii.member(jsii_name="resetCrossOrgUuids")
    def reset_cross_org_uuids(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCrossOrgUuids", []))

    @jsii.member(jsii_name="resetIsNormalizedCpu")
    def reset_is_normalized_cpu(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetIsNormalizedCpu", []))

    @jsii.member(jsii_name="resetLimit")
    def reset_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLimit", []))

    @jsii.member(jsii_name="resetSort")
    def reset_sort(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSort", []))

    @jsii.member(jsii_name="resetTagFilters")
    def reset_tag_filters(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTagFilters", []))

    @jsii.member(jsii_name="resetTextFilter")
    def reset_text_filter(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTextFilter", []))

    @builtins.property
    @jsii.member(jsii_name="aggregatorInput")
    def aggregator_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregatorInput"))

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuidsInput")
    def cross_org_uuids_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "crossOrgUuidsInput"))

    @builtins.property
    @jsii.member(jsii_name="dataSourceInput")
    def data_source_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "dataSourceInput"))

    @builtins.property
    @jsii.member(jsii_name="isNormalizedCpuInput")
    def is_normalized_cpu_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "isNormalizedCpuInput"))

    @builtins.property
    @jsii.member(jsii_name="limitInput")
    def limit_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "limitInput"))

    @builtins.property
    @jsii.member(jsii_name="metricInput")
    def metric_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "metricInput"))

    @builtins.property
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property
    @jsii.member(jsii_name="sortInput")
    def sort_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "sortInput"))

    @builtins.property
    @jsii.member(jsii_name="tagFiltersInput")
    def tag_filters_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "tagFiltersInput"))

    @builtins.property
    @jsii.member(jsii_name="textFilterInput")
    def text_filter_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "textFilterInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregator")
    def aggregator(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregator"))

    @aggregator.setter
    def aggregator(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b0ac73f466946d83010d9b1760b7436814d371b87b1424df904c21725071c3fe)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregator", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuids")
    def cross_org_uuids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "crossOrgUuids"))

    @cross_org_uuids.setter
    def cross_org_uuids(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7f02012f75e2b857651a177bda9521db736c359a6df3699720e6d5dc528ce6f4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "crossOrgUuids", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="dataSource")
    def data_source(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "dataSource"))

    @data_source.setter
    def data_source(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a28e8d33136afba67680761c0b413459e4b42740a1bcfb901cbd11d18abaca9c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "dataSource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="isNormalizedCpu")
    def is_normalized_cpu(
        self,
    ) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "isNormalizedCpu"))

    @is_normalized_cpu.setter
    def is_normalized_cpu(
        self,
        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8121fb044e9eafc7fd53526bd5e64db250ac2c8c6a2e11ced8fc20c7ee025476)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "isNormalizedCpu", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="limit")
    def limit(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "limit"))

    @limit.setter
    def limit(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__165fb1edac003b50641bf960013c4ddc0c39202015530705d4a2592e7df61593)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "limit", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="metric")
    def metric(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "metric"))

    @metric.setter
    def metric(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__87f13942610367b66c7201dc40d3d1f02b3e727eeefa17b057db96561d388b43)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "metric", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0ef78f867ebf71374a4164eab683de7f45524f3c6f07811c4fbbfc4f95e8650d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "name", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="sort")
    def sort(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "sort"))

    @sort.setter
    def sort(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__09b06304943f7171cdcbce4d740364ce28254e22356e483579fd4c15185c9a81)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "sort", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="tagFilters")
    def tag_filters(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "tagFilters"))

    @tag_filters.setter
    def tag_filters(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cb195023e7163378f92cc7171d9b683d1f8f2f9cb5ca3254bf6b80b62976ce6e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "tagFilters", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="textFilter")
    def text_filter(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "textFilter"))

    @text_filter.setter
    def text_filter(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3a183559c573eaa4f62d9bca02470399d9baaec68e3fb39a9b5dbbc604d378ab)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "textFilter", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryProcessQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryProcessQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryProcessQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c48664479e75e082f4f462f4c8df629392bd27f9a1d4a258ff7535c9f4cbc4b3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQuerySloQuery",
    jsii_struct_bases=[],
    name_mapping={
        "data_source": "dataSource",
        "measure": "measure",
        "slo_id": "sloId",
        "additional_query_filters": "additionalQueryFilters",
        "cross_org_uuids": "crossOrgUuids",
        "group_mode": "groupMode",
        "name": "name",
        "slo_query_type": "sloQueryType",
    },
)
class PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQuerySloQuery:
    def __init__(
        self,
        *,
        data_source: builtins.str,
        measure: builtins.str,
        slo_id: builtins.str,
        additional_query_filters: typing.Optional[builtins.str] = None,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        group_mode: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
        slo_query_type: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param data_source: The data source for SLO queries. Valid values are ``slo``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param measure: SLO measures queries. Valid values are ``good_events``, ``bad_events``, ``good_minutes``, ``bad_minutes``, ``slo_status``, ``error_budget_remaining``, ``burn_rate``, ``error_budget_burndown``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#measure Powerpack#measure}
        :param slo_id: ID of an SLO to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#slo_id Powerpack#slo_id}
        :param additional_query_filters: Additional filters applied to the SLO query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#additional_query_filters Powerpack#additional_query_filters}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param group_mode: Group mode to query measures. Valid values are ``overall``, ``components``. Defaults to ``"overall"``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_mode Powerpack#group_mode}
        :param name: The name of query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param slo_query_type: type of the SLO to query. Valid values are ``metric``, ``monitor``, ``time_slice``. Defaults to ``"metric"``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#slo_query_type Powerpack#slo_query_type}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4581556953626c04f9450b047a5cdc969bab4c183f684d2bee6067392bdb32cc)
            check_type(argname="argument data_source", value=data_source, expected_type=type_hints["data_source"])
            check_type(argname="argument measure", value=measure, expected_type=type_hints["measure"])
            check_type(argname="argument slo_id", value=slo_id, expected_type=type_hints["slo_id"])
            check_type(argname="argument additional_query_filters", value=additional_query_filters, expected_type=type_hints["additional_query_filters"])
            check_type(argname="argument cross_org_uuids", value=cross_org_uuids, expected_type=type_hints["cross_org_uuids"])
            check_type(argname="argument group_mode", value=group_mode, expected_type=type_hints["group_mode"])
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument slo_query_type", value=slo_query_type, expected_type=type_hints["slo_query_type"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "data_source": data_source,
            "measure": measure,
            "slo_id": slo_id,
        }
        if additional_query_filters is not None:
            self._values["additional_query_filters"] = additional_query_filters
        if cross_org_uuids is not None:
            self._values["cross_org_uuids"] = cross_org_uuids
        if group_mode is not None:
            self._values["group_mode"] = group_mode
        if name is not None:
            self._values["name"] = name
        if slo_query_type is not None:
            self._values["slo_query_type"] = slo_query_type

    @builtins.property
    def data_source(self) -> builtins.str:
        '''The data source for SLO queries. Valid values are ``slo``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        '''
        result = self._values.get("data_source")
        assert result is not None, "Required property 'data_source' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def measure(self) -> builtins.str:
        '''SLO measures queries. Valid values are ``good_events``, ``bad_events``, ``good_minutes``, ``bad_minutes``, ``slo_status``, ``error_budget_remaining``, ``burn_rate``, ``error_budget_burndown``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#measure Powerpack#measure}
        '''
        result = self._values.get("measure")
        assert result is not None, "Required property 'measure' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def slo_id(self) -> builtins.str:
        '''ID of an SLO to query.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#slo_id Powerpack#slo_id}
        '''
        result = self._values.get("slo_id")
        assert result is not None, "Required property 'slo_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def additional_query_filters(self) -> typing.Optional[builtins.str]:
        '''Additional filters applied to the SLO query.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#additional_query_filters Powerpack#additional_query_filters}
        '''
        result = self._values.get("additional_query_filters")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def cross_org_uuids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''The source organization UUID for cross organization queries. Feature in Private Beta.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        '''
        result = self._values.get("cross_org_uuids")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def group_mode(self) -> typing.Optional[builtins.str]:
        '''Group mode to query measures. Valid values are ``overall``, ``components``. Defaults to ``"overall"``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_mode Powerpack#group_mode}
        '''
        result = self._values.get("group_mode")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''The name of query for use in formulas.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        '''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def slo_query_type(self) -> typing.Optional[builtins.str]:
        '''type of the SLO to query. Valid values are ``metric``, ``monitor``, ``time_slice``. Defaults to ``"metric"``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#slo_query_type Powerpack#slo_query_type}
        '''
        result = self._values.get("slo_query_type")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQuerySloQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQuerySloQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQuerySloQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f2c60c0f480fbcdb249fcb075d2dfb1a272a4bd176d4fbbdc773565bfae918dc)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetAdditionalQueryFilters")
    def reset_additional_query_filters(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAdditionalQueryFilters", []))

    @jsii.member(jsii_name="resetCrossOrgUuids")
    def reset_cross_org_uuids(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCrossOrgUuids", []))

    @jsii.member(jsii_name="resetGroupMode")
    def reset_group_mode(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGroupMode", []))

    @jsii.member(jsii_name="resetName")
    def reset_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetName", []))

    @jsii.member(jsii_name="resetSloQueryType")
    def reset_slo_query_type(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSloQueryType", []))

    @builtins.property
    @jsii.member(jsii_name="additionalQueryFiltersInput")
    def additional_query_filters_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "additionalQueryFiltersInput"))

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuidsInput")
    def cross_org_uuids_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "crossOrgUuidsInput"))

    @builtins.property
    @jsii.member(jsii_name="dataSourceInput")
    def data_source_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "dataSourceInput"))

    @builtins.property
    @jsii.member(jsii_name="groupModeInput")
    def group_mode_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "groupModeInput"))

    @builtins.property
    @jsii.member(jsii_name="measureInput")
    def measure_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "measureInput"))

    @builtins.property
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property
    @jsii.member(jsii_name="sloIdInput")
    def slo_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "sloIdInput"))

    @builtins.property
    @jsii.member(jsii_name="sloQueryTypeInput")
    def slo_query_type_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "sloQueryTypeInput"))

    @builtins.property
    @jsii.member(jsii_name="additionalQueryFilters")
    def additional_query_filters(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "additionalQueryFilters"))

    @additional_query_filters.setter
    def additional_query_filters(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__331fc04bcbb5a27cc2457a1d2b404fb42866e7a6e208c65d908a56e025dddfd6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "additionalQueryFilters", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuids")
    def cross_org_uuids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "crossOrgUuids"))

    @cross_org_uuids.setter
    def cross_org_uuids(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__eb515c418ad272d679aba17a05e6ce285508f0ed57a52b7713abfa00657f7be3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "crossOrgUuids", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="dataSource")
    def data_source(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "dataSource"))

    @data_source.setter
    def data_source(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bd1b7b0511010a8d26b38d1a0d16860d2440b8e0d6f7e7c46808db8b41c0a562)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "dataSource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="groupMode")
    def group_mode(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "groupMode"))

    @group_mode.setter
    def group_mode(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6d0594e297e595d70ea02f022384efc315a44f85ed3473801195efcff67b3a29)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "groupMode", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="measure")
    def measure(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "measure"))

    @measure.setter
    def measure(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__05c1bb89fb9104e651d938815b5b5d0ca1a1c998420382e5797f0c907a82656d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "measure", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4e10dce7627ae5fe26f3e51632b4cbbe7b7d022de54f59824eeff7fff904931d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "name", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="sloId")
    def slo_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "sloId"))

    @slo_id.setter
    def slo_id(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f2fdcb2acf63c59d0c9d8bf603ea5d0fdc2e9cad7c20232144aebbb3c756161e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "sloId", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="sloQueryType")
    def slo_query_type(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "sloQueryType"))

    @slo_query_type.setter
    def slo_query_type(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__05e5824a3e244986171850d364cfd02c85df314641ccea808dc2f881832b3012)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "sloQueryType", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQuerySloQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQuerySloQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQuerySloQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__089370a286f4f637ea07b9b35150bb473a446257cdba1dc5599638c6ddfb5381)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestX",
    jsii_struct_bases=[],
    name_mapping={
        "aggregator": "aggregator",
        "apm_query": "apmQuery",
        "log_query": "logQuery",
        "process_query": "processQuery",
        "q": "q",
        "rum_query": "rumQuery",
        "security_query": "securityQuery",
    },
)
class PowerpackWidgetScatterplotDefinitionRequestX:
    def __init__(
        self,
        *,
        aggregator: typing.Optional[builtins.str] = None,
        apm_query: typing.Optional[typing.Union["PowerpackWidgetScatterplotDefinitionRequestXApmQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        log_query: typing.Optional[typing.Union["PowerpackWidgetScatterplotDefinitionRequestXLogQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        process_query: typing.Optional[typing.Union["PowerpackWidgetScatterplotDefinitionRequestXProcessQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        q: typing.Optional[builtins.str] = None,
        rum_query: typing.Optional[typing.Union["PowerpackWidgetScatterplotDefinitionRequestXRumQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        security_query: typing.Optional[typing.Union["PowerpackWidgetScatterplotDefinitionRequestXSecurityQuery", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param aggregator: Aggregator used for the request. Valid values are ``avg``, ``last``, ``max``, ``min``, ``sum``, ``percentile``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregator Powerpack#aggregator}
        :param apm_query: apm_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#apm_query Powerpack#apm_query}
        :param log_query: log_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#log_query Powerpack#log_query}
        :param process_query: process_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#process_query Powerpack#process_query}
        :param q: The metric query to use for this widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#q Powerpack#q}
        :param rum_query: rum_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#rum_query Powerpack#rum_query}
        :param security_query: security_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#security_query Powerpack#security_query}
        '''
        if isinstance(apm_query, dict):
            apm_query = PowerpackWidgetScatterplotDefinitionRequestXApmQuery(**apm_query)
        if isinstance(log_query, dict):
            log_query = PowerpackWidgetScatterplotDefinitionRequestXLogQuery(**log_query)
        if isinstance(process_query, dict):
            process_query = PowerpackWidgetScatterplotDefinitionRequestXProcessQuery(**process_query)
        if isinstance(rum_query, dict):
            rum_query = PowerpackWidgetScatterplotDefinitionRequestXRumQuery(**rum_query)
        if isinstance(security_query, dict):
            security_query = PowerpackWidgetScatterplotDefinitionRequestXSecurityQuery(**security_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7e0026617111ba406fe0484f34211612e46103ced61907e95c709298843b4641)
            check_type(argname="argument aggregator", value=aggregator, expected_type=type_hints["aggregator"])
            check_type(argname="argument apm_query", value=apm_query, expected_type=type_hints["apm_query"])
            check_type(argname="argument log_query", value=log_query, expected_type=type_hints["log_query"])
            check_type(argname="argument process_query", value=process_query, expected_type=type_hints["process_query"])
            check_type(argname="argument q", value=q, expected_type=type_hints["q"])
            check_type(argname="argument rum_query", value=rum_query, expected_type=type_hints["rum_query"])
            check_type(argname="argument security_query", value=security_query, expected_type=type_hints["security_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if aggregator is not None:
            self._values["aggregator"] = aggregator
        if apm_query is not None:
            self._values["apm_query"] = apm_query
        if log_query is not None:
            self._values["log_query"] = log_query
        if process_query is not None:
            self._values["process_query"] = process_query
        if q is not None:
            self._values["q"] = q
        if rum_query is not None:
            self._values["rum_query"] = rum_query
        if security_query is not None:
            self._values["security_query"] = security_query

    @builtins.property
    def aggregator(self) -> typing.Optional[builtins.str]:
        '''Aggregator used for the request. Valid values are ``avg``, ``last``, ``max``, ``min``, ``sum``, ``percentile``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregator Powerpack#aggregator}
        '''
        result = self._values.get("aggregator")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def apm_query(
        self,
    ) -> typing.Optional["PowerpackWidgetScatterplotDefinitionRequestXApmQuery"]:
        '''apm_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#apm_query Powerpack#apm_query}
        '''
        result = self._values.get("apm_query")
        return typing.cast(typing.Optional["PowerpackWidgetScatterplotDefinitionRequestXApmQuery"], result)

    @builtins.property
    def log_query(
        self,
    ) -> typing.Optional["PowerpackWidgetScatterplotDefinitionRequestXLogQuery"]:
        '''log_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#log_query Powerpack#log_query}
        '''
        result = self._values.get("log_query")
        return typing.cast(typing.Optional["PowerpackWidgetScatterplotDefinitionRequestXLogQuery"], result)

    @builtins.property
    def process_query(
        self,
    ) -> typing.Optional["PowerpackWidgetScatterplotDefinitionRequestXProcessQuery"]:
        '''process_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#process_query Powerpack#process_query}
        '''
        result = self._values.get("process_query")
        return typing.cast(typing.Optional["PowerpackWidgetScatterplotDefinitionRequestXProcessQuery"], result)

    @builtins.property
    def q(self) -> typing.Optional[builtins.str]:
        '''The metric query to use for this widget.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#q Powerpack#q}
        '''
        result = self._values.get("q")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def rum_query(
        self,
    ) -> typing.Optional["PowerpackWidgetScatterplotDefinitionRequestXRumQuery"]:
        '''rum_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#rum_query Powerpack#rum_query}
        '''
        result = self._values.get("rum_query")
        return typing.cast(typing.Optional["PowerpackWidgetScatterplotDefinitionRequestXRumQuery"], result)

    @builtins.property
    def security_query(
        self,
    ) -> typing.Optional["PowerpackWidgetScatterplotDefinitionRequestXSecurityQuery"]:
        '''security_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#security_query Powerpack#security_query}
        '''
        result = self._values.get("security_query")
        return typing.cast(typing.Optional["PowerpackWidgetScatterplotDefinitionRequestXSecurityQuery"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetScatterplotDefinitionRequestX(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestXApmQuery",
    jsii_struct_bases=[],
    name_mapping={
        "index": "index",
        "compute_query": "computeQuery",
        "group_by": "groupBy",
        "multi_compute": "multiCompute",
        "search_query": "searchQuery",
    },
)
class PowerpackWidgetScatterplotDefinitionRequestXApmQuery:
    def __init__(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union["PowerpackWidgetScatterplotDefinitionRequestXApmQueryComputeQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetScatterplotDefinitionRequestXApmQueryGroupBy", typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetScatterplotDefinitionRequestXApmQueryMultiCompute", typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        if isinstance(compute_query, dict):
            compute_query = PowerpackWidgetScatterplotDefinitionRequestXApmQueryComputeQuery(**compute_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e093dfd656d3639ff456eaba7eca213e1e977156d5004120cbdd52e4d9ca94ba)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
            check_type(argname="argument compute_query", value=compute_query, expected_type=type_hints["compute_query"])
            check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
            check_type(argname="argument multi_compute", value=multi_compute, expected_type=type_hints["multi_compute"])
            check_type(argname="argument search_query", value=search_query, expected_type=type_hints["search_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "index": index,
        }
        if compute_query is not None:
            self._values["compute_query"] = compute_query
        if group_by is not None:
            self._values["group_by"] = group_by
        if multi_compute is not None:
            self._values["multi_compute"] = multi_compute
        if search_query is not None:
            self._values["search_query"] = search_query

    @builtins.property
    def index(self) -> builtins.str:
        '''The name of the index to query.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        '''
        result = self._values.get("index")
        assert result is not None, "Required property 'index' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def compute_query(
        self,
    ) -> typing.Optional["PowerpackWidgetScatterplotDefinitionRequestXApmQueryComputeQuery"]:
        '''compute_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        '''
        result = self._values.get("compute_query")
        return typing.cast(typing.Optional["PowerpackWidgetScatterplotDefinitionRequestXApmQueryComputeQuery"], result)

    @builtins.property
    def group_by(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetScatterplotDefinitionRequestXApmQueryGroupBy"]]]:
        '''group_by block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        '''
        result = self._values.get("group_by")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetScatterplotDefinitionRequestXApmQueryGroupBy"]]], result)

    @builtins.property
    def multi_compute(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetScatterplotDefinitionRequestXApmQueryMultiCompute"]]]:
        '''multi_compute block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        '''
        result = self._values.get("multi_compute")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetScatterplotDefinitionRequestXApmQueryMultiCompute"]]], result)

    @builtins.property
    def search_query(self) -> typing.Optional[builtins.str]:
        '''The search query to use.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        result = self._values.get("search_query")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetScatterplotDefinitionRequestXApmQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestXApmQueryComputeQuery",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetScatterplotDefinitionRequestXApmQueryComputeQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c6315a2175485c7128ff3e62f6462bfa8555faf125e251d8604af77398a4908a)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetScatterplotDefinitionRequestXApmQueryComputeQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetScatterplotDefinitionRequestXApmQueryComputeQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestXApmQueryComputeQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__370dc8dd1bf5ef9262466bc86101dd3ce47c24c75177b5b4c7a2cfa1663f2b25)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a9044ae54371ce42547fe2708b4444bd9b99818e605d59da9a217f824d969278)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8ac5564e6e6139e9e11c35889033dfdfbeeb68e2adc992b1e948f50b2f6ea251)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__376d0ee91878bf249da419bb6dbcd4e5cfaf43120980903379b104cea6b0569f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetScatterplotDefinitionRequestXApmQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetScatterplotDefinitionRequestXApmQueryComputeQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetScatterplotDefinitionRequestXApmQueryComputeQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__83859613377302bcace865c56ada4337f9220b90b7bf44b991e4fc40bced6a13)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestXApmQueryGroupBy",
    jsii_struct_bases=[],
    name_mapping={"facet": "facet", "limit": "limit", "sort_query": "sortQuery"},
)
class PowerpackWidgetScatterplotDefinitionRequestXApmQueryGroupBy:
    def __init__(
        self,
        *,
        facet: typing.Optional[builtins.str] = None,
        limit: typing.Optional[jsii.Number] = None,
        sort_query: typing.Optional[typing.Union["PowerpackWidgetScatterplotDefinitionRequestXApmQueryGroupBySortQuery", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param limit: The maximum number of items in the group. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param sort_query: sort_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        if isinstance(sort_query, dict):
            sort_query = PowerpackWidgetScatterplotDefinitionRequestXApmQueryGroupBySortQuery(**sort_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8f4f7a83fc0f66a45cf506589dff0ae1b93224246b1549c5929b371fdbd4cead)
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
            check_type(argname="argument sort_query", value=sort_query, expected_type=type_hints["sort_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if facet is not None:
            self._values["facet"] = facet
        if limit is not None:
            self._values["limit"] = limit
        if sort_query is not None:
            self._values["sort_query"] = sort_query

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def limit(self) -> typing.Optional[jsii.Number]:
        '''The maximum number of items in the group.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        '''
        result = self._values.get("limit")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def sort_query(
        self,
    ) -> typing.Optional["PowerpackWidgetScatterplotDefinitionRequestXApmQueryGroupBySortQuery"]:
        '''sort_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        result = self._values.get("sort_query")
        return typing.cast(typing.Optional["PowerpackWidgetScatterplotDefinitionRequestXApmQueryGroupBySortQuery"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetScatterplotDefinitionRequestXApmQueryGroupBy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetScatterplotDefinitionRequestXApmQueryGroupByList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestXApmQueryGroupByList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a6bd78633e6375d7c7e125c10112baf5392c9d92c3fdc2fc71f48462eaad5b80)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetScatterplotDefinitionRequestXApmQueryGroupByOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__05b05e18ef165718f6357f602b72eff49e007ae0c1f704408c5b304d48fb271b)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetScatterplotDefinitionRequestXApmQueryGroupByOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__03f9ccc1d009f89ca2b1aa4fdd72d9e1a7b855297bf6a5e4e7213a69f2b1b889)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__28a33fdc915b6328ca66fba60bdb0799fce098d56d67a15e309c5ca683312a4c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6c8f2abdf2e809378852ff72a6686ebd30fff9a81ef4a00cfecb1b6473e80373)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestXApmQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestXApmQueryGroupBy]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestXApmQueryGroupBy]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4585d09ac4fd7d212cb18bf0091d635e85e34eb22b8717a0dfe5b55f95300d3f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetScatterplotDefinitionRequestXApmQueryGroupByOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestXApmQueryGroupByOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d29f5480112a4157ea8146d415a17a6073e94bab84c799ab46e5a19ec31f11e3)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putSortQuery")
    def put_sort_query(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        value = PowerpackWidgetScatterplotDefinitionRequestXApmQueryGroupBySortQuery(
            aggregation=aggregation, order=order, facet=facet
        )

        return typing.cast(None, jsii.invoke(self, "putSortQuery", [value]))

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetLimit")
    def reset_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLimit", []))

    @jsii.member(jsii_name="resetSortQuery")
    def reset_sort_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSortQuery", []))

    @builtins.property
    @jsii.member(jsii_name="sortQuery")
    def sort_query(
        self,
    ) -> "PowerpackWidgetScatterplotDefinitionRequestXApmQueryGroupBySortQueryOutputReference":
        return typing.cast("PowerpackWidgetScatterplotDefinitionRequestXApmQueryGroupBySortQueryOutputReference", jsii.get(self, "sortQuery"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="limitInput")
    def limit_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "limitInput"))

    @builtins.property
    @jsii.member(jsii_name="sortQueryInput")
    def sort_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetScatterplotDefinitionRequestXApmQueryGroupBySortQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetScatterplotDefinitionRequestXApmQueryGroupBySortQuery"], jsii.get(self, "sortQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1c38dd15d750c034092cc1e0f4f4dfdce1a0ceaf350f6d8930e07a2ad78eebb0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="limit")
    def limit(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "limit"))

    @limit.setter
    def limit(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9a87673ea1e8f66d7c676c391012d48dc0e064d9f2065fc63af2959204b973ef)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "limit", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetScatterplotDefinitionRequestXApmQueryGroupBy]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetScatterplotDefinitionRequestXApmQueryGroupBy]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetScatterplotDefinitionRequestXApmQueryGroupBy]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9a1f8098cac09a3659878f7954299e5b1a39e451aca38291b81999eca3b89f88)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestXApmQueryGroupBySortQuery",
    jsii_struct_bases=[],
    name_mapping={"aggregation": "aggregation", "order": "order", "facet": "facet"},
)
class PowerpackWidgetScatterplotDefinitionRequestXApmQueryGroupBySortQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__da63f8163334257652f9810804f5cf54099fa95e6bfa13308ecba829fcdeb2dd)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument order", value=order, expected_type=type_hints["order"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
            "order": order,
        }
        if facet is not None:
            self._values["facet"] = facet

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def order(self) -> builtins.str:
        '''Widget sorting methods. Valid values are ``asc``, ``desc``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        result = self._values.get("order")
        assert result is not None, "Required property 'order' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetScatterplotDefinitionRequestXApmQueryGroupBySortQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetScatterplotDefinitionRequestXApmQueryGroupBySortQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestXApmQueryGroupBySortQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0d89292ad26c7594cbde18e92910b0216af7143fc1c4cf884526a93945d7354f)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="orderInput")
    def order_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "orderInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__612ad08f682c4fb059f62d5770f679f632c8a633200a6a9de5e193536046a9d7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1b544cc8f4ff544eb10c618e19a5df696a9566d14f5999babe74bee61f2e2284)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="order")
    def order(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "order"))

    @order.setter
    def order(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__660c710fc775d6ef5f4f96e8f4a06ec6721f7c60c0e7bfb7e972e48437282512)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "order", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetScatterplotDefinitionRequestXApmQueryGroupBySortQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetScatterplotDefinitionRequestXApmQueryGroupBySortQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetScatterplotDefinitionRequestXApmQueryGroupBySortQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c101186c384153de8eb9c11c2ed43e6394711ab6c3d42a144c41f0aded8e40f4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestXApmQueryMultiCompute",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetScatterplotDefinitionRequestXApmQueryMultiCompute:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__04afeb89f8ac947e6875c4dca5ee93322175251e79257042f450defc1426a3dc)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetScatterplotDefinitionRequestXApmQueryMultiCompute(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetScatterplotDefinitionRequestXApmQueryMultiComputeList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestXApmQueryMultiComputeList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c3435a976e4e886529a93c08f0d008659b5d02dec18a758aba8b93770b06a0be)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetScatterplotDefinitionRequestXApmQueryMultiComputeOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d1644a0dc8e4ebc6863fb863b48108ce7b657494e166d39b1c2a5f71de5476cd)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetScatterplotDefinitionRequestXApmQueryMultiComputeOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__04b248b93baa805ec27df11c9a5c29d2c836cfb9399fbfe4e9e9490f7bf212f0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3afb1fae4936a54163511558200676a3eb747ce4c005f7f512d99e9ba7e92e9a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ad6f5573fd95cae149886d2d72de3905016d720d29d34e6dfbdb16194a9dcb15)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestXApmQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestXApmQueryMultiCompute]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestXApmQueryMultiCompute]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ba356e4a1ff90d18fba75520dcb12be0b66c698f57329cf7114d6b4649a57929)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetScatterplotDefinitionRequestXApmQueryMultiComputeOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestXApmQueryMultiComputeOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e74c325a9b8b18df14f060423b501e42bc46d634f4ea297cb080f78dc37f8840)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e0a54567957220da1675d331f905f4f9be4592944bbf921ef61fd56920a3c4cf)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__91bc44f23eee5c67fb175fde65a2113d0465d8b8e335d39d0d000f8dee99af74)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f8475a0c6a9c678d612ff62a4f6f10e5530cdea78ebfd866c3a7bf961e0b30f8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetScatterplotDefinitionRequestXApmQueryMultiCompute]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetScatterplotDefinitionRequestXApmQueryMultiCompute]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetScatterplotDefinitionRequestXApmQueryMultiCompute]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__14a36ccb6d9c347a5017db9fed8f1f699aa0ac9996dff9d959a08d3d61a38311)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetScatterplotDefinitionRequestXApmQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestXApmQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fce73f259d65a5f1688e1e0aa5d0f0df922915777ccbaf31ed7aa1d9113a5c62)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putComputeQuery")
    def put_compute_query(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        value = PowerpackWidgetScatterplotDefinitionRequestXApmQueryComputeQuery(
            aggregation=aggregation, facet=facet, interval=interval
        )

        return typing.cast(None, jsii.invoke(self, "putComputeQuery", [value]))

    @jsii.member(jsii_name="putGroupBy")
    def put_group_by(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetScatterplotDefinitionRequestXApmQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0c595fed64cd79c85290ab9c5ac4bae57b341783ab00a0374f2c360fbc2a9807)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putGroupBy", [value]))

    @jsii.member(jsii_name="putMultiCompute")
    def put_multi_compute(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetScatterplotDefinitionRequestXApmQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7a47e516c1ed180574f55ca1ccbb336ecf686c8af194b25e63f26cd55c84dc14)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putMultiCompute", [value]))

    @jsii.member(jsii_name="resetComputeQuery")
    def reset_compute_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetComputeQuery", []))

    @jsii.member(jsii_name="resetGroupBy")
    def reset_group_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGroupBy", []))

    @jsii.member(jsii_name="resetMultiCompute")
    def reset_multi_compute(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMultiCompute", []))

    @jsii.member(jsii_name="resetSearchQuery")
    def reset_search_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSearchQuery", []))

    @builtins.property
    @jsii.member(jsii_name="computeQuery")
    def compute_query(
        self,
    ) -> PowerpackWidgetScatterplotDefinitionRequestXApmQueryComputeQueryOutputReference:
        return typing.cast(PowerpackWidgetScatterplotDefinitionRequestXApmQueryComputeQueryOutputReference, jsii.get(self, "computeQuery"))

    @builtins.property
    @jsii.member(jsii_name="groupBy")
    def group_by(
        self,
    ) -> PowerpackWidgetScatterplotDefinitionRequestXApmQueryGroupByList:
        return typing.cast(PowerpackWidgetScatterplotDefinitionRequestXApmQueryGroupByList, jsii.get(self, "groupBy"))

    @builtins.property
    @jsii.member(jsii_name="multiCompute")
    def multi_compute(
        self,
    ) -> PowerpackWidgetScatterplotDefinitionRequestXApmQueryMultiComputeList:
        return typing.cast(PowerpackWidgetScatterplotDefinitionRequestXApmQueryMultiComputeList, jsii.get(self, "multiCompute"))

    @builtins.property
    @jsii.member(jsii_name="computeQueryInput")
    def compute_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetScatterplotDefinitionRequestXApmQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetScatterplotDefinitionRequestXApmQueryComputeQuery], jsii.get(self, "computeQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="groupByInput")
    def group_by_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestXApmQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestXApmQueryGroupBy]]], jsii.get(self, "groupByInput"))

    @builtins.property
    @jsii.member(jsii_name="indexInput")
    def index_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "indexInput"))

    @builtins.property
    @jsii.member(jsii_name="multiComputeInput")
    def multi_compute_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestXApmQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestXApmQueryMultiCompute]]], jsii.get(self, "multiComputeInput"))

    @builtins.property
    @jsii.member(jsii_name="searchQueryInput")
    def search_query_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "searchQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="index")
    def index(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "index"))

    @index.setter
    def index(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__02ee0f53a10fcef28f6ca986cb1428c05f6852dc7c48fa55f9a68a2eccf50f4a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "index", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="searchQuery")
    def search_query(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "searchQuery"))

    @search_query.setter
    def search_query(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d4172e35207a8392b34f003b71b88d61f622987ddfc1d1029d94f4b3de7a7c78)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "searchQuery", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetScatterplotDefinitionRequestXApmQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetScatterplotDefinitionRequestXApmQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetScatterplotDefinitionRequestXApmQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__68accea1fb031c29cf1b890cb1065c17beaec157d799f332a0a4e378de106cf4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetScatterplotDefinitionRequestXList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestXList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f4bc6f7e84077432a81bdf310c6411a1737be0e08170d357e7c59fd63e41799d)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetScatterplotDefinitionRequestXOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7e642466d7fbf51824bedb903de01bf8e78e2e945f8743ee00a967eba9c0b009)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetScatterplotDefinitionRequestXOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a6289ef577ca730b1639249e755414852b1a6b86e9a038870edbcc3c9e4a1a27)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dd8bfd8288e1a481b6dd48f678806d39c809bde09fc79aa0ba62386f7a888fdd)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__45ae8226878b06fefc958229b668cb97113c07c9126b1240a3ae041229cd29d4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestX]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestX]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestX]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9bbf6db58be9201dc7d0f38a90fa27d2d85d7d4567105a482d525d7d9797d577)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestXLogQuery",
    jsii_struct_bases=[],
    name_mapping={
        "index": "index",
        "compute_query": "computeQuery",
        "group_by": "groupBy",
        "multi_compute": "multiCompute",
        "search_query": "searchQuery",
    },
)
class PowerpackWidgetScatterplotDefinitionRequestXLogQuery:
    def __init__(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union["PowerpackWidgetScatterplotDefinitionRequestXLogQueryComputeQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetScatterplotDefinitionRequestXLogQueryGroupBy", typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetScatterplotDefinitionRequestXLogQueryMultiCompute", typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        if isinstance(compute_query, dict):
            compute_query = PowerpackWidgetScatterplotDefinitionRequestXLogQueryComputeQuery(**compute_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__955f7bd4989c91c38e727468a83f5b7d910383a214dc962013e49fd9f7817569)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
            check_type(argname="argument compute_query", value=compute_query, expected_type=type_hints["compute_query"])
            check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
            check_type(argname="argument multi_compute", value=multi_compute, expected_type=type_hints["multi_compute"])
            check_type(argname="argument search_query", value=search_query, expected_type=type_hints["search_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "index": index,
        }
        if compute_query is not None:
            self._values["compute_query"] = compute_query
        if group_by is not None:
            self._values["group_by"] = group_by
        if multi_compute is not None:
            self._values["multi_compute"] = multi_compute
        if search_query is not None:
            self._values["search_query"] = search_query

    @builtins.property
    def index(self) -> builtins.str:
        '''The name of the index to query.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        '''
        result = self._values.get("index")
        assert result is not None, "Required property 'index' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def compute_query(
        self,
    ) -> typing.Optional["PowerpackWidgetScatterplotDefinitionRequestXLogQueryComputeQuery"]:
        '''compute_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        '''
        result = self._values.get("compute_query")
        return typing.cast(typing.Optional["PowerpackWidgetScatterplotDefinitionRequestXLogQueryComputeQuery"], result)

    @builtins.property
    def group_by(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetScatterplotDefinitionRequestXLogQueryGroupBy"]]]:
        '''group_by block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        '''
        result = self._values.get("group_by")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetScatterplotDefinitionRequestXLogQueryGroupBy"]]], result)

    @builtins.property
    def multi_compute(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetScatterplotDefinitionRequestXLogQueryMultiCompute"]]]:
        '''multi_compute block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        '''
        result = self._values.get("multi_compute")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetScatterplotDefinitionRequestXLogQueryMultiCompute"]]], result)

    @builtins.property
    def search_query(self) -> typing.Optional[builtins.str]:
        '''The search query to use.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        result = self._values.get("search_query")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetScatterplotDefinitionRequestXLogQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestXLogQueryComputeQuery",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetScatterplotDefinitionRequestXLogQueryComputeQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__94a7d234290c0153887454e85cf1ae37834ec415a92f2c3d3eb65f669ac83ac0)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetScatterplotDefinitionRequestXLogQueryComputeQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetScatterplotDefinitionRequestXLogQueryComputeQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestXLogQueryComputeQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b58b123fc0c9476b66fccadce7262cea34c2f876fdefba9942afe34f8c665c8d)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f8b24168ba85294c611a53f1d7167d9d51645a6b7dfcf0e424bc1de1a27fc5ec)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c6551d7f7aba1ce177a2d1d35361249b03979271b83737aa6b355cc08697984e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6d660c1ddddfd7b85133fab71be1a4999e73f027b3a35b63ffad074344e6bd45)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetScatterplotDefinitionRequestXLogQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetScatterplotDefinitionRequestXLogQueryComputeQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetScatterplotDefinitionRequestXLogQueryComputeQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__065538b56b873fea237ed4380068a5337fd29f090fe9bbcab5140d38327aca73)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestXLogQueryGroupBy",
    jsii_struct_bases=[],
    name_mapping={"facet": "facet", "limit": "limit", "sort_query": "sortQuery"},
)
class PowerpackWidgetScatterplotDefinitionRequestXLogQueryGroupBy:
    def __init__(
        self,
        *,
        facet: typing.Optional[builtins.str] = None,
        limit: typing.Optional[jsii.Number] = None,
        sort_query: typing.Optional[typing.Union["PowerpackWidgetScatterplotDefinitionRequestXLogQueryGroupBySortQuery", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param limit: The maximum number of items in the group. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param sort_query: sort_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        if isinstance(sort_query, dict):
            sort_query = PowerpackWidgetScatterplotDefinitionRequestXLogQueryGroupBySortQuery(**sort_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9834f51021e0fb64a780a713902aeb849128778f7ef4b3493f911a0e7633cd9f)
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
            check_type(argname="argument sort_query", value=sort_query, expected_type=type_hints["sort_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if facet is not None:
            self._values["facet"] = facet
        if limit is not None:
            self._values["limit"] = limit
        if sort_query is not None:
            self._values["sort_query"] = sort_query

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def limit(self) -> typing.Optional[jsii.Number]:
        '''The maximum number of items in the group.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        '''
        result = self._values.get("limit")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def sort_query(
        self,
    ) -> typing.Optional["PowerpackWidgetScatterplotDefinitionRequestXLogQueryGroupBySortQuery"]:
        '''sort_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        result = self._values.get("sort_query")
        return typing.cast(typing.Optional["PowerpackWidgetScatterplotDefinitionRequestXLogQueryGroupBySortQuery"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetScatterplotDefinitionRequestXLogQueryGroupBy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetScatterplotDefinitionRequestXLogQueryGroupByList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestXLogQueryGroupByList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f9bc6b91142005599466e30b9374b32720994d9f71c9ea6789abd0ae2ea854b5)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetScatterplotDefinitionRequestXLogQueryGroupByOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__987fb5e8ddf6facbe320502aef5e4aba86d4937444cce463a739d1e90c9f2daa)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetScatterplotDefinitionRequestXLogQueryGroupByOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__afc4135663e000726ec39b902ed858604f69170ab78ed820bae7a9c85043fa16)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a748e1f6a6d162e4dda55b4c12ffa43ad85a96dd60b5710f9b0a3c67af52a477)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0c29346fd6630a8b136e399a32ef32bd0bc0458ef6b9f9f73b0c7b778eb523e4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestXLogQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestXLogQueryGroupBy]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestXLogQueryGroupBy]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3e6689c61dd363cc55e01bc8389763c3874a4c7990310900e44e86d5af3e51ae)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetScatterplotDefinitionRequestXLogQueryGroupByOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestXLogQueryGroupByOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f5eb516ca855c83793316e56c19982e2c04d08e683226dffa327709f73e628db)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putSortQuery")
    def put_sort_query(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        value = PowerpackWidgetScatterplotDefinitionRequestXLogQueryGroupBySortQuery(
            aggregation=aggregation, order=order, facet=facet
        )

        return typing.cast(None, jsii.invoke(self, "putSortQuery", [value]))

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetLimit")
    def reset_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLimit", []))

    @jsii.member(jsii_name="resetSortQuery")
    def reset_sort_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSortQuery", []))

    @builtins.property
    @jsii.member(jsii_name="sortQuery")
    def sort_query(
        self,
    ) -> "PowerpackWidgetScatterplotDefinitionRequestXLogQueryGroupBySortQueryOutputReference":
        return typing.cast("PowerpackWidgetScatterplotDefinitionRequestXLogQueryGroupBySortQueryOutputReference", jsii.get(self, "sortQuery"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="limitInput")
    def limit_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "limitInput"))

    @builtins.property
    @jsii.member(jsii_name="sortQueryInput")
    def sort_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetScatterplotDefinitionRequestXLogQueryGroupBySortQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetScatterplotDefinitionRequestXLogQueryGroupBySortQuery"], jsii.get(self, "sortQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d59b31456d0028a3ee8c92919629ad1edd4cdba474b6554199db082aa634e1fc)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="limit")
    def limit(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "limit"))

    @limit.setter
    def limit(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f918d057e2957e8681ca2e5bdad35a5f2af6915ed5b7f40c64bc89fc88ac10af)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "limit", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetScatterplotDefinitionRequestXLogQueryGroupBy]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetScatterplotDefinitionRequestXLogQueryGroupBy]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetScatterplotDefinitionRequestXLogQueryGroupBy]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3492ddaf5ac297e50bd90c241ac203904e34fa6aa20ab9a697f33558628bab5b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestXLogQueryGroupBySortQuery",
    jsii_struct_bases=[],
    name_mapping={"aggregation": "aggregation", "order": "order", "facet": "facet"},
)
class PowerpackWidgetScatterplotDefinitionRequestXLogQueryGroupBySortQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f5c8eb04749d4b9cc730e01ef1afaf42a4a5516a0152009a5240cb4eda99c54a)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument order", value=order, expected_type=type_hints["order"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
            "order": order,
        }
        if facet is not None:
            self._values["facet"] = facet

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def order(self) -> builtins.str:
        '''Widget sorting methods. Valid values are ``asc``, ``desc``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        result = self._values.get("order")
        assert result is not None, "Required property 'order' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetScatterplotDefinitionRequestXLogQueryGroupBySortQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetScatterplotDefinitionRequestXLogQueryGroupBySortQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestXLogQueryGroupBySortQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__333acb41b3cc89a0c0a4a66c741e271c1427873c3c2a3142dffd321d86d86dc2)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="orderInput")
    def order_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "orderInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e93e05005941bdfaa2b327d0f21f3742f44fcba53d07741b8f8009da7f0601ef)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__16e25f2b7d52dde7b47ff8ab751d9ad35f78e3ff35d73eb5d91167b06a32fb2b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="order")
    def order(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "order"))

    @order.setter
    def order(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cdac60026845277abf741ff3865c7f077f03c55fd0c286ecb7d38daf65744189)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "order", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetScatterplotDefinitionRequestXLogQueryGroupBySortQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetScatterplotDefinitionRequestXLogQueryGroupBySortQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetScatterplotDefinitionRequestXLogQueryGroupBySortQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__de932eca8618fa7516cb8bb2d51221492389c40e490ee74013a2e19161cf31c4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestXLogQueryMultiCompute",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetScatterplotDefinitionRequestXLogQueryMultiCompute:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__effc80b7c1e252ea54e9dc914508ac372fa7061c8d4417a77f173426a73e7c1c)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetScatterplotDefinitionRequestXLogQueryMultiCompute(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetScatterplotDefinitionRequestXLogQueryMultiComputeList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestXLogQueryMultiComputeList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__64c4720e27e1e5aff76d196644d153c8cd2bc6dba41871ff074b9ee67fc69bde)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetScatterplotDefinitionRequestXLogQueryMultiComputeOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__eac7f5c169695d0319262e4d2b9a9affa295431dd8db1c5128a8707384979ad5)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetScatterplotDefinitionRequestXLogQueryMultiComputeOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7834e34e8709b65adc0a82def17a3c549ac12ac055186e894f0fc9dd4bf6e261)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ca1e488fec13c9501fde4f590fd46cf5a4654ff7b07239fc35c177d1713aee4b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4e38eb73b77717afc4a80f48868a8c4f2c4a2189390400056f328a03672ec769)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestXLogQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestXLogQueryMultiCompute]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestXLogQueryMultiCompute]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__57ff46ffb33f70475b6534961160f2836af42708cdfc9b00daa309cacb0fc312)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetScatterplotDefinitionRequestXLogQueryMultiComputeOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestXLogQueryMultiComputeOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4763ed2e257d7ae7ee7bbee0299cb489c5493e4a5db9a5cfd760e9fd8cbd23d1)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b141675be0f7baca075ea8fa099c62854c66be38667d9d1fb46d8fd035561a13)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__868ae48a9ba13ddeba817d00b77b66de94a5cf422e7d326004411b036a70f5da)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7ec763f65b5501710d014e67310e1bebd7ca41533e589596cc4700af0bbf0ad2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetScatterplotDefinitionRequestXLogQueryMultiCompute]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetScatterplotDefinitionRequestXLogQueryMultiCompute]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetScatterplotDefinitionRequestXLogQueryMultiCompute]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c246f788c3ba0ea31c95c2d10be86f819995548766820ddd2011f29639e98794)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetScatterplotDefinitionRequestXLogQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestXLogQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f456087b966a2cfbd52e5c3171c55bfbe84dd1951053ae04258e9354945c1876)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putComputeQuery")
    def put_compute_query(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        value = PowerpackWidgetScatterplotDefinitionRequestXLogQueryComputeQuery(
            aggregation=aggregation, facet=facet, interval=interval
        )

        return typing.cast(None, jsii.invoke(self, "putComputeQuery", [value]))

    @jsii.member(jsii_name="putGroupBy")
    def put_group_by(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetScatterplotDefinitionRequestXLogQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c152e2aedc5c1998cb954f122ed20da3bb7fea2997459e9f2db6dfaa8800a4de)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putGroupBy", [value]))

    @jsii.member(jsii_name="putMultiCompute")
    def put_multi_compute(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetScatterplotDefinitionRequestXLogQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7fa4c49f62203c028ead32e1de5a8c731006c3b5937c34b1ccc61a2218f5413f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putMultiCompute", [value]))

    @jsii.member(jsii_name="resetComputeQuery")
    def reset_compute_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetComputeQuery", []))

    @jsii.member(jsii_name="resetGroupBy")
    def reset_group_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGroupBy", []))

    @jsii.member(jsii_name="resetMultiCompute")
    def reset_multi_compute(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMultiCompute", []))

    @jsii.member(jsii_name="resetSearchQuery")
    def reset_search_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSearchQuery", []))

    @builtins.property
    @jsii.member(jsii_name="computeQuery")
    def compute_query(
        self,
    ) -> PowerpackWidgetScatterplotDefinitionRequestXLogQueryComputeQueryOutputReference:
        return typing.cast(PowerpackWidgetScatterplotDefinitionRequestXLogQueryComputeQueryOutputReference, jsii.get(self, "computeQuery"))

    @builtins.property
    @jsii.member(jsii_name="groupBy")
    def group_by(
        self,
    ) -> PowerpackWidgetScatterplotDefinitionRequestXLogQueryGroupByList:
        return typing.cast(PowerpackWidgetScatterplotDefinitionRequestXLogQueryGroupByList, jsii.get(self, "groupBy"))

    @builtins.property
    @jsii.member(jsii_name="multiCompute")
    def multi_compute(
        self,
    ) -> PowerpackWidgetScatterplotDefinitionRequestXLogQueryMultiComputeList:
        return typing.cast(PowerpackWidgetScatterplotDefinitionRequestXLogQueryMultiComputeList, jsii.get(self, "multiCompute"))

    @builtins.property
    @jsii.member(jsii_name="computeQueryInput")
    def compute_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetScatterplotDefinitionRequestXLogQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetScatterplotDefinitionRequestXLogQueryComputeQuery], jsii.get(self, "computeQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="groupByInput")
    def group_by_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestXLogQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestXLogQueryGroupBy]]], jsii.get(self, "groupByInput"))

    @builtins.property
    @jsii.member(jsii_name="indexInput")
    def index_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "indexInput"))

    @builtins.property
    @jsii.member(jsii_name="multiComputeInput")
    def multi_compute_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestXLogQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestXLogQueryMultiCompute]]], jsii.get(self, "multiComputeInput"))

    @builtins.property
    @jsii.member(jsii_name="searchQueryInput")
    def search_query_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "searchQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="index")
    def index(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "index"))

    @index.setter
    def index(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4e3913c5d4ef433c64b42ac1fe2fea7b36c40105c56b83c3ab2f4d66f48d53a8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "index", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="searchQuery")
    def search_query(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "searchQuery"))

    @search_query.setter
    def search_query(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6bbc0bfc46e885dd39c3ec2a09efddf71ef6ce92b4ae30ee20d63dd64a39a965)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "searchQuery", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetScatterplotDefinitionRequestXLogQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetScatterplotDefinitionRequestXLogQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetScatterplotDefinitionRequestXLogQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9aff86424250622a6c00d7f23663ba888c1c0fdf2461b508760d49d3aa6a2bde)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetScatterplotDefinitionRequestXOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestXOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2c4afb7cd2758001f646c72e5bbe7513bc3c365878287dd4a273d6e1127534c9)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putApmQuery")
    def put_apm_query(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union[PowerpackWidgetScatterplotDefinitionRequestXApmQueryComputeQuery, typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetScatterplotDefinitionRequestXApmQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetScatterplotDefinitionRequestXApmQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        value = PowerpackWidgetScatterplotDefinitionRequestXApmQuery(
            index=index,
            compute_query=compute_query,
            group_by=group_by,
            multi_compute=multi_compute,
            search_query=search_query,
        )

        return typing.cast(None, jsii.invoke(self, "putApmQuery", [value]))

    @jsii.member(jsii_name="putLogQuery")
    def put_log_query(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union[PowerpackWidgetScatterplotDefinitionRequestXLogQueryComputeQuery, typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetScatterplotDefinitionRequestXLogQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetScatterplotDefinitionRequestXLogQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        value = PowerpackWidgetScatterplotDefinitionRequestXLogQuery(
            index=index,
            compute_query=compute_query,
            group_by=group_by,
            multi_compute=multi_compute,
            search_query=search_query,
        )

        return typing.cast(None, jsii.invoke(self, "putLogQuery", [value]))

    @jsii.member(jsii_name="putProcessQuery")
    def put_process_query(
        self,
        *,
        metric: builtins.str,
        filter_by: typing.Optional[typing.Sequence[builtins.str]] = None,
        limit: typing.Optional[jsii.Number] = None,
        search_by: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param metric: Your chosen metric. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        :param filter_by: A list of processes. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#filter_by Powerpack#filter_by}
        :param limit: The max number of items in the filter list. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param search_by: Your chosen search term. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_by Powerpack#search_by}
        '''
        value = PowerpackWidgetScatterplotDefinitionRequestXProcessQuery(
            metric=metric, filter_by=filter_by, limit=limit, search_by=search_by
        )

        return typing.cast(None, jsii.invoke(self, "putProcessQuery", [value]))

    @jsii.member(jsii_name="putRumQuery")
    def put_rum_query(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union["PowerpackWidgetScatterplotDefinitionRequestXRumQueryComputeQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetScatterplotDefinitionRequestXRumQueryGroupBy", typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetScatterplotDefinitionRequestXRumQueryMultiCompute", typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        value = PowerpackWidgetScatterplotDefinitionRequestXRumQuery(
            index=index,
            compute_query=compute_query,
            group_by=group_by,
            multi_compute=multi_compute,
            search_query=search_query,
        )

        return typing.cast(None, jsii.invoke(self, "putRumQuery", [value]))

    @jsii.member(jsii_name="putSecurityQuery")
    def put_security_query(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union["PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryComputeQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryGroupBy", typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryMultiCompute", typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        value = PowerpackWidgetScatterplotDefinitionRequestXSecurityQuery(
            index=index,
            compute_query=compute_query,
            group_by=group_by,
            multi_compute=multi_compute,
            search_query=search_query,
        )

        return typing.cast(None, jsii.invoke(self, "putSecurityQuery", [value]))

    @jsii.member(jsii_name="resetAggregator")
    def reset_aggregator(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAggregator", []))

    @jsii.member(jsii_name="resetApmQuery")
    def reset_apm_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetApmQuery", []))

    @jsii.member(jsii_name="resetLogQuery")
    def reset_log_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLogQuery", []))

    @jsii.member(jsii_name="resetProcessQuery")
    def reset_process_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetProcessQuery", []))

    @jsii.member(jsii_name="resetQ")
    def reset_q(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetQ", []))

    @jsii.member(jsii_name="resetRumQuery")
    def reset_rum_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetRumQuery", []))

    @jsii.member(jsii_name="resetSecurityQuery")
    def reset_security_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSecurityQuery", []))

    @builtins.property
    @jsii.member(jsii_name="apmQuery")
    def apm_query(
        self,
    ) -> PowerpackWidgetScatterplotDefinitionRequestXApmQueryOutputReference:
        return typing.cast(PowerpackWidgetScatterplotDefinitionRequestXApmQueryOutputReference, jsii.get(self, "apmQuery"))

    @builtins.property
    @jsii.member(jsii_name="logQuery")
    def log_query(
        self,
    ) -> PowerpackWidgetScatterplotDefinitionRequestXLogQueryOutputReference:
        return typing.cast(PowerpackWidgetScatterplotDefinitionRequestXLogQueryOutputReference, jsii.get(self, "logQuery"))

    @builtins.property
    @jsii.member(jsii_name="processQuery")
    def process_query(
        self,
    ) -> "PowerpackWidgetScatterplotDefinitionRequestXProcessQueryOutputReference":
        return typing.cast("PowerpackWidgetScatterplotDefinitionRequestXProcessQueryOutputReference", jsii.get(self, "processQuery"))

    @builtins.property
    @jsii.member(jsii_name="rumQuery")
    def rum_query(
        self,
    ) -> "PowerpackWidgetScatterplotDefinitionRequestXRumQueryOutputReference":
        return typing.cast("PowerpackWidgetScatterplotDefinitionRequestXRumQueryOutputReference", jsii.get(self, "rumQuery"))

    @builtins.property
    @jsii.member(jsii_name="securityQuery")
    def security_query(
        self,
    ) -> "PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryOutputReference":
        return typing.cast("PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryOutputReference", jsii.get(self, "securityQuery"))

    @builtins.property
    @jsii.member(jsii_name="aggregatorInput")
    def aggregator_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregatorInput"))

    @builtins.property
    @jsii.member(jsii_name="apmQueryInput")
    def apm_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetScatterplotDefinitionRequestXApmQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetScatterplotDefinitionRequestXApmQuery], jsii.get(self, "apmQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="logQueryInput")
    def log_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetScatterplotDefinitionRequestXLogQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetScatterplotDefinitionRequestXLogQuery], jsii.get(self, "logQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="processQueryInput")
    def process_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetScatterplotDefinitionRequestXProcessQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetScatterplotDefinitionRequestXProcessQuery"], jsii.get(self, "processQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="qInput")
    def q_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "qInput"))

    @builtins.property
    @jsii.member(jsii_name="rumQueryInput")
    def rum_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetScatterplotDefinitionRequestXRumQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetScatterplotDefinitionRequestXRumQuery"], jsii.get(self, "rumQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="securityQueryInput")
    def security_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetScatterplotDefinitionRequestXSecurityQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetScatterplotDefinitionRequestXSecurityQuery"], jsii.get(self, "securityQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregator")
    def aggregator(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregator"))

    @aggregator.setter
    def aggregator(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d012565a55bc6e49d80c7ddc1e8d7df63f0c4ab2481a30b234681f4545694e10)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregator", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="q")
    def q(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "q"))

    @q.setter
    def q(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0ffc3cff6c34f16387eb91f6eb705e47ae02f4c7a92d177cecb7706456b9d657)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "q", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetScatterplotDefinitionRequestX]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetScatterplotDefinitionRequestX]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetScatterplotDefinitionRequestX]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cafba75580e86f145623c5a5189bfefe9f019814a3b87bf6a90a32fe6fb72cac)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestXProcessQuery",
    jsii_struct_bases=[],
    name_mapping={
        "metric": "metric",
        "filter_by": "filterBy",
        "limit": "limit",
        "search_by": "searchBy",
    },
)
class PowerpackWidgetScatterplotDefinitionRequestXProcessQuery:
    def __init__(
        self,
        *,
        metric: builtins.str,
        filter_by: typing.Optional[typing.Sequence[builtins.str]] = None,
        limit: typing.Optional[jsii.Number] = None,
        search_by: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param metric: Your chosen metric. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        :param filter_by: A list of processes. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#filter_by Powerpack#filter_by}
        :param limit: The max number of items in the filter list. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param search_by: Your chosen search term. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_by Powerpack#search_by}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d05332d7dd508f69ec63d51aca257ef9561381c272342ed36ff324439f59ff6c)
            check_type(argname="argument metric", value=metric, expected_type=type_hints["metric"])
            check_type(argname="argument filter_by", value=filter_by, expected_type=type_hints["filter_by"])
            check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
            check_type(argname="argument search_by", value=search_by, expected_type=type_hints["search_by"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "metric": metric,
        }
        if filter_by is not None:
            self._values["filter_by"] = filter_by
        if limit is not None:
            self._values["limit"] = limit
        if search_by is not None:
            self._values["search_by"] = search_by

    @builtins.property
    def metric(self) -> builtins.str:
        '''Your chosen metric.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        '''
        result = self._values.get("metric")
        assert result is not None, "Required property 'metric' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def filter_by(self) -> typing.Optional[typing.List[builtins.str]]:
        '''A list of processes.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#filter_by Powerpack#filter_by}
        '''
        result = self._values.get("filter_by")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def limit(self) -> typing.Optional[jsii.Number]:
        '''The max number of items in the filter list.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        '''
        result = self._values.get("limit")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def search_by(self) -> typing.Optional[builtins.str]:
        '''Your chosen search term.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_by Powerpack#search_by}
        '''
        result = self._values.get("search_by")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetScatterplotDefinitionRequestXProcessQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetScatterplotDefinitionRequestXProcessQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestXProcessQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4ff8e01577c456839edb3e5d2a614cecd18f38c82d69465a9e661a68d8c36a2d)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFilterBy")
    def reset_filter_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFilterBy", []))

    @jsii.member(jsii_name="resetLimit")
    def reset_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLimit", []))

    @jsii.member(jsii_name="resetSearchBy")
    def reset_search_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSearchBy", []))

    @builtins.property
    @jsii.member(jsii_name="filterByInput")
    def filter_by_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "filterByInput"))

    @builtins.property
    @jsii.member(jsii_name="limitInput")
    def limit_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "limitInput"))

    @builtins.property
    @jsii.member(jsii_name="metricInput")
    def metric_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "metricInput"))

    @builtins.property
    @jsii.member(jsii_name="searchByInput")
    def search_by_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "searchByInput"))

    @builtins.property
    @jsii.member(jsii_name="filterBy")
    def filter_by(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "filterBy"))

    @filter_by.setter
    def filter_by(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6c6c67a483e0be37a52c7f7f05c97046ee7c6191608f4ccfdcb3853a461bd6d3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "filterBy", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="limit")
    def limit(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "limit"))

    @limit.setter
    def limit(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__75f0569e2230ae0e49386e6bc2ae93b592d541f1bc499ecc657935292eb88274)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "limit", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="metric")
    def metric(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "metric"))

    @metric.setter
    def metric(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8076a4197c3e696478e143f233097c2ed41ae46a853a954b769dadb7b71654a1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "metric", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="searchBy")
    def search_by(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "searchBy"))

    @search_by.setter
    def search_by(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3469d3e6ba1f928fddd6bd35f9ea57a01a3f9c85fd0f0593df590807465fc7dc)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "searchBy", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetScatterplotDefinitionRequestXProcessQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetScatterplotDefinitionRequestXProcessQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetScatterplotDefinitionRequestXProcessQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__861a9e1e76fac3456ae1ff6d0a5fd44f7fed910c21c086dd85755ce677144346)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestXRumQuery",
    jsii_struct_bases=[],
    name_mapping={
        "index": "index",
        "compute_query": "computeQuery",
        "group_by": "groupBy",
        "multi_compute": "multiCompute",
        "search_query": "searchQuery",
    },
)
class PowerpackWidgetScatterplotDefinitionRequestXRumQuery:
    def __init__(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union["PowerpackWidgetScatterplotDefinitionRequestXRumQueryComputeQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetScatterplotDefinitionRequestXRumQueryGroupBy", typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetScatterplotDefinitionRequestXRumQueryMultiCompute", typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        if isinstance(compute_query, dict):
            compute_query = PowerpackWidgetScatterplotDefinitionRequestXRumQueryComputeQuery(**compute_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9c5b4cac3ccf723c1e29c2f873b23fc261750264d9e150b3aca25821652de147)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
            check_type(argname="argument compute_query", value=compute_query, expected_type=type_hints["compute_query"])
            check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
            check_type(argname="argument multi_compute", value=multi_compute, expected_type=type_hints["multi_compute"])
            check_type(argname="argument search_query", value=search_query, expected_type=type_hints["search_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "index": index,
        }
        if compute_query is not None:
            self._values["compute_query"] = compute_query
        if group_by is not None:
            self._values["group_by"] = group_by
        if multi_compute is not None:
            self._values["multi_compute"] = multi_compute
        if search_query is not None:
            self._values["search_query"] = search_query

    @builtins.property
    def index(self) -> builtins.str:
        '''The name of the index to query.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        '''
        result = self._values.get("index")
        assert result is not None, "Required property 'index' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def compute_query(
        self,
    ) -> typing.Optional["PowerpackWidgetScatterplotDefinitionRequestXRumQueryComputeQuery"]:
        '''compute_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        '''
        result = self._values.get("compute_query")
        return typing.cast(typing.Optional["PowerpackWidgetScatterplotDefinitionRequestXRumQueryComputeQuery"], result)

    @builtins.property
    def group_by(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetScatterplotDefinitionRequestXRumQueryGroupBy"]]]:
        '''group_by block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        '''
        result = self._values.get("group_by")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetScatterplotDefinitionRequestXRumQueryGroupBy"]]], result)

    @builtins.property
    def multi_compute(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetScatterplotDefinitionRequestXRumQueryMultiCompute"]]]:
        '''multi_compute block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        '''
        result = self._values.get("multi_compute")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetScatterplotDefinitionRequestXRumQueryMultiCompute"]]], result)

    @builtins.property
    def search_query(self) -> typing.Optional[builtins.str]:
        '''The search query to use.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        result = self._values.get("search_query")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetScatterplotDefinitionRequestXRumQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestXRumQueryComputeQuery",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetScatterplotDefinitionRequestXRumQueryComputeQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bf720e6fa052642d19d0d9484bcedf089756eed861d7f84776fc0e203aea31ac)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetScatterplotDefinitionRequestXRumQueryComputeQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetScatterplotDefinitionRequestXRumQueryComputeQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestXRumQueryComputeQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__12cc8c2255f272850b95dca2e063626d4c5ca7de8b74d646bdaf7543934fb116)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__077c5f52ec01b3860ba5d321d7e5167d9b6bcf0d1d8f449cc7e6428eaaead914)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e704f2a158018a8a4a55460b1b0838dfe801c8bf34a7e3ad121c28e23ea0f720)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__da941c417216424dcb70bb986b9821591670c6eaa1e764dfd373d78a20d9424c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetScatterplotDefinitionRequestXRumQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetScatterplotDefinitionRequestXRumQueryComputeQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetScatterplotDefinitionRequestXRumQueryComputeQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fd3c51c0f32e6841db6d64364420103e3af88152d0f2aacf917efa03e75b06ca)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestXRumQueryGroupBy",
    jsii_struct_bases=[],
    name_mapping={"facet": "facet", "limit": "limit", "sort_query": "sortQuery"},
)
class PowerpackWidgetScatterplotDefinitionRequestXRumQueryGroupBy:
    def __init__(
        self,
        *,
        facet: typing.Optional[builtins.str] = None,
        limit: typing.Optional[jsii.Number] = None,
        sort_query: typing.Optional[typing.Union["PowerpackWidgetScatterplotDefinitionRequestXRumQueryGroupBySortQuery", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param limit: The maximum number of items in the group. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param sort_query: sort_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        if isinstance(sort_query, dict):
            sort_query = PowerpackWidgetScatterplotDefinitionRequestXRumQueryGroupBySortQuery(**sort_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__95b59e8e711220f40186b7543a29410801d16fec8fb55b9307bc79a17b98af75)
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
            check_type(argname="argument sort_query", value=sort_query, expected_type=type_hints["sort_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if facet is not None:
            self._values["facet"] = facet
        if limit is not None:
            self._values["limit"] = limit
        if sort_query is not None:
            self._values["sort_query"] = sort_query

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def limit(self) -> typing.Optional[jsii.Number]:
        '''The maximum number of items in the group.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        '''
        result = self._values.get("limit")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def sort_query(
        self,
    ) -> typing.Optional["PowerpackWidgetScatterplotDefinitionRequestXRumQueryGroupBySortQuery"]:
        '''sort_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        result = self._values.get("sort_query")
        return typing.cast(typing.Optional["PowerpackWidgetScatterplotDefinitionRequestXRumQueryGroupBySortQuery"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetScatterplotDefinitionRequestXRumQueryGroupBy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetScatterplotDefinitionRequestXRumQueryGroupByList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestXRumQueryGroupByList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f27cb23f51b55da7362c551480247ea68779cc66b1888c2f4d2731020993d9ab)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetScatterplotDefinitionRequestXRumQueryGroupByOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4ca4ae4e549a1f1897ce28326f8ecdf3d8b87740f7fcf6dfe50cf25644a2c967)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetScatterplotDefinitionRequestXRumQueryGroupByOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6a40a35e6225132f89a3f1832669550be17959da0e8cb7ba069af44fae6a2895)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0b758a8b5d667559da647fd34b335cb349d11f7fc302901a04f2e53197aa70ab)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__73bbe5187a853b13467f21a343006b3c2a83bacbabfc84062543ae2cca9d0362)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestXRumQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestXRumQueryGroupBy]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestXRumQueryGroupBy]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a755316f7a70efa2a8c2f89b6b804a03855b7ebc8ced3d4e3f53987d2803bff4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetScatterplotDefinitionRequestXRumQueryGroupByOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestXRumQueryGroupByOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5e72d0296a001b173fa195adbc18ed68ff8785525e72688933230265e5807635)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putSortQuery")
    def put_sort_query(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        value = PowerpackWidgetScatterplotDefinitionRequestXRumQueryGroupBySortQuery(
            aggregation=aggregation, order=order, facet=facet
        )

        return typing.cast(None, jsii.invoke(self, "putSortQuery", [value]))

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetLimit")
    def reset_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLimit", []))

    @jsii.member(jsii_name="resetSortQuery")
    def reset_sort_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSortQuery", []))

    @builtins.property
    @jsii.member(jsii_name="sortQuery")
    def sort_query(
        self,
    ) -> "PowerpackWidgetScatterplotDefinitionRequestXRumQueryGroupBySortQueryOutputReference":
        return typing.cast("PowerpackWidgetScatterplotDefinitionRequestXRumQueryGroupBySortQueryOutputReference", jsii.get(self, "sortQuery"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="limitInput")
    def limit_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "limitInput"))

    @builtins.property
    @jsii.member(jsii_name="sortQueryInput")
    def sort_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetScatterplotDefinitionRequestXRumQueryGroupBySortQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetScatterplotDefinitionRequestXRumQueryGroupBySortQuery"], jsii.get(self, "sortQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__baf8d881cec0d234aaef6eb544e1e19bcda4b16384b051b6f37c57a97614f8ff)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="limit")
    def limit(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "limit"))

    @limit.setter
    def limit(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bc93091604a9ad9a20c33caa40f192ea3a1ad152041eba1e15c6cde284f5d00c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "limit", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetScatterplotDefinitionRequestXRumQueryGroupBy]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetScatterplotDefinitionRequestXRumQueryGroupBy]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetScatterplotDefinitionRequestXRumQueryGroupBy]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fdb51f9e4d0539559af24e3fb42ef95f99d2d36c87de7b90bd20949bcbce12b7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestXRumQueryGroupBySortQuery",
    jsii_struct_bases=[],
    name_mapping={"aggregation": "aggregation", "order": "order", "facet": "facet"},
)
class PowerpackWidgetScatterplotDefinitionRequestXRumQueryGroupBySortQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4b81c929809d09dbdadf4f01d1457b5d2fb12c8925b0b77ef2f09853add5d577)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument order", value=order, expected_type=type_hints["order"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
            "order": order,
        }
        if facet is not None:
            self._values["facet"] = facet

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def order(self) -> builtins.str:
        '''Widget sorting methods. Valid values are ``asc``, ``desc``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        result = self._values.get("order")
        assert result is not None, "Required property 'order' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetScatterplotDefinitionRequestXRumQueryGroupBySortQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetScatterplotDefinitionRequestXRumQueryGroupBySortQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestXRumQueryGroupBySortQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__300b2270685c9a7012412dc3ebe55237817d48c50172edf36a41173abdb0358e)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="orderInput")
    def order_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "orderInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b645fb6994ac48d0a14307836a6b58080e90183e1ca7074386d319c7206299b2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__eed9074d2ffcd9bbc4174f2c7969b0bf04c1124a9b81caeb6ff15475810d639c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="order")
    def order(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "order"))

    @order.setter
    def order(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__200d0a6ad80a461c7b474761e67abf2d72bffabf8ca35629a3051956f02c76c3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "order", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetScatterplotDefinitionRequestXRumQueryGroupBySortQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetScatterplotDefinitionRequestXRumQueryGroupBySortQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetScatterplotDefinitionRequestXRumQueryGroupBySortQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__05c69d07df94a46813fa5eea9bec62dc1444807434723fecb1ebf25f98c7cce0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestXRumQueryMultiCompute",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetScatterplotDefinitionRequestXRumQueryMultiCompute:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dfa058ef9d8af8c0c5350658f321bec48e449c6223f7fe4f7d4fca2db8a64c52)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetScatterplotDefinitionRequestXRumQueryMultiCompute(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetScatterplotDefinitionRequestXRumQueryMultiComputeList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestXRumQueryMultiComputeList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b8caad5dc407e563c621106760fd97659f60246ba1e81032b492636a8816d2f0)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetScatterplotDefinitionRequestXRumQueryMultiComputeOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4c5f92981d27da9aef63319404eeb1d92f2a5285c0a1b9609b9c922e570bbc40)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetScatterplotDefinitionRequestXRumQueryMultiComputeOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9aae94d1a486b0d7877d2197af6aa8ec667d9b9b366bea08b037566a55556288)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5cdf1aba30c4ad8fdbc8cab9091086b8395d5fa0827a61f09b266cf036767c7b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d85d77753e7610f8822cdd0fb9df8a3561bd6de175331ad3f4b2db42aad1119b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestXRumQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestXRumQueryMultiCompute]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestXRumQueryMultiCompute]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__690906b5b2f3804f9612b431f76374f62e814668b8257736f8f549c4786dc926)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetScatterplotDefinitionRequestXRumQueryMultiComputeOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestXRumQueryMultiComputeOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__510fe7c94ab24717fde73b0bca40fa6afb8bd595262fddf99d43d74081927505)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2e4dba221d9f977d2e5836e7d9cffbd0e5aabc37488aa2a0eefeb79e229036ec)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fa2d322b613cc6e458b7f7353eac858ce450490d3ca218371106fb0d08bfb3e9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__226582084245b222e0a6e283148912820814513ffde0341b36151b39b4e2f072)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetScatterplotDefinitionRequestXRumQueryMultiCompute]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetScatterplotDefinitionRequestXRumQueryMultiCompute]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetScatterplotDefinitionRequestXRumQueryMultiCompute]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b052d974b7b5ce2cab27241d9ec5d79cf3303307409a3aa710ed059a790a0bf3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetScatterplotDefinitionRequestXRumQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestXRumQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__eb59d01de6523f9f604a6777303776b68b8d4bfe0bb80669407cf3465230caf7)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putComputeQuery")
    def put_compute_query(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        value = PowerpackWidgetScatterplotDefinitionRequestXRumQueryComputeQuery(
            aggregation=aggregation, facet=facet, interval=interval
        )

        return typing.cast(None, jsii.invoke(self, "putComputeQuery", [value]))

    @jsii.member(jsii_name="putGroupBy")
    def put_group_by(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetScatterplotDefinitionRequestXRumQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ab98d87efab611d03129841b79d24fc4f4a79551905bab9edaaac93c1bd3263f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putGroupBy", [value]))

    @jsii.member(jsii_name="putMultiCompute")
    def put_multi_compute(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetScatterplotDefinitionRequestXRumQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5ab9f4513be7b622699edc5af18d89f5b0d25bc6757176bf7af7996565303c84)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putMultiCompute", [value]))

    @jsii.member(jsii_name="resetComputeQuery")
    def reset_compute_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetComputeQuery", []))

    @jsii.member(jsii_name="resetGroupBy")
    def reset_group_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGroupBy", []))

    @jsii.member(jsii_name="resetMultiCompute")
    def reset_multi_compute(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMultiCompute", []))

    @jsii.member(jsii_name="resetSearchQuery")
    def reset_search_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSearchQuery", []))

    @builtins.property
    @jsii.member(jsii_name="computeQuery")
    def compute_query(
        self,
    ) -> PowerpackWidgetScatterplotDefinitionRequestXRumQueryComputeQueryOutputReference:
        return typing.cast(PowerpackWidgetScatterplotDefinitionRequestXRumQueryComputeQueryOutputReference, jsii.get(self, "computeQuery"))

    @builtins.property
    @jsii.member(jsii_name="groupBy")
    def group_by(
        self,
    ) -> PowerpackWidgetScatterplotDefinitionRequestXRumQueryGroupByList:
        return typing.cast(PowerpackWidgetScatterplotDefinitionRequestXRumQueryGroupByList, jsii.get(self, "groupBy"))

    @builtins.property
    @jsii.member(jsii_name="multiCompute")
    def multi_compute(
        self,
    ) -> PowerpackWidgetScatterplotDefinitionRequestXRumQueryMultiComputeList:
        return typing.cast(PowerpackWidgetScatterplotDefinitionRequestXRumQueryMultiComputeList, jsii.get(self, "multiCompute"))

    @builtins.property
    @jsii.member(jsii_name="computeQueryInput")
    def compute_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetScatterplotDefinitionRequestXRumQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetScatterplotDefinitionRequestXRumQueryComputeQuery], jsii.get(self, "computeQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="groupByInput")
    def group_by_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestXRumQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestXRumQueryGroupBy]]], jsii.get(self, "groupByInput"))

    @builtins.property
    @jsii.member(jsii_name="indexInput")
    def index_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "indexInput"))

    @builtins.property
    @jsii.member(jsii_name="multiComputeInput")
    def multi_compute_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestXRumQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestXRumQueryMultiCompute]]], jsii.get(self, "multiComputeInput"))

    @builtins.property
    @jsii.member(jsii_name="searchQueryInput")
    def search_query_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "searchQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="index")
    def index(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "index"))

    @index.setter
    def index(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cedb3eb8e0c2343ef5dc6c7e05e2d87a25a3a50add267212b80e2cc17c9eee08)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "index", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="searchQuery")
    def search_query(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "searchQuery"))

    @search_query.setter
    def search_query(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__84322facb3d350b043e4ed0966709a5f63d114baa7b82606370d595308862ed9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "searchQuery", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetScatterplotDefinitionRequestXRumQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetScatterplotDefinitionRequestXRumQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetScatterplotDefinitionRequestXRumQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6b178d6a2143b142ee45f6ad71429cc5db4c3f49ae39514b3807f8d3cdb21c65)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestXSecurityQuery",
    jsii_struct_bases=[],
    name_mapping={
        "index": "index",
        "compute_query": "computeQuery",
        "group_by": "groupBy",
        "multi_compute": "multiCompute",
        "search_query": "searchQuery",
    },
)
class PowerpackWidgetScatterplotDefinitionRequestXSecurityQuery:
    def __init__(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union["PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryComputeQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryGroupBy", typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryMultiCompute", typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        if isinstance(compute_query, dict):
            compute_query = PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryComputeQuery(**compute_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__91091bc9f4397b1a53e71ce2c76eab1860e9f878e3c76ef9cd98e8fb778a44f1)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
            check_type(argname="argument compute_query", value=compute_query, expected_type=type_hints["compute_query"])
            check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
            check_type(argname="argument multi_compute", value=multi_compute, expected_type=type_hints["multi_compute"])
            check_type(argname="argument search_query", value=search_query, expected_type=type_hints["search_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "index": index,
        }
        if compute_query is not None:
            self._values["compute_query"] = compute_query
        if group_by is not None:
            self._values["group_by"] = group_by
        if multi_compute is not None:
            self._values["multi_compute"] = multi_compute
        if search_query is not None:
            self._values["search_query"] = search_query

    @builtins.property
    def index(self) -> builtins.str:
        '''The name of the index to query.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        '''
        result = self._values.get("index")
        assert result is not None, "Required property 'index' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def compute_query(
        self,
    ) -> typing.Optional["PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryComputeQuery"]:
        '''compute_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        '''
        result = self._values.get("compute_query")
        return typing.cast(typing.Optional["PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryComputeQuery"], result)

    @builtins.property
    def group_by(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryGroupBy"]]]:
        '''group_by block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        '''
        result = self._values.get("group_by")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryGroupBy"]]], result)

    @builtins.property
    def multi_compute(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryMultiCompute"]]]:
        '''multi_compute block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        '''
        result = self._values.get("multi_compute")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryMultiCompute"]]], result)

    @builtins.property
    def search_query(self) -> typing.Optional[builtins.str]:
        '''The search query to use.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        result = self._values.get("search_query")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetScatterplotDefinitionRequestXSecurityQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryComputeQuery",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryComputeQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__025a2f17cee234ad031cc98aa2e0877bfc7ddadbcab992caf94455eecd0af4f2)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryComputeQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryComputeQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryComputeQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3b3437e1116c9ac721f63bfa0c2b39645b6bfbeaebd149af366a6f9b8f7f2d91)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__375471845eda7b6dc3fe073c722eec79e0e41c3b7637dd8d97605ca78fa314dd)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__59b6dc0215b9c5a08acef94298e0739426ccf3c7570df1e93b527235c3eb0783)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__590236a4a9ebbb62b8275bd10520671bb2ae4d42e43e7b1fab2016992da4fc1a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryComputeQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryComputeQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6efc871223f1b04fb2111d01ca01202e6cef12078c105c7eddfd15b3ebf407d6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryGroupBy",
    jsii_struct_bases=[],
    name_mapping={"facet": "facet", "limit": "limit", "sort_query": "sortQuery"},
)
class PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryGroupBy:
    def __init__(
        self,
        *,
        facet: typing.Optional[builtins.str] = None,
        limit: typing.Optional[jsii.Number] = None,
        sort_query: typing.Optional[typing.Union["PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryGroupBySortQuery", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param limit: The maximum number of items in the group. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param sort_query: sort_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        if isinstance(sort_query, dict):
            sort_query = PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryGroupBySortQuery(**sort_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__09a9547c081cdd7a8b28f725778df2a0c4c3d5460e25fbd139bceb9357baec5a)
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
            check_type(argname="argument sort_query", value=sort_query, expected_type=type_hints["sort_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if facet is not None:
            self._values["facet"] = facet
        if limit is not None:
            self._values["limit"] = limit
        if sort_query is not None:
            self._values["sort_query"] = sort_query

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def limit(self) -> typing.Optional[jsii.Number]:
        '''The maximum number of items in the group.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        '''
        result = self._values.get("limit")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def sort_query(
        self,
    ) -> typing.Optional["PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryGroupBySortQuery"]:
        '''sort_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        result = self._values.get("sort_query")
        return typing.cast(typing.Optional["PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryGroupBySortQuery"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryGroupBy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryGroupByList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryGroupByList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9f69e23e2f9de9630a59606c2e97711ccb114a028688f626ec35d9c414f7e241)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryGroupByOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0a8285ad8a577f7b69b8609d5cac1c52bb8eddc228607dac245c3b031fca1022)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryGroupByOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__02d427bb70925da21b6ba4d6614eebc31605895f9d05dc7042b6838f519bf128)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__781d1b2352dca5c9a943b2647b2988b1a79679e782ebf62885af3b56481e7ac4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2f0c037a4f1916a5ee1796ff663fb466ecc2adc3458645e1a16a74d65682ea1f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryGroupBy]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryGroupBy]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2f0198ae8726e69f8a09167c3f39b05cb1b0e5bf241694f21f84a969435b4b98)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryGroupByOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryGroupByOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ffdfa53abdc773b59b00b88758b9882ae0ce3b6fddfe2c430f2bedd96191263e)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putSortQuery")
    def put_sort_query(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        value = PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryGroupBySortQuery(
            aggregation=aggregation, order=order, facet=facet
        )

        return typing.cast(None, jsii.invoke(self, "putSortQuery", [value]))

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetLimit")
    def reset_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLimit", []))

    @jsii.member(jsii_name="resetSortQuery")
    def reset_sort_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSortQuery", []))

    @builtins.property
    @jsii.member(jsii_name="sortQuery")
    def sort_query(
        self,
    ) -> "PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryGroupBySortQueryOutputReference":
        return typing.cast("PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryGroupBySortQueryOutputReference", jsii.get(self, "sortQuery"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="limitInput")
    def limit_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "limitInput"))

    @builtins.property
    @jsii.member(jsii_name="sortQueryInput")
    def sort_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryGroupBySortQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryGroupBySortQuery"], jsii.get(self, "sortQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bf2325e26f2a3520b13d1c09774d93788b7c4c9587f05940a476d20ebf60fd12)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="limit")
    def limit(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "limit"))

    @limit.setter
    def limit(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5dea565b12a6d75e86bedf53f967a3a2ee4decaecbb08a9d8661859760e0b1b6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "limit", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryGroupBy]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryGroupBy]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryGroupBy]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c5fe415ae46505cfc29489e6bb3fbea4156430c12f5a3e8c6e9693b97fc506c9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryGroupBySortQuery",
    jsii_struct_bases=[],
    name_mapping={"aggregation": "aggregation", "order": "order", "facet": "facet"},
)
class PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryGroupBySortQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bdf6a69b4bd82c6986fdd2bd78228f3855dd5bed7be79fec73bab9bd48283d5c)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument order", value=order, expected_type=type_hints["order"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
            "order": order,
        }
        if facet is not None:
            self._values["facet"] = facet

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def order(self) -> builtins.str:
        '''Widget sorting methods. Valid values are ``asc``, ``desc``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        result = self._values.get("order")
        assert result is not None, "Required property 'order' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryGroupBySortQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryGroupBySortQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryGroupBySortQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d55b8da24c9e0ed1bd3c7173683089bc1b259829e5c4fba30643559ed9b5ef34)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="orderInput")
    def order_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "orderInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7c7a79f06e9cecd405101623b08e99bddbde44082a6d0b2db0553b8afa0d343f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f9b67c3b65d99b6dfbe8aad12fad8db41b0c8cc3a413834f3c16afa3ec62c0ed)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="order")
    def order(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "order"))

    @order.setter
    def order(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8bb48398548c1c27c4e5b9c0883e04cc1aad185b91e5c3293bef7084e881971d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "order", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryGroupBySortQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryGroupBySortQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryGroupBySortQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2df12d4e338914c1e55529b476b6ad2c0d58d6150c6205b12dc182ab210fad01)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryMultiCompute",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryMultiCompute:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__821e386af215194583186ab04693bea79df050bdf06be608a776cb687440fc1d)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryMultiCompute(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryMultiComputeList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryMultiComputeList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0998135452527ef60ab87df72b58b0e533dc5b17eefd350d93ccb7698b035edb)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryMultiComputeOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__46a83e7071c6d9972cd32f75faa39310b13c6470a38f2ed0b542194df5360ebe)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryMultiComputeOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5b9a848dce5987daa79a2e1aab31347462771f50856ea54be067ae2af1d9e714)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__67d4996a46b3d0fb526c4e0898e43653dd3a9bea4dfe051b28376259fb3891e2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1bbbd57b4d879a85cf5f02153e473c032b10201ac849243295355eaa32e67409)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryMultiCompute]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryMultiCompute]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9e3d9aa677f264e083052ef05d77cbd8646c79da71a3300e4aea0cbf8456d634)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryMultiComputeOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryMultiComputeOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c7faf0673bb5af6994850f259d3a3871e78624aeb2ce5600e2badfc80da30b14)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4e7f87b3bbbfeb9195eab449282cab0c61ca3bb176ad75cb39ac5ae080df7863)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__20d8ef1926023e58598b3e141da9a4332c8ee899986bb5a34baa62c6030312f9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9baf217fe1b16565f5673704833d166d0f815f2c5d4113d6b3cabe847770bb4a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryMultiCompute]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryMultiCompute]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryMultiCompute]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d3b5aba9305f643b92759f4393e827d6ed81acf9612e1f7cc13a6ff7f544261a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__18158c9b24353a2c8f3a166e34bc0bab4533de890623e638a4585aba94962a67)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putComputeQuery")
    def put_compute_query(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        value = PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryComputeQuery(
            aggregation=aggregation, facet=facet, interval=interval
        )

        return typing.cast(None, jsii.invoke(self, "putComputeQuery", [value]))

    @jsii.member(jsii_name="putGroupBy")
    def put_group_by(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__025593d1135da0eebd1e641ed74945337187cc3352e182d6c57c24fb9efd9d32)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putGroupBy", [value]))

    @jsii.member(jsii_name="putMultiCompute")
    def put_multi_compute(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__78e8d6b8d1a9eaf9ec48dc65edd57d2f6fd2a68690bb0706bae1bfc54eed54ef)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putMultiCompute", [value]))

    @jsii.member(jsii_name="resetComputeQuery")
    def reset_compute_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetComputeQuery", []))

    @jsii.member(jsii_name="resetGroupBy")
    def reset_group_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGroupBy", []))

    @jsii.member(jsii_name="resetMultiCompute")
    def reset_multi_compute(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMultiCompute", []))

    @jsii.member(jsii_name="resetSearchQuery")
    def reset_search_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSearchQuery", []))

    @builtins.property
    @jsii.member(jsii_name="computeQuery")
    def compute_query(
        self,
    ) -> PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryComputeQueryOutputReference:
        return typing.cast(PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryComputeQueryOutputReference, jsii.get(self, "computeQuery"))

    @builtins.property
    @jsii.member(jsii_name="groupBy")
    def group_by(
        self,
    ) -> PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryGroupByList:
        return typing.cast(PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryGroupByList, jsii.get(self, "groupBy"))

    @builtins.property
    @jsii.member(jsii_name="multiCompute")
    def multi_compute(
        self,
    ) -> PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryMultiComputeList:
        return typing.cast(PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryMultiComputeList, jsii.get(self, "multiCompute"))

    @builtins.property
    @jsii.member(jsii_name="computeQueryInput")
    def compute_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryComputeQuery], jsii.get(self, "computeQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="groupByInput")
    def group_by_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryGroupBy]]], jsii.get(self, "groupByInput"))

    @builtins.property
    @jsii.member(jsii_name="indexInput")
    def index_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "indexInput"))

    @builtins.property
    @jsii.member(jsii_name="multiComputeInput")
    def multi_compute_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryMultiCompute]]], jsii.get(self, "multiComputeInput"))

    @builtins.property
    @jsii.member(jsii_name="searchQueryInput")
    def search_query_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "searchQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="index")
    def index(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "index"))

    @index.setter
    def index(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2dac5c2057392b695fe85990c44309f36e229653fff1f62cb298050414fba183)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "index", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="searchQuery")
    def search_query(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "searchQuery"))

    @search_query.setter
    def search_query(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f0b97ba4f77479b02a5a1e011e5b2182394b1927a9e61f214ec1cda4c43fe410)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "searchQuery", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetScatterplotDefinitionRequestXSecurityQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetScatterplotDefinitionRequestXSecurityQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetScatterplotDefinitionRequestXSecurityQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__372ccc6ba8dab8991af85b7402216bc7e4963695a857b1d4ee364d1687f63c7d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestY",
    jsii_struct_bases=[],
    name_mapping={
        "aggregator": "aggregator",
        "apm_query": "apmQuery",
        "log_query": "logQuery",
        "process_query": "processQuery",
        "q": "q",
        "rum_query": "rumQuery",
        "security_query": "securityQuery",
    },
)
class PowerpackWidgetScatterplotDefinitionRequestY:
    def __init__(
        self,
        *,
        aggregator: typing.Optional[builtins.str] = None,
        apm_query: typing.Optional[typing.Union["PowerpackWidgetScatterplotDefinitionRequestYApmQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        log_query: typing.Optional[typing.Union["PowerpackWidgetScatterplotDefinitionRequestYLogQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        process_query: typing.Optional[typing.Union["PowerpackWidgetScatterplotDefinitionRequestYProcessQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        q: typing.Optional[builtins.str] = None,
        rum_query: typing.Optional[typing.Union["PowerpackWidgetScatterplotDefinitionRequestYRumQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        security_query: typing.Optional[typing.Union["PowerpackWidgetScatterplotDefinitionRequestYSecurityQuery", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param aggregator: Aggregator used for the request. Valid values are ``avg``, ``last``, ``max``, ``min``, ``sum``, ``percentile``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregator Powerpack#aggregator}
        :param apm_query: apm_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#apm_query Powerpack#apm_query}
        :param log_query: log_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#log_query Powerpack#log_query}
        :param process_query: process_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#process_query Powerpack#process_query}
        :param q: The metric query to use for this widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#q Powerpack#q}
        :param rum_query: rum_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#rum_query Powerpack#rum_query}
        :param security_query: security_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#security_query Powerpack#security_query}
        '''
        if isinstance(apm_query, dict):
            apm_query = PowerpackWidgetScatterplotDefinitionRequestYApmQuery(**apm_query)
        if isinstance(log_query, dict):
            log_query = PowerpackWidgetScatterplotDefinitionRequestYLogQuery(**log_query)
        if isinstance(process_query, dict):
            process_query = PowerpackWidgetScatterplotDefinitionRequestYProcessQuery(**process_query)
        if isinstance(rum_query, dict):
            rum_query = PowerpackWidgetScatterplotDefinitionRequestYRumQuery(**rum_query)
        if isinstance(security_query, dict):
            security_query = PowerpackWidgetScatterplotDefinitionRequestYSecurityQuery(**security_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b362edbc8fe4379e7a3ce40debe91859d0efdb67a63510df77fdd79501bbc9b6)
            check_type(argname="argument aggregator", value=aggregator, expected_type=type_hints["aggregator"])
            check_type(argname="argument apm_query", value=apm_query, expected_type=type_hints["apm_query"])
            check_type(argname="argument log_query", value=log_query, expected_type=type_hints["log_query"])
            check_type(argname="argument process_query", value=process_query, expected_type=type_hints["process_query"])
            check_type(argname="argument q", value=q, expected_type=type_hints["q"])
            check_type(argname="argument rum_query", value=rum_query, expected_type=type_hints["rum_query"])
            check_type(argname="argument security_query", value=security_query, expected_type=type_hints["security_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if aggregator is not None:
            self._values["aggregator"] = aggregator
        if apm_query is not None:
            self._values["apm_query"] = apm_query
        if log_query is not None:
            self._values["log_query"] = log_query
        if process_query is not None:
            self._values["process_query"] = process_query
        if q is not None:
            self._values["q"] = q
        if rum_query is not None:
            self._values["rum_query"] = rum_query
        if security_query is not None:
            self._values["security_query"] = security_query

    @builtins.property
    def aggregator(self) -> typing.Optional[builtins.str]:
        '''Aggregator used for the request. Valid values are ``avg``, ``last``, ``max``, ``min``, ``sum``, ``percentile``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregator Powerpack#aggregator}
        '''
        result = self._values.get("aggregator")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def apm_query(
        self,
    ) -> typing.Optional["PowerpackWidgetScatterplotDefinitionRequestYApmQuery"]:
        '''apm_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#apm_query Powerpack#apm_query}
        '''
        result = self._values.get("apm_query")
        return typing.cast(typing.Optional["PowerpackWidgetScatterplotDefinitionRequestYApmQuery"], result)

    @builtins.property
    def log_query(
        self,
    ) -> typing.Optional["PowerpackWidgetScatterplotDefinitionRequestYLogQuery"]:
        '''log_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#log_query Powerpack#log_query}
        '''
        result = self._values.get("log_query")
        return typing.cast(typing.Optional["PowerpackWidgetScatterplotDefinitionRequestYLogQuery"], result)

    @builtins.property
    def process_query(
        self,
    ) -> typing.Optional["PowerpackWidgetScatterplotDefinitionRequestYProcessQuery"]:
        '''process_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#process_query Powerpack#process_query}
        '''
        result = self._values.get("process_query")
        return typing.cast(typing.Optional["PowerpackWidgetScatterplotDefinitionRequestYProcessQuery"], result)

    @builtins.property
    def q(self) -> typing.Optional[builtins.str]:
        '''The metric query to use for this widget.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#q Powerpack#q}
        '''
        result = self._values.get("q")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def rum_query(
        self,
    ) -> typing.Optional["PowerpackWidgetScatterplotDefinitionRequestYRumQuery"]:
        '''rum_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#rum_query Powerpack#rum_query}
        '''
        result = self._values.get("rum_query")
        return typing.cast(typing.Optional["PowerpackWidgetScatterplotDefinitionRequestYRumQuery"], result)

    @builtins.property
    def security_query(
        self,
    ) -> typing.Optional["PowerpackWidgetScatterplotDefinitionRequestYSecurityQuery"]:
        '''security_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#security_query Powerpack#security_query}
        '''
        result = self._values.get("security_query")
        return typing.cast(typing.Optional["PowerpackWidgetScatterplotDefinitionRequestYSecurityQuery"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetScatterplotDefinitionRequestY(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestYApmQuery",
    jsii_struct_bases=[],
    name_mapping={
        "index": "index",
        "compute_query": "computeQuery",
        "group_by": "groupBy",
        "multi_compute": "multiCompute",
        "search_query": "searchQuery",
    },
)
class PowerpackWidgetScatterplotDefinitionRequestYApmQuery:
    def __init__(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union["PowerpackWidgetScatterplotDefinitionRequestYApmQueryComputeQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetScatterplotDefinitionRequestYApmQueryGroupBy", typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetScatterplotDefinitionRequestYApmQueryMultiCompute", typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        if isinstance(compute_query, dict):
            compute_query = PowerpackWidgetScatterplotDefinitionRequestYApmQueryComputeQuery(**compute_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0ec2a853f7aeb7e8258c7a3bccd7dffac001abba99bf84471c0d8a109ac7e211)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
            check_type(argname="argument compute_query", value=compute_query, expected_type=type_hints["compute_query"])
            check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
            check_type(argname="argument multi_compute", value=multi_compute, expected_type=type_hints["multi_compute"])
            check_type(argname="argument search_query", value=search_query, expected_type=type_hints["search_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "index": index,
        }
        if compute_query is not None:
            self._values["compute_query"] = compute_query
        if group_by is not None:
            self._values["group_by"] = group_by
        if multi_compute is not None:
            self._values["multi_compute"] = multi_compute
        if search_query is not None:
            self._values["search_query"] = search_query

    @builtins.property
    def index(self) -> builtins.str:
        '''The name of the index to query.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        '''
        result = self._values.get("index")
        assert result is not None, "Required property 'index' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def compute_query(
        self,
    ) -> typing.Optional["PowerpackWidgetScatterplotDefinitionRequestYApmQueryComputeQuery"]:
        '''compute_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        '''
        result = self._values.get("compute_query")
        return typing.cast(typing.Optional["PowerpackWidgetScatterplotDefinitionRequestYApmQueryComputeQuery"], result)

    @builtins.property
    def group_by(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetScatterplotDefinitionRequestYApmQueryGroupBy"]]]:
        '''group_by block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        '''
        result = self._values.get("group_by")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetScatterplotDefinitionRequestYApmQueryGroupBy"]]], result)

    @builtins.property
    def multi_compute(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetScatterplotDefinitionRequestYApmQueryMultiCompute"]]]:
        '''multi_compute block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        '''
        result = self._values.get("multi_compute")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetScatterplotDefinitionRequestYApmQueryMultiCompute"]]], result)

    @builtins.property
    def search_query(self) -> typing.Optional[builtins.str]:
        '''The search query to use.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        result = self._values.get("search_query")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetScatterplotDefinitionRequestYApmQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestYApmQueryComputeQuery",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetScatterplotDefinitionRequestYApmQueryComputeQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__033d0dfee9f10cff205e0e24bf7790422c9d42b34d64a65a05d946125a67d1a4)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetScatterplotDefinitionRequestYApmQueryComputeQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetScatterplotDefinitionRequestYApmQueryComputeQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestYApmQueryComputeQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6f2ec4b6f998b9f4755e8cdcedd13597cad00a7199733ef6111550e2df91003b)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8be55b70dd969cc958a3b9b2a6c008a6e2044d7cece70635d8cf9eb73b724c2c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a410db9cc69c5dadd26c5f8d57239baedefa66ad39c4bba8195981906e8a1f72)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2dec68eb7e97d3201d2817e4ff6e1f40a679b9a41370450f7fee60e6b6a075cc)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetScatterplotDefinitionRequestYApmQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetScatterplotDefinitionRequestYApmQueryComputeQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetScatterplotDefinitionRequestYApmQueryComputeQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b5b8c705f5ce63b9d3e54213a68c47498b7e01168e540bbbe38b99821503cd67)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestYApmQueryGroupBy",
    jsii_struct_bases=[],
    name_mapping={"facet": "facet", "limit": "limit", "sort_query": "sortQuery"},
)
class PowerpackWidgetScatterplotDefinitionRequestYApmQueryGroupBy:
    def __init__(
        self,
        *,
        facet: typing.Optional[builtins.str] = None,
        limit: typing.Optional[jsii.Number] = None,
        sort_query: typing.Optional[typing.Union["PowerpackWidgetScatterplotDefinitionRequestYApmQueryGroupBySortQuery", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param limit: The maximum number of items in the group. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param sort_query: sort_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        if isinstance(sort_query, dict):
            sort_query = PowerpackWidgetScatterplotDefinitionRequestYApmQueryGroupBySortQuery(**sort_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__77eb67e9aa1e866d9b29b6e2204856e735784c1ba2efd3693f4629944b5380c9)
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
            check_type(argname="argument sort_query", value=sort_query, expected_type=type_hints["sort_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if facet is not None:
            self._values["facet"] = facet
        if limit is not None:
            self._values["limit"] = limit
        if sort_query is not None:
            self._values["sort_query"] = sort_query

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def limit(self) -> typing.Optional[jsii.Number]:
        '''The maximum number of items in the group.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        '''
        result = self._values.get("limit")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def sort_query(
        self,
    ) -> typing.Optional["PowerpackWidgetScatterplotDefinitionRequestYApmQueryGroupBySortQuery"]:
        '''sort_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        result = self._values.get("sort_query")
        return typing.cast(typing.Optional["PowerpackWidgetScatterplotDefinitionRequestYApmQueryGroupBySortQuery"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetScatterplotDefinitionRequestYApmQueryGroupBy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetScatterplotDefinitionRequestYApmQueryGroupByList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestYApmQueryGroupByList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ca0beb12ccf1a3a466629055ae3e0d46a3091e2d6b80aa0df13015ea28eb259f)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetScatterplotDefinitionRequestYApmQueryGroupByOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8f99bc062236e601d39697ad13153a8e775ee16daad9e574153e47f36856913f)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetScatterplotDefinitionRequestYApmQueryGroupByOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ca95157341b44235bf3eeea6c08d092e843ea750d1931f1a2c9eb94e225e942c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__687c38de26346436a82b33d6bcecf3fda3fdb3a9f5fcc848f4f8cdb38769af51)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__41587fd098630e4d9aba71febacdcd7d8fdf00d61db660e7efa2b4396ae8b4a4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestYApmQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestYApmQueryGroupBy]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestYApmQueryGroupBy]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1bdc58a8dc631ad35f2da64757264b536c8194c774d17a91aa851e3fb40a34f1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetScatterplotDefinitionRequestYApmQueryGroupByOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestYApmQueryGroupByOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fa87fa89c29dd7b698fd081cc2620a6f1c54d4c370076bd9af056216f0f339b5)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putSortQuery")
    def put_sort_query(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        value = PowerpackWidgetScatterplotDefinitionRequestYApmQueryGroupBySortQuery(
            aggregation=aggregation, order=order, facet=facet
        )

        return typing.cast(None, jsii.invoke(self, "putSortQuery", [value]))

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetLimit")
    def reset_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLimit", []))

    @jsii.member(jsii_name="resetSortQuery")
    def reset_sort_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSortQuery", []))

    @builtins.property
    @jsii.member(jsii_name="sortQuery")
    def sort_query(
        self,
    ) -> "PowerpackWidgetScatterplotDefinitionRequestYApmQueryGroupBySortQueryOutputReference":
        return typing.cast("PowerpackWidgetScatterplotDefinitionRequestYApmQueryGroupBySortQueryOutputReference", jsii.get(self, "sortQuery"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="limitInput")
    def limit_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "limitInput"))

    @builtins.property
    @jsii.member(jsii_name="sortQueryInput")
    def sort_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetScatterplotDefinitionRequestYApmQueryGroupBySortQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetScatterplotDefinitionRequestYApmQueryGroupBySortQuery"], jsii.get(self, "sortQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__43ded7b400f6a58325b0d8e1bdcb1e1eee5c277989858114a9020e89351716d5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="limit")
    def limit(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "limit"))

    @limit.setter
    def limit(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2c79bd8956ed9f53ad037eba771bc2dc1bc124c0bc1ab02b477152ae5a77e45e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "limit", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetScatterplotDefinitionRequestYApmQueryGroupBy]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetScatterplotDefinitionRequestYApmQueryGroupBy]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetScatterplotDefinitionRequestYApmQueryGroupBy]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ce129ab3aacc992dcb3a7675eb0f6513a749290768d32cf75bd0c73041ac93bd)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestYApmQueryGroupBySortQuery",
    jsii_struct_bases=[],
    name_mapping={"aggregation": "aggregation", "order": "order", "facet": "facet"},
)
class PowerpackWidgetScatterplotDefinitionRequestYApmQueryGroupBySortQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8b1801dcf26ada3500001d6b4bef8cea1f871413c09e1008ddcbc93bff25dcf8)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument order", value=order, expected_type=type_hints["order"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
            "order": order,
        }
        if facet is not None:
            self._values["facet"] = facet

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def order(self) -> builtins.str:
        '''Widget sorting methods. Valid values are ``asc``, ``desc``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        result = self._values.get("order")
        assert result is not None, "Required property 'order' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetScatterplotDefinitionRequestYApmQueryGroupBySortQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetScatterplotDefinitionRequestYApmQueryGroupBySortQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestYApmQueryGroupBySortQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ee148e0e10574e07947c3f0529fb6e646ffc4036c04c45f6d6e986622732fda1)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="orderInput")
    def order_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "orderInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__612d7d70d70034de686249bed9dff5cf976064b094716d355ac4c9e943b788ed)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9a433f5dd1b39ca21d174503eec1920aa75c25facb0cd12260957a2b4d6acbf0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="order")
    def order(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "order"))

    @order.setter
    def order(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b5b7e7d23eb25cfc5caf9293bf125e8e32f915baa937ffb1f66edfe7d612599e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "order", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetScatterplotDefinitionRequestYApmQueryGroupBySortQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetScatterplotDefinitionRequestYApmQueryGroupBySortQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetScatterplotDefinitionRequestYApmQueryGroupBySortQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__467bfb49533cd5970c077329258a6a32364af84c9b737da8fd27072c94a0441b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestYApmQueryMultiCompute",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetScatterplotDefinitionRequestYApmQueryMultiCompute:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__90f3a5c85011ffc2fcb7f907419092be45bdf92490e6effcbb16549c8a25853d)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetScatterplotDefinitionRequestYApmQueryMultiCompute(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetScatterplotDefinitionRequestYApmQueryMultiComputeList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestYApmQueryMultiComputeList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ad2c0a9b6cd2e7b979171fb8d513e884fe92e33e161e4a1366e74d8b838e3c00)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetScatterplotDefinitionRequestYApmQueryMultiComputeOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7bf3599c5e543444fa119a43bc5c7b72a3995bc0cf9d0e8d9b293168b4c354f1)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetScatterplotDefinitionRequestYApmQueryMultiComputeOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__09b15d6058415b150d9a560927ee00b670344925f4af47e75afedf2eec7a21e2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__19b2fa1a60f023e1265b8566896e71266503ef53a4a5667bc710b7a090d037c5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4c4ad6787732b18c28a9bf408fe668d051daaadc736814a2fbc1956859ec8476)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestYApmQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestYApmQueryMultiCompute]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestYApmQueryMultiCompute]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f80d9dd328e1a4dad4989bc1fbefb275b5c4230aad82dd86630bae4b3e71f965)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetScatterplotDefinitionRequestYApmQueryMultiComputeOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestYApmQueryMultiComputeOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a73865827b01b6fb7a18b45f771dcdf510996962e2461ca1cf30c829624f4541)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a05b35c89fcb6d2519947da63c545cdcef655a7e3674208233b546f410b16a1e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f4a514772af37a24d39b5538048fdc35937583fcb45affba85022212644a32c7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5c90dbe514bed8da3b4382a8528438b8e5720e59e1e1960bf4c3d6f5d2f831b2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetScatterplotDefinitionRequestYApmQueryMultiCompute]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetScatterplotDefinitionRequestYApmQueryMultiCompute]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetScatterplotDefinitionRequestYApmQueryMultiCompute]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3f60495d27aba2d405e660ba2eabe3f0e4e4af9508665bccbf3118e25839ef55)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetScatterplotDefinitionRequestYApmQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestYApmQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9c83e32152bbf047dba3ce0d14cf26bc46c05ec696f0e58d9220ca40b30f3789)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putComputeQuery")
    def put_compute_query(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        value = PowerpackWidgetScatterplotDefinitionRequestYApmQueryComputeQuery(
            aggregation=aggregation, facet=facet, interval=interval
        )

        return typing.cast(None, jsii.invoke(self, "putComputeQuery", [value]))

    @jsii.member(jsii_name="putGroupBy")
    def put_group_by(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetScatterplotDefinitionRequestYApmQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ff1c14b75b300b4561167132b9842069e27df9dae68a25f016a3aba7f1503c78)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putGroupBy", [value]))

    @jsii.member(jsii_name="putMultiCompute")
    def put_multi_compute(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetScatterplotDefinitionRequestYApmQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4cf6c32f648d8e7c4393b5658decd37bb795a596c53bddda69335ad4813313bc)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putMultiCompute", [value]))

    @jsii.member(jsii_name="resetComputeQuery")
    def reset_compute_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetComputeQuery", []))

    @jsii.member(jsii_name="resetGroupBy")
    def reset_group_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGroupBy", []))

    @jsii.member(jsii_name="resetMultiCompute")
    def reset_multi_compute(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMultiCompute", []))

    @jsii.member(jsii_name="resetSearchQuery")
    def reset_search_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSearchQuery", []))

    @builtins.property
    @jsii.member(jsii_name="computeQuery")
    def compute_query(
        self,
    ) -> PowerpackWidgetScatterplotDefinitionRequestYApmQueryComputeQueryOutputReference:
        return typing.cast(PowerpackWidgetScatterplotDefinitionRequestYApmQueryComputeQueryOutputReference, jsii.get(self, "computeQuery"))

    @builtins.property
    @jsii.member(jsii_name="groupBy")
    def group_by(
        self,
    ) -> PowerpackWidgetScatterplotDefinitionRequestYApmQueryGroupByList:
        return typing.cast(PowerpackWidgetScatterplotDefinitionRequestYApmQueryGroupByList, jsii.get(self, "groupBy"))

    @builtins.property
    @jsii.member(jsii_name="multiCompute")
    def multi_compute(
        self,
    ) -> PowerpackWidgetScatterplotDefinitionRequestYApmQueryMultiComputeList:
        return typing.cast(PowerpackWidgetScatterplotDefinitionRequestYApmQueryMultiComputeList, jsii.get(self, "multiCompute"))

    @builtins.property
    @jsii.member(jsii_name="computeQueryInput")
    def compute_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetScatterplotDefinitionRequestYApmQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetScatterplotDefinitionRequestYApmQueryComputeQuery], jsii.get(self, "computeQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="groupByInput")
    def group_by_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestYApmQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestYApmQueryGroupBy]]], jsii.get(self, "groupByInput"))

    @builtins.property
    @jsii.member(jsii_name="indexInput")
    def index_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "indexInput"))

    @builtins.property
    @jsii.member(jsii_name="multiComputeInput")
    def multi_compute_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestYApmQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestYApmQueryMultiCompute]]], jsii.get(self, "multiComputeInput"))

    @builtins.property
    @jsii.member(jsii_name="searchQueryInput")
    def search_query_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "searchQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="index")
    def index(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "index"))

    @index.setter
    def index(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d4260e962b507596c705fe9dd2a21efadc1704146b7bed947f3dd05cc813f964)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "index", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="searchQuery")
    def search_query(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "searchQuery"))

    @search_query.setter
    def search_query(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d14e6e3c5ee2eb49a549b19623655cda6baa663ba9f901b98495662bef75d0e7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "searchQuery", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetScatterplotDefinitionRequestYApmQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetScatterplotDefinitionRequestYApmQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetScatterplotDefinitionRequestYApmQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ab6d3a2419879f094ba66e08bf1e7d2164adf18a5f70d895056bf0c8751b2a23)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetScatterplotDefinitionRequestYList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestYList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__52966dd89c55bd60d19c088b21950979154be68084b2e37a6f5fe57c4f1b04ef)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetScatterplotDefinitionRequestYOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d2f76a7e387c5d7d6ffe2fe8c5f248b276f387cf30064526e7a17266fcd448fd)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetScatterplotDefinitionRequestYOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3940067cc1fa1bdccb4b23144a5023a22740f1dce5a23a39d72c26fe7a3cc045)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__34e2bd374dcdad1d352805df9338bdc6a3d9ddc932dade7dfe476b48d4450922)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9acb6bb676d15c14db33e3be6f43dcdcfaf413d72c035c230143efe98825afae)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestY]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestY]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestY]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e6519021c9dd12cc93987553ab27c6e10b2cf55aca41d0102ac6ec5e477a3f98)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestYLogQuery",
    jsii_struct_bases=[],
    name_mapping={
        "index": "index",
        "compute_query": "computeQuery",
        "group_by": "groupBy",
        "multi_compute": "multiCompute",
        "search_query": "searchQuery",
    },
)
class PowerpackWidgetScatterplotDefinitionRequestYLogQuery:
    def __init__(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union["PowerpackWidgetScatterplotDefinitionRequestYLogQueryComputeQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetScatterplotDefinitionRequestYLogQueryGroupBy", typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetScatterplotDefinitionRequestYLogQueryMultiCompute", typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        if isinstance(compute_query, dict):
            compute_query = PowerpackWidgetScatterplotDefinitionRequestYLogQueryComputeQuery(**compute_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dc5105d0150ca1b5b50f8f916b6feda3cb2c61174879ffc67608e15417f8b977)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
            check_type(argname="argument compute_query", value=compute_query, expected_type=type_hints["compute_query"])
            check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
            check_type(argname="argument multi_compute", value=multi_compute, expected_type=type_hints["multi_compute"])
            check_type(argname="argument search_query", value=search_query, expected_type=type_hints["search_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "index": index,
        }
        if compute_query is not None:
            self._values["compute_query"] = compute_query
        if group_by is not None:
            self._values["group_by"] = group_by
        if multi_compute is not None:
            self._values["multi_compute"] = multi_compute
        if search_query is not None:
            self._values["search_query"] = search_query

    @builtins.property
    def index(self) -> builtins.str:
        '''The name of the index to query.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        '''
        result = self._values.get("index")
        assert result is not None, "Required property 'index' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def compute_query(
        self,
    ) -> typing.Optional["PowerpackWidgetScatterplotDefinitionRequestYLogQueryComputeQuery"]:
        '''compute_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        '''
        result = self._values.get("compute_query")
        return typing.cast(typing.Optional["PowerpackWidgetScatterplotDefinitionRequestYLogQueryComputeQuery"], result)

    @builtins.property
    def group_by(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetScatterplotDefinitionRequestYLogQueryGroupBy"]]]:
        '''group_by block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        '''
        result = self._values.get("group_by")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetScatterplotDefinitionRequestYLogQueryGroupBy"]]], result)

    @builtins.property
    def multi_compute(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetScatterplotDefinitionRequestYLogQueryMultiCompute"]]]:
        '''multi_compute block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        '''
        result = self._values.get("multi_compute")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetScatterplotDefinitionRequestYLogQueryMultiCompute"]]], result)

    @builtins.property
    def search_query(self) -> typing.Optional[builtins.str]:
        '''The search query to use.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        result = self._values.get("search_query")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetScatterplotDefinitionRequestYLogQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestYLogQueryComputeQuery",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetScatterplotDefinitionRequestYLogQueryComputeQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2c252309c614fe418c63f8a41314ea43f94087842d956c43a106763bf8473e0c)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetScatterplotDefinitionRequestYLogQueryComputeQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetScatterplotDefinitionRequestYLogQueryComputeQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestYLogQueryComputeQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3b2a8ec1f338e7477d819bed71dd37b1ce27f9eea468cdee40f51bc6f7d03d23)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fa54523959ca93c338eed09248211477192c6003eccb6552c274d552a4b7ebb5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9a49ce8b4ccd221aeb856efa0ba07c8da27b8dd6db1751d36e74e06c835eaa42)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8106453654f200b99384fe79efcd94a3a6fa973bf0aeed25a637518caa20e8d4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetScatterplotDefinitionRequestYLogQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetScatterplotDefinitionRequestYLogQueryComputeQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetScatterplotDefinitionRequestYLogQueryComputeQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cd80519b86702bf53b990407246601dfb4c3722f304bed46cedbf3da1b99f147)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestYLogQueryGroupBy",
    jsii_struct_bases=[],
    name_mapping={"facet": "facet", "limit": "limit", "sort_query": "sortQuery"},
)
class PowerpackWidgetScatterplotDefinitionRequestYLogQueryGroupBy:
    def __init__(
        self,
        *,
        facet: typing.Optional[builtins.str] = None,
        limit: typing.Optional[jsii.Number] = None,
        sort_query: typing.Optional[typing.Union["PowerpackWidgetScatterplotDefinitionRequestYLogQueryGroupBySortQuery", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param limit: The maximum number of items in the group. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param sort_query: sort_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        if isinstance(sort_query, dict):
            sort_query = PowerpackWidgetScatterplotDefinitionRequestYLogQueryGroupBySortQuery(**sort_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__813fd5dd477c3ca7661528957caa8afbc0c2393fd0a99f712a5b2c182c5f318f)
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
            check_type(argname="argument sort_query", value=sort_query, expected_type=type_hints["sort_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if facet is not None:
            self._values["facet"] = facet
        if limit is not None:
            self._values["limit"] = limit
        if sort_query is not None:
            self._values["sort_query"] = sort_query

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def limit(self) -> typing.Optional[jsii.Number]:
        '''The maximum number of items in the group.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        '''
        result = self._values.get("limit")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def sort_query(
        self,
    ) -> typing.Optional["PowerpackWidgetScatterplotDefinitionRequestYLogQueryGroupBySortQuery"]:
        '''sort_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        result = self._values.get("sort_query")
        return typing.cast(typing.Optional["PowerpackWidgetScatterplotDefinitionRequestYLogQueryGroupBySortQuery"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetScatterplotDefinitionRequestYLogQueryGroupBy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetScatterplotDefinitionRequestYLogQueryGroupByList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestYLogQueryGroupByList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b267bece16c6778b4ddac98b893fd30f2a1c5c08195ffb49d117a58542035c59)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetScatterplotDefinitionRequestYLogQueryGroupByOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__00932c167c682ac4408ced0d64a8c86448db28f5b7d215c988c45b37f59fc383)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetScatterplotDefinitionRequestYLogQueryGroupByOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__32615237207ee8ffd06911cb9d863585996c0b14058bd2c4f467814e42e2f4ce)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a4462b9458d463c1983a7829358806f0ddd17137c1f087102f98c81ef4d5b182)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b660638909e67eb3b8f36063b221fb124eb1d1dc099f72031ea565220d625003)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestYLogQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestYLogQueryGroupBy]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestYLogQueryGroupBy]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b9eb3bc37f003aa3389022cd9920020aca30d1927d3010ef2c3aa4877926f34d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetScatterplotDefinitionRequestYLogQueryGroupByOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestYLogQueryGroupByOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cd33543ff6e7013e7b60d71908f75e66adef914a7019959df2c9a9dfae6c210c)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putSortQuery")
    def put_sort_query(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        value = PowerpackWidgetScatterplotDefinitionRequestYLogQueryGroupBySortQuery(
            aggregation=aggregation, order=order, facet=facet
        )

        return typing.cast(None, jsii.invoke(self, "putSortQuery", [value]))

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetLimit")
    def reset_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLimit", []))

    @jsii.member(jsii_name="resetSortQuery")
    def reset_sort_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSortQuery", []))

    @builtins.property
    @jsii.member(jsii_name="sortQuery")
    def sort_query(
        self,
    ) -> "PowerpackWidgetScatterplotDefinitionRequestYLogQueryGroupBySortQueryOutputReference":
        return typing.cast("PowerpackWidgetScatterplotDefinitionRequestYLogQueryGroupBySortQueryOutputReference", jsii.get(self, "sortQuery"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="limitInput")
    def limit_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "limitInput"))

    @builtins.property
    @jsii.member(jsii_name="sortQueryInput")
    def sort_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetScatterplotDefinitionRequestYLogQueryGroupBySortQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetScatterplotDefinitionRequestYLogQueryGroupBySortQuery"], jsii.get(self, "sortQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fa9aec60be1f0df51fab88edc92e9199a9374bed233fad85255a061fa9c3aa53)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="limit")
    def limit(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "limit"))

    @limit.setter
    def limit(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b7bde759e222475f7381163e40f5aa3e28c2bfc7d5d5570dd870e403470414b7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "limit", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetScatterplotDefinitionRequestYLogQueryGroupBy]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetScatterplotDefinitionRequestYLogQueryGroupBy]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetScatterplotDefinitionRequestYLogQueryGroupBy]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__51870017e48b5824cda1b633f3b5b4eb6536b95a3d4fab4ef577b360a98ec863)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestYLogQueryGroupBySortQuery",
    jsii_struct_bases=[],
    name_mapping={"aggregation": "aggregation", "order": "order", "facet": "facet"},
)
class PowerpackWidgetScatterplotDefinitionRequestYLogQueryGroupBySortQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b409d7dadc9d199e1f07bea4f92da449d263a8f59738cee208faa2373f35c757)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument order", value=order, expected_type=type_hints["order"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
            "order": order,
        }
        if facet is not None:
            self._values["facet"] = facet

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def order(self) -> builtins.str:
        '''Widget sorting methods. Valid values are ``asc``, ``desc``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        result = self._values.get("order")
        assert result is not None, "Required property 'order' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetScatterplotDefinitionRequestYLogQueryGroupBySortQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetScatterplotDefinitionRequestYLogQueryGroupBySortQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestYLogQueryGroupBySortQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__447ba52b7fffd192aa44fddddc8eadf79750297cdfccd92ec85739a491db817e)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="orderInput")
    def order_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "orderInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5993890480612443383cfc311a372c284760ff9581f9b88d4687c03a6b79fb37)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__08e37a33f7659d82bb9c505ac66be2694dfb1103dc41a42c76a4836c4a4e2d56)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="order")
    def order(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "order"))

    @order.setter
    def order(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__be07fe43c5de43f247a360afc5368ddac93622977ec96d86e93f1552c1fb6dd1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "order", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetScatterplotDefinitionRequestYLogQueryGroupBySortQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetScatterplotDefinitionRequestYLogQueryGroupBySortQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetScatterplotDefinitionRequestYLogQueryGroupBySortQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2ef50a9b09290cdcf36950c0ce14088c615bc44efcad28471a24debebc7d35b7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestYLogQueryMultiCompute",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetScatterplotDefinitionRequestYLogQueryMultiCompute:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8ae7840fafbd51e074018f699fffb5559bc26fcf70314760770781af32fb1ffe)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetScatterplotDefinitionRequestYLogQueryMultiCompute(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetScatterplotDefinitionRequestYLogQueryMultiComputeList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestYLogQueryMultiComputeList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7332b36fb45d2d6bf91fca1319095b8f5d7083c93e0a7392766f9f29b12d082f)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetScatterplotDefinitionRequestYLogQueryMultiComputeOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4c4a9fff990d2038ae1db17eaa88496f64490c1285c4f491b0b4d226c6d0affa)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetScatterplotDefinitionRequestYLogQueryMultiComputeOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__02985933af2aaaff1814652742ef3c1bba221ba929636526e7c0a31ef0139a41)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__562fdea7d2d2553f77a3c883a5243698724cb7da6259cd3e27ef21dde77f1029)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8408e90250b7f1a1eb12a8dc0762f7b98a4150d57dc7e0cc6c775a63c4590415)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestYLogQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestYLogQueryMultiCompute]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestYLogQueryMultiCompute]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__01892d6fa630fc4b2cba1f28a12fc512226b4a7c35745e0d17d1308be920aa87)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetScatterplotDefinitionRequestYLogQueryMultiComputeOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestYLogQueryMultiComputeOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1cd65499f1326a5f68b542ed9fbd6bffa2887689da6fee68cf662bbf6e1aa680)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0a5729a658baefc392c11fd35d951bd40c5c71d620d9ad25f60f50f5d3d34831)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3ca4a636364a50b3c21a8cbc95c711089e7697dadb095594b70e62021d7d3df8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b6db98a593354aa2cc9fca9034ca51051c04265d650ae6a8ba7cdf2eebc68367)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetScatterplotDefinitionRequestYLogQueryMultiCompute]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetScatterplotDefinitionRequestYLogQueryMultiCompute]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetScatterplotDefinitionRequestYLogQueryMultiCompute]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ad9efb04f341a9f69322c6b5624781734b309ce77bc47d1a9aad0de130e6258f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetScatterplotDefinitionRequestYLogQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestYLogQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__56010203c64266ee4250ffc928cea3e70620a419f4e2985f565cafcb8ce67eeb)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putComputeQuery")
    def put_compute_query(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        value = PowerpackWidgetScatterplotDefinitionRequestYLogQueryComputeQuery(
            aggregation=aggregation, facet=facet, interval=interval
        )

        return typing.cast(None, jsii.invoke(self, "putComputeQuery", [value]))

    @jsii.member(jsii_name="putGroupBy")
    def put_group_by(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetScatterplotDefinitionRequestYLogQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3d582e12f93a6f59e48de169cedfd3f68846a4f3cd84d76a686362044b8a6783)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putGroupBy", [value]))

    @jsii.member(jsii_name="putMultiCompute")
    def put_multi_compute(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetScatterplotDefinitionRequestYLogQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__eee5dbacb13fb7fd377651bdc67a7add1a6c1cb9e8afe70bb9bc597dd5c83c85)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putMultiCompute", [value]))

    @jsii.member(jsii_name="resetComputeQuery")
    def reset_compute_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetComputeQuery", []))

    @jsii.member(jsii_name="resetGroupBy")
    def reset_group_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGroupBy", []))

    @jsii.member(jsii_name="resetMultiCompute")
    def reset_multi_compute(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMultiCompute", []))

    @jsii.member(jsii_name="resetSearchQuery")
    def reset_search_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSearchQuery", []))

    @builtins.property
    @jsii.member(jsii_name="computeQuery")
    def compute_query(
        self,
    ) -> PowerpackWidgetScatterplotDefinitionRequestYLogQueryComputeQueryOutputReference:
        return typing.cast(PowerpackWidgetScatterplotDefinitionRequestYLogQueryComputeQueryOutputReference, jsii.get(self, "computeQuery"))

    @builtins.property
    @jsii.member(jsii_name="groupBy")
    def group_by(
        self,
    ) -> PowerpackWidgetScatterplotDefinitionRequestYLogQueryGroupByList:
        return typing.cast(PowerpackWidgetScatterplotDefinitionRequestYLogQueryGroupByList, jsii.get(self, "groupBy"))

    @builtins.property
    @jsii.member(jsii_name="multiCompute")
    def multi_compute(
        self,
    ) -> PowerpackWidgetScatterplotDefinitionRequestYLogQueryMultiComputeList:
        return typing.cast(PowerpackWidgetScatterplotDefinitionRequestYLogQueryMultiComputeList, jsii.get(self, "multiCompute"))

    @builtins.property
    @jsii.member(jsii_name="computeQueryInput")
    def compute_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetScatterplotDefinitionRequestYLogQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetScatterplotDefinitionRequestYLogQueryComputeQuery], jsii.get(self, "computeQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="groupByInput")
    def group_by_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestYLogQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestYLogQueryGroupBy]]], jsii.get(self, "groupByInput"))

    @builtins.property
    @jsii.member(jsii_name="indexInput")
    def index_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "indexInput"))

    @builtins.property
    @jsii.member(jsii_name="multiComputeInput")
    def multi_compute_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestYLogQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestYLogQueryMultiCompute]]], jsii.get(self, "multiComputeInput"))

    @builtins.property
    @jsii.member(jsii_name="searchQueryInput")
    def search_query_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "searchQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="index")
    def index(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "index"))

    @index.setter
    def index(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__58bdc0a760dd7c28f140d45ab40699dfa32888e3dcf81138329ab6dbac58494f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "index", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="searchQuery")
    def search_query(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "searchQuery"))

    @search_query.setter
    def search_query(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7a66636ece4f70c248e8c1f0fab1a14a62ecd2dc8fb4c236a9ddc20175390b99)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "searchQuery", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetScatterplotDefinitionRequestYLogQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetScatterplotDefinitionRequestYLogQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetScatterplotDefinitionRequestYLogQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c79a4a21db09afd653625b6eb0c47da341c9bd2f595421aa87a9d7ccbd4da5b3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetScatterplotDefinitionRequestYOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestYOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5349cab4096b0d7a9ee1d102ce1bc953e7be2ef7c7402b5e00332c3c5874d39a)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putApmQuery")
    def put_apm_query(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union[PowerpackWidgetScatterplotDefinitionRequestYApmQueryComputeQuery, typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetScatterplotDefinitionRequestYApmQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetScatterplotDefinitionRequestYApmQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        value = PowerpackWidgetScatterplotDefinitionRequestYApmQuery(
            index=index,
            compute_query=compute_query,
            group_by=group_by,
            multi_compute=multi_compute,
            search_query=search_query,
        )

        return typing.cast(None, jsii.invoke(self, "putApmQuery", [value]))

    @jsii.member(jsii_name="putLogQuery")
    def put_log_query(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union[PowerpackWidgetScatterplotDefinitionRequestYLogQueryComputeQuery, typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetScatterplotDefinitionRequestYLogQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetScatterplotDefinitionRequestYLogQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        value = PowerpackWidgetScatterplotDefinitionRequestYLogQuery(
            index=index,
            compute_query=compute_query,
            group_by=group_by,
            multi_compute=multi_compute,
            search_query=search_query,
        )

        return typing.cast(None, jsii.invoke(self, "putLogQuery", [value]))

    @jsii.member(jsii_name="putProcessQuery")
    def put_process_query(
        self,
        *,
        metric: builtins.str,
        filter_by: typing.Optional[typing.Sequence[builtins.str]] = None,
        limit: typing.Optional[jsii.Number] = None,
        search_by: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param metric: Your chosen metric. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        :param filter_by: A list of processes. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#filter_by Powerpack#filter_by}
        :param limit: The max number of items in the filter list. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param search_by: Your chosen search term. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_by Powerpack#search_by}
        '''
        value = PowerpackWidgetScatterplotDefinitionRequestYProcessQuery(
            metric=metric, filter_by=filter_by, limit=limit, search_by=search_by
        )

        return typing.cast(None, jsii.invoke(self, "putProcessQuery", [value]))

    @jsii.member(jsii_name="putRumQuery")
    def put_rum_query(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union["PowerpackWidgetScatterplotDefinitionRequestYRumQueryComputeQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetScatterplotDefinitionRequestYRumQueryGroupBy", typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetScatterplotDefinitionRequestYRumQueryMultiCompute", typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        value = PowerpackWidgetScatterplotDefinitionRequestYRumQuery(
            index=index,
            compute_query=compute_query,
            group_by=group_by,
            multi_compute=multi_compute,
            search_query=search_query,
        )

        return typing.cast(None, jsii.invoke(self, "putRumQuery", [value]))

    @jsii.member(jsii_name="putSecurityQuery")
    def put_security_query(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union["PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryComputeQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryGroupBy", typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryMultiCompute", typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        value = PowerpackWidgetScatterplotDefinitionRequestYSecurityQuery(
            index=index,
            compute_query=compute_query,
            group_by=group_by,
            multi_compute=multi_compute,
            search_query=search_query,
        )

        return typing.cast(None, jsii.invoke(self, "putSecurityQuery", [value]))

    @jsii.member(jsii_name="resetAggregator")
    def reset_aggregator(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAggregator", []))

    @jsii.member(jsii_name="resetApmQuery")
    def reset_apm_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetApmQuery", []))

    @jsii.member(jsii_name="resetLogQuery")
    def reset_log_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLogQuery", []))

    @jsii.member(jsii_name="resetProcessQuery")
    def reset_process_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetProcessQuery", []))

    @jsii.member(jsii_name="resetQ")
    def reset_q(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetQ", []))

    @jsii.member(jsii_name="resetRumQuery")
    def reset_rum_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetRumQuery", []))

    @jsii.member(jsii_name="resetSecurityQuery")
    def reset_security_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSecurityQuery", []))

    @builtins.property
    @jsii.member(jsii_name="apmQuery")
    def apm_query(
        self,
    ) -> PowerpackWidgetScatterplotDefinitionRequestYApmQueryOutputReference:
        return typing.cast(PowerpackWidgetScatterplotDefinitionRequestYApmQueryOutputReference, jsii.get(self, "apmQuery"))

    @builtins.property
    @jsii.member(jsii_name="logQuery")
    def log_query(
        self,
    ) -> PowerpackWidgetScatterplotDefinitionRequestYLogQueryOutputReference:
        return typing.cast(PowerpackWidgetScatterplotDefinitionRequestYLogQueryOutputReference, jsii.get(self, "logQuery"))

    @builtins.property
    @jsii.member(jsii_name="processQuery")
    def process_query(
        self,
    ) -> "PowerpackWidgetScatterplotDefinitionRequestYProcessQueryOutputReference":
        return typing.cast("PowerpackWidgetScatterplotDefinitionRequestYProcessQueryOutputReference", jsii.get(self, "processQuery"))

    @builtins.property
    @jsii.member(jsii_name="rumQuery")
    def rum_query(
        self,
    ) -> "PowerpackWidgetScatterplotDefinitionRequestYRumQueryOutputReference":
        return typing.cast("PowerpackWidgetScatterplotDefinitionRequestYRumQueryOutputReference", jsii.get(self, "rumQuery"))

    @builtins.property
    @jsii.member(jsii_name="securityQuery")
    def security_query(
        self,
    ) -> "PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryOutputReference":
        return typing.cast("PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryOutputReference", jsii.get(self, "securityQuery"))

    @builtins.property
    @jsii.member(jsii_name="aggregatorInput")
    def aggregator_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregatorInput"))

    @builtins.property
    @jsii.member(jsii_name="apmQueryInput")
    def apm_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetScatterplotDefinitionRequestYApmQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetScatterplotDefinitionRequestYApmQuery], jsii.get(self, "apmQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="logQueryInput")
    def log_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetScatterplotDefinitionRequestYLogQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetScatterplotDefinitionRequestYLogQuery], jsii.get(self, "logQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="processQueryInput")
    def process_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetScatterplotDefinitionRequestYProcessQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetScatterplotDefinitionRequestYProcessQuery"], jsii.get(self, "processQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="qInput")
    def q_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "qInput"))

    @builtins.property
    @jsii.member(jsii_name="rumQueryInput")
    def rum_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetScatterplotDefinitionRequestYRumQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetScatterplotDefinitionRequestYRumQuery"], jsii.get(self, "rumQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="securityQueryInput")
    def security_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetScatterplotDefinitionRequestYSecurityQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetScatterplotDefinitionRequestYSecurityQuery"], jsii.get(self, "securityQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregator")
    def aggregator(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregator"))

    @aggregator.setter
    def aggregator(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c9e714137b4be3dec34e6b9f9a049d49bbc748edda4f53f0a41a2b9e27ae09e6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregator", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="q")
    def q(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "q"))

    @q.setter
    def q(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8c08b12e39a8d84610a5ed46c35ffe71e698fbf465021e95df437f9b74e04cf4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "q", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetScatterplotDefinitionRequestY]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetScatterplotDefinitionRequestY]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetScatterplotDefinitionRequestY]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1686ffbf2dbb189031ba695033a125a497827b995d98d4d794b43a01a184c045)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestYProcessQuery",
    jsii_struct_bases=[],
    name_mapping={
        "metric": "metric",
        "filter_by": "filterBy",
        "limit": "limit",
        "search_by": "searchBy",
    },
)
class PowerpackWidgetScatterplotDefinitionRequestYProcessQuery:
    def __init__(
        self,
        *,
        metric: builtins.str,
        filter_by: typing.Optional[typing.Sequence[builtins.str]] = None,
        limit: typing.Optional[jsii.Number] = None,
        search_by: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param metric: Your chosen metric. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        :param filter_by: A list of processes. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#filter_by Powerpack#filter_by}
        :param limit: The max number of items in the filter list. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param search_by: Your chosen search term. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_by Powerpack#search_by}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2179a7bf62e351428edf3c6e8e174a9365888a8e4357bb7b3571489ca78d19bc)
            check_type(argname="argument metric", value=metric, expected_type=type_hints["metric"])
            check_type(argname="argument filter_by", value=filter_by, expected_type=type_hints["filter_by"])
            check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
            check_type(argname="argument search_by", value=search_by, expected_type=type_hints["search_by"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "metric": metric,
        }
        if filter_by is not None:
            self._values["filter_by"] = filter_by
        if limit is not None:
            self._values["limit"] = limit
        if search_by is not None:
            self._values["search_by"] = search_by

    @builtins.property
    def metric(self) -> builtins.str:
        '''Your chosen metric.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        '''
        result = self._values.get("metric")
        assert result is not None, "Required property 'metric' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def filter_by(self) -> typing.Optional[typing.List[builtins.str]]:
        '''A list of processes.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#filter_by Powerpack#filter_by}
        '''
        result = self._values.get("filter_by")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def limit(self) -> typing.Optional[jsii.Number]:
        '''The max number of items in the filter list.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        '''
        result = self._values.get("limit")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def search_by(self) -> typing.Optional[builtins.str]:
        '''Your chosen search term.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_by Powerpack#search_by}
        '''
        result = self._values.get("search_by")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetScatterplotDefinitionRequestYProcessQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetScatterplotDefinitionRequestYProcessQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestYProcessQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d046a6ba5f8529881fcc96a030c76a9c475c3252f9e571b8224b3b30a4d0f498)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFilterBy")
    def reset_filter_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFilterBy", []))

    @jsii.member(jsii_name="resetLimit")
    def reset_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLimit", []))

    @jsii.member(jsii_name="resetSearchBy")
    def reset_search_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSearchBy", []))

    @builtins.property
    @jsii.member(jsii_name="filterByInput")
    def filter_by_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "filterByInput"))

    @builtins.property
    @jsii.member(jsii_name="limitInput")
    def limit_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "limitInput"))

    @builtins.property
    @jsii.member(jsii_name="metricInput")
    def metric_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "metricInput"))

    @builtins.property
    @jsii.member(jsii_name="searchByInput")
    def search_by_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "searchByInput"))

    @builtins.property
    @jsii.member(jsii_name="filterBy")
    def filter_by(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "filterBy"))

    @filter_by.setter
    def filter_by(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__58ccf274936f93746dd2f4c568b2e410d040b4278778c6f9c6582298cf527515)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "filterBy", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="limit")
    def limit(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "limit"))

    @limit.setter
    def limit(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cb7ef290c2735a13510c6db2acddef13eddd78ac8f9fa691f3e2e38c09f92661)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "limit", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="metric")
    def metric(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "metric"))

    @metric.setter
    def metric(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__83978aaf78b3f67f5cc44ac977b54d972f22ab9d2851cdd92bb2146d8888e032)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "metric", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="searchBy")
    def search_by(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "searchBy"))

    @search_by.setter
    def search_by(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6e468882f34c50df35d0b3cd847e315dfba9ef9c1376b2077af9743b2e207bfe)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "searchBy", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetScatterplotDefinitionRequestYProcessQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetScatterplotDefinitionRequestYProcessQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetScatterplotDefinitionRequestYProcessQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e3ea9f313980e4d3fd9574173d13c537eaa29fabf70da73cf45c0040357fdfdc)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestYRumQuery",
    jsii_struct_bases=[],
    name_mapping={
        "index": "index",
        "compute_query": "computeQuery",
        "group_by": "groupBy",
        "multi_compute": "multiCompute",
        "search_query": "searchQuery",
    },
)
class PowerpackWidgetScatterplotDefinitionRequestYRumQuery:
    def __init__(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union["PowerpackWidgetScatterplotDefinitionRequestYRumQueryComputeQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetScatterplotDefinitionRequestYRumQueryGroupBy", typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetScatterplotDefinitionRequestYRumQueryMultiCompute", typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        if isinstance(compute_query, dict):
            compute_query = PowerpackWidgetScatterplotDefinitionRequestYRumQueryComputeQuery(**compute_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ce481fd84da0188a8cd4242610ac365ae24bfdc029efd2c625f0f9b2076189a0)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
            check_type(argname="argument compute_query", value=compute_query, expected_type=type_hints["compute_query"])
            check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
            check_type(argname="argument multi_compute", value=multi_compute, expected_type=type_hints["multi_compute"])
            check_type(argname="argument search_query", value=search_query, expected_type=type_hints["search_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "index": index,
        }
        if compute_query is not None:
            self._values["compute_query"] = compute_query
        if group_by is not None:
            self._values["group_by"] = group_by
        if multi_compute is not None:
            self._values["multi_compute"] = multi_compute
        if search_query is not None:
            self._values["search_query"] = search_query

    @builtins.property
    def index(self) -> builtins.str:
        '''The name of the index to query.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        '''
        result = self._values.get("index")
        assert result is not None, "Required property 'index' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def compute_query(
        self,
    ) -> typing.Optional["PowerpackWidgetScatterplotDefinitionRequestYRumQueryComputeQuery"]:
        '''compute_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        '''
        result = self._values.get("compute_query")
        return typing.cast(typing.Optional["PowerpackWidgetScatterplotDefinitionRequestYRumQueryComputeQuery"], result)

    @builtins.property
    def group_by(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetScatterplotDefinitionRequestYRumQueryGroupBy"]]]:
        '''group_by block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        '''
        result = self._values.get("group_by")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetScatterplotDefinitionRequestYRumQueryGroupBy"]]], result)

    @builtins.property
    def multi_compute(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetScatterplotDefinitionRequestYRumQueryMultiCompute"]]]:
        '''multi_compute block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        '''
        result = self._values.get("multi_compute")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetScatterplotDefinitionRequestYRumQueryMultiCompute"]]], result)

    @builtins.property
    def search_query(self) -> typing.Optional[builtins.str]:
        '''The search query to use.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        result = self._values.get("search_query")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetScatterplotDefinitionRequestYRumQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestYRumQueryComputeQuery",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetScatterplotDefinitionRequestYRumQueryComputeQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9e6493319cbe31578918f0fcc8c18a9ac47809d38abdf29640a4fd0c001b0591)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetScatterplotDefinitionRequestYRumQueryComputeQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetScatterplotDefinitionRequestYRumQueryComputeQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestYRumQueryComputeQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9d1b015c30332a6710e84b97c77fd6407aa0d6e813d32780b2a3e8e67ada21a3)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__659a1e38b948d46939d6afed9770da8ccadc0cfd863b4322a270d0cb923fb726)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8880f7e2f632ea3f3c0b52ad7806d377b6a46b9ef2d85b5a0986f93513934f42)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__81ad0d20d538f764faae68e94c268181d6f23ab8776274064b462bef0edd5b00)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetScatterplotDefinitionRequestYRumQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetScatterplotDefinitionRequestYRumQueryComputeQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetScatterplotDefinitionRequestYRumQueryComputeQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c9e2316b99de0d091c444f657ec128add6defe5fb3a4db784ff5ee731b3f0aa4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestYRumQueryGroupBy",
    jsii_struct_bases=[],
    name_mapping={"facet": "facet", "limit": "limit", "sort_query": "sortQuery"},
)
class PowerpackWidgetScatterplotDefinitionRequestYRumQueryGroupBy:
    def __init__(
        self,
        *,
        facet: typing.Optional[builtins.str] = None,
        limit: typing.Optional[jsii.Number] = None,
        sort_query: typing.Optional[typing.Union["PowerpackWidgetScatterplotDefinitionRequestYRumQueryGroupBySortQuery", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param limit: The maximum number of items in the group. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param sort_query: sort_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        if isinstance(sort_query, dict):
            sort_query = PowerpackWidgetScatterplotDefinitionRequestYRumQueryGroupBySortQuery(**sort_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__508ecece20d519d55338b2d1771bd7c2abd0136ef351c3cbd6f735c4aca6247c)
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
            check_type(argname="argument sort_query", value=sort_query, expected_type=type_hints["sort_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if facet is not None:
            self._values["facet"] = facet
        if limit is not None:
            self._values["limit"] = limit
        if sort_query is not None:
            self._values["sort_query"] = sort_query

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def limit(self) -> typing.Optional[jsii.Number]:
        '''The maximum number of items in the group.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        '''
        result = self._values.get("limit")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def sort_query(
        self,
    ) -> typing.Optional["PowerpackWidgetScatterplotDefinitionRequestYRumQueryGroupBySortQuery"]:
        '''sort_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        result = self._values.get("sort_query")
        return typing.cast(typing.Optional["PowerpackWidgetScatterplotDefinitionRequestYRumQueryGroupBySortQuery"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetScatterplotDefinitionRequestYRumQueryGroupBy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetScatterplotDefinitionRequestYRumQueryGroupByList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestYRumQueryGroupByList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__91dd0a93580945c4450829e42c496a38fe5119b6bf4449974b66dc774011c4e8)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetScatterplotDefinitionRequestYRumQueryGroupByOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__733cd322ad68c3fb6c0fea9c12826f3b709f6005e24833e5be0dee872028c0ec)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetScatterplotDefinitionRequestYRumQueryGroupByOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bb1257a078fbc89fe38c1e7641151f013507dbdeb0099d0f8cf5827d1776e3d7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a83b6dfef1dfef68da428a4aad5c3ba045ddf9e5b2216f1c2c1049daab0e4db4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cf39ea8c2e2732e04ab264e9d7a0df20d0c1adb58fb4b2481fe3b3c548b7ae4b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestYRumQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestYRumQueryGroupBy]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestYRumQueryGroupBy]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cc0f609cb462eb9001021ad7393c534705220a1394b57346915be08b62f106c9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetScatterplotDefinitionRequestYRumQueryGroupByOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestYRumQueryGroupByOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d8490de67f289282ac4a1be6806ccb8f9551d40cd480a038f382e2ba78add1d4)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putSortQuery")
    def put_sort_query(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        value = PowerpackWidgetScatterplotDefinitionRequestYRumQueryGroupBySortQuery(
            aggregation=aggregation, order=order, facet=facet
        )

        return typing.cast(None, jsii.invoke(self, "putSortQuery", [value]))

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetLimit")
    def reset_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLimit", []))

    @jsii.member(jsii_name="resetSortQuery")
    def reset_sort_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSortQuery", []))

    @builtins.property
    @jsii.member(jsii_name="sortQuery")
    def sort_query(
        self,
    ) -> "PowerpackWidgetScatterplotDefinitionRequestYRumQueryGroupBySortQueryOutputReference":
        return typing.cast("PowerpackWidgetScatterplotDefinitionRequestYRumQueryGroupBySortQueryOutputReference", jsii.get(self, "sortQuery"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="limitInput")
    def limit_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "limitInput"))

    @builtins.property
    @jsii.member(jsii_name="sortQueryInput")
    def sort_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetScatterplotDefinitionRequestYRumQueryGroupBySortQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetScatterplotDefinitionRequestYRumQueryGroupBySortQuery"], jsii.get(self, "sortQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__76c4901714a2c8c771dc9365e22f776558176afc3f59acfaec829c1175268b5f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="limit")
    def limit(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "limit"))

    @limit.setter
    def limit(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f28b7312db534dc9a8c80d5961ea4d4575cf9fe8440f877ffe069e01512de347)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "limit", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetScatterplotDefinitionRequestYRumQueryGroupBy]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetScatterplotDefinitionRequestYRumQueryGroupBy]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetScatterplotDefinitionRequestYRumQueryGroupBy]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3361951520452c3537a5c51f7cf337faccaae6990d39c0125be55655b13da4c8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestYRumQueryGroupBySortQuery",
    jsii_struct_bases=[],
    name_mapping={"aggregation": "aggregation", "order": "order", "facet": "facet"},
)
class PowerpackWidgetScatterplotDefinitionRequestYRumQueryGroupBySortQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8122df6432929a518eb0b4a6cfed50a73af65a2ae40a5d5f9fa1fc4530948df1)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument order", value=order, expected_type=type_hints["order"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
            "order": order,
        }
        if facet is not None:
            self._values["facet"] = facet

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def order(self) -> builtins.str:
        '''Widget sorting methods. Valid values are ``asc``, ``desc``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        result = self._values.get("order")
        assert result is not None, "Required property 'order' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetScatterplotDefinitionRequestYRumQueryGroupBySortQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetScatterplotDefinitionRequestYRumQueryGroupBySortQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestYRumQueryGroupBySortQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__588d76a4f87ecb65191f8381e98bcb2ecdba24b9390d240a0ad5cab423974a64)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="orderInput")
    def order_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "orderInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__04938b7714a957c49f19b36415baf9576d8406a2d618fe32ce081e385792c2fc)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0d90919a437851e99aebe0eb6caca2b62cd13251fb4188aed1f96b4cd2331568)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="order")
    def order(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "order"))

    @order.setter
    def order(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2cf8267f3fa1ce0a4536b0e7aae817581dc3e5f65194054db639ccd09837a7ae)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "order", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetScatterplotDefinitionRequestYRumQueryGroupBySortQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetScatterplotDefinitionRequestYRumQueryGroupBySortQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetScatterplotDefinitionRequestYRumQueryGroupBySortQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c072e0b6960670a4a388486185ad0947b43bf6eb614f0adc6ddcb26e9faa18cb)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestYRumQueryMultiCompute",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetScatterplotDefinitionRequestYRumQueryMultiCompute:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9026d94378566021b575cd1e2d7b1609658a046e592bd4a8e8dee6b1df3e1eb0)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetScatterplotDefinitionRequestYRumQueryMultiCompute(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetScatterplotDefinitionRequestYRumQueryMultiComputeList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestYRumQueryMultiComputeList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__48768f9649bc1d84d95e1cfcbd5098904f0f4438b636e87155f54e8e267fea1a)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetScatterplotDefinitionRequestYRumQueryMultiComputeOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a2546fc55d082e9fbf7e95c312fd409b2ae6a1826f516bd8e62b5b12b5bc88bb)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetScatterplotDefinitionRequestYRumQueryMultiComputeOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__57bd2c66ebc85f4d6f8e102d2dfcc258878daac210cc9fe8dbed4f17b93d9494)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ea356f0ceb7002e97caa877258aeb02a900d09f92b9bfa3f5721ed1a3df2322d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b41a00322914b5e5ccf4540c0a239e21020fc916807500bc18503bddb9688bf0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestYRumQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestYRumQueryMultiCompute]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestYRumQueryMultiCompute]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__819eee6ec07bd26d22e02bb8ebf1ef51cfe885220e842f92098ff62fcfd2cc99)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetScatterplotDefinitionRequestYRumQueryMultiComputeOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestYRumQueryMultiComputeOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__63193ce4a22f48a014ad195885aaefbe5ecc3673e0c8a6f8cb23b6beea1e69fe)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bb2acbe6ec8fcee390e98964d2bec6787833ed0143301c69210088b341ad585c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b93e62d98f9c1b434687b4cb728f6d951b5cc64a0748784e481b0dc2a0fe9c33)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c096bf23bddd259d889c3080e2b3e86c6e4dfe72c133d355b98a8249f60716bd)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetScatterplotDefinitionRequestYRumQueryMultiCompute]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetScatterplotDefinitionRequestYRumQueryMultiCompute]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetScatterplotDefinitionRequestYRumQueryMultiCompute]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e01c4470fa41252d0666e432d83f80ba4e2772f2e43df30517ebdaff2a1ca335)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetScatterplotDefinitionRequestYRumQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestYRumQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c9e992b6b1a697953bbe621ec3f843bacf56ea5703972a8a03f3e69f075941a8)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putComputeQuery")
    def put_compute_query(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        value = PowerpackWidgetScatterplotDefinitionRequestYRumQueryComputeQuery(
            aggregation=aggregation, facet=facet, interval=interval
        )

        return typing.cast(None, jsii.invoke(self, "putComputeQuery", [value]))

    @jsii.member(jsii_name="putGroupBy")
    def put_group_by(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetScatterplotDefinitionRequestYRumQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6edbd6a83c8cefa1efc8f531cd18c74635661ca84ec3ebfda4d60ec3e0d6b87e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putGroupBy", [value]))

    @jsii.member(jsii_name="putMultiCompute")
    def put_multi_compute(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetScatterplotDefinitionRequestYRumQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__85eea9cb5eebe8e95bf6e9bb55430523dcb960b8a9d20a68dda7c1998aac7474)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putMultiCompute", [value]))

    @jsii.member(jsii_name="resetComputeQuery")
    def reset_compute_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetComputeQuery", []))

    @jsii.member(jsii_name="resetGroupBy")
    def reset_group_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGroupBy", []))

    @jsii.member(jsii_name="resetMultiCompute")
    def reset_multi_compute(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMultiCompute", []))

    @jsii.member(jsii_name="resetSearchQuery")
    def reset_search_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSearchQuery", []))

    @builtins.property
    @jsii.member(jsii_name="computeQuery")
    def compute_query(
        self,
    ) -> PowerpackWidgetScatterplotDefinitionRequestYRumQueryComputeQueryOutputReference:
        return typing.cast(PowerpackWidgetScatterplotDefinitionRequestYRumQueryComputeQueryOutputReference, jsii.get(self, "computeQuery"))

    @builtins.property
    @jsii.member(jsii_name="groupBy")
    def group_by(
        self,
    ) -> PowerpackWidgetScatterplotDefinitionRequestYRumQueryGroupByList:
        return typing.cast(PowerpackWidgetScatterplotDefinitionRequestYRumQueryGroupByList, jsii.get(self, "groupBy"))

    @builtins.property
    @jsii.member(jsii_name="multiCompute")
    def multi_compute(
        self,
    ) -> PowerpackWidgetScatterplotDefinitionRequestYRumQueryMultiComputeList:
        return typing.cast(PowerpackWidgetScatterplotDefinitionRequestYRumQueryMultiComputeList, jsii.get(self, "multiCompute"))

    @builtins.property
    @jsii.member(jsii_name="computeQueryInput")
    def compute_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetScatterplotDefinitionRequestYRumQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetScatterplotDefinitionRequestYRumQueryComputeQuery], jsii.get(self, "computeQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="groupByInput")
    def group_by_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestYRumQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestYRumQueryGroupBy]]], jsii.get(self, "groupByInput"))

    @builtins.property
    @jsii.member(jsii_name="indexInput")
    def index_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "indexInput"))

    @builtins.property
    @jsii.member(jsii_name="multiComputeInput")
    def multi_compute_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestYRumQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestYRumQueryMultiCompute]]], jsii.get(self, "multiComputeInput"))

    @builtins.property
    @jsii.member(jsii_name="searchQueryInput")
    def search_query_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "searchQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="index")
    def index(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "index"))

    @index.setter
    def index(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e818add657bbc9deb969adbbf360819aa45e7592b2a3723e968d1e5fbe56d867)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "index", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="searchQuery")
    def search_query(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "searchQuery"))

    @search_query.setter
    def search_query(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__85a13ee72d04953d61710ef6c2311ddbcdc48d6e760925acaf9f88416550677b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "searchQuery", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetScatterplotDefinitionRequestYRumQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetScatterplotDefinitionRequestYRumQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetScatterplotDefinitionRequestYRumQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c5c7526a808da31e5994d620b33ef5299f60ef80272c87d56d14164264807af9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestYSecurityQuery",
    jsii_struct_bases=[],
    name_mapping={
        "index": "index",
        "compute_query": "computeQuery",
        "group_by": "groupBy",
        "multi_compute": "multiCompute",
        "search_query": "searchQuery",
    },
)
class PowerpackWidgetScatterplotDefinitionRequestYSecurityQuery:
    def __init__(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union["PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryComputeQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryGroupBy", typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryMultiCompute", typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        if isinstance(compute_query, dict):
            compute_query = PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryComputeQuery(**compute_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__82bbc2d6c38206443aca8794f6dc6c9a74de714cfbb3d08ea53c1bc5578bb4a7)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
            check_type(argname="argument compute_query", value=compute_query, expected_type=type_hints["compute_query"])
            check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
            check_type(argname="argument multi_compute", value=multi_compute, expected_type=type_hints["multi_compute"])
            check_type(argname="argument search_query", value=search_query, expected_type=type_hints["search_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "index": index,
        }
        if compute_query is not None:
            self._values["compute_query"] = compute_query
        if group_by is not None:
            self._values["group_by"] = group_by
        if multi_compute is not None:
            self._values["multi_compute"] = multi_compute
        if search_query is not None:
            self._values["search_query"] = search_query

    @builtins.property
    def index(self) -> builtins.str:
        '''The name of the index to query.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        '''
        result = self._values.get("index")
        assert result is not None, "Required property 'index' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def compute_query(
        self,
    ) -> typing.Optional["PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryComputeQuery"]:
        '''compute_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        '''
        result = self._values.get("compute_query")
        return typing.cast(typing.Optional["PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryComputeQuery"], result)

    @builtins.property
    def group_by(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryGroupBy"]]]:
        '''group_by block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        '''
        result = self._values.get("group_by")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryGroupBy"]]], result)

    @builtins.property
    def multi_compute(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryMultiCompute"]]]:
        '''multi_compute block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        '''
        result = self._values.get("multi_compute")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryMultiCompute"]]], result)

    @builtins.property
    def search_query(self) -> typing.Optional[builtins.str]:
        '''The search query to use.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        result = self._values.get("search_query")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetScatterplotDefinitionRequestYSecurityQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryComputeQuery",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryComputeQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5e4fca4283099974d5a6ce144a4f98d8f4ddbe87c3262c438c4740c5105f1776)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryComputeQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryComputeQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryComputeQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f73f4908cd19290de6b01f8245f12e3c087ee770757855c26680a2f58001b5f3)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3d9c4a0e7a48b7eeeb01820b28109cf181332f2dc033e7783e0001c69272f450)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dc4d9fca2ef7a44f9e16dd02dc5b7d90ca7e1a9d85385449da1b71d80bc6c76a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0ded48ca92290704c650d8ea8f4a127c3fc457c1aa9d82081651b1434ea6b56e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryComputeQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryComputeQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__119fbf4fb0075aebefbb5e6967597b103af8e059568f0c8c4df6a095992cde13)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryGroupBy",
    jsii_struct_bases=[],
    name_mapping={"facet": "facet", "limit": "limit", "sort_query": "sortQuery"},
)
class PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryGroupBy:
    def __init__(
        self,
        *,
        facet: typing.Optional[builtins.str] = None,
        limit: typing.Optional[jsii.Number] = None,
        sort_query: typing.Optional[typing.Union["PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryGroupBySortQuery", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param limit: The maximum number of items in the group. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param sort_query: sort_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        if isinstance(sort_query, dict):
            sort_query = PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryGroupBySortQuery(**sort_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__35935568f894dbad386a874d147f4ac8ec1cc89d056308beb8544431850b4949)
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
            check_type(argname="argument sort_query", value=sort_query, expected_type=type_hints["sort_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if facet is not None:
            self._values["facet"] = facet
        if limit is not None:
            self._values["limit"] = limit
        if sort_query is not None:
            self._values["sort_query"] = sort_query

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def limit(self) -> typing.Optional[jsii.Number]:
        '''The maximum number of items in the group.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        '''
        result = self._values.get("limit")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def sort_query(
        self,
    ) -> typing.Optional["PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryGroupBySortQuery"]:
        '''sort_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        result = self._values.get("sort_query")
        return typing.cast(typing.Optional["PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryGroupBySortQuery"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryGroupBy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryGroupByList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryGroupByList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f9fd47e78d025f245a90774a9f2d013994063b845b4e8ffd250af40829a8d0fb)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryGroupByOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b1cbf5500a0da26af82900530be353274c82456bee6271e1bf499ab2c93d6bf1)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryGroupByOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__aa131d69d6b606b72d3a96601f20e89646cabd2a2d580040dab2bcbb7a34bbec)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fe49efff42ca2945cd6d95744e932bc7a0692044c8e8c798ec2fbe8473307d54)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9b5b003acf626cfc4424b20795cd3968d7c2c244c32dc884c7a8aa3ea2fda65f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryGroupBy]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryGroupBy]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a518c3075d25e2a03f11f01e5b7891bc901d1361cd6d2d558e133a6c4a243f75)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryGroupByOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryGroupByOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__520a5d5e694f988648006f48717f12118c8ffb0607eb87a6a28512c6a2be0fe3)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putSortQuery")
    def put_sort_query(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        value = PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryGroupBySortQuery(
            aggregation=aggregation, order=order, facet=facet
        )

        return typing.cast(None, jsii.invoke(self, "putSortQuery", [value]))

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetLimit")
    def reset_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLimit", []))

    @jsii.member(jsii_name="resetSortQuery")
    def reset_sort_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSortQuery", []))

    @builtins.property
    @jsii.member(jsii_name="sortQuery")
    def sort_query(
        self,
    ) -> "PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryGroupBySortQueryOutputReference":
        return typing.cast("PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryGroupBySortQueryOutputReference", jsii.get(self, "sortQuery"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="limitInput")
    def limit_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "limitInput"))

    @builtins.property
    @jsii.member(jsii_name="sortQueryInput")
    def sort_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryGroupBySortQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryGroupBySortQuery"], jsii.get(self, "sortQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c1a72dfa5c707ffeceeca06349fc2957a7e0e8c79b04d924b75c536f2eb3708f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="limit")
    def limit(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "limit"))

    @limit.setter
    def limit(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1b53a9d4b86827c850bdc3b917adf9609f7ea4ba20702bbcec56002331d575d9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "limit", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryGroupBy]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryGroupBy]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryGroupBy]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1a83e28e6aba1c7d4a41e51e751f1d94904037b2fdbcccc5f60731f2e0343ea5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryGroupBySortQuery",
    jsii_struct_bases=[],
    name_mapping={"aggregation": "aggregation", "order": "order", "facet": "facet"},
)
class PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryGroupBySortQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9cdfc86b4ead4a754acb2f9702844a2a3773293dc9d3d7e725698a0bca52a1c2)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument order", value=order, expected_type=type_hints["order"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
            "order": order,
        }
        if facet is not None:
            self._values["facet"] = facet

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def order(self) -> builtins.str:
        '''Widget sorting methods. Valid values are ``asc``, ``desc``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        result = self._values.get("order")
        assert result is not None, "Required property 'order' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryGroupBySortQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryGroupBySortQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryGroupBySortQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cdb518eee4b27d166a6a7524a9fa64f96367a0f34c6191780c1607af3fe7f00b)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="orderInput")
    def order_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "orderInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__528c8122b44a53aec33b0cd2680cf7fa3b34b968527a0ca656807a09517b27b0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__170febe0243f4484011fcd2077e2f1363c168c2dfac178bd67f12e5db19e62b4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="order")
    def order(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "order"))

    @order.setter
    def order(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ee01b249c90d6707918eea845f2d62d24d652c30b51c65464a5c3c413dcb8f29)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "order", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryGroupBySortQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryGroupBySortQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryGroupBySortQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0d11370c5354db46683022386cc7c337224078925078742ce3ab6cf1603ee58d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryMultiCompute",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryMultiCompute:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__69373306edc8fce579857eac9621cdf40858ed365e7fe5743e9b0dcbb66292c6)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryMultiCompute(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryMultiComputeList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryMultiComputeList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9e3916bce7b980226bd94defce79959b17b2a9cb501359314c9e7a6f0ab6d9dc)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryMultiComputeOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bc331f3f1321083d6a2797efa62a457c2547ac262096a5452fa1d18ff97506b2)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryMultiComputeOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__16be26cfac9754156cf8315adf778304bd5fdfae43e8cecb2e637074b2af1430)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f7696c0946cd6e3a6187652e4627a0b3bc03b5759fea16f364a8dc62a02a167f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__01351692bb40e0e73e76b1a6e99821cdaab1de30e5f6059bc449a393ac54a1dd)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryMultiCompute]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryMultiCompute]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e2fcaaf5ddaf45508028fed28ac44fcec5cf8b974870e7152122cdf292323b00)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryMultiComputeOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryMultiComputeOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cabf30e5ec33f049e3efa2390152c3d4d8227e85a47cd536413a0c6728ec5186)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__14373c374afa6e7f6c2b839e8c505d3d7d49dd09ebaf23e709b202ba708a5a26)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fa0f2a99b994cc5a294193e325a58f2b5ccb5532f74ab9d8c32a8c23ad28acaa)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9f6ed788f1d87fc4096dc4eb04f7c87534c3add6f8189dab2cb1acf760f83293)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryMultiCompute]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryMultiCompute]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryMultiCompute]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c2fb500f4edcdecf89a42c02b484f41b00331ae356defb1b061a43cf3f143469)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e6850aaf091628eda53b8440c29a7a71afaa439f926e4390507fefedc44f4a35)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putComputeQuery")
    def put_compute_query(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        value = PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryComputeQuery(
            aggregation=aggregation, facet=facet, interval=interval
        )

        return typing.cast(None, jsii.invoke(self, "putComputeQuery", [value]))

    @jsii.member(jsii_name="putGroupBy")
    def put_group_by(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__22cae836453ab6ab995aff12a4ed45d8ca58972d201c1426659d2d166ea9bcce)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putGroupBy", [value]))

    @jsii.member(jsii_name="putMultiCompute")
    def put_multi_compute(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bdc6c85e603f18c4903b501f0e52662cc2e145a1028d679f5a941e562ecc68a5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putMultiCompute", [value]))

    @jsii.member(jsii_name="resetComputeQuery")
    def reset_compute_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetComputeQuery", []))

    @jsii.member(jsii_name="resetGroupBy")
    def reset_group_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGroupBy", []))

    @jsii.member(jsii_name="resetMultiCompute")
    def reset_multi_compute(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMultiCompute", []))

    @jsii.member(jsii_name="resetSearchQuery")
    def reset_search_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSearchQuery", []))

    @builtins.property
    @jsii.member(jsii_name="computeQuery")
    def compute_query(
        self,
    ) -> PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryComputeQueryOutputReference:
        return typing.cast(PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryComputeQueryOutputReference, jsii.get(self, "computeQuery"))

    @builtins.property
    @jsii.member(jsii_name="groupBy")
    def group_by(
        self,
    ) -> PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryGroupByList:
        return typing.cast(PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryGroupByList, jsii.get(self, "groupBy"))

    @builtins.property
    @jsii.member(jsii_name="multiCompute")
    def multi_compute(
        self,
    ) -> PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryMultiComputeList:
        return typing.cast(PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryMultiComputeList, jsii.get(self, "multiCompute"))

    @builtins.property
    @jsii.member(jsii_name="computeQueryInput")
    def compute_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryComputeQuery], jsii.get(self, "computeQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="groupByInput")
    def group_by_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryGroupBy]]], jsii.get(self, "groupByInput"))

    @builtins.property
    @jsii.member(jsii_name="indexInput")
    def index_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "indexInput"))

    @builtins.property
    @jsii.member(jsii_name="multiComputeInput")
    def multi_compute_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryMultiCompute]]], jsii.get(self, "multiComputeInput"))

    @builtins.property
    @jsii.member(jsii_name="searchQueryInput")
    def search_query_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "searchQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="index")
    def index(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "index"))

    @index.setter
    def index(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9c834f72abb1dd6a96eadc23ca507c9c9d755719f826fb5055d12df7d54a9739)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "index", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="searchQuery")
    def search_query(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "searchQuery"))

    @search_query.setter
    def search_query(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cdfa1375bf80a70771358e0de53b2ebc8d7c3f53a2a3dc8e5562cdbd39299cc1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "searchQuery", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetScatterplotDefinitionRequestYSecurityQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetScatterplotDefinitionRequestYSecurityQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetScatterplotDefinitionRequestYSecurityQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9799583a3969837861ddae0c87b7bf47d71b42e09bd071653102e01c78dcff1d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionXaxis",
    jsii_struct_bases=[],
    name_mapping={
        "include_zero": "includeZero",
        "label": "label",
        "max": "max",
        "min": "min",
        "scale": "scale",
    },
)
class PowerpackWidgetScatterplotDefinitionXaxis:
    def __init__(
        self,
        *,
        include_zero: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        label: typing.Optional[builtins.str] = None,
        max: typing.Optional[builtins.str] = None,
        min: typing.Optional[builtins.str] = None,
        scale: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param include_zero: Always include zero or fit the axis to the data range. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#include_zero Powerpack#include_zero}
        :param label: The label of the axis to display on the graph. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#label Powerpack#label}
        :param max: Specify the maximum value to show on the Y-axis. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#max Powerpack#max}
        :param min: Specify the minimum value to show on the Y-axis. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#min Powerpack#min}
        :param scale: Specify the scale type, options: ``linear``, ``log``, ``pow``, ``sqrt``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#scale Powerpack#scale}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fe4471c1e7f29df32a3945bb4d36d95d35b6265f9d234fd930612d52e8901e4b)
            check_type(argname="argument include_zero", value=include_zero, expected_type=type_hints["include_zero"])
            check_type(argname="argument label", value=label, expected_type=type_hints["label"])
            check_type(argname="argument max", value=max, expected_type=type_hints["max"])
            check_type(argname="argument min", value=min, expected_type=type_hints["min"])
            check_type(argname="argument scale", value=scale, expected_type=type_hints["scale"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if include_zero is not None:
            self._values["include_zero"] = include_zero
        if label is not None:
            self._values["label"] = label
        if max is not None:
            self._values["max"] = max
        if min is not None:
            self._values["min"] = min
        if scale is not None:
            self._values["scale"] = scale

    @builtins.property
    def include_zero(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        '''Always include zero or fit the axis to the data range.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#include_zero Powerpack#include_zero}
        '''
        result = self._values.get("include_zero")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)

    @builtins.property
    def label(self) -> typing.Optional[builtins.str]:
        '''The label of the axis to display on the graph.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#label Powerpack#label}
        '''
        result = self._values.get("label")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def max(self) -> typing.Optional[builtins.str]:
        '''Specify the maximum value to show on the Y-axis.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#max Powerpack#max}
        '''
        result = self._values.get("max")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def min(self) -> typing.Optional[builtins.str]:
        '''Specify the minimum value to show on the Y-axis.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#min Powerpack#min}
        '''
        result = self._values.get("min")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def scale(self) -> typing.Optional[builtins.str]:
        '''Specify the scale type, options: ``linear``, ``log``, ``pow``, ``sqrt``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#scale Powerpack#scale}
        '''
        result = self._values.get("scale")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetScatterplotDefinitionXaxis(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetScatterplotDefinitionXaxisOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionXaxisOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d8a77fada173a299e1bd040c009128f82f63a37963495a16f41500f0170cc6ea)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetIncludeZero")
    def reset_include_zero(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetIncludeZero", []))

    @jsii.member(jsii_name="resetLabel")
    def reset_label(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLabel", []))

    @jsii.member(jsii_name="resetMax")
    def reset_max(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMax", []))

    @jsii.member(jsii_name="resetMin")
    def reset_min(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMin", []))

    @jsii.member(jsii_name="resetScale")
    def reset_scale(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetScale", []))

    @builtins.property
    @jsii.member(jsii_name="includeZeroInput")
    def include_zero_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "includeZeroInput"))

    @builtins.property
    @jsii.member(jsii_name="labelInput")
    def label_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "labelInput"))

    @builtins.property
    @jsii.member(jsii_name="maxInput")
    def max_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "maxInput"))

    @builtins.property
    @jsii.member(jsii_name="minInput")
    def min_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "minInput"))

    @builtins.property
    @jsii.member(jsii_name="scaleInput")
    def scale_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "scaleInput"))

    @builtins.property
    @jsii.member(jsii_name="includeZero")
    def include_zero(self) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "includeZero"))

    @include_zero.setter
    def include_zero(
        self,
        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__342a41c37978acb8a03058c0fa083f44d0e00a4bc433956ffa99358249a7bf49)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "includeZero", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="label")
    def label(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "label"))

    @label.setter
    def label(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c065018298a619b000b192fa24c9c441bca5ee46064743d63ea4d3a6468af2b7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "label", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="max")
    def max(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "max"))

    @max.setter
    def max(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__67bf875d153d7028cb5f57f40d5de5443e57facabfb19a81a809dfc55c299939)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "max", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="min")
    def min(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "min"))

    @min.setter
    def min(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ab870528563c39330a88585d7a564ad0a128f6411176670e8aaafc33773bb62f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "min", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="scale")
    def scale(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "scale"))

    @scale.setter
    def scale(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dccb67617e7cac16d7bd88003111b29e59c67a19e951cc1285693aab88e155f4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "scale", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetScatterplotDefinitionXaxis]:
        return typing.cast(typing.Optional[PowerpackWidgetScatterplotDefinitionXaxis], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetScatterplotDefinitionXaxis],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__254e741fa076796e97037387e8447c16c5f3e3b8a96981812e5c933c218ed43b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionYaxis",
    jsii_struct_bases=[],
    name_mapping={
        "include_zero": "includeZero",
        "label": "label",
        "max": "max",
        "min": "min",
        "scale": "scale",
    },
)
class PowerpackWidgetScatterplotDefinitionYaxis:
    def __init__(
        self,
        *,
        include_zero: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        label: typing.Optional[builtins.str] = None,
        max: typing.Optional[builtins.str] = None,
        min: typing.Optional[builtins.str] = None,
        scale: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param include_zero: Always include zero or fit the axis to the data range. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#include_zero Powerpack#include_zero}
        :param label: The label of the axis to display on the graph. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#label Powerpack#label}
        :param max: Specify the maximum value to show on the Y-axis. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#max Powerpack#max}
        :param min: Specify the minimum value to show on the Y-axis. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#min Powerpack#min}
        :param scale: Specify the scale type, options: ``linear``, ``log``, ``pow``, ``sqrt``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#scale Powerpack#scale}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1dac0b1a98078a8963b3adecf0671e52ddf6d9625a130216154962f23c749420)
            check_type(argname="argument include_zero", value=include_zero, expected_type=type_hints["include_zero"])
            check_type(argname="argument label", value=label, expected_type=type_hints["label"])
            check_type(argname="argument max", value=max, expected_type=type_hints["max"])
            check_type(argname="argument min", value=min, expected_type=type_hints["min"])
            check_type(argname="argument scale", value=scale, expected_type=type_hints["scale"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if include_zero is not None:
            self._values["include_zero"] = include_zero
        if label is not None:
            self._values["label"] = label
        if max is not None:
            self._values["max"] = max
        if min is not None:
            self._values["min"] = min
        if scale is not None:
            self._values["scale"] = scale

    @builtins.property
    def include_zero(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        '''Always include zero or fit the axis to the data range.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#include_zero Powerpack#include_zero}
        '''
        result = self._values.get("include_zero")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)

    @builtins.property
    def label(self) -> typing.Optional[builtins.str]:
        '''The label of the axis to display on the graph.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#label Powerpack#label}
        '''
        result = self._values.get("label")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def max(self) -> typing.Optional[builtins.str]:
        '''Specify the maximum value to show on the Y-axis.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#max Powerpack#max}
        '''
        result = self._values.get("max")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def min(self) -> typing.Optional[builtins.str]:
        '''Specify the minimum value to show on the Y-axis.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#min Powerpack#min}
        '''
        result = self._values.get("min")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def scale(self) -> typing.Optional[builtins.str]:
        '''Specify the scale type, options: ``linear``, ``log``, ``pow``, ``sqrt``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#scale Powerpack#scale}
        '''
        result = self._values.get("scale")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetScatterplotDefinitionYaxis(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetScatterplotDefinitionYaxisOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetScatterplotDefinitionYaxisOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__490e597a5cbd271853dea4c6c3df927def392b6e516700e0eec4c7be6caad85b)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetIncludeZero")
    def reset_include_zero(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetIncludeZero", []))

    @jsii.member(jsii_name="resetLabel")
    def reset_label(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLabel", []))

    @jsii.member(jsii_name="resetMax")
    def reset_max(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMax", []))

    @jsii.member(jsii_name="resetMin")
    def reset_min(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMin", []))

    @jsii.member(jsii_name="resetScale")
    def reset_scale(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetScale", []))

    @builtins.property
    @jsii.member(jsii_name="includeZeroInput")
    def include_zero_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "includeZeroInput"))

    @builtins.property
    @jsii.member(jsii_name="labelInput")
    def label_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "labelInput"))

    @builtins.property
    @jsii.member(jsii_name="maxInput")
    def max_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "maxInput"))

    @builtins.property
    @jsii.member(jsii_name="minInput")
    def min_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "minInput"))

    @builtins.property
    @jsii.member(jsii_name="scaleInput")
    def scale_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "scaleInput"))

    @builtins.property
    @jsii.member(jsii_name="includeZero")
    def include_zero(self) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "includeZero"))

    @include_zero.setter
    def include_zero(
        self,
        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__118718bb4c78f02f2427bb126ba605b207f36f7932ae17f55c1ea9676a172f99)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "includeZero", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="label")
    def label(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "label"))

    @label.setter
    def label(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2fd9a8201952bf91c2589930245fb0cd65a2965222caa5e607f359e36f518507)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "label", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="max")
    def max(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "max"))

    @max.setter
    def max(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dabe28b478a0126a82b819f22a057977b7f5295df37e73ee9b7e6477a9f26f4e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "max", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="min")
    def min(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "min"))

    @min.setter
    def min(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__99848a2fee0ff626487345e09b351ebe8451f1d235c69ae47e2473fd841cc501)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "min", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="scale")
    def scale(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "scale"))

    @scale.setter
    def scale(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c7e1dba7fb33e3348f4be8b26f7a8a575e104c85da2fe9233a8cf8b96851472a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "scale", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetScatterplotDefinitionYaxis]:
        return typing.cast(typing.Optional[PowerpackWidgetScatterplotDefinitionYaxis], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetScatterplotDefinitionYaxis],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d78f10d381642a18d2f471e627b055f28cc5ff83405e895906b431587693dabe)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetServiceLevelObjectiveDefinition",
    jsii_struct_bases=[],
    name_mapping={
        "slo_id": "sloId",
        "time_windows": "timeWindows",
        "view_mode": "viewMode",
        "view_type": "viewType",
        "additional_query_filters": "additionalQueryFilters",
        "global_time_target": "globalTimeTarget",
        "show_error_budget": "showErrorBudget",
        "title": "title",
        "title_align": "titleAlign",
        "title_size": "titleSize",
    },
)
class PowerpackWidgetServiceLevelObjectiveDefinition:
    def __init__(
        self,
        *,
        slo_id: builtins.str,
        time_windows: typing.Sequence[builtins.str],
        view_mode: builtins.str,
        view_type: builtins.str,
        additional_query_filters: typing.Optional[builtins.str] = None,
        global_time_target: typing.Optional[builtins.str] = None,
        show_error_budget: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        title: typing.Optional[builtins.str] = None,
        title_align: typing.Optional[builtins.str] = None,
        title_size: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param slo_id: The ID of the service level objective used by the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#slo_id Powerpack#slo_id}
        :param time_windows: A list of time windows to display in the widget. Valid values are ``7d``, ``30d``, ``90d``, ``week_to_date``, ``previous_week``, ``month_to_date``, ``previous_month``, ``global_time``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#time_windows Powerpack#time_windows}
        :param view_mode: The view mode for the widget. Valid values are ``overall``, ``component``, ``both``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#view_mode Powerpack#view_mode}
        :param view_type: The type of view to use when displaying the widget. Only ``detail`` is supported. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#view_type Powerpack#view_type}
        :param additional_query_filters: Additional filters applied to the SLO query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#additional_query_filters Powerpack#additional_query_filters}
        :param global_time_target: The global time target of the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#global_time_target Powerpack#global_time_target}
        :param show_error_budget: Whether to show the error budget or not. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#show_error_budget Powerpack#show_error_budget}
        :param title: The title of the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title Powerpack#title}
        :param title_align: The alignment of the widget's title. Valid values are ``center``, ``left``, ``right``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_align Powerpack#title_align}
        :param title_size: The size of the widget's title (defaults to 16). Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_size Powerpack#title_size}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__feea9b78cf9cb4110c6c0da11dbc00ca2f293e089d185ddd670fe126d3096400)
            check_type(argname="argument slo_id", value=slo_id, expected_type=type_hints["slo_id"])
            check_type(argname="argument time_windows", value=time_windows, expected_type=type_hints["time_windows"])
            check_type(argname="argument view_mode", value=view_mode, expected_type=type_hints["view_mode"])
            check_type(argname="argument view_type", value=view_type, expected_type=type_hints["view_type"])
            check_type(argname="argument additional_query_filters", value=additional_query_filters, expected_type=type_hints["additional_query_filters"])
            check_type(argname="argument global_time_target", value=global_time_target, expected_type=type_hints["global_time_target"])
            check_type(argname="argument show_error_budget", value=show_error_budget, expected_type=type_hints["show_error_budget"])
            check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            check_type(argname="argument title_align", value=title_align, expected_type=type_hints["title_align"])
            check_type(argname="argument title_size", value=title_size, expected_type=type_hints["title_size"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "slo_id": slo_id,
            "time_windows": time_windows,
            "view_mode": view_mode,
            "view_type": view_type,
        }
        if additional_query_filters is not None:
            self._values["additional_query_filters"] = additional_query_filters
        if global_time_target is not None:
            self._values["global_time_target"] = global_time_target
        if show_error_budget is not None:
            self._values["show_error_budget"] = show_error_budget
        if title is not None:
            self._values["title"] = title
        if title_align is not None:
            self._values["title_align"] = title_align
        if title_size is not None:
            self._values["title_size"] = title_size

    @builtins.property
    def slo_id(self) -> builtins.str:
        '''The ID of the service level objective used by the widget.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#slo_id Powerpack#slo_id}
        '''
        result = self._values.get("slo_id")
        assert result is not None, "Required property 'slo_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def time_windows(self) -> typing.List[builtins.str]:
        '''A list of time windows to display in the widget.

        Valid values are ``7d``, ``30d``, ``90d``, ``week_to_date``, ``previous_week``, ``month_to_date``, ``previous_month``, ``global_time``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#time_windows Powerpack#time_windows}
        '''
        result = self._values.get("time_windows")
        assert result is not None, "Required property 'time_windows' is missing"
        return typing.cast(typing.List[builtins.str], result)

    @builtins.property
    def view_mode(self) -> builtins.str:
        '''The view mode for the widget. Valid values are ``overall``, ``component``, ``both``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#view_mode Powerpack#view_mode}
        '''
        result = self._values.get("view_mode")
        assert result is not None, "Required property 'view_mode' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def view_type(self) -> builtins.str:
        '''The type of view to use when displaying the widget. Only ``detail`` is supported.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#view_type Powerpack#view_type}
        '''
        result = self._values.get("view_type")
        assert result is not None, "Required property 'view_type' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def additional_query_filters(self) -> typing.Optional[builtins.str]:
        '''Additional filters applied to the SLO query.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#additional_query_filters Powerpack#additional_query_filters}
        '''
        result = self._values.get("additional_query_filters")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def global_time_target(self) -> typing.Optional[builtins.str]:
        '''The global time target of the widget.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#global_time_target Powerpack#global_time_target}
        '''
        result = self._values.get("global_time_target")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def show_error_budget(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        '''Whether to show the error budget or not.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#show_error_budget Powerpack#show_error_budget}
        '''
        result = self._values.get("show_error_budget")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)

    @builtins.property
    def title(self) -> typing.Optional[builtins.str]:
        '''The title of the widget.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title Powerpack#title}
        '''
        result = self._values.get("title")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def title_align(self) -> typing.Optional[builtins.str]:
        '''The alignment of the widget's title. Valid values are ``center``, ``left``, ``right``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_align Powerpack#title_align}
        '''
        result = self._values.get("title_align")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def title_size(self) -> typing.Optional[builtins.str]:
        '''The size of the widget's title (defaults to 16).

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_size Powerpack#title_size}
        '''
        result = self._values.get("title_size")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetServiceLevelObjectiveDefinition(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetServiceLevelObjectiveDefinitionOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetServiceLevelObjectiveDefinitionOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e3e0b9eb45c832831436314eaf91a3dac0966a57cb573f890239767a7714be9b)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetAdditionalQueryFilters")
    def reset_additional_query_filters(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAdditionalQueryFilters", []))

    @jsii.member(jsii_name="resetGlobalTimeTarget")
    def reset_global_time_target(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGlobalTimeTarget", []))

    @jsii.member(jsii_name="resetShowErrorBudget")
    def reset_show_error_budget(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetShowErrorBudget", []))

    @jsii.member(jsii_name="resetTitle")
    def reset_title(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTitle", []))

    @jsii.member(jsii_name="resetTitleAlign")
    def reset_title_align(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTitleAlign", []))

    @jsii.member(jsii_name="resetTitleSize")
    def reset_title_size(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTitleSize", []))

    @builtins.property
    @jsii.member(jsii_name="additionalQueryFiltersInput")
    def additional_query_filters_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "additionalQueryFiltersInput"))

    @builtins.property
    @jsii.member(jsii_name="globalTimeTargetInput")
    def global_time_target_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "globalTimeTargetInput"))

    @builtins.property
    @jsii.member(jsii_name="showErrorBudgetInput")
    def show_error_budget_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "showErrorBudgetInput"))

    @builtins.property
    @jsii.member(jsii_name="sloIdInput")
    def slo_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "sloIdInput"))

    @builtins.property
    @jsii.member(jsii_name="timeWindowsInput")
    def time_windows_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "timeWindowsInput"))

    @builtins.property
    @jsii.member(jsii_name="titleAlignInput")
    def title_align_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "titleAlignInput"))

    @builtins.property
    @jsii.member(jsii_name="titleInput")
    def title_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "titleInput"))

    @builtins.property
    @jsii.member(jsii_name="titleSizeInput")
    def title_size_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "titleSizeInput"))

    @builtins.property
    @jsii.member(jsii_name="viewModeInput")
    def view_mode_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "viewModeInput"))

    @builtins.property
    @jsii.member(jsii_name="viewTypeInput")
    def view_type_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "viewTypeInput"))

    @builtins.property
    @jsii.member(jsii_name="additionalQueryFilters")
    def additional_query_filters(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "additionalQueryFilters"))

    @additional_query_filters.setter
    def additional_query_filters(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__428aee7f92556a3dca09ae71d76633a87e7c1451fd66217e403b0f602999c646)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "additionalQueryFilters", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="globalTimeTarget")
    def global_time_target(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "globalTimeTarget"))

    @global_time_target.setter
    def global_time_target(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__705b9be5064777482e856a8dd5e62db3b820df8bfbf55935f2e47ddc6054973d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "globalTimeTarget", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="showErrorBudget")
    def show_error_budget(
        self,
    ) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "showErrorBudget"))

    @show_error_budget.setter
    def show_error_budget(
        self,
        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__10e0d2d815ea6b71645960c0bb53817e0cdc67eb30311a00cb1edd9fca1e7e4a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "showErrorBudget", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="sloId")
    def slo_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "sloId"))

    @slo_id.setter
    def slo_id(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__21a61c174ba098798a9f4be7e1dc5afabda5f2a7aef1f2bbd841209e8699c3bf)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "sloId", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="timeWindows")
    def time_windows(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "timeWindows"))

    @time_windows.setter
    def time_windows(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__38ba764fd2495be21e14938ada7862dd0a1203163357cf416bcc5cb75b0e070c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "timeWindows", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="title")
    def title(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "title"))

    @title.setter
    def title(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__30c3741c4530afce3433c67a1733340b6cc8be25596a673aea946633468d196a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "title", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="titleAlign")
    def title_align(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "titleAlign"))

    @title_align.setter
    def title_align(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2f7b454156aeaa1007cbe7bc8796108a568cef3b8de0b1f9c79b88faf838905f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "titleAlign", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="titleSize")
    def title_size(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "titleSize"))

    @title_size.setter
    def title_size(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3514a380d80dbe89ce493ab17589a2865dc646300c731ba8434b707e875f5557)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "titleSize", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="viewMode")
    def view_mode(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "viewMode"))

    @view_mode.setter
    def view_mode(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a459b4df00c72bb3b22a403b7339cc8c25e669915b5bebfbca6e84e1d3f3a88d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "viewMode", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="viewType")
    def view_type(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "viewType"))

    @view_type.setter
    def view_type(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2fadf9488665b8dd3c5bb5d26eb5f5b1cb3a18ecf77acdfd7c3ac0231e06b7c0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "viewType", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetServiceLevelObjectiveDefinition]:
        return typing.cast(typing.Optional[PowerpackWidgetServiceLevelObjectiveDefinition], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetServiceLevelObjectiveDefinition],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e51edd2518ee4dcd0e0ef214e886b30d7f2a64e3667c85fa54cdb26eeaaef325)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetServicemapDefinition",
    jsii_struct_bases=[],
    name_mapping={
        "filters": "filters",
        "service": "service",
        "custom_link": "customLink",
        "title": "title",
        "title_align": "titleAlign",
        "title_size": "titleSize",
    },
)
class PowerpackWidgetServicemapDefinition:
    def __init__(
        self,
        *,
        filters: typing.Sequence[builtins.str],
        service: builtins.str,
        custom_link: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetServicemapDefinitionCustomLink", typing.Dict[builtins.str, typing.Any]]]]] = None,
        title: typing.Optional[builtins.str] = None,
        title_align: typing.Optional[builtins.str] = None,
        title_size: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param filters: Your environment and primary tag (or ``*`` if enabled for your account). Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#filters Powerpack#filters}
        :param service: The ID of the service to map. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#service Powerpack#service}
        :param custom_link: custom_link block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom_link Powerpack#custom_link}
        :param title: The title of the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title Powerpack#title}
        :param title_align: The alignment of the widget's title. Valid values are ``center``, ``left``, ``right``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_align Powerpack#title_align}
        :param title_size: The size of the widget's title (defaults to 16). Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_size Powerpack#title_size}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__075b143164fe2f8ef7a1aef3e096d6d892726d512afb6d8daf512bd764003a11)
            check_type(argname="argument filters", value=filters, expected_type=type_hints["filters"])
            check_type(argname="argument service", value=service, expected_type=type_hints["service"])
            check_type(argname="argument custom_link", value=custom_link, expected_type=type_hints["custom_link"])
            check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            check_type(argname="argument title_align", value=title_align, expected_type=type_hints["title_align"])
            check_type(argname="argument title_size", value=title_size, expected_type=type_hints["title_size"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "filters": filters,
            "service": service,
        }
        if custom_link is not None:
            self._values["custom_link"] = custom_link
        if title is not None:
            self._values["title"] = title
        if title_align is not None:
            self._values["title_align"] = title_align
        if title_size is not None:
            self._values["title_size"] = title_size

    @builtins.property
    def filters(self) -> typing.List[builtins.str]:
        '''Your environment and primary tag (or ``*`` if enabled for your account).

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#filters Powerpack#filters}
        '''
        result = self._values.get("filters")
        assert result is not None, "Required property 'filters' is missing"
        return typing.cast(typing.List[builtins.str], result)

    @builtins.property
    def service(self) -> builtins.str:
        '''The ID of the service to map.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#service Powerpack#service}
        '''
        result = self._values.get("service")
        assert result is not None, "Required property 'service' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def custom_link(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetServicemapDefinitionCustomLink"]]]:
        '''custom_link block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom_link Powerpack#custom_link}
        '''
        result = self._values.get("custom_link")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetServicemapDefinitionCustomLink"]]], result)

    @builtins.property
    def title(self) -> typing.Optional[builtins.str]:
        '''The title of the widget.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title Powerpack#title}
        '''
        result = self._values.get("title")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def title_align(self) -> typing.Optional[builtins.str]:
        '''The alignment of the widget's title. Valid values are ``center``, ``left``, ``right``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_align Powerpack#title_align}
        '''
        result = self._values.get("title_align")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def title_size(self) -> typing.Optional[builtins.str]:
        '''The size of the widget's title (defaults to 16).

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_size Powerpack#title_size}
        '''
        result = self._values.get("title_size")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetServicemapDefinition(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetServicemapDefinitionCustomLink",
    jsii_struct_bases=[],
    name_mapping={
        "is_hidden": "isHidden",
        "label": "label",
        "link": "link",
        "override_label": "overrideLabel",
    },
)
class PowerpackWidgetServicemapDefinitionCustomLink:
    def __init__(
        self,
        *,
        is_hidden: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        label: typing.Optional[builtins.str] = None,
        link: typing.Optional[builtins.str] = None,
        override_label: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param is_hidden: The flag for toggling context menu link visibility. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#is_hidden Powerpack#is_hidden}
        :param label: The label for the custom link URL. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#label Powerpack#label}
        :param link: The URL of the custom link. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#link Powerpack#link}
        :param override_label: The label ID that refers to a context menu link item. When ``override_label`` is provided, the client request omits the label field. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#override_label Powerpack#override_label}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7022f50b8b93445f2580066eb16de0f285eaf390b98086e90275a2a953862b03)
            check_type(argname="argument is_hidden", value=is_hidden, expected_type=type_hints["is_hidden"])
            check_type(argname="argument label", value=label, expected_type=type_hints["label"])
            check_type(argname="argument link", value=link, expected_type=type_hints["link"])
            check_type(argname="argument override_label", value=override_label, expected_type=type_hints["override_label"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if is_hidden is not None:
            self._values["is_hidden"] = is_hidden
        if label is not None:
            self._values["label"] = label
        if link is not None:
            self._values["link"] = link
        if override_label is not None:
            self._values["override_label"] = override_label

    @builtins.property
    def is_hidden(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        '''The flag for toggling context menu link visibility.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#is_hidden Powerpack#is_hidden}
        '''
        result = self._values.get("is_hidden")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)

    @builtins.property
    def label(self) -> typing.Optional[builtins.str]:
        '''The label for the custom link URL.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#label Powerpack#label}
        '''
        result = self._values.get("label")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def link(self) -> typing.Optional[builtins.str]:
        '''The URL of the custom link.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#link Powerpack#link}
        '''
        result = self._values.get("link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def override_label(self) -> typing.Optional[builtins.str]:
        '''The label ID that refers to a context menu link item.

        When ``override_label`` is provided, the client request omits the label field.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#override_label Powerpack#override_label}
        '''
        result = self._values.get("override_label")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetServicemapDefinitionCustomLink(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetServicemapDefinitionCustomLinkList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetServicemapDefinitionCustomLinkList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a4f533ec410d3dc721084fa8fded47047641902f4cacbd11d73e42e5a302774b)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetServicemapDefinitionCustomLinkOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__42e0b122e0900dbdc982ce79f61e3a17e19cddfdc17c04bd1a9f07b27ca63cad)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetServicemapDefinitionCustomLinkOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1384159e1b5c26981d2288a93e5fdb191e489a76c8f3591e826f53678d0e1d43)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4a29954ffcb6892e016597cf5928c209f1919fb3248b99fb669ab78175999468)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8b84d4d142464e059676dd1ad8cb2eac31e8335b4caab449a0a69afa37755116)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetServicemapDefinitionCustomLink]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetServicemapDefinitionCustomLink]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetServicemapDefinitionCustomLink]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2698d6333c22c087d98a5f9ca6d03e1f4ec7913cb7dc94dade88d866bd9b5415)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetServicemapDefinitionCustomLinkOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetServicemapDefinitionCustomLinkOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6409a13af1f3a8e13233cfb7cd2ff77ff2ae0e1d4194b45acc350f9a5f1ec701)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetIsHidden")
    def reset_is_hidden(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetIsHidden", []))

    @jsii.member(jsii_name="resetLabel")
    def reset_label(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLabel", []))

    @jsii.member(jsii_name="resetLink")
    def reset_link(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLink", []))

    @jsii.member(jsii_name="resetOverrideLabel")
    def reset_override_label(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetOverrideLabel", []))

    @builtins.property
    @jsii.member(jsii_name="isHiddenInput")
    def is_hidden_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "isHiddenInput"))

    @builtins.property
    @jsii.member(jsii_name="labelInput")
    def label_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "labelInput"))

    @builtins.property
    @jsii.member(jsii_name="linkInput")
    def link_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "linkInput"))

    @builtins.property
    @jsii.member(jsii_name="overrideLabelInput")
    def override_label_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "overrideLabelInput"))

    @builtins.property
    @jsii.member(jsii_name="isHidden")
    def is_hidden(self) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "isHidden"))

    @is_hidden.setter
    def is_hidden(
        self,
        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d33c95421e8e6e799ced40a9471db0e2796bf69e1c12aea0aeb01594e8c0f40b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "isHidden", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="label")
    def label(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "label"))

    @label.setter
    def label(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9c01ab462d4e18b66e129a8fd08c9911f5fbbb69d6b4e4cbe1c768797369255b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "label", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="link")
    def link(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "link"))

    @link.setter
    def link(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__03c89b97dc9b6cabfae132978226a404dbc78eb715be0efaea03f02d66c1d40d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "link", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="overrideLabel")
    def override_label(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "overrideLabel"))

    @override_label.setter
    def override_label(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9ab854789f796b685cf8d61bde74befe1185651632e0da46fe182b31f1f965e7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "overrideLabel", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetServicemapDefinitionCustomLink]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetServicemapDefinitionCustomLink]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetServicemapDefinitionCustomLink]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e0c0de7b6d4a01fbf9d1450bd25598a80d652e0d09c51c90bbdb9d4fcb28959d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetServicemapDefinitionOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetServicemapDefinitionOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__654d5dd425e56e980b1153435561e20f2a3fa45acc55d8f73ba29040e73be43e)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putCustomLink")
    def put_custom_link(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetServicemapDefinitionCustomLink, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__954514cc0d1d6cd16fd94a8e8f0e464e297a34547cc05a042b5accaad657b102)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putCustomLink", [value]))

    @jsii.member(jsii_name="resetCustomLink")
    def reset_custom_link(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCustomLink", []))

    @jsii.member(jsii_name="resetTitle")
    def reset_title(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTitle", []))

    @jsii.member(jsii_name="resetTitleAlign")
    def reset_title_align(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTitleAlign", []))

    @jsii.member(jsii_name="resetTitleSize")
    def reset_title_size(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTitleSize", []))

    @builtins.property
    @jsii.member(jsii_name="customLink")
    def custom_link(self) -> PowerpackWidgetServicemapDefinitionCustomLinkList:
        return typing.cast(PowerpackWidgetServicemapDefinitionCustomLinkList, jsii.get(self, "customLink"))

    @builtins.property
    @jsii.member(jsii_name="customLinkInput")
    def custom_link_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetServicemapDefinitionCustomLink]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetServicemapDefinitionCustomLink]]], jsii.get(self, "customLinkInput"))

    @builtins.property
    @jsii.member(jsii_name="filtersInput")
    def filters_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "filtersInput"))

    @builtins.property
    @jsii.member(jsii_name="serviceInput")
    def service_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "serviceInput"))

    @builtins.property
    @jsii.member(jsii_name="titleAlignInput")
    def title_align_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "titleAlignInput"))

    @builtins.property
    @jsii.member(jsii_name="titleInput")
    def title_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "titleInput"))

    @builtins.property
    @jsii.member(jsii_name="titleSizeInput")
    def title_size_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "titleSizeInput"))

    @builtins.property
    @jsii.member(jsii_name="filters")
    def filters(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "filters"))

    @filters.setter
    def filters(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4477ddc3309aa6fde553ab6d532e81afb45b4cacc1f14644b59c2649497b15fb)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "filters", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="service")
    def service(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "service"))

    @service.setter
    def service(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0b7c430d3bd34a4b55e1de16563852417c40eb08a8467f017e04a307053b2f8c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "service", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="title")
    def title(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "title"))

    @title.setter
    def title(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e50bf2aef9d932595c143f1d9cd6cde05fb5a72918717ec2f72cd8c422a6838b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "title", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="titleAlign")
    def title_align(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "titleAlign"))

    @title_align.setter
    def title_align(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0c6bd5172ab4083d01df4738faa1ba6713bc63a6deedec4f2b4cb47bad90be60)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "titleAlign", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="titleSize")
    def title_size(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "titleSize"))

    @title_size.setter
    def title_size(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3b4b6f7f723c378b661f949786d1139b9ee446402a8af59b0c2ddce53fbff51e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "titleSize", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[PowerpackWidgetServicemapDefinition]:
        return typing.cast(typing.Optional[PowerpackWidgetServicemapDefinition], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetServicemapDefinition],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__65e915321c1ad8d0015873cd287e08b5741192f82d192074ed6ae56d9ce39942)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSloListDefinition",
    jsii_struct_bases=[],
    name_mapping={
        "request": "request",
        "title": "title",
        "title_align": "titleAlign",
        "title_size": "titleSize",
    },
)
class PowerpackWidgetSloListDefinition:
    def __init__(
        self,
        *,
        request: typing.Union["PowerpackWidgetSloListDefinitionRequest", typing.Dict[builtins.str, typing.Any]],
        title: typing.Optional[builtins.str] = None,
        title_align: typing.Optional[builtins.str] = None,
        title_size: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param request: request block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#request Powerpack#request}
        :param title: The title of the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title Powerpack#title}
        :param title_align: The alignment of the widget's title. Valid values are ``center``, ``left``, ``right``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_align Powerpack#title_align}
        :param title_size: The size of the widget's title (defaults to 16). Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_size Powerpack#title_size}
        '''
        if isinstance(request, dict):
            request = PowerpackWidgetSloListDefinitionRequest(**request)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4ad6d4aa7e87858913530061a320d8c4597ddc4f59ca0283289803d28e8706b0)
            check_type(argname="argument request", value=request, expected_type=type_hints["request"])
            check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            check_type(argname="argument title_align", value=title_align, expected_type=type_hints["title_align"])
            check_type(argname="argument title_size", value=title_size, expected_type=type_hints["title_size"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "request": request,
        }
        if title is not None:
            self._values["title"] = title
        if title_align is not None:
            self._values["title_align"] = title_align
        if title_size is not None:
            self._values["title_size"] = title_size

    @builtins.property
    def request(self) -> "PowerpackWidgetSloListDefinitionRequest":
        '''request block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#request Powerpack#request}
        '''
        result = self._values.get("request")
        assert result is not None, "Required property 'request' is missing"
        return typing.cast("PowerpackWidgetSloListDefinitionRequest", result)

    @builtins.property
    def title(self) -> typing.Optional[builtins.str]:
        '''The title of the widget.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title Powerpack#title}
        '''
        result = self._values.get("title")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def title_align(self) -> typing.Optional[builtins.str]:
        '''The alignment of the widget's title. Valid values are ``center``, ``left``, ``right``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_align Powerpack#title_align}
        '''
        result = self._values.get("title_align")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def title_size(self) -> typing.Optional[builtins.str]:
        '''The size of the widget's title (defaults to 16).

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_size Powerpack#title_size}
        '''
        result = self._values.get("title_size")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetSloListDefinition(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetSloListDefinitionOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSloListDefinitionOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c2f852b1aa8fad1dfc340c29833c0ec8650545b013ddc2e04f6f23e837794dd6)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putRequest")
    def put_request(
        self,
        *,
        query: typing.Union["PowerpackWidgetSloListDefinitionRequestQuery", typing.Dict[builtins.str, typing.Any]],
        request_type: builtins.str,
    ) -> None:
        '''
        :param query: query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        :param request_type: The request type for the SLO List request. Valid values are ``slo_list``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#request_type Powerpack#request_type}
        '''
        value = PowerpackWidgetSloListDefinitionRequest(
            query=query, request_type=request_type
        )

        return typing.cast(None, jsii.invoke(self, "putRequest", [value]))

    @jsii.member(jsii_name="resetTitle")
    def reset_title(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTitle", []))

    @jsii.member(jsii_name="resetTitleAlign")
    def reset_title_align(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTitleAlign", []))

    @jsii.member(jsii_name="resetTitleSize")
    def reset_title_size(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTitleSize", []))

    @builtins.property
    @jsii.member(jsii_name="request")
    def request(self) -> "PowerpackWidgetSloListDefinitionRequestOutputReference":
        return typing.cast("PowerpackWidgetSloListDefinitionRequestOutputReference", jsii.get(self, "request"))

    @builtins.property
    @jsii.member(jsii_name="requestInput")
    def request_input(
        self,
    ) -> typing.Optional["PowerpackWidgetSloListDefinitionRequest"]:
        return typing.cast(typing.Optional["PowerpackWidgetSloListDefinitionRequest"], jsii.get(self, "requestInput"))

    @builtins.property
    @jsii.member(jsii_name="titleAlignInput")
    def title_align_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "titleAlignInput"))

    @builtins.property
    @jsii.member(jsii_name="titleInput")
    def title_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "titleInput"))

    @builtins.property
    @jsii.member(jsii_name="titleSizeInput")
    def title_size_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "titleSizeInput"))

    @builtins.property
    @jsii.member(jsii_name="title")
    def title(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "title"))

    @title.setter
    def title(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__89c19dce651449f771a4273e7f38de3bd69bfdd7fa08f50f1d485de7bfc2943b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "title", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="titleAlign")
    def title_align(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "titleAlign"))

    @title_align.setter
    def title_align(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d669ceefe987b5659ec0f9722cee6ba9a3c4e5b2cbbce3b6df0f17b90314f844)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "titleAlign", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="titleSize")
    def title_size(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "titleSize"))

    @title_size.setter
    def title_size(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ef1ffdf68e40f46ef2c85e95ca580ed4e6af1e3de08117aa6bf3f2beae02aac8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "titleSize", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[PowerpackWidgetSloListDefinition]:
        return typing.cast(typing.Optional[PowerpackWidgetSloListDefinition], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetSloListDefinition],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1d382b7b2b2dbcdc65e3dadb9a605c2f21ad76eed0c61ade46a606da278c0f76)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSloListDefinitionRequest",
    jsii_struct_bases=[],
    name_mapping={"query": "query", "request_type": "requestType"},
)
class PowerpackWidgetSloListDefinitionRequest:
    def __init__(
        self,
        *,
        query: typing.Union["PowerpackWidgetSloListDefinitionRequestQuery", typing.Dict[builtins.str, typing.Any]],
        request_type: builtins.str,
    ) -> None:
        '''
        :param query: query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        :param request_type: The request type for the SLO List request. Valid values are ``slo_list``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#request_type Powerpack#request_type}
        '''
        if isinstance(query, dict):
            query = PowerpackWidgetSloListDefinitionRequestQuery(**query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8891b1c792a8f6740a399ed86ae1f7cd99ee6b8056071309f162dc6bb6e434a0)
            check_type(argname="argument query", value=query, expected_type=type_hints["query"])
            check_type(argname="argument request_type", value=request_type, expected_type=type_hints["request_type"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "query": query,
            "request_type": request_type,
        }

    @builtins.property
    def query(self) -> "PowerpackWidgetSloListDefinitionRequestQuery":
        '''query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        '''
        result = self._values.get("query")
        assert result is not None, "Required property 'query' is missing"
        return typing.cast("PowerpackWidgetSloListDefinitionRequestQuery", result)

    @builtins.property
    def request_type(self) -> builtins.str:
        '''The request type for the SLO List request. Valid values are ``slo_list``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#request_type Powerpack#request_type}
        '''
        result = self._values.get("request_type")
        assert result is not None, "Required property 'request_type' is missing"
        return typing.cast(builtins.str, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetSloListDefinitionRequest(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetSloListDefinitionRequestOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSloListDefinitionRequestOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f1468e188a39e7938c562bb5c579f98a44dd48eade55cfac307e1ad67498facf)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putQuery")
    def put_query(
        self,
        *,
        query_string: builtins.str,
        limit: typing.Optional[jsii.Number] = None,
        sort: typing.Optional[typing.Union["PowerpackWidgetSloListDefinitionRequestQuerySort", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param query_string: Widget query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query_string Powerpack#query_string}
        :param limit: Maximum number of results to display in the table. Defaults to ``100``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param sort: sort block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort Powerpack#sort}
        '''
        value = PowerpackWidgetSloListDefinitionRequestQuery(
            query_string=query_string, limit=limit, sort=sort
        )

        return typing.cast(None, jsii.invoke(self, "putQuery", [value]))

    @builtins.property
    @jsii.member(jsii_name="query")
    def query(self) -> "PowerpackWidgetSloListDefinitionRequestQueryOutputReference":
        return typing.cast("PowerpackWidgetSloListDefinitionRequestQueryOutputReference", jsii.get(self, "query"))

    @builtins.property
    @jsii.member(jsii_name="queryInput")
    def query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetSloListDefinitionRequestQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetSloListDefinitionRequestQuery"], jsii.get(self, "queryInput"))

    @builtins.property
    @jsii.member(jsii_name="requestTypeInput")
    def request_type_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "requestTypeInput"))

    @builtins.property
    @jsii.member(jsii_name="requestType")
    def request_type(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "requestType"))

    @request_type.setter
    def request_type(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__132b16c1e23198a5d63ede30bd319b6b1801e9ac780c0ca297604de037f0506a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "requestType", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetSloListDefinitionRequest]:
        return typing.cast(typing.Optional[PowerpackWidgetSloListDefinitionRequest], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetSloListDefinitionRequest],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fd01bd3c5a1302c1d606a208feb4e2776b9176a0bc4fb32d57254afdb0dbf373)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSloListDefinitionRequestQuery",
    jsii_struct_bases=[],
    name_mapping={"query_string": "queryString", "limit": "limit", "sort": "sort"},
)
class PowerpackWidgetSloListDefinitionRequestQuery:
    def __init__(
        self,
        *,
        query_string: builtins.str,
        limit: typing.Optional[jsii.Number] = None,
        sort: typing.Optional[typing.Union["PowerpackWidgetSloListDefinitionRequestQuerySort", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param query_string: Widget query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query_string Powerpack#query_string}
        :param limit: Maximum number of results to display in the table. Defaults to ``100``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param sort: sort block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort Powerpack#sort}
        '''
        if isinstance(sort, dict):
            sort = PowerpackWidgetSloListDefinitionRequestQuerySort(**sort)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__96b05562519cb993b0e520be9e943ad666ed132aed45b0afaad29d873fc2af57)
            check_type(argname="argument query_string", value=query_string, expected_type=type_hints["query_string"])
            check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
            check_type(argname="argument sort", value=sort, expected_type=type_hints["sort"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "query_string": query_string,
        }
        if limit is not None:
            self._values["limit"] = limit
        if sort is not None:
            self._values["sort"] = sort

    @builtins.property
    def query_string(self) -> builtins.str:
        '''Widget query.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query_string Powerpack#query_string}
        '''
        result = self._values.get("query_string")
        assert result is not None, "Required property 'query_string' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def limit(self) -> typing.Optional[jsii.Number]:
        '''Maximum number of results to display in the table. Defaults to ``100``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        '''
        result = self._values.get("limit")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def sort(
        self,
    ) -> typing.Optional["PowerpackWidgetSloListDefinitionRequestQuerySort"]:
        '''sort block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort Powerpack#sort}
        '''
        result = self._values.get("sort")
        return typing.cast(typing.Optional["PowerpackWidgetSloListDefinitionRequestQuerySort"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetSloListDefinitionRequestQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetSloListDefinitionRequestQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSloListDefinitionRequestQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__694b4606cb246a04b9d9ed1097c44197a182c00491f25fd291ebb772ff7b1ce6)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putSort")
    def put_sort(self, *, column: builtins.str, order: builtins.str) -> None:
        '''
        :param column: The facet path for the column. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#column Powerpack#column}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        value = PowerpackWidgetSloListDefinitionRequestQuerySort(
            column=column, order=order
        )

        return typing.cast(None, jsii.invoke(self, "putSort", [value]))

    @jsii.member(jsii_name="resetLimit")
    def reset_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLimit", []))

    @jsii.member(jsii_name="resetSort")
    def reset_sort(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSort", []))

    @builtins.property
    @jsii.member(jsii_name="sort")
    def sort(self) -> "PowerpackWidgetSloListDefinitionRequestQuerySortOutputReference":
        return typing.cast("PowerpackWidgetSloListDefinitionRequestQuerySortOutputReference", jsii.get(self, "sort"))

    @builtins.property
    @jsii.member(jsii_name="limitInput")
    def limit_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "limitInput"))

    @builtins.property
    @jsii.member(jsii_name="queryStringInput")
    def query_string_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "queryStringInput"))

    @builtins.property
    @jsii.member(jsii_name="sortInput")
    def sort_input(
        self,
    ) -> typing.Optional["PowerpackWidgetSloListDefinitionRequestQuerySort"]:
        return typing.cast(typing.Optional["PowerpackWidgetSloListDefinitionRequestQuerySort"], jsii.get(self, "sortInput"))

    @builtins.property
    @jsii.member(jsii_name="limit")
    def limit(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "limit"))

    @limit.setter
    def limit(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__520b542aecd40063ce3d38a0424a39858b415190d2193288f0a072880b8b339e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "limit", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="queryString")
    def query_string(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "queryString"))

    @query_string.setter
    def query_string(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c179e279d677dcfce5559532032ab845722c442b77d7fec10e0d447d587bf19e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "queryString", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetSloListDefinitionRequestQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetSloListDefinitionRequestQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetSloListDefinitionRequestQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1cf5a7333de3ff886efd16393d5cec5ab3d56ac98c8723401039a5360dc91004)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSloListDefinitionRequestQuerySort",
    jsii_struct_bases=[],
    name_mapping={"column": "column", "order": "order"},
)
class PowerpackWidgetSloListDefinitionRequestQuerySort:
    def __init__(self, *, column: builtins.str, order: builtins.str) -> None:
        '''
        :param column: The facet path for the column. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#column Powerpack#column}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__58fd60ceb1a0675117a2f7cff3eebb7857a9ca7c67e819eb3d48d8d06955f501)
            check_type(argname="argument column", value=column, expected_type=type_hints["column"])
            check_type(argname="argument order", value=order, expected_type=type_hints["order"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "column": column,
            "order": order,
        }

    @builtins.property
    def column(self) -> builtins.str:
        '''The facet path for the column.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#column Powerpack#column}
        '''
        result = self._values.get("column")
        assert result is not None, "Required property 'column' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def order(self) -> builtins.str:
        '''Widget sorting methods. Valid values are ``asc``, ``desc``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        result = self._values.get("order")
        assert result is not None, "Required property 'order' is missing"
        return typing.cast(builtins.str, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetSloListDefinitionRequestQuerySort(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetSloListDefinitionRequestQuerySortOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSloListDefinitionRequestQuerySortOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b8ecf70ba5973312c55e910c80441dac18c2d38fa3eadf004187d04cc0afed97)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @builtins.property
    @jsii.member(jsii_name="columnInput")
    def column_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "columnInput"))

    @builtins.property
    @jsii.member(jsii_name="orderInput")
    def order_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "orderInput"))

    @builtins.property
    @jsii.member(jsii_name="column")
    def column(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "column"))

    @column.setter
    def column(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__98bba7c7b9242ba65290b29cc6651a350fe1ae0f145f991f37758f4e8e1de5cf)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "column", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="order")
    def order(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "order"))

    @order.setter
    def order(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__62f1ce3986dadbe0696e1b1df5076c25953e9ee3050be372a68c31f05f8f5ab8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "order", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetSloListDefinitionRequestQuerySort]:
        return typing.cast(typing.Optional[PowerpackWidgetSloListDefinitionRequestQuerySort], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetSloListDefinitionRequestQuerySort],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a1b3d5a85f9c2ee17068c70cabb6d97a445a4bf528489a7a87a019559a5f21ae)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinition",
    jsii_struct_bases=[],
    name_mapping={
        "custom_link": "customLink",
        "hide_total": "hideTotal",
        "legend_inline": "legendInline",
        "legend_table": "legendTable",
        "live_span": "liveSpan",
        "request": "request",
        "title": "title",
        "title_align": "titleAlign",
        "title_size": "titleSize",
    },
)
class PowerpackWidgetSunburstDefinition:
    def __init__(
        self,
        *,
        custom_link: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetSunburstDefinitionCustomLink", typing.Dict[builtins.str, typing.Any]]]]] = None,
        hide_total: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        legend_inline: typing.Optional[typing.Union["PowerpackWidgetSunburstDefinitionLegendInline", typing.Dict[builtins.str, typing.Any]]] = None,
        legend_table: typing.Optional[typing.Union["PowerpackWidgetSunburstDefinitionLegendTable", typing.Dict[builtins.str, typing.Any]]] = None,
        live_span: typing.Optional[builtins.str] = None,
        request: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetSunburstDefinitionRequest", typing.Dict[builtins.str, typing.Any]]]]] = None,
        title: typing.Optional[builtins.str] = None,
        title_align: typing.Optional[builtins.str] = None,
        title_size: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param custom_link: custom_link block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom_link Powerpack#custom_link}
        :param hide_total: Whether or not to show the total value in the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#hide_total Powerpack#hide_total}
        :param legend_inline: legend_inline block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#legend_inline Powerpack#legend_inline}
        :param legend_table: legend_table block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#legend_table Powerpack#legend_table}
        :param live_span: The timeframe to use when displaying the widget. Valid values are ``1m``, ``5m``, ``10m``, ``15m``, ``30m``, ``1h``, ``4h``, ``1d``, ``2d``, ``1w``, ``1mo``, ``3mo``, ``6mo``, ``week_to_date``, ``month_to_date``, ``1y``, ``alert``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#live_span Powerpack#live_span}
        :param request: request block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#request Powerpack#request}
        :param title: The title of the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title Powerpack#title}
        :param title_align: The alignment of the widget's title. One of ``left``, ``center``, or ``right``. Valid values are ``center``, ``left``, ``right``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_align Powerpack#title_align}
        :param title_size: The size of the widget's title. Default is 16. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_size Powerpack#title_size}
        '''
        if isinstance(legend_inline, dict):
            legend_inline = PowerpackWidgetSunburstDefinitionLegendInline(**legend_inline)
        if isinstance(legend_table, dict):
            legend_table = PowerpackWidgetSunburstDefinitionLegendTable(**legend_table)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0958c8551643bbd19235d6a777918af400d7a30ff57cb18eff21b24445d88179)
            check_type(argname="argument custom_link", value=custom_link, expected_type=type_hints["custom_link"])
            check_type(argname="argument hide_total", value=hide_total, expected_type=type_hints["hide_total"])
            check_type(argname="argument legend_inline", value=legend_inline, expected_type=type_hints["legend_inline"])
            check_type(argname="argument legend_table", value=legend_table, expected_type=type_hints["legend_table"])
            check_type(argname="argument live_span", value=live_span, expected_type=type_hints["live_span"])
            check_type(argname="argument request", value=request, expected_type=type_hints["request"])
            check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            check_type(argname="argument title_align", value=title_align, expected_type=type_hints["title_align"])
            check_type(argname="argument title_size", value=title_size, expected_type=type_hints["title_size"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if custom_link is not None:
            self._values["custom_link"] = custom_link
        if hide_total is not None:
            self._values["hide_total"] = hide_total
        if legend_inline is not None:
            self._values["legend_inline"] = legend_inline
        if legend_table is not None:
            self._values["legend_table"] = legend_table
        if live_span is not None:
            self._values["live_span"] = live_span
        if request is not None:
            self._values["request"] = request
        if title is not None:
            self._values["title"] = title
        if title_align is not None:
            self._values["title_align"] = title_align
        if title_size is not None:
            self._values["title_size"] = title_size

    @builtins.property
    def custom_link(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetSunburstDefinitionCustomLink"]]]:
        '''custom_link block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom_link Powerpack#custom_link}
        '''
        result = self._values.get("custom_link")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetSunburstDefinitionCustomLink"]]], result)

    @builtins.property
    def hide_total(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        '''Whether or not to show the total value in the widget.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#hide_total Powerpack#hide_total}
        '''
        result = self._values.get("hide_total")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)

    @builtins.property
    def legend_inline(
        self,
    ) -> typing.Optional["PowerpackWidgetSunburstDefinitionLegendInline"]:
        '''legend_inline block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#legend_inline Powerpack#legend_inline}
        '''
        result = self._values.get("legend_inline")
        return typing.cast(typing.Optional["PowerpackWidgetSunburstDefinitionLegendInline"], result)

    @builtins.property
    def legend_table(
        self,
    ) -> typing.Optional["PowerpackWidgetSunburstDefinitionLegendTable"]:
        '''legend_table block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#legend_table Powerpack#legend_table}
        '''
        result = self._values.get("legend_table")
        return typing.cast(typing.Optional["PowerpackWidgetSunburstDefinitionLegendTable"], result)

    @builtins.property
    def live_span(self) -> typing.Optional[builtins.str]:
        '''The timeframe to use when displaying the widget.

        Valid values are ``1m``, ``5m``, ``10m``, ``15m``, ``30m``, ``1h``, ``4h``, ``1d``, ``2d``, ``1w``, ``1mo``, ``3mo``, ``6mo``, ``week_to_date``, ``month_to_date``, ``1y``, ``alert``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#live_span Powerpack#live_span}
        '''
        result = self._values.get("live_span")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def request(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetSunburstDefinitionRequest"]]]:
        '''request block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#request Powerpack#request}
        '''
        result = self._values.get("request")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetSunburstDefinitionRequest"]]], result)

    @builtins.property
    def title(self) -> typing.Optional[builtins.str]:
        '''The title of the widget.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title Powerpack#title}
        '''
        result = self._values.get("title")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def title_align(self) -> typing.Optional[builtins.str]:
        '''The alignment of the widget's title. One of ``left``, ``center``, or ``right``. Valid values are ``center``, ``left``, ``right``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_align Powerpack#title_align}
        '''
        result = self._values.get("title_align")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def title_size(self) -> typing.Optional[builtins.str]:
        '''The size of the widget's title. Default is 16.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_size Powerpack#title_size}
        '''
        result = self._values.get("title_size")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetSunburstDefinition(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionCustomLink",
    jsii_struct_bases=[],
    name_mapping={
        "is_hidden": "isHidden",
        "label": "label",
        "link": "link",
        "override_label": "overrideLabel",
    },
)
class PowerpackWidgetSunburstDefinitionCustomLink:
    def __init__(
        self,
        *,
        is_hidden: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        label: typing.Optional[builtins.str] = None,
        link: typing.Optional[builtins.str] = None,
        override_label: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param is_hidden: The flag for toggling context menu link visibility. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#is_hidden Powerpack#is_hidden}
        :param label: The label for the custom link URL. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#label Powerpack#label}
        :param link: The URL of the custom link. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#link Powerpack#link}
        :param override_label: The label ID that refers to a context menu link item. When ``override_label`` is provided, the client request omits the label field. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#override_label Powerpack#override_label}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__94c91f8aa14990a005e63523799bf75ec23386dd1098701e20cd83bf4d0e03bd)
            check_type(argname="argument is_hidden", value=is_hidden, expected_type=type_hints["is_hidden"])
            check_type(argname="argument label", value=label, expected_type=type_hints["label"])
            check_type(argname="argument link", value=link, expected_type=type_hints["link"])
            check_type(argname="argument override_label", value=override_label, expected_type=type_hints["override_label"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if is_hidden is not None:
            self._values["is_hidden"] = is_hidden
        if label is not None:
            self._values["label"] = label
        if link is not None:
            self._values["link"] = link
        if override_label is not None:
            self._values["override_label"] = override_label

    @builtins.property
    def is_hidden(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        '''The flag for toggling context menu link visibility.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#is_hidden Powerpack#is_hidden}
        '''
        result = self._values.get("is_hidden")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)

    @builtins.property
    def label(self) -> typing.Optional[builtins.str]:
        '''The label for the custom link URL.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#label Powerpack#label}
        '''
        result = self._values.get("label")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def link(self) -> typing.Optional[builtins.str]:
        '''The URL of the custom link.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#link Powerpack#link}
        '''
        result = self._values.get("link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def override_label(self) -> typing.Optional[builtins.str]:
        '''The label ID that refers to a context menu link item.

        When ``override_label`` is provided, the client request omits the label field.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#override_label Powerpack#override_label}
        '''
        result = self._values.get("override_label")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetSunburstDefinitionCustomLink(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetSunburstDefinitionCustomLinkList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionCustomLinkList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6c75654f4309b293e022e6b528ccbfe1cd63828e6019b3e1e6a857de6fad4e42)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetSunburstDefinitionCustomLinkOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ab15b3506f7f146b6c2fa2f3419ba19cb9ab2872825bcc72b7e8d8f544c8dc2c)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetSunburstDefinitionCustomLinkOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__78343ba251729ee2b1d7a988b6b829f38b34e0ca19bf07e8571e3389d09a34e4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c87fd3f750d4be3746f2f5b37885b66b5410e38eb577ab35b77f335a56034445)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a9cf6d418282433404858e0d90104ecb12151818439c7f338d2a7eb56fd57aa7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionCustomLink]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionCustomLink]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionCustomLink]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__28697c0b5adb963a99379fbc8788df83c6cb7502b935e5729d3fba42f1ab2c39)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetSunburstDefinitionCustomLinkOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionCustomLinkOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d73c83ca7c8f6acb6f6ec7d36376208a142763eed490ac51d041a6a58a1fe570)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetIsHidden")
    def reset_is_hidden(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetIsHidden", []))

    @jsii.member(jsii_name="resetLabel")
    def reset_label(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLabel", []))

    @jsii.member(jsii_name="resetLink")
    def reset_link(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLink", []))

    @jsii.member(jsii_name="resetOverrideLabel")
    def reset_override_label(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetOverrideLabel", []))

    @builtins.property
    @jsii.member(jsii_name="isHiddenInput")
    def is_hidden_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "isHiddenInput"))

    @builtins.property
    @jsii.member(jsii_name="labelInput")
    def label_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "labelInput"))

    @builtins.property
    @jsii.member(jsii_name="linkInput")
    def link_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "linkInput"))

    @builtins.property
    @jsii.member(jsii_name="overrideLabelInput")
    def override_label_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "overrideLabelInput"))

    @builtins.property
    @jsii.member(jsii_name="isHidden")
    def is_hidden(self) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "isHidden"))

    @is_hidden.setter
    def is_hidden(
        self,
        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__38895a862d2b1061e495ca61d7511b6ef74d64a3b1819e6d7728f498b2946fe0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "isHidden", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="label")
    def label(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "label"))

    @label.setter
    def label(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__794d6cdc7768f077e5db5a9f4f0d456f4f4ebbc10339621373c8757e58318f72)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "label", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="link")
    def link(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "link"))

    @link.setter
    def link(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6dfc9a64bd443b7cbe9458b6a3eaa956cb800d94366eaa4acb69c99afd91681a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "link", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="overrideLabel")
    def override_label(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "overrideLabel"))

    @override_label.setter
    def override_label(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__76713a227f48faf8278599eede42cc3c4e4b2ae9be923f40048fea84427d5a00)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "overrideLabel", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetSunburstDefinitionCustomLink]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetSunburstDefinitionCustomLink]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetSunburstDefinitionCustomLink]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a7bf366732a43775cebdcf1221bdb037e7d9180f58771cb02bfbf383ddd7df64)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionLegendInline",
    jsii_struct_bases=[],
    name_mapping={
        "type": "type",
        "hide_percent": "hidePercent",
        "hide_value": "hideValue",
    },
)
class PowerpackWidgetSunburstDefinitionLegendInline:
    def __init__(
        self,
        *,
        type: builtins.str,
        hide_percent: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        hide_value: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
    ) -> None:
        '''
        :param type: The type of legend (inline or automatic). Valid values are ``inline``, ``automatic``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#type Powerpack#type}
        :param hide_percent: Whether to hide the percentages of the groups. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#hide_percent Powerpack#hide_percent}
        :param hide_value: Whether to hide the values of the groups. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#hide_value Powerpack#hide_value}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0c4bd910fc991e671466791fb1612d1fbb85b7c27893382605068c0a883f13b1)
            check_type(argname="argument type", value=type, expected_type=type_hints["type"])
            check_type(argname="argument hide_percent", value=hide_percent, expected_type=type_hints["hide_percent"])
            check_type(argname="argument hide_value", value=hide_value, expected_type=type_hints["hide_value"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "type": type,
        }
        if hide_percent is not None:
            self._values["hide_percent"] = hide_percent
        if hide_value is not None:
            self._values["hide_value"] = hide_value

    @builtins.property
    def type(self) -> builtins.str:
        '''The type of legend (inline or automatic). Valid values are ``inline``, ``automatic``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#type Powerpack#type}
        '''
        result = self._values.get("type")
        assert result is not None, "Required property 'type' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def hide_percent(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        '''Whether to hide the percentages of the groups.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#hide_percent Powerpack#hide_percent}
        '''
        result = self._values.get("hide_percent")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)

    @builtins.property
    def hide_value(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        '''Whether to hide the values of the groups.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#hide_value Powerpack#hide_value}
        '''
        result = self._values.get("hide_value")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetSunburstDefinitionLegendInline(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetSunburstDefinitionLegendInlineOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionLegendInlineOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c834992542725a244c7a990a77360133ee60833026fad92865c1f38715762a86)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetHidePercent")
    def reset_hide_percent(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHidePercent", []))

    @jsii.member(jsii_name="resetHideValue")
    def reset_hide_value(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHideValue", []))

    @builtins.property
    @jsii.member(jsii_name="hidePercentInput")
    def hide_percent_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "hidePercentInput"))

    @builtins.property
    @jsii.member(jsii_name="hideValueInput")
    def hide_value_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "hideValueInput"))

    @builtins.property
    @jsii.member(jsii_name="typeInput")
    def type_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "typeInput"))

    @builtins.property
    @jsii.member(jsii_name="hidePercent")
    def hide_percent(self) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "hidePercent"))

    @hide_percent.setter
    def hide_percent(
        self,
        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8bd3690edfde6d2b625062e301e3e6d70759dd7388750afecf3641eccc226f9d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "hidePercent", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="hideValue")
    def hide_value(self) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "hideValue"))

    @hide_value.setter
    def hide_value(
        self,
        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8fe1f6df917da0913fe52d598a935a112d7b708107c62b83da98d9825a466bb9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "hideValue", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="type")
    def type(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "type"))

    @type.setter
    def type(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__023437540af754f195ed3d14661856ed62a31dd77e458088c3fadd2d40847b84)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "type", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetSunburstDefinitionLegendInline]:
        return typing.cast(typing.Optional[PowerpackWidgetSunburstDefinitionLegendInline], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetSunburstDefinitionLegendInline],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bfc0c8d22cd6fac5dbe4ba8413a2a19e8aafa33562f3a954bf17089586046d43)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionLegendTable",
    jsii_struct_bases=[],
    name_mapping={"type": "type"},
)
class PowerpackWidgetSunburstDefinitionLegendTable:
    def __init__(self, *, type: builtins.str) -> None:
        '''
        :param type: The type of legend (table or none). Valid values are ``table``, ``none``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#type Powerpack#type}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__97146e165b7348fe5ff14c201b4c3b0601c3d16d6efed94f9c5bb445a4a324d0)
            check_type(argname="argument type", value=type, expected_type=type_hints["type"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "type": type,
        }

    @builtins.property
    def type(self) -> builtins.str:
        '''The type of legend (table or none). Valid values are ``table``, ``none``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#type Powerpack#type}
        '''
        result = self._values.get("type")
        assert result is not None, "Required property 'type' is missing"
        return typing.cast(builtins.str, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetSunburstDefinitionLegendTable(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetSunburstDefinitionLegendTableOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionLegendTableOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__353dc719a17d6468605981f44164375d9d5d67d229806b7c45222522b60759a5)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @builtins.property
    @jsii.member(jsii_name="typeInput")
    def type_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "typeInput"))

    @builtins.property
    @jsii.member(jsii_name="type")
    def type(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "type"))

    @type.setter
    def type(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7a1c6c4a50968ea06438a310f23b07e066745db45adc514666f07f6cacc312a3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "type", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetSunburstDefinitionLegendTable]:
        return typing.cast(typing.Optional[PowerpackWidgetSunburstDefinitionLegendTable], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetSunburstDefinitionLegendTable],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1210213cfb3835a0397249a1d6b1cfda077a96c6d806ac2ff4d7f837331044e0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetSunburstDefinitionOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__169d0ca45bc32edad5c8ba141e7d35b0dfc64f2e4e734cf8fb6cc88b708661c6)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putCustomLink")
    def put_custom_link(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetSunburstDefinitionCustomLink, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__28d4d6688a62c9c6e28b3a9ba96d246e7a43ccdcc34930b4a1614983ff906ed3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putCustomLink", [value]))

    @jsii.member(jsii_name="putLegendInline")
    def put_legend_inline(
        self,
        *,
        type: builtins.str,
        hide_percent: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        hide_value: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
    ) -> None:
        '''
        :param type: The type of legend (inline or automatic). Valid values are ``inline``, ``automatic``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#type Powerpack#type}
        :param hide_percent: Whether to hide the percentages of the groups. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#hide_percent Powerpack#hide_percent}
        :param hide_value: Whether to hide the values of the groups. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#hide_value Powerpack#hide_value}
        '''
        value = PowerpackWidgetSunburstDefinitionLegendInline(
            type=type, hide_percent=hide_percent, hide_value=hide_value
        )

        return typing.cast(None, jsii.invoke(self, "putLegendInline", [value]))

    @jsii.member(jsii_name="putLegendTable")
    def put_legend_table(self, *, type: builtins.str) -> None:
        '''
        :param type: The type of legend (table or none). Valid values are ``table``, ``none``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#type Powerpack#type}
        '''
        value = PowerpackWidgetSunburstDefinitionLegendTable(type=type)

        return typing.cast(None, jsii.invoke(self, "putLegendTable", [value]))

    @jsii.member(jsii_name="putRequest")
    def put_request(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetSunburstDefinitionRequest", typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__897f5fd636be1f996318d40b88d1e57aac605235712806a1f9f916759b611850)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putRequest", [value]))

    @jsii.member(jsii_name="resetCustomLink")
    def reset_custom_link(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCustomLink", []))

    @jsii.member(jsii_name="resetHideTotal")
    def reset_hide_total(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHideTotal", []))

    @jsii.member(jsii_name="resetLegendInline")
    def reset_legend_inline(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLegendInline", []))

    @jsii.member(jsii_name="resetLegendTable")
    def reset_legend_table(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLegendTable", []))

    @jsii.member(jsii_name="resetLiveSpan")
    def reset_live_span(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLiveSpan", []))

    @jsii.member(jsii_name="resetRequest")
    def reset_request(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetRequest", []))

    @jsii.member(jsii_name="resetTitle")
    def reset_title(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTitle", []))

    @jsii.member(jsii_name="resetTitleAlign")
    def reset_title_align(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTitleAlign", []))

    @jsii.member(jsii_name="resetTitleSize")
    def reset_title_size(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTitleSize", []))

    @builtins.property
    @jsii.member(jsii_name="customLink")
    def custom_link(self) -> PowerpackWidgetSunburstDefinitionCustomLinkList:
        return typing.cast(PowerpackWidgetSunburstDefinitionCustomLinkList, jsii.get(self, "customLink"))

    @builtins.property
    @jsii.member(jsii_name="legendInline")
    def legend_inline(
        self,
    ) -> PowerpackWidgetSunburstDefinitionLegendInlineOutputReference:
        return typing.cast(PowerpackWidgetSunburstDefinitionLegendInlineOutputReference, jsii.get(self, "legendInline"))

    @builtins.property
    @jsii.member(jsii_name="legendTable")
    def legend_table(
        self,
    ) -> PowerpackWidgetSunburstDefinitionLegendTableOutputReference:
        return typing.cast(PowerpackWidgetSunburstDefinitionLegendTableOutputReference, jsii.get(self, "legendTable"))

    @builtins.property
    @jsii.member(jsii_name="request")
    def request(self) -> "PowerpackWidgetSunburstDefinitionRequestList":
        return typing.cast("PowerpackWidgetSunburstDefinitionRequestList", jsii.get(self, "request"))

    @builtins.property
    @jsii.member(jsii_name="customLinkInput")
    def custom_link_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionCustomLink]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionCustomLink]]], jsii.get(self, "customLinkInput"))

    @builtins.property
    @jsii.member(jsii_name="hideTotalInput")
    def hide_total_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "hideTotalInput"))

    @builtins.property
    @jsii.member(jsii_name="legendInlineInput")
    def legend_inline_input(
        self,
    ) -> typing.Optional[PowerpackWidgetSunburstDefinitionLegendInline]:
        return typing.cast(typing.Optional[PowerpackWidgetSunburstDefinitionLegendInline], jsii.get(self, "legendInlineInput"))

    @builtins.property
    @jsii.member(jsii_name="legendTableInput")
    def legend_table_input(
        self,
    ) -> typing.Optional[PowerpackWidgetSunburstDefinitionLegendTable]:
        return typing.cast(typing.Optional[PowerpackWidgetSunburstDefinitionLegendTable], jsii.get(self, "legendTableInput"))

    @builtins.property
    @jsii.member(jsii_name="liveSpanInput")
    def live_span_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "liveSpanInput"))

    @builtins.property
    @jsii.member(jsii_name="requestInput")
    def request_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetSunburstDefinitionRequest"]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetSunburstDefinitionRequest"]]], jsii.get(self, "requestInput"))

    @builtins.property
    @jsii.member(jsii_name="titleAlignInput")
    def title_align_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "titleAlignInput"))

    @builtins.property
    @jsii.member(jsii_name="titleInput")
    def title_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "titleInput"))

    @builtins.property
    @jsii.member(jsii_name="titleSizeInput")
    def title_size_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "titleSizeInput"))

    @builtins.property
    @jsii.member(jsii_name="hideTotal")
    def hide_total(self) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "hideTotal"))

    @hide_total.setter
    def hide_total(
        self,
        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8be8ff4e1b4a15b9b5fdb96735539192d4d54e2cb49692cae14832c30dcffee0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "hideTotal", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="liveSpan")
    def live_span(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "liveSpan"))

    @live_span.setter
    def live_span(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3be81ab0e6b8b241b6bc2acdfd7cd43ae6a098dcc33aceba8590d8df8e50fb64)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "liveSpan", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="title")
    def title(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "title"))

    @title.setter
    def title(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a88eca10709b40f3cfdf1a5e4f84d5952240dd6922b47da6a7f309ae0db82fc9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "title", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="titleAlign")
    def title_align(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "titleAlign"))

    @title_align.setter
    def title_align(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ae22019ac43b72ee5b68f7e0e356aa26d6d3649ec15525bf19c297eb0a809f94)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "titleAlign", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="titleSize")
    def title_size(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "titleSize"))

    @title_size.setter
    def title_size(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a3567eab573d68af3bdadee95d86f40975ded12ac2b6238cbcb923dc7c2de24b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "titleSize", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[PowerpackWidgetSunburstDefinition]:
        return typing.cast(typing.Optional[PowerpackWidgetSunburstDefinition], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetSunburstDefinition],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__25c8b2fc5a7058441e40c0f8dd9892a9092100c4d4967dee920238b605babad8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequest",
    jsii_struct_bases=[],
    name_mapping={
        "apm_query": "apmQuery",
        "audit_query": "auditQuery",
        "formula": "formula",
        "log_query": "logQuery",
        "network_query": "networkQuery",
        "process_query": "processQuery",
        "q": "q",
        "query": "query",
        "rum_query": "rumQuery",
        "security_query": "securityQuery",
        "style": "style",
    },
)
class PowerpackWidgetSunburstDefinitionRequest:
    def __init__(
        self,
        *,
        apm_query: typing.Optional[typing.Union["PowerpackWidgetSunburstDefinitionRequestApmQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        audit_query: typing.Optional[typing.Union["PowerpackWidgetSunburstDefinitionRequestAuditQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        formula: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetSunburstDefinitionRequestFormula", typing.Dict[builtins.str, typing.Any]]]]] = None,
        log_query: typing.Optional[typing.Union["PowerpackWidgetSunburstDefinitionRequestLogQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        network_query: typing.Optional[typing.Union["PowerpackWidgetSunburstDefinitionRequestNetworkQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        process_query: typing.Optional[typing.Union["PowerpackWidgetSunburstDefinitionRequestProcessQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        q: typing.Optional[builtins.str] = None,
        query: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetSunburstDefinitionRequestQuery", typing.Dict[builtins.str, typing.Any]]]]] = None,
        rum_query: typing.Optional[typing.Union["PowerpackWidgetSunburstDefinitionRequestRumQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        security_query: typing.Optional[typing.Union["PowerpackWidgetSunburstDefinitionRequestSecurityQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        style: typing.Optional[typing.Union["PowerpackWidgetSunburstDefinitionRequestStyle", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param apm_query: apm_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#apm_query Powerpack#apm_query}
        :param audit_query: audit_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#audit_query Powerpack#audit_query}
        :param formula: formula block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#formula Powerpack#formula}
        :param log_query: log_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#log_query Powerpack#log_query}
        :param network_query: network_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#network_query Powerpack#network_query}
        :param process_query: process_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#process_query Powerpack#process_query}
        :param q: The metric query to use for this widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#q Powerpack#q}
        :param query: query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        :param rum_query: rum_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#rum_query Powerpack#rum_query}
        :param security_query: security_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#security_query Powerpack#security_query}
        :param style: style block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#style Powerpack#style}
        '''
        if isinstance(apm_query, dict):
            apm_query = PowerpackWidgetSunburstDefinitionRequestApmQuery(**apm_query)
        if isinstance(audit_query, dict):
            audit_query = PowerpackWidgetSunburstDefinitionRequestAuditQuery(**audit_query)
        if isinstance(log_query, dict):
            log_query = PowerpackWidgetSunburstDefinitionRequestLogQuery(**log_query)
        if isinstance(network_query, dict):
            network_query = PowerpackWidgetSunburstDefinitionRequestNetworkQuery(**network_query)
        if isinstance(process_query, dict):
            process_query = PowerpackWidgetSunburstDefinitionRequestProcessQuery(**process_query)
        if isinstance(rum_query, dict):
            rum_query = PowerpackWidgetSunburstDefinitionRequestRumQuery(**rum_query)
        if isinstance(security_query, dict):
            security_query = PowerpackWidgetSunburstDefinitionRequestSecurityQuery(**security_query)
        if isinstance(style, dict):
            style = PowerpackWidgetSunburstDefinitionRequestStyle(**style)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e0995dc9e66889ebb98ced81f2f65bd6a274cafce41caa998358e9c3bd5a4861)
            check_type(argname="argument apm_query", value=apm_query, expected_type=type_hints["apm_query"])
            check_type(argname="argument audit_query", value=audit_query, expected_type=type_hints["audit_query"])
            check_type(argname="argument formula", value=formula, expected_type=type_hints["formula"])
            check_type(argname="argument log_query", value=log_query, expected_type=type_hints["log_query"])
            check_type(argname="argument network_query", value=network_query, expected_type=type_hints["network_query"])
            check_type(argname="argument process_query", value=process_query, expected_type=type_hints["process_query"])
            check_type(argname="argument q", value=q, expected_type=type_hints["q"])
            check_type(argname="argument query", value=query, expected_type=type_hints["query"])
            check_type(argname="argument rum_query", value=rum_query, expected_type=type_hints["rum_query"])
            check_type(argname="argument security_query", value=security_query, expected_type=type_hints["security_query"])
            check_type(argname="argument style", value=style, expected_type=type_hints["style"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if apm_query is not None:
            self._values["apm_query"] = apm_query
        if audit_query is not None:
            self._values["audit_query"] = audit_query
        if formula is not None:
            self._values["formula"] = formula
        if log_query is not None:
            self._values["log_query"] = log_query
        if network_query is not None:
            self._values["network_query"] = network_query
        if process_query is not None:
            self._values["process_query"] = process_query
        if q is not None:
            self._values["q"] = q
        if query is not None:
            self._values["query"] = query
        if rum_query is not None:
            self._values["rum_query"] = rum_query
        if security_query is not None:
            self._values["security_query"] = security_query
        if style is not None:
            self._values["style"] = style

    @builtins.property
    def apm_query(
        self,
    ) -> typing.Optional["PowerpackWidgetSunburstDefinitionRequestApmQuery"]:
        '''apm_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#apm_query Powerpack#apm_query}
        '''
        result = self._values.get("apm_query")
        return typing.cast(typing.Optional["PowerpackWidgetSunburstDefinitionRequestApmQuery"], result)

    @builtins.property
    def audit_query(
        self,
    ) -> typing.Optional["PowerpackWidgetSunburstDefinitionRequestAuditQuery"]:
        '''audit_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#audit_query Powerpack#audit_query}
        '''
        result = self._values.get("audit_query")
        return typing.cast(typing.Optional["PowerpackWidgetSunburstDefinitionRequestAuditQuery"], result)

    @builtins.property
    def formula(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetSunburstDefinitionRequestFormula"]]]:
        '''formula block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#formula Powerpack#formula}
        '''
        result = self._values.get("formula")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetSunburstDefinitionRequestFormula"]]], result)

    @builtins.property
    def log_query(
        self,
    ) -> typing.Optional["PowerpackWidgetSunburstDefinitionRequestLogQuery"]:
        '''log_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#log_query Powerpack#log_query}
        '''
        result = self._values.get("log_query")
        return typing.cast(typing.Optional["PowerpackWidgetSunburstDefinitionRequestLogQuery"], result)

    @builtins.property
    def network_query(
        self,
    ) -> typing.Optional["PowerpackWidgetSunburstDefinitionRequestNetworkQuery"]:
        '''network_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#network_query Powerpack#network_query}
        '''
        result = self._values.get("network_query")
        return typing.cast(typing.Optional["PowerpackWidgetSunburstDefinitionRequestNetworkQuery"], result)

    @builtins.property
    def process_query(
        self,
    ) -> typing.Optional["PowerpackWidgetSunburstDefinitionRequestProcessQuery"]:
        '''process_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#process_query Powerpack#process_query}
        '''
        result = self._values.get("process_query")
        return typing.cast(typing.Optional["PowerpackWidgetSunburstDefinitionRequestProcessQuery"], result)

    @builtins.property
    def q(self) -> typing.Optional[builtins.str]:
        '''The metric query to use for this widget.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#q Powerpack#q}
        '''
        result = self._values.get("q")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def query(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetSunburstDefinitionRequestQuery"]]]:
        '''query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        '''
        result = self._values.get("query")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetSunburstDefinitionRequestQuery"]]], result)

    @builtins.property
    def rum_query(
        self,
    ) -> typing.Optional["PowerpackWidgetSunburstDefinitionRequestRumQuery"]:
        '''rum_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#rum_query Powerpack#rum_query}
        '''
        result = self._values.get("rum_query")
        return typing.cast(typing.Optional["PowerpackWidgetSunburstDefinitionRequestRumQuery"], result)

    @builtins.property
    def security_query(
        self,
    ) -> typing.Optional["PowerpackWidgetSunburstDefinitionRequestSecurityQuery"]:
        '''security_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#security_query Powerpack#security_query}
        '''
        result = self._values.get("security_query")
        return typing.cast(typing.Optional["PowerpackWidgetSunburstDefinitionRequestSecurityQuery"], result)

    @builtins.property
    def style(self) -> typing.Optional["PowerpackWidgetSunburstDefinitionRequestStyle"]:
        '''style block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#style Powerpack#style}
        '''
        result = self._values.get("style")
        return typing.cast(typing.Optional["PowerpackWidgetSunburstDefinitionRequestStyle"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetSunburstDefinitionRequest(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestApmQuery",
    jsii_struct_bases=[],
    name_mapping={
        "index": "index",
        "compute_query": "computeQuery",
        "group_by": "groupBy",
        "multi_compute": "multiCompute",
        "search_query": "searchQuery",
    },
)
class PowerpackWidgetSunburstDefinitionRequestApmQuery:
    def __init__(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union["PowerpackWidgetSunburstDefinitionRequestApmQueryComputeQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetSunburstDefinitionRequestApmQueryGroupBy", typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetSunburstDefinitionRequestApmQueryMultiCompute", typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        if isinstance(compute_query, dict):
            compute_query = PowerpackWidgetSunburstDefinitionRequestApmQueryComputeQuery(**compute_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8a7a7c31d226ccb28e0503cc6a94fdd2500edf7f7a873582fecefeda5a455220)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
            check_type(argname="argument compute_query", value=compute_query, expected_type=type_hints["compute_query"])
            check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
            check_type(argname="argument multi_compute", value=multi_compute, expected_type=type_hints["multi_compute"])
            check_type(argname="argument search_query", value=search_query, expected_type=type_hints["search_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "index": index,
        }
        if compute_query is not None:
            self._values["compute_query"] = compute_query
        if group_by is not None:
            self._values["group_by"] = group_by
        if multi_compute is not None:
            self._values["multi_compute"] = multi_compute
        if search_query is not None:
            self._values["search_query"] = search_query

    @builtins.property
    def index(self) -> builtins.str:
        '''The name of the index to query.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        '''
        result = self._values.get("index")
        assert result is not None, "Required property 'index' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def compute_query(
        self,
    ) -> typing.Optional["PowerpackWidgetSunburstDefinitionRequestApmQueryComputeQuery"]:
        '''compute_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        '''
        result = self._values.get("compute_query")
        return typing.cast(typing.Optional["PowerpackWidgetSunburstDefinitionRequestApmQueryComputeQuery"], result)

    @builtins.property
    def group_by(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetSunburstDefinitionRequestApmQueryGroupBy"]]]:
        '''group_by block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        '''
        result = self._values.get("group_by")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetSunburstDefinitionRequestApmQueryGroupBy"]]], result)

    @builtins.property
    def multi_compute(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetSunburstDefinitionRequestApmQueryMultiCompute"]]]:
        '''multi_compute block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        '''
        result = self._values.get("multi_compute")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetSunburstDefinitionRequestApmQueryMultiCompute"]]], result)

    @builtins.property
    def search_query(self) -> typing.Optional[builtins.str]:
        '''The search query to use.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        result = self._values.get("search_query")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetSunburstDefinitionRequestApmQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestApmQueryComputeQuery",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetSunburstDefinitionRequestApmQueryComputeQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3af82652904acec2e556f14659527eca04f6c8ccd5472e971dbecaebbbe378ed)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetSunburstDefinitionRequestApmQueryComputeQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetSunburstDefinitionRequestApmQueryComputeQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestApmQueryComputeQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7b9bd8f283049137b4b8f35e92dbc42a4e5d6873bd3116c79c481859e09083be)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1253c058e75a5078bdf9d43734b50f95337c895cf7501a9359acbe31ea6a1e92)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__eb5d0f578836ef7546f54bf600e0fb96a44a6a95ae279ddb5d91558faddb6e09)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ac87c55e12fd88f422455ff974e7c9845f9f0e59918d9e4e15ccd0cba95bf3b9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetSunburstDefinitionRequestApmQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetSunburstDefinitionRequestApmQueryComputeQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetSunburstDefinitionRequestApmQueryComputeQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7dda0323481c03b51b43725cc066e34e5c861916000c394ffe6eb41a0b7a5b43)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestApmQueryGroupBy",
    jsii_struct_bases=[],
    name_mapping={"facet": "facet", "limit": "limit", "sort_query": "sortQuery"},
)
class PowerpackWidgetSunburstDefinitionRequestApmQueryGroupBy:
    def __init__(
        self,
        *,
        facet: typing.Optional[builtins.str] = None,
        limit: typing.Optional[jsii.Number] = None,
        sort_query: typing.Optional[typing.Union["PowerpackWidgetSunburstDefinitionRequestApmQueryGroupBySortQuery", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param limit: The maximum number of items in the group. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param sort_query: sort_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        if isinstance(sort_query, dict):
            sort_query = PowerpackWidgetSunburstDefinitionRequestApmQueryGroupBySortQuery(**sort_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f25d100fb5c5e9c5417c949546c7e3dbed2e5321efeef70c20f625cb72bd6ac7)
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
            check_type(argname="argument sort_query", value=sort_query, expected_type=type_hints["sort_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if facet is not None:
            self._values["facet"] = facet
        if limit is not None:
            self._values["limit"] = limit
        if sort_query is not None:
            self._values["sort_query"] = sort_query

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def limit(self) -> typing.Optional[jsii.Number]:
        '''The maximum number of items in the group.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        '''
        result = self._values.get("limit")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def sort_query(
        self,
    ) -> typing.Optional["PowerpackWidgetSunburstDefinitionRequestApmQueryGroupBySortQuery"]:
        '''sort_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        result = self._values.get("sort_query")
        return typing.cast(typing.Optional["PowerpackWidgetSunburstDefinitionRequestApmQueryGroupBySortQuery"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetSunburstDefinitionRequestApmQueryGroupBy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetSunburstDefinitionRequestApmQueryGroupByList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestApmQueryGroupByList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__baf75af7d06aa1eed1f8edb800029f4fc2e3d1b52abf14943d1f23c31ae7e056)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetSunburstDefinitionRequestApmQueryGroupByOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__537d0ed1c60e3063868afc6a642c685596ac75cf2d8c829625da29135e99b72d)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetSunburstDefinitionRequestApmQueryGroupByOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e882adacbbbc5f5b9a4957a282056314d95930db745e66ed5ca288b95bdc0e59)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8b9970554a5fbc4dc431f339408d1df1c216972eda16df8df17777e52970bbf7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a34d24f96fdea38371a8dcf68e3f3e247855617b4bc62b2273b562d011f69180)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequestApmQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequestApmQueryGroupBy]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequestApmQueryGroupBy]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6416759d8fdc029236fe418f295ad90e815f4cba88d11f656f61866d69142d9c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetSunburstDefinitionRequestApmQueryGroupByOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestApmQueryGroupByOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2439d617c83fdec8726245450ecf7e0463d09dc7e805d5fa41b1d0b4c33dd154)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putSortQuery")
    def put_sort_query(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        value = PowerpackWidgetSunburstDefinitionRequestApmQueryGroupBySortQuery(
            aggregation=aggregation, order=order, facet=facet
        )

        return typing.cast(None, jsii.invoke(self, "putSortQuery", [value]))

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetLimit")
    def reset_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLimit", []))

    @jsii.member(jsii_name="resetSortQuery")
    def reset_sort_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSortQuery", []))

    @builtins.property
    @jsii.member(jsii_name="sortQuery")
    def sort_query(
        self,
    ) -> "PowerpackWidgetSunburstDefinitionRequestApmQueryGroupBySortQueryOutputReference":
        return typing.cast("PowerpackWidgetSunburstDefinitionRequestApmQueryGroupBySortQueryOutputReference", jsii.get(self, "sortQuery"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="limitInput")
    def limit_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "limitInput"))

    @builtins.property
    @jsii.member(jsii_name="sortQueryInput")
    def sort_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetSunburstDefinitionRequestApmQueryGroupBySortQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetSunburstDefinitionRequestApmQueryGroupBySortQuery"], jsii.get(self, "sortQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__014df03dfb91647cc6fc03bd703e8d734ad870beb7d8df21508498c6c9d250fb)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="limit")
    def limit(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "limit"))

    @limit.setter
    def limit(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0b228cea44e1c1ec686110af559711970dbfd3a8676370a17e00f1fbf312f814)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "limit", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetSunburstDefinitionRequestApmQueryGroupBy]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetSunburstDefinitionRequestApmQueryGroupBy]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetSunburstDefinitionRequestApmQueryGroupBy]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__15e3bf3b35c47b92879aa53390ba0eefdd019f9141f5a5e6fde0f304eb0e8094)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestApmQueryGroupBySortQuery",
    jsii_struct_bases=[],
    name_mapping={"aggregation": "aggregation", "order": "order", "facet": "facet"},
)
class PowerpackWidgetSunburstDefinitionRequestApmQueryGroupBySortQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__079a0229759ac4eba10fd9e649e7dbfc6ae5782d4bbef6b3ded659996d0ca806)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument order", value=order, expected_type=type_hints["order"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
            "order": order,
        }
        if facet is not None:
            self._values["facet"] = facet

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def order(self) -> builtins.str:
        '''Widget sorting methods. Valid values are ``asc``, ``desc``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        result = self._values.get("order")
        assert result is not None, "Required property 'order' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetSunburstDefinitionRequestApmQueryGroupBySortQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetSunburstDefinitionRequestApmQueryGroupBySortQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestApmQueryGroupBySortQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a794240ce44682936a2d6e86c99a5a9c1d9edb66e6503787f22f907f7be6c219)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="orderInput")
    def order_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "orderInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__50e441eceee159deac6845b90ab9f0d13de2ed7414b8bc92d51a8547689a30cc)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f7edcccb19f3c35161686b6fe28192699a59da2b3a738424989aabd7c405b156)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="order")
    def order(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "order"))

    @order.setter
    def order(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b78586c624a010ec4fd5f9530bcd5993133635c0438f0a57706cbf3e53d0b4ce)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "order", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetSunburstDefinitionRequestApmQueryGroupBySortQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetSunburstDefinitionRequestApmQueryGroupBySortQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetSunburstDefinitionRequestApmQueryGroupBySortQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ce44cef874b5ab123471d8f9799e5a1b26ffa5aa2984eae06a6519d2388bd38e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestApmQueryMultiCompute",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetSunburstDefinitionRequestApmQueryMultiCompute:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dbc1b83f062e90528bc9ecf2e2af9f291c26b5976e7b0670a87ac196660ee816)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetSunburstDefinitionRequestApmQueryMultiCompute(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetSunburstDefinitionRequestApmQueryMultiComputeList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestApmQueryMultiComputeList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__df9ca306df622ecb8d184df540ae83ee631100d918f390c6110a9168e385475e)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetSunburstDefinitionRequestApmQueryMultiComputeOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4ded005353127fbae441cb72353ac48693edd14c2f95af7c72014ac637e0b26a)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetSunburstDefinitionRequestApmQueryMultiComputeOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c7e0b596654a5523f5d26beecaf90d4ebc26aa140be644c1da157ea920e08c5a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__525f527f31581b5d64a1238544b732c16d54a8cf26fe2ec2f304f27cfe449c22)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b5dc26ded03b6da063de979eb72f47cf01575a45287c78bccc5e4b67cd425e98)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequestApmQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequestApmQueryMultiCompute]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequestApmQueryMultiCompute]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__06520043b54533a1984eaee1ecfe2a01d78c86222636d7dca72de9f059322aea)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetSunburstDefinitionRequestApmQueryMultiComputeOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestApmQueryMultiComputeOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c5af327799355ffe8dfc61d43c85d67425430fa8dbd09806afb19ccc4d896d42)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cb1f8855d356f826137783b802ae589152fa43267bd49f1e44e2c5cde2593be6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__54aaa1cedec7e4d200017a3a4febb8687fbdc458c2ff5e58f89de837b522f56c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cf779b622a1e2aff82633ac3d6640009df85b86c08846209726cca51d2161617)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetSunburstDefinitionRequestApmQueryMultiCompute]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetSunburstDefinitionRequestApmQueryMultiCompute]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetSunburstDefinitionRequestApmQueryMultiCompute]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dde0f7527b953989027c5dc917604147fa346357afe64c4993887f73b914f712)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetSunburstDefinitionRequestApmQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestApmQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6887314d0ab9c4d80dd31a987b66268b85a84dcae0a4a7180aea71e0068c10d1)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putComputeQuery")
    def put_compute_query(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        value = PowerpackWidgetSunburstDefinitionRequestApmQueryComputeQuery(
            aggregation=aggregation, facet=facet, interval=interval
        )

        return typing.cast(None, jsii.invoke(self, "putComputeQuery", [value]))

    @jsii.member(jsii_name="putGroupBy")
    def put_group_by(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetSunburstDefinitionRequestApmQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c6ee691088dd6001bb296b2be75f04bc108e289ef3ca63124ca932404f5f99c1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putGroupBy", [value]))

    @jsii.member(jsii_name="putMultiCompute")
    def put_multi_compute(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetSunburstDefinitionRequestApmQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b9e85ac810c5276ba13f69156705b24f8561e29a5048b489502eb6ec6dc25e9b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putMultiCompute", [value]))

    @jsii.member(jsii_name="resetComputeQuery")
    def reset_compute_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetComputeQuery", []))

    @jsii.member(jsii_name="resetGroupBy")
    def reset_group_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGroupBy", []))

    @jsii.member(jsii_name="resetMultiCompute")
    def reset_multi_compute(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMultiCompute", []))

    @jsii.member(jsii_name="resetSearchQuery")
    def reset_search_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSearchQuery", []))

    @builtins.property
    @jsii.member(jsii_name="computeQuery")
    def compute_query(
        self,
    ) -> PowerpackWidgetSunburstDefinitionRequestApmQueryComputeQueryOutputReference:
        return typing.cast(PowerpackWidgetSunburstDefinitionRequestApmQueryComputeQueryOutputReference, jsii.get(self, "computeQuery"))

    @builtins.property
    @jsii.member(jsii_name="groupBy")
    def group_by(self) -> PowerpackWidgetSunburstDefinitionRequestApmQueryGroupByList:
        return typing.cast(PowerpackWidgetSunburstDefinitionRequestApmQueryGroupByList, jsii.get(self, "groupBy"))

    @builtins.property
    @jsii.member(jsii_name="multiCompute")
    def multi_compute(
        self,
    ) -> PowerpackWidgetSunburstDefinitionRequestApmQueryMultiComputeList:
        return typing.cast(PowerpackWidgetSunburstDefinitionRequestApmQueryMultiComputeList, jsii.get(self, "multiCompute"))

    @builtins.property
    @jsii.member(jsii_name="computeQueryInput")
    def compute_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetSunburstDefinitionRequestApmQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetSunburstDefinitionRequestApmQueryComputeQuery], jsii.get(self, "computeQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="groupByInput")
    def group_by_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequestApmQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequestApmQueryGroupBy]]], jsii.get(self, "groupByInput"))

    @builtins.property
    @jsii.member(jsii_name="indexInput")
    def index_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "indexInput"))

    @builtins.property
    @jsii.member(jsii_name="multiComputeInput")
    def multi_compute_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequestApmQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequestApmQueryMultiCompute]]], jsii.get(self, "multiComputeInput"))

    @builtins.property
    @jsii.member(jsii_name="searchQueryInput")
    def search_query_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "searchQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="index")
    def index(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "index"))

    @index.setter
    def index(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__43507b14f40d83ab3218c69b637ac167a0ba1b7d37206417914f37432b1f5b72)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "index", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="searchQuery")
    def search_query(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "searchQuery"))

    @search_query.setter
    def search_query(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3e840ced79f48ac6ed9a68580119f1877bd9830065d8e3ba03fe2c5835d062a0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "searchQuery", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetSunburstDefinitionRequestApmQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetSunburstDefinitionRequestApmQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetSunburstDefinitionRequestApmQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__83419e80597c2e03e65e2d03c8650599d4368136a5193bdd98da8d07cfa6a5bf)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestAuditQuery",
    jsii_struct_bases=[],
    name_mapping={
        "index": "index",
        "compute_query": "computeQuery",
        "group_by": "groupBy",
        "multi_compute": "multiCompute",
        "search_query": "searchQuery",
    },
)
class PowerpackWidgetSunburstDefinitionRequestAuditQuery:
    def __init__(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union["PowerpackWidgetSunburstDefinitionRequestAuditQueryComputeQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetSunburstDefinitionRequestAuditQueryGroupBy", typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetSunburstDefinitionRequestAuditQueryMultiCompute", typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        if isinstance(compute_query, dict):
            compute_query = PowerpackWidgetSunburstDefinitionRequestAuditQueryComputeQuery(**compute_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cac3328ad983c004f52a9e94b3120165ec4729e9c423c0f23cbddfc3a88acd11)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
            check_type(argname="argument compute_query", value=compute_query, expected_type=type_hints["compute_query"])
            check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
            check_type(argname="argument multi_compute", value=multi_compute, expected_type=type_hints["multi_compute"])
            check_type(argname="argument search_query", value=search_query, expected_type=type_hints["search_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "index": index,
        }
        if compute_query is not None:
            self._values["compute_query"] = compute_query
        if group_by is not None:
            self._values["group_by"] = group_by
        if multi_compute is not None:
            self._values["multi_compute"] = multi_compute
        if search_query is not None:
            self._values["search_query"] = search_query

    @builtins.property
    def index(self) -> builtins.str:
        '''The name of the index to query.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        '''
        result = self._values.get("index")
        assert result is not None, "Required property 'index' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def compute_query(
        self,
    ) -> typing.Optional["PowerpackWidgetSunburstDefinitionRequestAuditQueryComputeQuery"]:
        '''compute_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        '''
        result = self._values.get("compute_query")
        return typing.cast(typing.Optional["PowerpackWidgetSunburstDefinitionRequestAuditQueryComputeQuery"], result)

    @builtins.property
    def group_by(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetSunburstDefinitionRequestAuditQueryGroupBy"]]]:
        '''group_by block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        '''
        result = self._values.get("group_by")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetSunburstDefinitionRequestAuditQueryGroupBy"]]], result)

    @builtins.property
    def multi_compute(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetSunburstDefinitionRequestAuditQueryMultiCompute"]]]:
        '''multi_compute block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        '''
        result = self._values.get("multi_compute")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetSunburstDefinitionRequestAuditQueryMultiCompute"]]], result)

    @builtins.property
    def search_query(self) -> typing.Optional[builtins.str]:
        '''The search query to use.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        result = self._values.get("search_query")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetSunburstDefinitionRequestAuditQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestAuditQueryComputeQuery",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetSunburstDefinitionRequestAuditQueryComputeQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__802ebd40be3bd5f61e2f7bc2461101b82470d317bb1da78d9952c1c0d52fe129)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetSunburstDefinitionRequestAuditQueryComputeQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetSunburstDefinitionRequestAuditQueryComputeQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestAuditQueryComputeQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d386c820b0beeadb7b962b82fcb6ff4923080a623b1856d80d280ff70f4fbb03)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f1af238b3eefcb1734f9e253869106f987e9692c6d0b5b3f1b3ea3a2989d2492)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5a701e5865efe94cbf74b27b6d5c467ffa836d7d060a43c304d24287a859da02)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1da0b6af0f087d1b75500ad48fbba0b9f1f957aeb534095d3d5596c13759a433)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetSunburstDefinitionRequestAuditQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetSunburstDefinitionRequestAuditQueryComputeQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetSunburstDefinitionRequestAuditQueryComputeQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__72df6a6dd902dac41ddc6209302939efdbd6c6d7ac5656da4323e3a1ee9473f8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestAuditQueryGroupBy",
    jsii_struct_bases=[],
    name_mapping={"facet": "facet", "limit": "limit", "sort_query": "sortQuery"},
)
class PowerpackWidgetSunburstDefinitionRequestAuditQueryGroupBy:
    def __init__(
        self,
        *,
        facet: typing.Optional[builtins.str] = None,
        limit: typing.Optional[jsii.Number] = None,
        sort_query: typing.Optional[typing.Union["PowerpackWidgetSunburstDefinitionRequestAuditQueryGroupBySortQuery", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param limit: The maximum number of items in the group. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param sort_query: sort_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        if isinstance(sort_query, dict):
            sort_query = PowerpackWidgetSunburstDefinitionRequestAuditQueryGroupBySortQuery(**sort_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f5dce7d563fd18431e9d8d33e50de0713bc666ec240f8bcc80f5a87e68c6fb29)
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
            check_type(argname="argument sort_query", value=sort_query, expected_type=type_hints["sort_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if facet is not None:
            self._values["facet"] = facet
        if limit is not None:
            self._values["limit"] = limit
        if sort_query is not None:
            self._values["sort_query"] = sort_query

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def limit(self) -> typing.Optional[jsii.Number]:
        '''The maximum number of items in the group.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        '''
        result = self._values.get("limit")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def sort_query(
        self,
    ) -> typing.Optional["PowerpackWidgetSunburstDefinitionRequestAuditQueryGroupBySortQuery"]:
        '''sort_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        result = self._values.get("sort_query")
        return typing.cast(typing.Optional["PowerpackWidgetSunburstDefinitionRequestAuditQueryGroupBySortQuery"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetSunburstDefinitionRequestAuditQueryGroupBy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetSunburstDefinitionRequestAuditQueryGroupByList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestAuditQueryGroupByList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__574ca919b602d20db238a73ecf1218b4dde83f1cf4857e1d7d335e7db0980d8b)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetSunburstDefinitionRequestAuditQueryGroupByOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__03586746a22f8758406ca54d9e9e35c0268b646c3d622e8ebbf9636a10a38285)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetSunburstDefinitionRequestAuditQueryGroupByOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__62a47df4f9dc30e5ea65a413e4c421df07acb1497c2572ba8ec18a40648522c5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0c303addd6525640ded4554f2fe7aab0c3d28ab8d5cd13138f8afd39a7a51efb)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__15fc886dec5eb632c7ea836e7232740b63c13324304ed2175812cd755bf07d5d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequestAuditQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequestAuditQueryGroupBy]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequestAuditQueryGroupBy]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__64a4ee7c73c61db7bc8555542742fb30c8ad156758f5c0162e266b776e9df8f8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetSunburstDefinitionRequestAuditQueryGroupByOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestAuditQueryGroupByOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__73c2c5a342cb08b8459a013e0eb05bdb3632c6a26118c47d9294f5025cd6ae68)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putSortQuery")
    def put_sort_query(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        value = PowerpackWidgetSunburstDefinitionRequestAuditQueryGroupBySortQuery(
            aggregation=aggregation, order=order, facet=facet
        )

        return typing.cast(None, jsii.invoke(self, "putSortQuery", [value]))

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetLimit")
    def reset_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLimit", []))

    @jsii.member(jsii_name="resetSortQuery")
    def reset_sort_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSortQuery", []))

    @builtins.property
    @jsii.member(jsii_name="sortQuery")
    def sort_query(
        self,
    ) -> "PowerpackWidgetSunburstDefinitionRequestAuditQueryGroupBySortQueryOutputReference":
        return typing.cast("PowerpackWidgetSunburstDefinitionRequestAuditQueryGroupBySortQueryOutputReference", jsii.get(self, "sortQuery"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="limitInput")
    def limit_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "limitInput"))

    @builtins.property
    @jsii.member(jsii_name="sortQueryInput")
    def sort_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetSunburstDefinitionRequestAuditQueryGroupBySortQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetSunburstDefinitionRequestAuditQueryGroupBySortQuery"], jsii.get(self, "sortQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__94b7b77dafbd589442bb7db785b6e8d66be25096272f788a5f1e1abe9d0718cf)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="limit")
    def limit(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "limit"))

    @limit.setter
    def limit(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__51c1a7c88c6875473cd59ac7162b127c37fc6c3125f187bf45021e3db12d6bd6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "limit", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetSunburstDefinitionRequestAuditQueryGroupBy]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetSunburstDefinitionRequestAuditQueryGroupBy]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetSunburstDefinitionRequestAuditQueryGroupBy]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__eb5ff62f4b257e18a70117c92923d7717ca4d06e84b17e41829eca42a0a16f9f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestAuditQueryGroupBySortQuery",
    jsii_struct_bases=[],
    name_mapping={"aggregation": "aggregation", "order": "order", "facet": "facet"},
)
class PowerpackWidgetSunburstDefinitionRequestAuditQueryGroupBySortQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__de6a32f27b289f6e4b9a8ba4eebf3611a1e5972aced1531e1fc7f88cc2e885b3)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument order", value=order, expected_type=type_hints["order"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
            "order": order,
        }
        if facet is not None:
            self._values["facet"] = facet

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def order(self) -> builtins.str:
        '''Widget sorting methods. Valid values are ``asc``, ``desc``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        result = self._values.get("order")
        assert result is not None, "Required property 'order' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetSunburstDefinitionRequestAuditQueryGroupBySortQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetSunburstDefinitionRequestAuditQueryGroupBySortQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestAuditQueryGroupBySortQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e4e3ee536522bb8f583865156a7fb2d46967f0a9993a679c17a8044417513c45)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="orderInput")
    def order_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "orderInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a603a5d0efc5bfa7c0360981b328bf34d82ea22055d44de3af977d3866151d87)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__af0cf869b5c65aa6f90bc3d87354dc3071b7a15d5a0997d5b533e0e5bf393fd8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="order")
    def order(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "order"))

    @order.setter
    def order(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9b54496087aa1d172f32bb9c5106e903d13d7550e2cfbef5e86400660d3e772f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "order", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetSunburstDefinitionRequestAuditQueryGroupBySortQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetSunburstDefinitionRequestAuditQueryGroupBySortQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetSunburstDefinitionRequestAuditQueryGroupBySortQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2d11068e44323539c41d7c579349f48f9776c899bab085bca61a3a7f5b0104c8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestAuditQueryMultiCompute",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetSunburstDefinitionRequestAuditQueryMultiCompute:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__aaecbf86bee0953858f5e59c3027fc6d8a6f43f7aa960927ed7a0ae227338320)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetSunburstDefinitionRequestAuditQueryMultiCompute(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetSunburstDefinitionRequestAuditQueryMultiComputeList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestAuditQueryMultiComputeList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__11c63b610f38e0a1d03781bbfc9e81b6a717d1ba4ebd7cd82efe3793b52e8d41)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetSunburstDefinitionRequestAuditQueryMultiComputeOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c46de066897049882f9ff1ee211f9ab3ae0becd8735f0796c6ff4e44cb0f9e67)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetSunburstDefinitionRequestAuditQueryMultiComputeOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__697319a017d81d1c98ae2a46bccefe4dd8e89588bf1658b1aa9521f98ce421bd)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f72314cac09dcc1f69a2d070dfed8149149730a506b0fd3069ff741f734b6a01)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__045c134459048efe7ad2324bb971f001acdac240ac0e5bd196366d1595d5f349)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequestAuditQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequestAuditQueryMultiCompute]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequestAuditQueryMultiCompute]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7d658d3c91c6005d32b4c7eac3da82b371aa45fe21a52fd63d3f9f1fb47fffb3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetSunburstDefinitionRequestAuditQueryMultiComputeOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestAuditQueryMultiComputeOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__804639cae287b684964f27d4430833631fd7695b1189daf98a13f658adb50f77)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d1e343482d71ef61f2c5ad79743d2c2efbde3dcb164f3bb33aab480e88ebf870)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f715ce3f4b5a9489ae8298b3c4b27087439f05740891332b9061315cee823b7b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a6ef8506d1c177e726c6aef7f87515174afeef0986e6705615285bfd29b7019f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetSunburstDefinitionRequestAuditQueryMultiCompute]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetSunburstDefinitionRequestAuditQueryMultiCompute]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetSunburstDefinitionRequestAuditQueryMultiCompute]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__854e62c1b724d84a7ab8bb10fe38cd8e8b97268b69cb530054c1c92e0d665ac0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetSunburstDefinitionRequestAuditQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestAuditQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f1546f9bf16cce7fb70f99ce24fbb8598d3b6297ca8f4754d076945226b557e0)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putComputeQuery")
    def put_compute_query(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        value = PowerpackWidgetSunburstDefinitionRequestAuditQueryComputeQuery(
            aggregation=aggregation, facet=facet, interval=interval
        )

        return typing.cast(None, jsii.invoke(self, "putComputeQuery", [value]))

    @jsii.member(jsii_name="putGroupBy")
    def put_group_by(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetSunburstDefinitionRequestAuditQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4b2acb213f69056b6abcf1338035a0256d82904ae854f8ac99673a2b30b37320)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putGroupBy", [value]))

    @jsii.member(jsii_name="putMultiCompute")
    def put_multi_compute(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetSunburstDefinitionRequestAuditQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ada9e39829917ca5add5204cff5b4f670e9c515d0b479b9a311255d6da811794)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putMultiCompute", [value]))

    @jsii.member(jsii_name="resetComputeQuery")
    def reset_compute_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetComputeQuery", []))

    @jsii.member(jsii_name="resetGroupBy")
    def reset_group_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGroupBy", []))

    @jsii.member(jsii_name="resetMultiCompute")
    def reset_multi_compute(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMultiCompute", []))

    @jsii.member(jsii_name="resetSearchQuery")
    def reset_search_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSearchQuery", []))

    @builtins.property
    @jsii.member(jsii_name="computeQuery")
    def compute_query(
        self,
    ) -> PowerpackWidgetSunburstDefinitionRequestAuditQueryComputeQueryOutputReference:
        return typing.cast(PowerpackWidgetSunburstDefinitionRequestAuditQueryComputeQueryOutputReference, jsii.get(self, "computeQuery"))

    @builtins.property
    @jsii.member(jsii_name="groupBy")
    def group_by(self) -> PowerpackWidgetSunburstDefinitionRequestAuditQueryGroupByList:
        return typing.cast(PowerpackWidgetSunburstDefinitionRequestAuditQueryGroupByList, jsii.get(self, "groupBy"))

    @builtins.property
    @jsii.member(jsii_name="multiCompute")
    def multi_compute(
        self,
    ) -> PowerpackWidgetSunburstDefinitionRequestAuditQueryMultiComputeList:
        return typing.cast(PowerpackWidgetSunburstDefinitionRequestAuditQueryMultiComputeList, jsii.get(self, "multiCompute"))

    @builtins.property
    @jsii.member(jsii_name="computeQueryInput")
    def compute_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetSunburstDefinitionRequestAuditQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetSunburstDefinitionRequestAuditQueryComputeQuery], jsii.get(self, "computeQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="groupByInput")
    def group_by_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequestAuditQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequestAuditQueryGroupBy]]], jsii.get(self, "groupByInput"))

    @builtins.property
    @jsii.member(jsii_name="indexInput")
    def index_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "indexInput"))

    @builtins.property
    @jsii.member(jsii_name="multiComputeInput")
    def multi_compute_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequestAuditQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequestAuditQueryMultiCompute]]], jsii.get(self, "multiComputeInput"))

    @builtins.property
    @jsii.member(jsii_name="searchQueryInput")
    def search_query_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "searchQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="index")
    def index(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "index"))

    @index.setter
    def index(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__92271f3f6f47900260b15ab58849b52c2487f902c17d9946028b524bfc4760ec)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "index", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="searchQuery")
    def search_query(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "searchQuery"))

    @search_query.setter
    def search_query(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7f9ac15e06e6e0cd541e19bd6ec395956781fc5a1e32833d0aee76550997763b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "searchQuery", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetSunburstDefinitionRequestAuditQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetSunburstDefinitionRequestAuditQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetSunburstDefinitionRequestAuditQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d3de1db196020a00176e63f341567adf49bfd7fa7dedfb148e990f1e342e9f44)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestFormula",
    jsii_struct_bases=[],
    name_mapping={
        "formula_expression": "formulaExpression",
        "alias": "alias",
        "cell_display_mode": "cellDisplayMode",
        "conditional_formats": "conditionalFormats",
        "limit": "limit",
        "number_format": "numberFormat",
        "style": "style",
    },
)
class PowerpackWidgetSunburstDefinitionRequestFormula:
    def __init__(
        self,
        *,
        formula_expression: builtins.str,
        alias: typing.Optional[builtins.str] = None,
        cell_display_mode: typing.Optional[builtins.str] = None,
        conditional_formats: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetSunburstDefinitionRequestFormulaConditionalFormats", typing.Dict[builtins.str, typing.Any]]]]] = None,
        limit: typing.Optional[typing.Union["PowerpackWidgetSunburstDefinitionRequestFormulaLimit", typing.Dict[builtins.str, typing.Any]]] = None,
        number_format: typing.Optional[typing.Union["PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormat", typing.Dict[builtins.str, typing.Any]]] = None,
        style: typing.Optional[typing.Union["PowerpackWidgetSunburstDefinitionRequestFormulaStyle", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param formula_expression: A string expression built from queries, formulas, and functions. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#formula_expression Powerpack#formula_expression}
        :param alias: An expression alias. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#alias Powerpack#alias}
        :param cell_display_mode: A list of display modes for each table cell. Valid values are ``number``, ``bar``, ``trend``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cell_display_mode Powerpack#cell_display_mode}
        :param conditional_formats: conditional_formats block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#conditional_formats Powerpack#conditional_formats}
        :param limit: limit block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param number_format: number_format block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#number_format Powerpack#number_format}
        :param style: style block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#style Powerpack#style}
        '''
        if isinstance(limit, dict):
            limit = PowerpackWidgetSunburstDefinitionRequestFormulaLimit(**limit)
        if isinstance(number_format, dict):
            number_format = PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormat(**number_format)
        if isinstance(style, dict):
            style = PowerpackWidgetSunburstDefinitionRequestFormulaStyle(**style)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b7a297ff7c2a03bf5a982965cfab4ddd98f5f1d071dae850bfa3ccbe7998744d)
            check_type(argname="argument formula_expression", value=formula_expression, expected_type=type_hints["formula_expression"])
            check_type(argname="argument alias", value=alias, expected_type=type_hints["alias"])
            check_type(argname="argument cell_display_mode", value=cell_display_mode, expected_type=type_hints["cell_display_mode"])
            check_type(argname="argument conditional_formats", value=conditional_formats, expected_type=type_hints["conditional_formats"])
            check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
            check_type(argname="argument number_format", value=number_format, expected_type=type_hints["number_format"])
            check_type(argname="argument style", value=style, expected_type=type_hints["style"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "formula_expression": formula_expression,
        }
        if alias is not None:
            self._values["alias"] = alias
        if cell_display_mode is not None:
            self._values["cell_display_mode"] = cell_display_mode
        if conditional_formats is not None:
            self._values["conditional_formats"] = conditional_formats
        if limit is not None:
            self._values["limit"] = limit
        if number_format is not None:
            self._values["number_format"] = number_format
        if style is not None:
            self._values["style"] = style

    @builtins.property
    def formula_expression(self) -> builtins.str:
        '''A string expression built from queries, formulas, and functions.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#formula_expression Powerpack#formula_expression}
        '''
        result = self._values.get("formula_expression")
        assert result is not None, "Required property 'formula_expression' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def alias(self) -> typing.Optional[builtins.str]:
        '''An expression alias.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#alias Powerpack#alias}
        '''
        result = self._values.get("alias")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def cell_display_mode(self) -> typing.Optional[builtins.str]:
        '''A list of display modes for each table cell. Valid values are ``number``, ``bar``, ``trend``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cell_display_mode Powerpack#cell_display_mode}
        '''
        result = self._values.get("cell_display_mode")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def conditional_formats(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetSunburstDefinitionRequestFormulaConditionalFormats"]]]:
        '''conditional_formats block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#conditional_formats Powerpack#conditional_formats}
        '''
        result = self._values.get("conditional_formats")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetSunburstDefinitionRequestFormulaConditionalFormats"]]], result)

    @builtins.property
    def limit(
        self,
    ) -> typing.Optional["PowerpackWidgetSunburstDefinitionRequestFormulaLimit"]:
        '''limit block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        '''
        result = self._values.get("limit")
        return typing.cast(typing.Optional["PowerpackWidgetSunburstDefinitionRequestFormulaLimit"], result)

    @builtins.property
    def number_format(
        self,
    ) -> typing.Optional["PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormat"]:
        '''number_format block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#number_format Powerpack#number_format}
        '''
        result = self._values.get("number_format")
        return typing.cast(typing.Optional["PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormat"], result)

    @builtins.property
    def style(
        self,
    ) -> typing.Optional["PowerpackWidgetSunburstDefinitionRequestFormulaStyle"]:
        '''style block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#style Powerpack#style}
        '''
        result = self._values.get("style")
        return typing.cast(typing.Optional["PowerpackWidgetSunburstDefinitionRequestFormulaStyle"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetSunburstDefinitionRequestFormula(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestFormulaConditionalFormats",
    jsii_struct_bases=[],
    name_mapping={
        "comparator": "comparator",
        "palette": "palette",
        "value": "value",
        "custom_bg_color": "customBgColor",
        "custom_fg_color": "customFgColor",
        "hide_value": "hideValue",
        "image_url": "imageUrl",
        "metric": "metric",
        "timeframe": "timeframe",
    },
)
class PowerpackWidgetSunburstDefinitionRequestFormulaConditionalFormats:
    def __init__(
        self,
        *,
        comparator: builtins.str,
        palette: builtins.str,
        value: jsii.Number,
        custom_bg_color: typing.Optional[builtins.str] = None,
        custom_fg_color: typing.Optional[builtins.str] = None,
        hide_value: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        image_url: typing.Optional[builtins.str] = None,
        metric: typing.Optional[builtins.str] = None,
        timeframe: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param comparator: The comparator to use. Valid values are ``=``, ``>``, ``>=``, ``<``, ``<=``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#comparator Powerpack#comparator}
        :param palette: The color palette to apply. Valid values are ``blue``, ``custom_bg``, ``custom_image``, ``custom_text``, ``gray_on_white``, ``grey``, ``green``, ``orange``, ``red``, ``red_on_white``, ``white_on_gray``, ``white_on_green``, ``green_on_white``, ``white_on_red``, ``white_on_yellow``, ``yellow_on_white``, ``black_on_light_yellow``, ``black_on_light_green``, ``black_on_light_red``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette Powerpack#palette}
        :param value: A value for the comparator. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#value Powerpack#value}
        :param custom_bg_color: The color palette to apply to the background, same values available as palette. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom_bg_color Powerpack#custom_bg_color}
        :param custom_fg_color: The color palette to apply to the foreground, same values available as palette. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom_fg_color Powerpack#custom_fg_color}
        :param hide_value: Setting this to True hides values. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#hide_value Powerpack#hide_value}
        :param image_url: Displays an image as the background. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#image_url Powerpack#image_url}
        :param metric: The metric from the request to correlate with this conditional format. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        :param timeframe: Defines the displayed timeframe. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#timeframe Powerpack#timeframe}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__446d3d863bc4abecd26fa250ffd9815da1f7fe18a22ca3f43d062751624ac389)
            check_type(argname="argument comparator", value=comparator, expected_type=type_hints["comparator"])
            check_type(argname="argument palette", value=palette, expected_type=type_hints["palette"])
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument custom_bg_color", value=custom_bg_color, expected_type=type_hints["custom_bg_color"])
            check_type(argname="argument custom_fg_color", value=custom_fg_color, expected_type=type_hints["custom_fg_color"])
            check_type(argname="argument hide_value", value=hide_value, expected_type=type_hints["hide_value"])
            check_type(argname="argument image_url", value=image_url, expected_type=type_hints["image_url"])
            check_type(argname="argument metric", value=metric, expected_type=type_hints["metric"])
            check_type(argname="argument timeframe", value=timeframe, expected_type=type_hints["timeframe"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "comparator": comparator,
            "palette": palette,
            "value": value,
        }
        if custom_bg_color is not None:
            self._values["custom_bg_color"] = custom_bg_color
        if custom_fg_color is not None:
            self._values["custom_fg_color"] = custom_fg_color
        if hide_value is not None:
            self._values["hide_value"] = hide_value
        if image_url is not None:
            self._values["image_url"] = image_url
        if metric is not None:
            self._values["metric"] = metric
        if timeframe is not None:
            self._values["timeframe"] = timeframe

    @builtins.property
    def comparator(self) -> builtins.str:
        '''The comparator to use. Valid values are ``=``, ``>``, ``>=``, ``<``, ``<=``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#comparator Powerpack#comparator}
        '''
        result = self._values.get("comparator")
        assert result is not None, "Required property 'comparator' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def palette(self) -> builtins.str:
        '''The color palette to apply.

        Valid values are ``blue``, ``custom_bg``, ``custom_image``, ``custom_text``, ``gray_on_white``, ``grey``, ``green``, ``orange``, ``red``, ``red_on_white``, ``white_on_gray``, ``white_on_green``, ``green_on_white``, ``white_on_red``, ``white_on_yellow``, ``yellow_on_white``, ``black_on_light_yellow``, ``black_on_light_green``, ``black_on_light_red``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette Powerpack#palette}
        '''
        result = self._values.get("palette")
        assert result is not None, "Required property 'palette' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def value(self) -> jsii.Number:
        '''A value for the comparator.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#value Powerpack#value}
        '''
        result = self._values.get("value")
        assert result is not None, "Required property 'value' is missing"
        return typing.cast(jsii.Number, result)

    @builtins.property
    def custom_bg_color(self) -> typing.Optional[builtins.str]:
        '''The color palette to apply to the background, same values available as palette.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom_bg_color Powerpack#custom_bg_color}
        '''
        result = self._values.get("custom_bg_color")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def custom_fg_color(self) -> typing.Optional[builtins.str]:
        '''The color palette to apply to the foreground, same values available as palette.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom_fg_color Powerpack#custom_fg_color}
        '''
        result = self._values.get("custom_fg_color")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def hide_value(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        '''Setting this to True hides values.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#hide_value Powerpack#hide_value}
        '''
        result = self._values.get("hide_value")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)

    @builtins.property
    def image_url(self) -> typing.Optional[builtins.str]:
        '''Displays an image as the background.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#image_url Powerpack#image_url}
        '''
        result = self._values.get("image_url")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def metric(self) -> typing.Optional[builtins.str]:
        '''The metric from the request to correlate with this conditional format.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        '''
        result = self._values.get("metric")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def timeframe(self) -> typing.Optional[builtins.str]:
        '''Defines the displayed timeframe.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#timeframe Powerpack#timeframe}
        '''
        result = self._values.get("timeframe")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetSunburstDefinitionRequestFormulaConditionalFormats(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetSunburstDefinitionRequestFormulaConditionalFormatsList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestFormulaConditionalFormatsList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6e94e22ffeea988274924a5d0eaac3085405cb7b5be663cb22f5e84d02126768)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetSunburstDefinitionRequestFormulaConditionalFormatsOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f5d8046521ac25212eec7fb35d93ae24f297292ace697f3021506c5a61770f62)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetSunburstDefinitionRequestFormulaConditionalFormatsOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__498682372220216b3ea54ebae76432841501b4ee3fa9d31fbe14ec82ff68b77e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9f9fdbce16fe3ff44fc1a6eaecf211182c8ed35d83b6f1ade87557b1c4139c81)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5b9e1f95aa67142a4f0fd91f9c965ba4a146acea8bc09e04678cdd7423bc3fd8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequestFormulaConditionalFormats]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequestFormulaConditionalFormats]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequestFormulaConditionalFormats]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2003d10ef1abf6b68fa157718e599f090534e2e523331eeddac90e6271a9445f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetSunburstDefinitionRequestFormulaConditionalFormatsOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestFormulaConditionalFormatsOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1e2462c3d383913593de51a6cc0d7c9fd22a0449557e388c0c1180a8ff3f1ab3)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetCustomBgColor")
    def reset_custom_bg_color(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCustomBgColor", []))

    @jsii.member(jsii_name="resetCustomFgColor")
    def reset_custom_fg_color(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCustomFgColor", []))

    @jsii.member(jsii_name="resetHideValue")
    def reset_hide_value(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHideValue", []))

    @jsii.member(jsii_name="resetImageUrl")
    def reset_image_url(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetImageUrl", []))

    @jsii.member(jsii_name="resetMetric")
    def reset_metric(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMetric", []))

    @jsii.member(jsii_name="resetTimeframe")
    def reset_timeframe(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTimeframe", []))

    @builtins.property
    @jsii.member(jsii_name="comparatorInput")
    def comparator_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "comparatorInput"))

    @builtins.property
    @jsii.member(jsii_name="customBgColorInput")
    def custom_bg_color_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "customBgColorInput"))

    @builtins.property
    @jsii.member(jsii_name="customFgColorInput")
    def custom_fg_color_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "customFgColorInput"))

    @builtins.property
    @jsii.member(jsii_name="hideValueInput")
    def hide_value_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "hideValueInput"))

    @builtins.property
    @jsii.member(jsii_name="imageUrlInput")
    def image_url_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "imageUrlInput"))

    @builtins.property
    @jsii.member(jsii_name="metricInput")
    def metric_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "metricInput"))

    @builtins.property
    @jsii.member(jsii_name="paletteInput")
    def palette_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "paletteInput"))

    @builtins.property
    @jsii.member(jsii_name="timeframeInput")
    def timeframe_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "timeframeInput"))

    @builtins.property
    @jsii.member(jsii_name="valueInput")
    def value_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "valueInput"))

    @builtins.property
    @jsii.member(jsii_name="comparator")
    def comparator(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "comparator"))

    @comparator.setter
    def comparator(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__db7283b43d1032d1610f4993a8ec8fc997599cbb062f58234e528fb6b288a04d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "comparator", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="customBgColor")
    def custom_bg_color(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "customBgColor"))

    @custom_bg_color.setter
    def custom_bg_color(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8c2caa2d90b2d2f3927782c47c40bf8dfbfb2f16cd91ed86411bd0ea0a961af1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "customBgColor", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="customFgColor")
    def custom_fg_color(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "customFgColor"))

    @custom_fg_color.setter
    def custom_fg_color(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5c7ce0cd68745760f9ff3b9d3f44b8f0a182275f7958638f833a19fa3d65d34e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "customFgColor", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="hideValue")
    def hide_value(self) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "hideValue"))

    @hide_value.setter
    def hide_value(
        self,
        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2d07b0bf7ce1ece087d98cfcffb97165e94a67fae5bc5f45b97bce9edaa71d25)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "hideValue", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="imageUrl")
    def image_url(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "imageUrl"))

    @image_url.setter
    def image_url(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__92a2c7b18c6990085140fee3f13a677a11a9856f7c3f20e6d2de8a130b038295)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "imageUrl", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="metric")
    def metric(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "metric"))

    @metric.setter
    def metric(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7f35e029be30e14f8a543b653c485cf7b2be0af1c894bc22eb7fa859c913b9ca)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "metric", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="palette")
    def palette(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "palette"))

    @palette.setter
    def palette(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__93d57937201626b4f5c30082d3323cc3054c437b42b78eee1b509acfa858f5a2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "palette", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="timeframe")
    def timeframe(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "timeframe"))

    @timeframe.setter
    def timeframe(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c30762956a66e77f8ee3381c4a8b6d34129f306494a2d75df91b1f154644c981)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "timeframe", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="value")
    def value(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "value"))

    @value.setter
    def value(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__97c697efa0959108fc88766276e45b964bd8393f11eca626d042056b3d4dea29)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "value", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetSunburstDefinitionRequestFormulaConditionalFormats]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetSunburstDefinitionRequestFormulaConditionalFormats]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetSunburstDefinitionRequestFormulaConditionalFormats]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__04e99faf2a1ca5eb3c41f30389d8b2d46281d56f970dd3dd92178fb982d00bce)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestFormulaLimit",
    jsii_struct_bases=[],
    name_mapping={"count": "count", "order": "order"},
)
class PowerpackWidgetSunburstDefinitionRequestFormulaLimit:
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        order: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param count: The number of results to return. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#count Powerpack#count}
        :param order: The direction of the sort. Valid values are ``asc``, ``desc``. Defaults to ``"desc"``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__80e8d615008f0b4761057fbf9394d96ec1319d726f791e862c251bd969f57694)
            check_type(argname="argument count", value=count, expected_type=type_hints["count"])
            check_type(argname="argument order", value=order, expected_type=type_hints["order"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if count is not None:
            self._values["count"] = count
        if order is not None:
            self._values["order"] = order

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''The number of results to return.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#count Powerpack#count}
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def order(self) -> typing.Optional[builtins.str]:
        '''The direction of the sort. Valid values are ``asc``, ``desc``. Defaults to ``"desc"``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        result = self._values.get("order")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetSunburstDefinitionRequestFormulaLimit(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetSunburstDefinitionRequestFormulaLimitOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestFormulaLimitOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__20349244e549901ffbca9453a177516f6c7e372471a2a60de598bd95e8a4e394)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetCount")
    def reset_count(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCount", []))

    @jsii.member(jsii_name="resetOrder")
    def reset_order(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetOrder", []))

    @builtins.property
    @jsii.member(jsii_name="countInput")
    def count_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "countInput"))

    @builtins.property
    @jsii.member(jsii_name="orderInput")
    def order_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "orderInput"))

    @builtins.property
    @jsii.member(jsii_name="count")
    def count(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "count"))

    @count.setter
    def count(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7338f04550c7e816dac951d488ac7b40dec98ca232b1db860779be5cfc7e5821)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "count", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="order")
    def order(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "order"))

    @order.setter
    def order(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9222643ca909def373e8860b92265ada6edfd1bd1a40b8ad4d3f30f118e9a939)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "order", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetSunburstDefinitionRequestFormulaLimit]:
        return typing.cast(typing.Optional[PowerpackWidgetSunburstDefinitionRequestFormulaLimit], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetSunburstDefinitionRequestFormulaLimit],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__43eea59c153c9ef8a4443b29d02838d1355db728c193a592f823e3d83ba70280)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetSunburstDefinitionRequestFormulaList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestFormulaList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ad8e72520d28e9e1f439c2c48b6c4b593f6415ebb991af0498465f75a9ec1d75)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetSunburstDefinitionRequestFormulaOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dc38e23866564cce735cdb0bbcb4cb7197f707527ec4596e5e158503e73ac562)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetSunburstDefinitionRequestFormulaOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__becd4d697d1139392f32753c196d13fbd6343c7b521d5fb48829de256732036a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7a61590c8817749106d5d30965744f768715c6a09fd3b70d86f56407b8302ffd)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__56ab0ef27568b05bc1a8a3f1a33ef13c348c778f345435e1370a90c775623193)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequestFormula]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequestFormula]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequestFormula]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c9d1146c9fa0d501998c9a38c8204267ce142b55c7ff8b0ab7888cf4ce8847c8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormat",
    jsii_struct_bases=[],
    name_mapping={"unit": "unit", "unit_scale": "unitScale"},
)
class PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormat:
    def __init__(
        self,
        *,
        unit: typing.Union["PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormatUnit", typing.Dict[builtins.str, typing.Any]],
        unit_scale: typing.Optional[typing.Union["PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormatUnitScale", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param unit: unit block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit Powerpack#unit}
        :param unit_scale: unit_scale block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit_scale Powerpack#unit_scale}
        '''
        if isinstance(unit, dict):
            unit = PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormatUnit(**unit)
        if isinstance(unit_scale, dict):
            unit_scale = PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormatUnitScale(**unit_scale)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e50eb6e78b71a6df83c42f81a5683da98e95385b2671cbe90f036d4757f7a0f4)
            check_type(argname="argument unit", value=unit, expected_type=type_hints["unit"])
            check_type(argname="argument unit_scale", value=unit_scale, expected_type=type_hints["unit_scale"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "unit": unit,
        }
        if unit_scale is not None:
            self._values["unit_scale"] = unit_scale

    @builtins.property
    def unit(self) -> "PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormatUnit":
        '''unit block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit Powerpack#unit}
        '''
        result = self._values.get("unit")
        assert result is not None, "Required property 'unit' is missing"
        return typing.cast("PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormatUnit", result)

    @builtins.property
    def unit_scale(
        self,
    ) -> typing.Optional["PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormatUnitScale"]:
        '''unit_scale block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit_scale Powerpack#unit_scale}
        '''
        result = self._values.get("unit_scale")
        return typing.cast(typing.Optional["PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormatUnitScale"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormat(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormatOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormatOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5bd074118429c0b018a31927905e8d16a945ce70e6665ede42678d4e52c0749a)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putUnit")
    def put_unit(
        self,
        *,
        canonical: typing.Optional[typing.Union["PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormatUnitCanonical", typing.Dict[builtins.str, typing.Any]]] = None,
        custom: typing.Optional[typing.Union["PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormatUnitCustom", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param canonical: canonical block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#canonical Powerpack#canonical}
        :param custom: custom block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom Powerpack#custom}
        '''
        value = PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormatUnit(
            canonical=canonical, custom=custom
        )

        return typing.cast(None, jsii.invoke(self, "putUnit", [value]))

    @jsii.member(jsii_name="putUnitScale")
    def put_unit_scale(self, *, unit_name: builtins.str) -> None:
        '''
        :param unit_name: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit_name Powerpack#unit_name}.
        '''
        value = PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormatUnitScale(
            unit_name=unit_name
        )

        return typing.cast(None, jsii.invoke(self, "putUnitScale", [value]))

    @jsii.member(jsii_name="resetUnitScale")
    def reset_unit_scale(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetUnitScale", []))

    @builtins.property
    @jsii.member(jsii_name="unit")
    def unit(
        self,
    ) -> "PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormatUnitOutputReference":
        return typing.cast("PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormatUnitOutputReference", jsii.get(self, "unit"))

    @builtins.property
    @jsii.member(jsii_name="unitScale")
    def unit_scale(
        self,
    ) -> "PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormatUnitScaleOutputReference":
        return typing.cast("PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormatUnitScaleOutputReference", jsii.get(self, "unitScale"))

    @builtins.property
    @jsii.member(jsii_name="unitInput")
    def unit_input(
        self,
    ) -> typing.Optional["PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormatUnit"]:
        return typing.cast(typing.Optional["PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormatUnit"], jsii.get(self, "unitInput"))

    @builtins.property
    @jsii.member(jsii_name="unitScaleInput")
    def unit_scale_input(
        self,
    ) -> typing.Optional["PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormatUnitScale"]:
        return typing.cast(typing.Optional["PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormatUnitScale"], jsii.get(self, "unitScaleInput"))

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormat]:
        return typing.cast(typing.Optional[PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormat], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormat],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b6b43baf6e2fc0b805528c6cb962fb0103f20ce497074cdbc8e39484ddf07ce0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormatUnit",
    jsii_struct_bases=[],
    name_mapping={"canonical": "canonical", "custom": "custom"},
)
class PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormatUnit:
    def __init__(
        self,
        *,
        canonical: typing.Optional[typing.Union["PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormatUnitCanonical", typing.Dict[builtins.str, typing.Any]]] = None,
        custom: typing.Optional[typing.Union["PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormatUnitCustom", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param canonical: canonical block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#canonical Powerpack#canonical}
        :param custom: custom block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom Powerpack#custom}
        '''
        if isinstance(canonical, dict):
            canonical = PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormatUnitCanonical(**canonical)
        if isinstance(custom, dict):
            custom = PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormatUnitCustom(**custom)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bc3cba64425bc4a6361e1e5de92166d2daffa8734f7d30720cb528d548ecc99a)
            check_type(argname="argument canonical", value=canonical, expected_type=type_hints["canonical"])
            check_type(argname="argument custom", value=custom, expected_type=type_hints["custom"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if canonical is not None:
            self._values["canonical"] = canonical
        if custom is not None:
            self._values["custom"] = custom

    @builtins.property
    def canonical(
        self,
    ) -> typing.Optional["PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormatUnitCanonical"]:
        '''canonical block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#canonical Powerpack#canonical}
        '''
        result = self._values.get("canonical")
        return typing.cast(typing.Optional["PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormatUnitCanonical"], result)

    @builtins.property
    def custom(
        self,
    ) -> typing.Optional["PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormatUnitCustom"]:
        '''custom block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom Powerpack#custom}
        '''
        result = self._values.get("custom")
        return typing.cast(typing.Optional["PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormatUnitCustom"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormatUnit(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormatUnitCanonical",
    jsii_struct_bases=[],
    name_mapping={"unit_name": "unitName", "per_unit_name": "perUnitName"},
)
class PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormatUnitCanonical:
    def __init__(
        self,
        *,
        unit_name: builtins.str,
        per_unit_name: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param unit_name: Unit name. It should be in singular form ('megabyte' and not 'megabytes'). Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit_name Powerpack#unit_name}
        :param per_unit_name: per unit name. If you want to represent megabytes/s, you set 'unit_name' = 'megabyte' and 'per_unit_name = 'second'. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#per_unit_name Powerpack#per_unit_name}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1ef08f883264805463f061b6a89cb15138ed1e551cdc1d20a7885fd0bc4be4e8)
            check_type(argname="argument unit_name", value=unit_name, expected_type=type_hints["unit_name"])
            check_type(argname="argument per_unit_name", value=per_unit_name, expected_type=type_hints["per_unit_name"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "unit_name": unit_name,
        }
        if per_unit_name is not None:
            self._values["per_unit_name"] = per_unit_name

    @builtins.property
    def unit_name(self) -> builtins.str:
        '''Unit name. It should be in singular form ('megabyte' and not 'megabytes').

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit_name Powerpack#unit_name}
        '''
        result = self._values.get("unit_name")
        assert result is not None, "Required property 'unit_name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def per_unit_name(self) -> typing.Optional[builtins.str]:
        '''per unit name. If you want to represent megabytes/s, you set 'unit_name' = 'megabyte' and 'per_unit_name = 'second'.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#per_unit_name Powerpack#per_unit_name}
        '''
        result = self._values.get("per_unit_name")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormatUnitCanonical(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormatUnitCanonicalOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormatUnitCanonicalOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5c343bc84776d5c205b416bc1ff076056ea6c751aca50df9bafbbabdd9a2bfae)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetPerUnitName")
    def reset_per_unit_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPerUnitName", []))

    @builtins.property
    @jsii.member(jsii_name="perUnitNameInput")
    def per_unit_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "perUnitNameInput"))

    @builtins.property
    @jsii.member(jsii_name="unitNameInput")
    def unit_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "unitNameInput"))

    @builtins.property
    @jsii.member(jsii_name="perUnitName")
    def per_unit_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "perUnitName"))

    @per_unit_name.setter
    def per_unit_name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__60f749a16eefcc0963a0557a946f8a9809caa0a14be6fca0391109a16fc23906)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "perUnitName", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="unitName")
    def unit_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "unitName"))

    @unit_name.setter
    def unit_name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1e0a16b8f6448a528d93ff0e59bbaf143d154fefbcc5cad6b1041c2be0562f66)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "unitName", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormatUnitCanonical]:
        return typing.cast(typing.Optional[PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormatUnitCanonical], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormatUnitCanonical],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5fbe52f7d9945baa845bee4c5863f179f8ae6f3149cd9b247ec0d0d15873f3cc)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormatUnitCustom",
    jsii_struct_bases=[],
    name_mapping={"label": "label"},
)
class PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormatUnitCustom:
    def __init__(self, *, label: builtins.str) -> None:
        '''
        :param label: Unit label. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#label Powerpack#label}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__707fe16e529e6835d93913b0ca44bbf2eefa47a9ef5f7617649f984973cf1bfc)
            check_type(argname="argument label", value=label, expected_type=type_hints["label"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "label": label,
        }

    @builtins.property
    def label(self) -> builtins.str:
        '''Unit label.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#label Powerpack#label}
        '''
        result = self._values.get("label")
        assert result is not None, "Required property 'label' is missing"
        return typing.cast(builtins.str, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormatUnitCustom(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormatUnitCustomOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormatUnitCustomOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__666f879bfae940b9ab97868624dcc9379b1ad59e7a10be9af07e967ff83e5a93)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @builtins.property
    @jsii.member(jsii_name="labelInput")
    def label_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "labelInput"))

    @builtins.property
    @jsii.member(jsii_name="label")
    def label(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "label"))

    @label.setter
    def label(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__241f97cd8a75c026809eea44c978d3aebfffb4b24ed401a604c44c04e1768d35)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "label", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormatUnitCustom]:
        return typing.cast(typing.Optional[PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormatUnitCustom], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormatUnitCustom],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__51fe7f2c3e6b3e01a037c9088b6650441c7088f82e924a4b004c9bf9c8811fbf)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormatUnitOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormatUnitOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__85738f95508f972c61c138298f377a53bf6a4c1e528e83f86fe3ea34bdc91ce6)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putCanonical")
    def put_canonical(
        self,
        *,
        unit_name: builtins.str,
        per_unit_name: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param unit_name: Unit name. It should be in singular form ('megabyte' and not 'megabytes'). Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit_name Powerpack#unit_name}
        :param per_unit_name: per unit name. If you want to represent megabytes/s, you set 'unit_name' = 'megabyte' and 'per_unit_name = 'second'. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#per_unit_name Powerpack#per_unit_name}
        '''
        value = PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormatUnitCanonical(
            unit_name=unit_name, per_unit_name=per_unit_name
        )

        return typing.cast(None, jsii.invoke(self, "putCanonical", [value]))

    @jsii.member(jsii_name="putCustom")
    def put_custom(self, *, label: builtins.str) -> None:
        '''
        :param label: Unit label. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#label Powerpack#label}
        '''
        value = PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormatUnitCustom(
            label=label
        )

        return typing.cast(None, jsii.invoke(self, "putCustom", [value]))

    @jsii.member(jsii_name="resetCanonical")
    def reset_canonical(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCanonical", []))

    @jsii.member(jsii_name="resetCustom")
    def reset_custom(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCustom", []))

    @builtins.property
    @jsii.member(jsii_name="canonical")
    def canonical(
        self,
    ) -> PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormatUnitCanonicalOutputReference:
        return typing.cast(PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormatUnitCanonicalOutputReference, jsii.get(self, "canonical"))

    @builtins.property
    @jsii.member(jsii_name="custom")
    def custom(
        self,
    ) -> PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormatUnitCustomOutputReference:
        return typing.cast(PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormatUnitCustomOutputReference, jsii.get(self, "custom"))

    @builtins.property
    @jsii.member(jsii_name="canonicalInput")
    def canonical_input(
        self,
    ) -> typing.Optional[PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormatUnitCanonical]:
        return typing.cast(typing.Optional[PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormatUnitCanonical], jsii.get(self, "canonicalInput"))

    @builtins.property
    @jsii.member(jsii_name="customInput")
    def custom_input(
        self,
    ) -> typing.Optional[PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormatUnitCustom]:
        return typing.cast(typing.Optional[PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormatUnitCustom], jsii.get(self, "customInput"))

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormatUnit]:
        return typing.cast(typing.Optional[PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormatUnit], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormatUnit],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1d37114e56e1c58603cc4c1915d11eddae5bf8f3b834b8420ad443ff6a2ec24e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormatUnitScale",
    jsii_struct_bases=[],
    name_mapping={"unit_name": "unitName"},
)
class PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormatUnitScale:
    def __init__(self, *, unit_name: builtins.str) -> None:
        '''
        :param unit_name: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit_name Powerpack#unit_name}.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__09f6fe0595180d81bdd643b67bc28286c4ef05dc8f39ebb71e18ea5bed228a26)
            check_type(argname="argument unit_name", value=unit_name, expected_type=type_hints["unit_name"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "unit_name": unit_name,
        }

    @builtins.property
    def unit_name(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit_name Powerpack#unit_name}.'''
        result = self._values.get("unit_name")
        assert result is not None, "Required property 'unit_name' is missing"
        return typing.cast(builtins.str, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormatUnitScale(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormatUnitScaleOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormatUnitScaleOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2fb4407ffa8f3be2a298a0e800ef40e7d0c46dbcc56ba0dcde6644b9dadfb542)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @builtins.property
    @jsii.member(jsii_name="unitNameInput")
    def unit_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "unitNameInput"))

    @builtins.property
    @jsii.member(jsii_name="unitName")
    def unit_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "unitName"))

    @unit_name.setter
    def unit_name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__363edc60f4ec2136b37b5cf268d4a109a3d4b32853c5a751394eea2b5ac5a5ec)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "unitName", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormatUnitScale]:
        return typing.cast(typing.Optional[PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormatUnitScale], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormatUnitScale],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__db854819fb7a48319abc70ac012862eeacb0b4fd74734f618235a8658bf5afee)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetSunburstDefinitionRequestFormulaOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestFormulaOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__68269d9327569a124607c9bd18e2ff8dba454470e500e9397b5b9a6ce6b65c2b)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putConditionalFormats")
    def put_conditional_formats(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetSunburstDefinitionRequestFormulaConditionalFormats, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f9e5c176982937fc21c6f173234a95ef533cdb757178ea2647b1c10e5f2e644e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putConditionalFormats", [value]))

    @jsii.member(jsii_name="putLimit")
    def put_limit(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        order: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param count: The number of results to return. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#count Powerpack#count}
        :param order: The direction of the sort. Valid values are ``asc``, ``desc``. Defaults to ``"desc"``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        value = PowerpackWidgetSunburstDefinitionRequestFormulaLimit(
            count=count, order=order
        )

        return typing.cast(None, jsii.invoke(self, "putLimit", [value]))

    @jsii.member(jsii_name="putNumberFormat")
    def put_number_format(
        self,
        *,
        unit: typing.Union[PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormatUnit, typing.Dict[builtins.str, typing.Any]],
        unit_scale: typing.Optional[typing.Union[PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormatUnitScale, typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param unit: unit block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit Powerpack#unit}
        :param unit_scale: unit_scale block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit_scale Powerpack#unit_scale}
        '''
        value = PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormat(
            unit=unit, unit_scale=unit_scale
        )

        return typing.cast(None, jsii.invoke(self, "putNumberFormat", [value]))

    @jsii.member(jsii_name="putStyle")
    def put_style(
        self,
        *,
        palette: typing.Optional[builtins.str] = None,
        palette_index: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param palette: The color palette used to display the formula. A guide to the available color palettes can be found at https://docs.datadoghq.com/dashboards/guide/widget_colors. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette Powerpack#palette}
        :param palette_index: Index specifying which color to use within the palette. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette_index Powerpack#palette_index}
        '''
        value = PowerpackWidgetSunburstDefinitionRequestFormulaStyle(
            palette=palette, palette_index=palette_index
        )

        return typing.cast(None, jsii.invoke(self, "putStyle", [value]))

    @jsii.member(jsii_name="resetAlias")
    def reset_alias(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAlias", []))

    @jsii.member(jsii_name="resetCellDisplayMode")
    def reset_cell_display_mode(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCellDisplayMode", []))

    @jsii.member(jsii_name="resetConditionalFormats")
    def reset_conditional_formats(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetConditionalFormats", []))

    @jsii.member(jsii_name="resetLimit")
    def reset_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLimit", []))

    @jsii.member(jsii_name="resetNumberFormat")
    def reset_number_format(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetNumberFormat", []))

    @jsii.member(jsii_name="resetStyle")
    def reset_style(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetStyle", []))

    @builtins.property
    @jsii.member(jsii_name="conditionalFormats")
    def conditional_formats(
        self,
    ) -> PowerpackWidgetSunburstDefinitionRequestFormulaConditionalFormatsList:
        return typing.cast(PowerpackWidgetSunburstDefinitionRequestFormulaConditionalFormatsList, jsii.get(self, "conditionalFormats"))

    @builtins.property
    @jsii.member(jsii_name="limit")
    def limit(
        self,
    ) -> PowerpackWidgetSunburstDefinitionRequestFormulaLimitOutputReference:
        return typing.cast(PowerpackWidgetSunburstDefinitionRequestFormulaLimitOutputReference, jsii.get(self, "limit"))

    @builtins.property
    @jsii.member(jsii_name="numberFormat")
    def number_format(
        self,
    ) -> PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormatOutputReference:
        return typing.cast(PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormatOutputReference, jsii.get(self, "numberFormat"))

    @builtins.property
    @jsii.member(jsii_name="style")
    def style(
        self,
    ) -> "PowerpackWidgetSunburstDefinitionRequestFormulaStyleOutputReference":
        return typing.cast("PowerpackWidgetSunburstDefinitionRequestFormulaStyleOutputReference", jsii.get(self, "style"))

    @builtins.property
    @jsii.member(jsii_name="aliasInput")
    def alias_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aliasInput"))

    @builtins.property
    @jsii.member(jsii_name="cellDisplayModeInput")
    def cell_display_mode_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "cellDisplayModeInput"))

    @builtins.property
    @jsii.member(jsii_name="conditionalFormatsInput")
    def conditional_formats_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequestFormulaConditionalFormats]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequestFormulaConditionalFormats]]], jsii.get(self, "conditionalFormatsInput"))

    @builtins.property
    @jsii.member(jsii_name="formulaExpressionInput")
    def formula_expression_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "formulaExpressionInput"))

    @builtins.property
    @jsii.member(jsii_name="limitInput")
    def limit_input(
        self,
    ) -> typing.Optional[PowerpackWidgetSunburstDefinitionRequestFormulaLimit]:
        return typing.cast(typing.Optional[PowerpackWidgetSunburstDefinitionRequestFormulaLimit], jsii.get(self, "limitInput"))

    @builtins.property
    @jsii.member(jsii_name="numberFormatInput")
    def number_format_input(
        self,
    ) -> typing.Optional[PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormat]:
        return typing.cast(typing.Optional[PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormat], jsii.get(self, "numberFormatInput"))

    @builtins.property
    @jsii.member(jsii_name="styleInput")
    def style_input(
        self,
    ) -> typing.Optional["PowerpackWidgetSunburstDefinitionRequestFormulaStyle"]:
        return typing.cast(typing.Optional["PowerpackWidgetSunburstDefinitionRequestFormulaStyle"], jsii.get(self, "styleInput"))

    @builtins.property
    @jsii.member(jsii_name="alias")
    def alias(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "alias"))

    @alias.setter
    def alias(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cb334c2a9599c62f4079fcd62c24864edd01199ff7f9e211ea444fcc3f9ed305)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "alias", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="cellDisplayMode")
    def cell_display_mode(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "cellDisplayMode"))

    @cell_display_mode.setter
    def cell_display_mode(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7f6a420c68892ec1a5c78e3a4e8e747a80e046352cff52d89e0da49d4d70ddfb)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "cellDisplayMode", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="formulaExpression")
    def formula_expression(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "formulaExpression"))

    @formula_expression.setter
    def formula_expression(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__901ac238bf8c3b6820cbb9d1f079b82432c604849d4265d21ecbee78b8ff0c33)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "formulaExpression", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetSunburstDefinitionRequestFormula]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetSunburstDefinitionRequestFormula]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetSunburstDefinitionRequestFormula]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ece6ffbe8a62c48c325caaddbb0ef112317cd76821cb68451aaf2be6962ce01f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestFormulaStyle",
    jsii_struct_bases=[],
    name_mapping={"palette": "palette", "palette_index": "paletteIndex"},
)
class PowerpackWidgetSunburstDefinitionRequestFormulaStyle:
    def __init__(
        self,
        *,
        palette: typing.Optional[builtins.str] = None,
        palette_index: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param palette: The color palette used to display the formula. A guide to the available color palettes can be found at https://docs.datadoghq.com/dashboards/guide/widget_colors. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette Powerpack#palette}
        :param palette_index: Index specifying which color to use within the palette. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette_index Powerpack#palette_index}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ab3154a4563d073370f0e6f315cdd6ae0169b554a73b16dd4ef86b6e16700cd9)
            check_type(argname="argument palette", value=palette, expected_type=type_hints["palette"])
            check_type(argname="argument palette_index", value=palette_index, expected_type=type_hints["palette_index"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if palette is not None:
            self._values["palette"] = palette
        if palette_index is not None:
            self._values["palette_index"] = palette_index

    @builtins.property
    def palette(self) -> typing.Optional[builtins.str]:
        '''The color palette used to display the formula.

        A guide to the available color palettes can be found at https://docs.datadoghq.com/dashboards/guide/widget_colors.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette Powerpack#palette}
        '''
        result = self._values.get("palette")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def palette_index(self) -> typing.Optional[jsii.Number]:
        '''Index specifying which color to use within the palette.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette_index Powerpack#palette_index}
        '''
        result = self._values.get("palette_index")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetSunburstDefinitionRequestFormulaStyle(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetSunburstDefinitionRequestFormulaStyleOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestFormulaStyleOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0ea2c1ff0fe8161211894e6697a22dfe084eb159e1eb987013ea2b329d2371b8)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetPalette")
    def reset_palette(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPalette", []))

    @jsii.member(jsii_name="resetPaletteIndex")
    def reset_palette_index(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPaletteIndex", []))

    @builtins.property
    @jsii.member(jsii_name="paletteIndexInput")
    def palette_index_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "paletteIndexInput"))

    @builtins.property
    @jsii.member(jsii_name="paletteInput")
    def palette_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "paletteInput"))

    @builtins.property
    @jsii.member(jsii_name="palette")
    def palette(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "palette"))

    @palette.setter
    def palette(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6d6fa23383095e9e0ddd2541e08db5b8850b45c707c56c9c64be0b5422d5bf92)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "palette", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="paletteIndex")
    def palette_index(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "paletteIndex"))

    @palette_index.setter
    def palette_index(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b083d8106e275a4f4c26671f005c42b8c2647628e5a943d7d9b46961097988ee)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "paletteIndex", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetSunburstDefinitionRequestFormulaStyle]:
        return typing.cast(typing.Optional[PowerpackWidgetSunburstDefinitionRequestFormulaStyle], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetSunburstDefinitionRequestFormulaStyle],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1bd24e3fe6db95d61503179bc339ab0f90a896878ff6739c9804017d05a20e57)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetSunburstDefinitionRequestList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e29b9593b7a148844ca4dc06b269f927aff17104616d05cd5e71cff4a71af22b)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetSunburstDefinitionRequestOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5337cca460a5e9ad84fc0b5539551ceff3b476900464a3d6d257b8ce713be13d)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetSunburstDefinitionRequestOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__382335d0b190bd07f406536199176a78651ffa422d4fd2e70a99f6e7f5aa4f9e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__abf4d797830afd44d55a9e3ad3cef56aeef5e9eebee45fa0f975911435aa2d1f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f4e1af7624cea8632a60c9bb9d41f8befc6cc905d5a1253669a0c1baa151211a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequest]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequest]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequest]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b003e064bf075f556e23c638a9386d8f7ce0ab70485674c4246dac7eb0309232)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestLogQuery",
    jsii_struct_bases=[],
    name_mapping={
        "index": "index",
        "compute_query": "computeQuery",
        "group_by": "groupBy",
        "multi_compute": "multiCompute",
        "search_query": "searchQuery",
    },
)
class PowerpackWidgetSunburstDefinitionRequestLogQuery:
    def __init__(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union["PowerpackWidgetSunburstDefinitionRequestLogQueryComputeQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetSunburstDefinitionRequestLogQueryGroupBy", typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetSunburstDefinitionRequestLogQueryMultiCompute", typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        if isinstance(compute_query, dict):
            compute_query = PowerpackWidgetSunburstDefinitionRequestLogQueryComputeQuery(**compute_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dfde00dabdde12714dd9b6bfd242ed36699e510813cd9c3a1589a797fbabb7a6)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
            check_type(argname="argument compute_query", value=compute_query, expected_type=type_hints["compute_query"])
            check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
            check_type(argname="argument multi_compute", value=multi_compute, expected_type=type_hints["multi_compute"])
            check_type(argname="argument search_query", value=search_query, expected_type=type_hints["search_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "index": index,
        }
        if compute_query is not None:
            self._values["compute_query"] = compute_query
        if group_by is not None:
            self._values["group_by"] = group_by
        if multi_compute is not None:
            self._values["multi_compute"] = multi_compute
        if search_query is not None:
            self._values["search_query"] = search_query

    @builtins.property
    def index(self) -> builtins.str:
        '''The name of the index to query.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        '''
        result = self._values.get("index")
        assert result is not None, "Required property 'index' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def compute_query(
        self,
    ) -> typing.Optional["PowerpackWidgetSunburstDefinitionRequestLogQueryComputeQuery"]:
        '''compute_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        '''
        result = self._values.get("compute_query")
        return typing.cast(typing.Optional["PowerpackWidgetSunburstDefinitionRequestLogQueryComputeQuery"], result)

    @builtins.property
    def group_by(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetSunburstDefinitionRequestLogQueryGroupBy"]]]:
        '''group_by block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        '''
        result = self._values.get("group_by")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetSunburstDefinitionRequestLogQueryGroupBy"]]], result)

    @builtins.property
    def multi_compute(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetSunburstDefinitionRequestLogQueryMultiCompute"]]]:
        '''multi_compute block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        '''
        result = self._values.get("multi_compute")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetSunburstDefinitionRequestLogQueryMultiCompute"]]], result)

    @builtins.property
    def search_query(self) -> typing.Optional[builtins.str]:
        '''The search query to use.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        result = self._values.get("search_query")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetSunburstDefinitionRequestLogQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestLogQueryComputeQuery",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetSunburstDefinitionRequestLogQueryComputeQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__96208bb84b1265da750adc4035ad3f73d31dc965cd7c74bbe40119453672b02f)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetSunburstDefinitionRequestLogQueryComputeQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetSunburstDefinitionRequestLogQueryComputeQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestLogQueryComputeQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__92a1ed4cc2a849e84caae0654accbe776f8f57f78589405f17ba1ac9da6d16a0)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__307a0841505791a879a99bb05f59dd8d99d58a101a40dedfc0f3733460b4a341)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0209729865d1f2d12d52bfa1361e4029b87b7ef114382b33192e91ea5c194739)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2035b7fd0a68577b24ac29159432ee530c61c00d889f37183ea94b763464a415)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetSunburstDefinitionRequestLogQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetSunburstDefinitionRequestLogQueryComputeQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetSunburstDefinitionRequestLogQueryComputeQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d6f2dd54448d8ec221654445369b37d4d5bebbb65375048a435819a51cd0c804)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestLogQueryGroupBy",
    jsii_struct_bases=[],
    name_mapping={"facet": "facet", "limit": "limit", "sort_query": "sortQuery"},
)
class PowerpackWidgetSunburstDefinitionRequestLogQueryGroupBy:
    def __init__(
        self,
        *,
        facet: typing.Optional[builtins.str] = None,
        limit: typing.Optional[jsii.Number] = None,
        sort_query: typing.Optional[typing.Union["PowerpackWidgetSunburstDefinitionRequestLogQueryGroupBySortQuery", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param limit: The maximum number of items in the group. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param sort_query: sort_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        if isinstance(sort_query, dict):
            sort_query = PowerpackWidgetSunburstDefinitionRequestLogQueryGroupBySortQuery(**sort_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__48a741ac667f1ad0340fff3728cddda8cd017de851939d2b32f9028fe87b549a)
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
            check_type(argname="argument sort_query", value=sort_query, expected_type=type_hints["sort_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if facet is not None:
            self._values["facet"] = facet
        if limit is not None:
            self._values["limit"] = limit
        if sort_query is not None:
            self._values["sort_query"] = sort_query

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def limit(self) -> typing.Optional[jsii.Number]:
        '''The maximum number of items in the group.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        '''
        result = self._values.get("limit")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def sort_query(
        self,
    ) -> typing.Optional["PowerpackWidgetSunburstDefinitionRequestLogQueryGroupBySortQuery"]:
        '''sort_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        result = self._values.get("sort_query")
        return typing.cast(typing.Optional["PowerpackWidgetSunburstDefinitionRequestLogQueryGroupBySortQuery"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetSunburstDefinitionRequestLogQueryGroupBy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetSunburstDefinitionRequestLogQueryGroupByList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestLogQueryGroupByList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e24efb78183ba18858e80ed2fc6fd255ea06044136139e2f65dcf066dc6d8f52)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetSunburstDefinitionRequestLogQueryGroupByOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2f6fad132cbe940b10535112732914bc2a552d2c4dd9cba95d18258ef7268ec0)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetSunburstDefinitionRequestLogQueryGroupByOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__35d8688129c0ae2416aaae4fd7b6d8eee3a2acff2bc83de573441cf53588deec)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__128a4d1ee2a39aa5972e89830bcfc6e56cf44be677bd6927ed88125d0ea0aae2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fef8beceb360bb45681a41652f8ab1d6a81d94508452828c039cfa0542cbbce0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequestLogQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequestLogQueryGroupBy]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequestLogQueryGroupBy]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bcee36606933244ffd5881f2353883fa707eb204b75544a970607647e44c1d9c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetSunburstDefinitionRequestLogQueryGroupByOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestLogQueryGroupByOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4f1f4691d0a10edda5d2c17a462a55fea143c1d5407328c7b060c27bf47c7df7)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putSortQuery")
    def put_sort_query(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        value = PowerpackWidgetSunburstDefinitionRequestLogQueryGroupBySortQuery(
            aggregation=aggregation, order=order, facet=facet
        )

        return typing.cast(None, jsii.invoke(self, "putSortQuery", [value]))

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetLimit")
    def reset_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLimit", []))

    @jsii.member(jsii_name="resetSortQuery")
    def reset_sort_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSortQuery", []))

    @builtins.property
    @jsii.member(jsii_name="sortQuery")
    def sort_query(
        self,
    ) -> "PowerpackWidgetSunburstDefinitionRequestLogQueryGroupBySortQueryOutputReference":
        return typing.cast("PowerpackWidgetSunburstDefinitionRequestLogQueryGroupBySortQueryOutputReference", jsii.get(self, "sortQuery"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="limitInput")
    def limit_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "limitInput"))

    @builtins.property
    @jsii.member(jsii_name="sortQueryInput")
    def sort_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetSunburstDefinitionRequestLogQueryGroupBySortQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetSunburstDefinitionRequestLogQueryGroupBySortQuery"], jsii.get(self, "sortQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__70864a083203183e67f5badd07e16613d52629bf4cd3c3c0145027dea7de91ed)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="limit")
    def limit(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "limit"))

    @limit.setter
    def limit(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a4cfd1b19f977ba60dd015c429a5e4c90ae0756e122cbdf747f905479eef5510)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "limit", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetSunburstDefinitionRequestLogQueryGroupBy]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetSunburstDefinitionRequestLogQueryGroupBy]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetSunburstDefinitionRequestLogQueryGroupBy]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ac51a8d31c807ff078c398ac3e9e2acbdaf7874e8e7b35f360cc60ae11b8b84d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestLogQueryGroupBySortQuery",
    jsii_struct_bases=[],
    name_mapping={"aggregation": "aggregation", "order": "order", "facet": "facet"},
)
class PowerpackWidgetSunburstDefinitionRequestLogQueryGroupBySortQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f966ba2e808218e719d32e44147d49e40f9003364b085194ba5ac395ee685b32)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument order", value=order, expected_type=type_hints["order"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
            "order": order,
        }
        if facet is not None:
            self._values["facet"] = facet

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def order(self) -> builtins.str:
        '''Widget sorting methods. Valid values are ``asc``, ``desc``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        result = self._values.get("order")
        assert result is not None, "Required property 'order' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetSunburstDefinitionRequestLogQueryGroupBySortQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetSunburstDefinitionRequestLogQueryGroupBySortQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestLogQueryGroupBySortQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c2096ee4bc21b10d4303bd73cea567b748055f26bf24f9cdaf3fd3ab0067e1d2)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="orderInput")
    def order_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "orderInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4caa089bb4776a8bffdcd6a795a34f70f91fc28b0671f3a80f6698103d425b19)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a08574b77206f7da5126f06d84af732df258f2c9bea1e2fcf9b340c9016669dd)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="order")
    def order(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "order"))

    @order.setter
    def order(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0949474e6359c96186a0c242a771bdc719b0603ded3c5186c1346a08d37e308d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "order", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetSunburstDefinitionRequestLogQueryGroupBySortQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetSunburstDefinitionRequestLogQueryGroupBySortQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetSunburstDefinitionRequestLogQueryGroupBySortQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f9d497a7a059d5649455e87238afd1d9a32734f7d6bf396a65c1cfe997fcec68)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestLogQueryMultiCompute",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetSunburstDefinitionRequestLogQueryMultiCompute:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4f939fafc0865d5bac37e8d5b6cbf4982953485a70aa1353a90e57defd6662e1)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetSunburstDefinitionRequestLogQueryMultiCompute(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetSunburstDefinitionRequestLogQueryMultiComputeList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestLogQueryMultiComputeList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__09ab0733ad7c7902223adab907b8b10754098ddc8b565cd43d2b05556cda7dba)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetSunburstDefinitionRequestLogQueryMultiComputeOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d48cc5321218b5082274bb8558af3cb460a6cd4a86f7b86938a7319104908ed5)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetSunburstDefinitionRequestLogQueryMultiComputeOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__91552b01c857085cbcadbff2b4e67c5ab2652357f5fc76763645bb0be8422fca)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d8d747ef59ae2e2b7592fc9410f202d5278da9c7a1f499c0046690ec826b5f77)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d7ea6f68fcade609d5e03a7639c4168bd4126629b7cb00374454b8048b13f10d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequestLogQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequestLogQueryMultiCompute]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequestLogQueryMultiCompute]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ecee38fc00ce1b397cab4eee047a540432885c29f54c60a5f7700ff6347c737d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetSunburstDefinitionRequestLogQueryMultiComputeOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestLogQueryMultiComputeOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9d3bfa5d8c26df8b7a694dbd27323e492b1561ed4e49cfe87887332df5c30718)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__384ccd23a46a53e429173259e0d2bc754f88abe20162e6c2fa4027141dad43e2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3273fe1a27762f7b82d039dd4e56dfccc7eae5c7a4c47273f78e50abc3429acf)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__83b7654f71b4dca140f6d2cd39a88eeb99d171316b6414552bffa1690a29b8ce)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetSunburstDefinitionRequestLogQueryMultiCompute]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetSunburstDefinitionRequestLogQueryMultiCompute]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetSunburstDefinitionRequestLogQueryMultiCompute]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__237b0d4d7eeea38f153d8b8fccb86adbd9b90095002f79ed2f62ab459de1ede4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetSunburstDefinitionRequestLogQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestLogQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6ee3b947a5786685351be1cfac79251f99b0056141b48ebdc5194af8d9c90560)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putComputeQuery")
    def put_compute_query(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        value = PowerpackWidgetSunburstDefinitionRequestLogQueryComputeQuery(
            aggregation=aggregation, facet=facet, interval=interval
        )

        return typing.cast(None, jsii.invoke(self, "putComputeQuery", [value]))

    @jsii.member(jsii_name="putGroupBy")
    def put_group_by(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetSunburstDefinitionRequestLogQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2a2361e1d9c4db8747f64509a127ab5f8d2a083e9409436a884864ee22116890)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putGroupBy", [value]))

    @jsii.member(jsii_name="putMultiCompute")
    def put_multi_compute(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetSunburstDefinitionRequestLogQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e7b86a90d1c6f6ca852ce67e4a24e8609838f2438f2d52de4bc2b189507efc9c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putMultiCompute", [value]))

    @jsii.member(jsii_name="resetComputeQuery")
    def reset_compute_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetComputeQuery", []))

    @jsii.member(jsii_name="resetGroupBy")
    def reset_group_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGroupBy", []))

    @jsii.member(jsii_name="resetMultiCompute")
    def reset_multi_compute(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMultiCompute", []))

    @jsii.member(jsii_name="resetSearchQuery")
    def reset_search_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSearchQuery", []))

    @builtins.property
    @jsii.member(jsii_name="computeQuery")
    def compute_query(
        self,
    ) -> PowerpackWidgetSunburstDefinitionRequestLogQueryComputeQueryOutputReference:
        return typing.cast(PowerpackWidgetSunburstDefinitionRequestLogQueryComputeQueryOutputReference, jsii.get(self, "computeQuery"))

    @builtins.property
    @jsii.member(jsii_name="groupBy")
    def group_by(self) -> PowerpackWidgetSunburstDefinitionRequestLogQueryGroupByList:
        return typing.cast(PowerpackWidgetSunburstDefinitionRequestLogQueryGroupByList, jsii.get(self, "groupBy"))

    @builtins.property
    @jsii.member(jsii_name="multiCompute")
    def multi_compute(
        self,
    ) -> PowerpackWidgetSunburstDefinitionRequestLogQueryMultiComputeList:
        return typing.cast(PowerpackWidgetSunburstDefinitionRequestLogQueryMultiComputeList, jsii.get(self, "multiCompute"))

    @builtins.property
    @jsii.member(jsii_name="computeQueryInput")
    def compute_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetSunburstDefinitionRequestLogQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetSunburstDefinitionRequestLogQueryComputeQuery], jsii.get(self, "computeQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="groupByInput")
    def group_by_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequestLogQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequestLogQueryGroupBy]]], jsii.get(self, "groupByInput"))

    @builtins.property
    @jsii.member(jsii_name="indexInput")
    def index_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "indexInput"))

    @builtins.property
    @jsii.member(jsii_name="multiComputeInput")
    def multi_compute_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequestLogQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequestLogQueryMultiCompute]]], jsii.get(self, "multiComputeInput"))

    @builtins.property
    @jsii.member(jsii_name="searchQueryInput")
    def search_query_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "searchQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="index")
    def index(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "index"))

    @index.setter
    def index(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__24604abe049b7f7604f17546f339202cfb6473903b50445749cdc51bd81c18fb)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "index", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="searchQuery")
    def search_query(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "searchQuery"))

    @search_query.setter
    def search_query(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__84dd25a34ca7316d709be8266a8f72a98fd63b15ba650aa5cf1b532b2062d580)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "searchQuery", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetSunburstDefinitionRequestLogQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetSunburstDefinitionRequestLogQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetSunburstDefinitionRequestLogQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__07ad1c6409e8a29043417137128b22cf54227387f14e96eda7c27bb20d29aefb)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestNetworkQuery",
    jsii_struct_bases=[],
    name_mapping={
        "index": "index",
        "compute_query": "computeQuery",
        "group_by": "groupBy",
        "multi_compute": "multiCompute",
        "search_query": "searchQuery",
    },
)
class PowerpackWidgetSunburstDefinitionRequestNetworkQuery:
    def __init__(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union["PowerpackWidgetSunburstDefinitionRequestNetworkQueryComputeQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetSunburstDefinitionRequestNetworkQueryGroupBy", typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetSunburstDefinitionRequestNetworkQueryMultiCompute", typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        if isinstance(compute_query, dict):
            compute_query = PowerpackWidgetSunburstDefinitionRequestNetworkQueryComputeQuery(**compute_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4efa3c8a351745bb2cb0a6feb64c5c506caebb55c15c171dd5ef2a7b922c9258)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
            check_type(argname="argument compute_query", value=compute_query, expected_type=type_hints["compute_query"])
            check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
            check_type(argname="argument multi_compute", value=multi_compute, expected_type=type_hints["multi_compute"])
            check_type(argname="argument search_query", value=search_query, expected_type=type_hints["search_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "index": index,
        }
        if compute_query is not None:
            self._values["compute_query"] = compute_query
        if group_by is not None:
            self._values["group_by"] = group_by
        if multi_compute is not None:
            self._values["multi_compute"] = multi_compute
        if search_query is not None:
            self._values["search_query"] = search_query

    @builtins.property
    def index(self) -> builtins.str:
        '''The name of the index to query.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        '''
        result = self._values.get("index")
        assert result is not None, "Required property 'index' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def compute_query(
        self,
    ) -> typing.Optional["PowerpackWidgetSunburstDefinitionRequestNetworkQueryComputeQuery"]:
        '''compute_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        '''
        result = self._values.get("compute_query")
        return typing.cast(typing.Optional["PowerpackWidgetSunburstDefinitionRequestNetworkQueryComputeQuery"], result)

    @builtins.property
    def group_by(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetSunburstDefinitionRequestNetworkQueryGroupBy"]]]:
        '''group_by block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        '''
        result = self._values.get("group_by")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetSunburstDefinitionRequestNetworkQueryGroupBy"]]], result)

    @builtins.property
    def multi_compute(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetSunburstDefinitionRequestNetworkQueryMultiCompute"]]]:
        '''multi_compute block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        '''
        result = self._values.get("multi_compute")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetSunburstDefinitionRequestNetworkQueryMultiCompute"]]], result)

    @builtins.property
    def search_query(self) -> typing.Optional[builtins.str]:
        '''The search query to use.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        result = self._values.get("search_query")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetSunburstDefinitionRequestNetworkQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestNetworkQueryComputeQuery",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetSunburstDefinitionRequestNetworkQueryComputeQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0e3edf8e9a094116581cc8dc49048315fca6c2b3c7cb4162e1cc4c32e9d19658)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetSunburstDefinitionRequestNetworkQueryComputeQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetSunburstDefinitionRequestNetworkQueryComputeQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestNetworkQueryComputeQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e0ea56aa0d8c6595d546c3cdda34afd099cf1e23ed9f41cb5d99da9f1a495a58)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__823297cb25886d8f77d19491e0bd02c7ed04687a4db85130e4050658c3a3483e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e1cef5e46a7ce960c5c7b46b029395a9e5452605826c5adcd4db99fbe0da322d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__878cab84be97251ed931b05a3ebddf0a8ab0f91db71fd41e266554e1aed3cf74)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetSunburstDefinitionRequestNetworkQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetSunburstDefinitionRequestNetworkQueryComputeQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetSunburstDefinitionRequestNetworkQueryComputeQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__de8f72d7635a9d8e524eab44eb311a3e74d5daf3d1ecf2368cd3516543263c43)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestNetworkQueryGroupBy",
    jsii_struct_bases=[],
    name_mapping={"facet": "facet", "limit": "limit", "sort_query": "sortQuery"},
)
class PowerpackWidgetSunburstDefinitionRequestNetworkQueryGroupBy:
    def __init__(
        self,
        *,
        facet: typing.Optional[builtins.str] = None,
        limit: typing.Optional[jsii.Number] = None,
        sort_query: typing.Optional[typing.Union["PowerpackWidgetSunburstDefinitionRequestNetworkQueryGroupBySortQuery", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param limit: The maximum number of items in the group. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param sort_query: sort_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        if isinstance(sort_query, dict):
            sort_query = PowerpackWidgetSunburstDefinitionRequestNetworkQueryGroupBySortQuery(**sort_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9edbdf4c38a3c3ee79bf51bce232398a03c8ab6d77491341ffebd3823ec0a527)
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
            check_type(argname="argument sort_query", value=sort_query, expected_type=type_hints["sort_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if facet is not None:
            self._values["facet"] = facet
        if limit is not None:
            self._values["limit"] = limit
        if sort_query is not None:
            self._values["sort_query"] = sort_query

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def limit(self) -> typing.Optional[jsii.Number]:
        '''The maximum number of items in the group.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        '''
        result = self._values.get("limit")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def sort_query(
        self,
    ) -> typing.Optional["PowerpackWidgetSunburstDefinitionRequestNetworkQueryGroupBySortQuery"]:
        '''sort_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        result = self._values.get("sort_query")
        return typing.cast(typing.Optional["PowerpackWidgetSunburstDefinitionRequestNetworkQueryGroupBySortQuery"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetSunburstDefinitionRequestNetworkQueryGroupBy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetSunburstDefinitionRequestNetworkQueryGroupByList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestNetworkQueryGroupByList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__912135f9e24cb1bdd196c3732f02e551dee9512dd541aca2edeb554082cafa41)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetSunburstDefinitionRequestNetworkQueryGroupByOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4b9072c9bb61eebcbc94c71ae42f3fdf0a0cd7955c5e8482dd2d064f15e3a097)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetSunburstDefinitionRequestNetworkQueryGroupByOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d5380d7aaee9cf0450992deb85dd683cde781d9ad3f7d0896ad67bc6b598f366)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4047108167369a61144ec16bc2511699329304f9c1d2905465da83cfaa3e665d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3ecf6e811909246550784a7461a41c241ccc2c260aa9b51a982001c159663769)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequestNetworkQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequestNetworkQueryGroupBy]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequestNetworkQueryGroupBy]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ac43a95c3aa4ce936c3c4d2e0d3c79ad27534f4dc47094bf5cc7aab2570f776d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetSunburstDefinitionRequestNetworkQueryGroupByOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestNetworkQueryGroupByOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a9f8e09e1f687f9235daa7addaea6cb2eefe71dd90a27af476531c2d76a23b56)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putSortQuery")
    def put_sort_query(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        value = PowerpackWidgetSunburstDefinitionRequestNetworkQueryGroupBySortQuery(
            aggregation=aggregation, order=order, facet=facet
        )

        return typing.cast(None, jsii.invoke(self, "putSortQuery", [value]))

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetLimit")
    def reset_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLimit", []))

    @jsii.member(jsii_name="resetSortQuery")
    def reset_sort_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSortQuery", []))

    @builtins.property
    @jsii.member(jsii_name="sortQuery")
    def sort_query(
        self,
    ) -> "PowerpackWidgetSunburstDefinitionRequestNetworkQueryGroupBySortQueryOutputReference":
        return typing.cast("PowerpackWidgetSunburstDefinitionRequestNetworkQueryGroupBySortQueryOutputReference", jsii.get(self, "sortQuery"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="limitInput")
    def limit_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "limitInput"))

    @builtins.property
    @jsii.member(jsii_name="sortQueryInput")
    def sort_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetSunburstDefinitionRequestNetworkQueryGroupBySortQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetSunburstDefinitionRequestNetworkQueryGroupBySortQuery"], jsii.get(self, "sortQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7772db6b6a24e1c0bbab04663c689c6d2a2500e631779a47a47abab208012ca1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="limit")
    def limit(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "limit"))

    @limit.setter
    def limit(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__414bafeeebab94009fe846b24cccd576b48ab2288ddcd10cbf785c8eef2d0758)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "limit", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetSunburstDefinitionRequestNetworkQueryGroupBy]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetSunburstDefinitionRequestNetworkQueryGroupBy]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetSunburstDefinitionRequestNetworkQueryGroupBy]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1d62663443f3a52f79c7313af22fdd3104f3b8e6916436744f9f7e2fb3004afa)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestNetworkQueryGroupBySortQuery",
    jsii_struct_bases=[],
    name_mapping={"aggregation": "aggregation", "order": "order", "facet": "facet"},
)
class PowerpackWidgetSunburstDefinitionRequestNetworkQueryGroupBySortQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3d741cc464aae5ca9636a5c5f51d24143b3e4fb0ab41550b9477d832504ddfbc)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument order", value=order, expected_type=type_hints["order"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
            "order": order,
        }
        if facet is not None:
            self._values["facet"] = facet

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def order(self) -> builtins.str:
        '''Widget sorting methods. Valid values are ``asc``, ``desc``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        result = self._values.get("order")
        assert result is not None, "Required property 'order' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetSunburstDefinitionRequestNetworkQueryGroupBySortQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetSunburstDefinitionRequestNetworkQueryGroupBySortQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestNetworkQueryGroupBySortQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b20524c7cea80a5c00b8c6129ec83c835d748d2381444a19d8fcee5798272de3)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="orderInput")
    def order_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "orderInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c9d131433d584fec47a75a941e0761e913600856ea7d0c891ed0f8883aecd92f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c9e0876155f1c5aed967d35698f02492af3f6832abb2d49d8a7d017dad99204f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="order")
    def order(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "order"))

    @order.setter
    def order(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__21061d44c150636bb5dbc4367d1973b6210a980a787a3a222899147f460a6ccc)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "order", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetSunburstDefinitionRequestNetworkQueryGroupBySortQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetSunburstDefinitionRequestNetworkQueryGroupBySortQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetSunburstDefinitionRequestNetworkQueryGroupBySortQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0d2a4045919014fbbb6a29fca154c26d8d131acfc0cfb9e5e4f3be6a3c5325c6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestNetworkQueryMultiCompute",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetSunburstDefinitionRequestNetworkQueryMultiCompute:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__abe8bb23e2ad6671f4c7ac460aec63e3db863080f18759ee452b0c4739a34cfc)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetSunburstDefinitionRequestNetworkQueryMultiCompute(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetSunburstDefinitionRequestNetworkQueryMultiComputeList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestNetworkQueryMultiComputeList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cda090c4863e925f60f7b05c2d62c99e9271ae031d48a5a55f2e6012ba2aa8da)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetSunburstDefinitionRequestNetworkQueryMultiComputeOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4c018ec47cbcd617382b045944cb3632fff5bda39306397baf7584c99322a85c)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetSunburstDefinitionRequestNetworkQueryMultiComputeOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__74ef625d2af96c33375445126120d0008f623e7a17ea741e7a5ae769df4d74c6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f8268874d76b895eb19aba7b88496623ae44db2a6f1a8f6774610cb9f48f061a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__de9f52963e757e0dccd3b762faf0aa9220c908b1babccf3275fcce28acce7f6b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequestNetworkQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequestNetworkQueryMultiCompute]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequestNetworkQueryMultiCompute]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__64269e295dfabfa8987c148174619597a1d7a2a549754ba4adfe5e1c0c298ba4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetSunburstDefinitionRequestNetworkQueryMultiComputeOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestNetworkQueryMultiComputeOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__45bcc5c088e3d12f6e5745916a292f12e0b1794b9a8249e31b429079e73510ed)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8e9d6fcf2228492a8554b7cc233efacc666262368b440f9fb5a352259f75d5f6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__762f53a573c1af60c00c6f721412c24c962056ca7b1ce97e877695e476630dd8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1fd432e41dcda5e3602a54f0823499f399ff5a0c54ded183bb7a82e8f0a634a7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetSunburstDefinitionRequestNetworkQueryMultiCompute]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetSunburstDefinitionRequestNetworkQueryMultiCompute]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetSunburstDefinitionRequestNetworkQueryMultiCompute]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c84f4531bc2cb1aa26189c1722176fbcccf9bfeb99a908318ff90b6eb6e61ff3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetSunburstDefinitionRequestNetworkQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestNetworkQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3f2ca55bce2abadc6007e99477957b44df445466a3f24c3de30a3b7083050b27)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putComputeQuery")
    def put_compute_query(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        value = PowerpackWidgetSunburstDefinitionRequestNetworkQueryComputeQuery(
            aggregation=aggregation, facet=facet, interval=interval
        )

        return typing.cast(None, jsii.invoke(self, "putComputeQuery", [value]))

    @jsii.member(jsii_name="putGroupBy")
    def put_group_by(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetSunburstDefinitionRequestNetworkQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8853a3b8da97d1922660ad79804346ed61d3c68263fa64aaca8a61f29ac5eac2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putGroupBy", [value]))

    @jsii.member(jsii_name="putMultiCompute")
    def put_multi_compute(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetSunburstDefinitionRequestNetworkQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8662bdc3c2f5f29eb089122e9b67127eb53eeaddb0ca68f38efaee9f769a8906)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putMultiCompute", [value]))

    @jsii.member(jsii_name="resetComputeQuery")
    def reset_compute_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetComputeQuery", []))

    @jsii.member(jsii_name="resetGroupBy")
    def reset_group_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGroupBy", []))

    @jsii.member(jsii_name="resetMultiCompute")
    def reset_multi_compute(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMultiCompute", []))

    @jsii.member(jsii_name="resetSearchQuery")
    def reset_search_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSearchQuery", []))

    @builtins.property
    @jsii.member(jsii_name="computeQuery")
    def compute_query(
        self,
    ) -> PowerpackWidgetSunburstDefinitionRequestNetworkQueryComputeQueryOutputReference:
        return typing.cast(PowerpackWidgetSunburstDefinitionRequestNetworkQueryComputeQueryOutputReference, jsii.get(self, "computeQuery"))

    @builtins.property
    @jsii.member(jsii_name="groupBy")
    def group_by(
        self,
    ) -> PowerpackWidgetSunburstDefinitionRequestNetworkQueryGroupByList:
        return typing.cast(PowerpackWidgetSunburstDefinitionRequestNetworkQueryGroupByList, jsii.get(self, "groupBy"))

    @builtins.property
    @jsii.member(jsii_name="multiCompute")
    def multi_compute(
        self,
    ) -> PowerpackWidgetSunburstDefinitionRequestNetworkQueryMultiComputeList:
        return typing.cast(PowerpackWidgetSunburstDefinitionRequestNetworkQueryMultiComputeList, jsii.get(self, "multiCompute"))

    @builtins.property
    @jsii.member(jsii_name="computeQueryInput")
    def compute_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetSunburstDefinitionRequestNetworkQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetSunburstDefinitionRequestNetworkQueryComputeQuery], jsii.get(self, "computeQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="groupByInput")
    def group_by_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequestNetworkQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequestNetworkQueryGroupBy]]], jsii.get(self, "groupByInput"))

    @builtins.property
    @jsii.member(jsii_name="indexInput")
    def index_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "indexInput"))

    @builtins.property
    @jsii.member(jsii_name="multiComputeInput")
    def multi_compute_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequestNetworkQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequestNetworkQueryMultiCompute]]], jsii.get(self, "multiComputeInput"))

    @builtins.property
    @jsii.member(jsii_name="searchQueryInput")
    def search_query_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "searchQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="index")
    def index(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "index"))

    @index.setter
    def index(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e8d2bb7bf3110938111f53167b052db2f65971c732139d3ff11ce0c952693ddf)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "index", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="searchQuery")
    def search_query(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "searchQuery"))

    @search_query.setter
    def search_query(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__26130c7e86bef07e41ccd49a58b82225cfb4122646851ee9ab62f89daf160bf6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "searchQuery", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetSunburstDefinitionRequestNetworkQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetSunburstDefinitionRequestNetworkQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetSunburstDefinitionRequestNetworkQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3f00da3be295f76474f378868a74c4d7289d94e341e698968a89ce2ad11a0a99)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetSunburstDefinitionRequestOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5aaecdd16746d53aacd41ff81b836ac0b3e70dc2e9e186263e4de79f1fc4c9ba)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putApmQuery")
    def put_apm_query(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union[PowerpackWidgetSunburstDefinitionRequestApmQueryComputeQuery, typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetSunburstDefinitionRequestApmQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetSunburstDefinitionRequestApmQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        value = PowerpackWidgetSunburstDefinitionRequestApmQuery(
            index=index,
            compute_query=compute_query,
            group_by=group_by,
            multi_compute=multi_compute,
            search_query=search_query,
        )

        return typing.cast(None, jsii.invoke(self, "putApmQuery", [value]))

    @jsii.member(jsii_name="putAuditQuery")
    def put_audit_query(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union[PowerpackWidgetSunburstDefinitionRequestAuditQueryComputeQuery, typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetSunburstDefinitionRequestAuditQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetSunburstDefinitionRequestAuditQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        value = PowerpackWidgetSunburstDefinitionRequestAuditQuery(
            index=index,
            compute_query=compute_query,
            group_by=group_by,
            multi_compute=multi_compute,
            search_query=search_query,
        )

        return typing.cast(None, jsii.invoke(self, "putAuditQuery", [value]))

    @jsii.member(jsii_name="putFormula")
    def put_formula(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetSunburstDefinitionRequestFormula, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7b85cd8cb23888591a60a7d2f94bfcd78d0cbcfd0828a16dd6930e97a80d6127)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putFormula", [value]))

    @jsii.member(jsii_name="putLogQuery")
    def put_log_query(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union[PowerpackWidgetSunburstDefinitionRequestLogQueryComputeQuery, typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetSunburstDefinitionRequestLogQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetSunburstDefinitionRequestLogQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        value = PowerpackWidgetSunburstDefinitionRequestLogQuery(
            index=index,
            compute_query=compute_query,
            group_by=group_by,
            multi_compute=multi_compute,
            search_query=search_query,
        )

        return typing.cast(None, jsii.invoke(self, "putLogQuery", [value]))

    @jsii.member(jsii_name="putNetworkQuery")
    def put_network_query(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union[PowerpackWidgetSunburstDefinitionRequestNetworkQueryComputeQuery, typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetSunburstDefinitionRequestNetworkQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetSunburstDefinitionRequestNetworkQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        value = PowerpackWidgetSunburstDefinitionRequestNetworkQuery(
            index=index,
            compute_query=compute_query,
            group_by=group_by,
            multi_compute=multi_compute,
            search_query=search_query,
        )

        return typing.cast(None, jsii.invoke(self, "putNetworkQuery", [value]))

    @jsii.member(jsii_name="putProcessQuery")
    def put_process_query(
        self,
        *,
        metric: builtins.str,
        filter_by: typing.Optional[typing.Sequence[builtins.str]] = None,
        limit: typing.Optional[jsii.Number] = None,
        search_by: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param metric: Your chosen metric. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        :param filter_by: A list of processes. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#filter_by Powerpack#filter_by}
        :param limit: The max number of items in the filter list. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param search_by: Your chosen search term. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_by Powerpack#search_by}
        '''
        value = PowerpackWidgetSunburstDefinitionRequestProcessQuery(
            metric=metric, filter_by=filter_by, limit=limit, search_by=search_by
        )

        return typing.cast(None, jsii.invoke(self, "putProcessQuery", [value]))

    @jsii.member(jsii_name="putQuery")
    def put_query(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetSunburstDefinitionRequestQuery", typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9a75dd292395a20a5165cf0a12c59f3c7f6cd0af785e61dfa28fae2ad43a2d36)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putQuery", [value]))

    @jsii.member(jsii_name="putRumQuery")
    def put_rum_query(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union["PowerpackWidgetSunburstDefinitionRequestRumQueryComputeQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetSunburstDefinitionRequestRumQueryGroupBy", typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetSunburstDefinitionRequestRumQueryMultiCompute", typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        value = PowerpackWidgetSunburstDefinitionRequestRumQuery(
            index=index,
            compute_query=compute_query,
            group_by=group_by,
            multi_compute=multi_compute,
            search_query=search_query,
        )

        return typing.cast(None, jsii.invoke(self, "putRumQuery", [value]))

    @jsii.member(jsii_name="putSecurityQuery")
    def put_security_query(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union["PowerpackWidgetSunburstDefinitionRequestSecurityQueryComputeQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetSunburstDefinitionRequestSecurityQueryGroupBy", typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetSunburstDefinitionRequestSecurityQueryMultiCompute", typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        value = PowerpackWidgetSunburstDefinitionRequestSecurityQuery(
            index=index,
            compute_query=compute_query,
            group_by=group_by,
            multi_compute=multi_compute,
            search_query=search_query,
        )

        return typing.cast(None, jsii.invoke(self, "putSecurityQuery", [value]))

    @jsii.member(jsii_name="putStyle")
    def put_style(self, *, palette: typing.Optional[builtins.str] = None) -> None:
        '''
        :param palette: A color palette to apply to the widget. The available options are available at: https://docs.datadoghq.com/dashboards/widgets/timeseries/#appearance. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette Powerpack#palette}
        '''
        value = PowerpackWidgetSunburstDefinitionRequestStyle(palette=palette)

        return typing.cast(None, jsii.invoke(self, "putStyle", [value]))

    @jsii.member(jsii_name="resetApmQuery")
    def reset_apm_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetApmQuery", []))

    @jsii.member(jsii_name="resetAuditQuery")
    def reset_audit_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAuditQuery", []))

    @jsii.member(jsii_name="resetFormula")
    def reset_formula(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFormula", []))

    @jsii.member(jsii_name="resetLogQuery")
    def reset_log_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLogQuery", []))

    @jsii.member(jsii_name="resetNetworkQuery")
    def reset_network_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetNetworkQuery", []))

    @jsii.member(jsii_name="resetProcessQuery")
    def reset_process_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetProcessQuery", []))

    @jsii.member(jsii_name="resetQ")
    def reset_q(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetQ", []))

    @jsii.member(jsii_name="resetQuery")
    def reset_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetQuery", []))

    @jsii.member(jsii_name="resetRumQuery")
    def reset_rum_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetRumQuery", []))

    @jsii.member(jsii_name="resetSecurityQuery")
    def reset_security_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSecurityQuery", []))

    @jsii.member(jsii_name="resetStyle")
    def reset_style(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetStyle", []))

    @builtins.property
    @jsii.member(jsii_name="apmQuery")
    def apm_query(
        self,
    ) -> PowerpackWidgetSunburstDefinitionRequestApmQueryOutputReference:
        return typing.cast(PowerpackWidgetSunburstDefinitionRequestApmQueryOutputReference, jsii.get(self, "apmQuery"))

    @builtins.property
    @jsii.member(jsii_name="auditQuery")
    def audit_query(
        self,
    ) -> PowerpackWidgetSunburstDefinitionRequestAuditQueryOutputReference:
        return typing.cast(PowerpackWidgetSunburstDefinitionRequestAuditQueryOutputReference, jsii.get(self, "auditQuery"))

    @builtins.property
    @jsii.member(jsii_name="formula")
    def formula(self) -> PowerpackWidgetSunburstDefinitionRequestFormulaList:
        return typing.cast(PowerpackWidgetSunburstDefinitionRequestFormulaList, jsii.get(self, "formula"))

    @builtins.property
    @jsii.member(jsii_name="logQuery")
    def log_query(
        self,
    ) -> PowerpackWidgetSunburstDefinitionRequestLogQueryOutputReference:
        return typing.cast(PowerpackWidgetSunburstDefinitionRequestLogQueryOutputReference, jsii.get(self, "logQuery"))

    @builtins.property
    @jsii.member(jsii_name="networkQuery")
    def network_query(
        self,
    ) -> PowerpackWidgetSunburstDefinitionRequestNetworkQueryOutputReference:
        return typing.cast(PowerpackWidgetSunburstDefinitionRequestNetworkQueryOutputReference, jsii.get(self, "networkQuery"))

    @builtins.property
    @jsii.member(jsii_name="processQuery")
    def process_query(
        self,
    ) -> "PowerpackWidgetSunburstDefinitionRequestProcessQueryOutputReference":
        return typing.cast("PowerpackWidgetSunburstDefinitionRequestProcessQueryOutputReference", jsii.get(self, "processQuery"))

    @builtins.property
    @jsii.member(jsii_name="query")
    def query(self) -> "PowerpackWidgetSunburstDefinitionRequestQueryList":
        return typing.cast("PowerpackWidgetSunburstDefinitionRequestQueryList", jsii.get(self, "query"))

    @builtins.property
    @jsii.member(jsii_name="rumQuery")
    def rum_query(
        self,
    ) -> "PowerpackWidgetSunburstDefinitionRequestRumQueryOutputReference":
        return typing.cast("PowerpackWidgetSunburstDefinitionRequestRumQueryOutputReference", jsii.get(self, "rumQuery"))

    @builtins.property
    @jsii.member(jsii_name="securityQuery")
    def security_query(
        self,
    ) -> "PowerpackWidgetSunburstDefinitionRequestSecurityQueryOutputReference":
        return typing.cast("PowerpackWidgetSunburstDefinitionRequestSecurityQueryOutputReference", jsii.get(self, "securityQuery"))

    @builtins.property
    @jsii.member(jsii_name="style")
    def style(self) -> "PowerpackWidgetSunburstDefinitionRequestStyleOutputReference":
        return typing.cast("PowerpackWidgetSunburstDefinitionRequestStyleOutputReference", jsii.get(self, "style"))

    @builtins.property
    @jsii.member(jsii_name="apmQueryInput")
    def apm_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetSunburstDefinitionRequestApmQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetSunburstDefinitionRequestApmQuery], jsii.get(self, "apmQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="auditQueryInput")
    def audit_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetSunburstDefinitionRequestAuditQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetSunburstDefinitionRequestAuditQuery], jsii.get(self, "auditQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="formulaInput")
    def formula_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequestFormula]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequestFormula]]], jsii.get(self, "formulaInput"))

    @builtins.property
    @jsii.member(jsii_name="logQueryInput")
    def log_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetSunburstDefinitionRequestLogQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetSunburstDefinitionRequestLogQuery], jsii.get(self, "logQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="networkQueryInput")
    def network_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetSunburstDefinitionRequestNetworkQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetSunburstDefinitionRequestNetworkQuery], jsii.get(self, "networkQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="processQueryInput")
    def process_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetSunburstDefinitionRequestProcessQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetSunburstDefinitionRequestProcessQuery"], jsii.get(self, "processQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="qInput")
    def q_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "qInput"))

    @builtins.property
    @jsii.member(jsii_name="queryInput")
    def query_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetSunburstDefinitionRequestQuery"]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetSunburstDefinitionRequestQuery"]]], jsii.get(self, "queryInput"))

    @builtins.property
    @jsii.member(jsii_name="rumQueryInput")
    def rum_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetSunburstDefinitionRequestRumQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetSunburstDefinitionRequestRumQuery"], jsii.get(self, "rumQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="securityQueryInput")
    def security_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetSunburstDefinitionRequestSecurityQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetSunburstDefinitionRequestSecurityQuery"], jsii.get(self, "securityQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="styleInput")
    def style_input(
        self,
    ) -> typing.Optional["PowerpackWidgetSunburstDefinitionRequestStyle"]:
        return typing.cast(typing.Optional["PowerpackWidgetSunburstDefinitionRequestStyle"], jsii.get(self, "styleInput"))

    @builtins.property
    @jsii.member(jsii_name="q")
    def q(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "q"))

    @q.setter
    def q(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bbf01ce7422f8524c1ac4065050a1fb85fec33ba2faa057f2a1dbd5cc2e8b19d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "q", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetSunburstDefinitionRequest]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetSunburstDefinitionRequest]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetSunburstDefinitionRequest]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2866035cdb6debcbf3580cd67b27314cae487a47213bcec5e0c5420105129465)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestProcessQuery",
    jsii_struct_bases=[],
    name_mapping={
        "metric": "metric",
        "filter_by": "filterBy",
        "limit": "limit",
        "search_by": "searchBy",
    },
)
class PowerpackWidgetSunburstDefinitionRequestProcessQuery:
    def __init__(
        self,
        *,
        metric: builtins.str,
        filter_by: typing.Optional[typing.Sequence[builtins.str]] = None,
        limit: typing.Optional[jsii.Number] = None,
        search_by: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param metric: Your chosen metric. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        :param filter_by: A list of processes. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#filter_by Powerpack#filter_by}
        :param limit: The max number of items in the filter list. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param search_by: Your chosen search term. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_by Powerpack#search_by}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3049126131f9cc914e6abc51a07deb817daa3bdbfde03a91057c0abf91e93808)
            check_type(argname="argument metric", value=metric, expected_type=type_hints["metric"])
            check_type(argname="argument filter_by", value=filter_by, expected_type=type_hints["filter_by"])
            check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
            check_type(argname="argument search_by", value=search_by, expected_type=type_hints["search_by"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "metric": metric,
        }
        if filter_by is not None:
            self._values["filter_by"] = filter_by
        if limit is not None:
            self._values["limit"] = limit
        if search_by is not None:
            self._values["search_by"] = search_by

    @builtins.property
    def metric(self) -> builtins.str:
        '''Your chosen metric.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        '''
        result = self._values.get("metric")
        assert result is not None, "Required property 'metric' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def filter_by(self) -> typing.Optional[typing.List[builtins.str]]:
        '''A list of processes.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#filter_by Powerpack#filter_by}
        '''
        result = self._values.get("filter_by")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def limit(self) -> typing.Optional[jsii.Number]:
        '''The max number of items in the filter list.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        '''
        result = self._values.get("limit")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def search_by(self) -> typing.Optional[builtins.str]:
        '''Your chosen search term.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_by Powerpack#search_by}
        '''
        result = self._values.get("search_by")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetSunburstDefinitionRequestProcessQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetSunburstDefinitionRequestProcessQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestProcessQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3dfb2342ee171068a57987c050e3898a56903c66744b324e1a9290ef282ebbc6)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFilterBy")
    def reset_filter_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFilterBy", []))

    @jsii.member(jsii_name="resetLimit")
    def reset_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLimit", []))

    @jsii.member(jsii_name="resetSearchBy")
    def reset_search_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSearchBy", []))

    @builtins.property
    @jsii.member(jsii_name="filterByInput")
    def filter_by_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "filterByInput"))

    @builtins.property
    @jsii.member(jsii_name="limitInput")
    def limit_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "limitInput"))

    @builtins.property
    @jsii.member(jsii_name="metricInput")
    def metric_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "metricInput"))

    @builtins.property
    @jsii.member(jsii_name="searchByInput")
    def search_by_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "searchByInput"))

    @builtins.property
    @jsii.member(jsii_name="filterBy")
    def filter_by(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "filterBy"))

    @filter_by.setter
    def filter_by(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9234139a9118123cadb293d6d42a8324f161f7e9e4e8530d41c466bb65b71b27)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "filterBy", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="limit")
    def limit(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "limit"))

    @limit.setter
    def limit(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__866122b60bb803dcee699a6efb01392e8b1ec74e64852a68c61f286e46d877d8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "limit", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="metric")
    def metric(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "metric"))

    @metric.setter
    def metric(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__65cf96fabc6593beb1ac676f7fcbc87aa6dd596f6a650170d702a713208a446f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "metric", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="searchBy")
    def search_by(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "searchBy"))

    @search_by.setter
    def search_by(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d0b90555c189fd97d0a32fab1d4cecb257cdde083c938c811aa6bea35170ac71)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "searchBy", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetSunburstDefinitionRequestProcessQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetSunburstDefinitionRequestProcessQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetSunburstDefinitionRequestProcessQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__eac856bf8b1abba663c0bff4e61e294649ebef0911c57babb983e38105bec067)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestQuery",
    jsii_struct_bases=[],
    name_mapping={
        "apm_dependency_stats_query": "apmDependencyStatsQuery",
        "apm_resource_stats_query": "apmResourceStatsQuery",
        "cloud_cost_query": "cloudCostQuery",
        "event_query": "eventQuery",
        "metric_query": "metricQuery",
        "process_query": "processQuery",
        "slo_query": "sloQuery",
    },
)
class PowerpackWidgetSunburstDefinitionRequestQuery:
    def __init__(
        self,
        *,
        apm_dependency_stats_query: typing.Optional[typing.Union["PowerpackWidgetSunburstDefinitionRequestQueryApmDependencyStatsQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        apm_resource_stats_query: typing.Optional[typing.Union["PowerpackWidgetSunburstDefinitionRequestQueryApmResourceStatsQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        cloud_cost_query: typing.Optional[typing.Union["PowerpackWidgetSunburstDefinitionRequestQueryCloudCostQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        event_query: typing.Optional[typing.Union["PowerpackWidgetSunburstDefinitionRequestQueryEventQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        metric_query: typing.Optional[typing.Union["PowerpackWidgetSunburstDefinitionRequestQueryMetricQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        process_query: typing.Optional[typing.Union["PowerpackWidgetSunburstDefinitionRequestQueryProcessQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        slo_query: typing.Optional[typing.Union["PowerpackWidgetSunburstDefinitionRequestQuerySloQuery", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param apm_dependency_stats_query: apm_dependency_stats_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#apm_dependency_stats_query Powerpack#apm_dependency_stats_query}
        :param apm_resource_stats_query: apm_resource_stats_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#apm_resource_stats_query Powerpack#apm_resource_stats_query}
        :param cloud_cost_query: cloud_cost_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cloud_cost_query Powerpack#cloud_cost_query}
        :param event_query: event_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#event_query Powerpack#event_query}
        :param metric_query: metric_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric_query Powerpack#metric_query}
        :param process_query: process_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#process_query Powerpack#process_query}
        :param slo_query: slo_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#slo_query Powerpack#slo_query}
        '''
        if isinstance(apm_dependency_stats_query, dict):
            apm_dependency_stats_query = PowerpackWidgetSunburstDefinitionRequestQueryApmDependencyStatsQuery(**apm_dependency_stats_query)
        if isinstance(apm_resource_stats_query, dict):
            apm_resource_stats_query = PowerpackWidgetSunburstDefinitionRequestQueryApmResourceStatsQuery(**apm_resource_stats_query)
        if isinstance(cloud_cost_query, dict):
            cloud_cost_query = PowerpackWidgetSunburstDefinitionRequestQueryCloudCostQuery(**cloud_cost_query)
        if isinstance(event_query, dict):
            event_query = PowerpackWidgetSunburstDefinitionRequestQueryEventQuery(**event_query)
        if isinstance(metric_query, dict):
            metric_query = PowerpackWidgetSunburstDefinitionRequestQueryMetricQuery(**metric_query)
        if isinstance(process_query, dict):
            process_query = PowerpackWidgetSunburstDefinitionRequestQueryProcessQuery(**process_query)
        if isinstance(slo_query, dict):
            slo_query = PowerpackWidgetSunburstDefinitionRequestQuerySloQuery(**slo_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1d29aba37fd281bc31c0af62f38c43efb4c06a4e828095cc84329d12e4dd8eea)
            check_type(argname="argument apm_dependency_stats_query", value=apm_dependency_stats_query, expected_type=type_hints["apm_dependency_stats_query"])
            check_type(argname="argument apm_resource_stats_query", value=apm_resource_stats_query, expected_type=type_hints["apm_resource_stats_query"])
            check_type(argname="argument cloud_cost_query", value=cloud_cost_query, expected_type=type_hints["cloud_cost_query"])
            check_type(argname="argument event_query", value=event_query, expected_type=type_hints["event_query"])
            check_type(argname="argument metric_query", value=metric_query, expected_type=type_hints["metric_query"])
            check_type(argname="argument process_query", value=process_query, expected_type=type_hints["process_query"])
            check_type(argname="argument slo_query", value=slo_query, expected_type=type_hints["slo_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if apm_dependency_stats_query is not None:
            self._values["apm_dependency_stats_query"] = apm_dependency_stats_query
        if apm_resource_stats_query is not None:
            self._values["apm_resource_stats_query"] = apm_resource_stats_query
        if cloud_cost_query is not None:
            self._values["cloud_cost_query"] = cloud_cost_query
        if event_query is not None:
            self._values["event_query"] = event_query
        if metric_query is not None:
            self._values["metric_query"] = metric_query
        if process_query is not None:
            self._values["process_query"] = process_query
        if slo_query is not None:
            self._values["slo_query"] = slo_query

    @builtins.property
    def apm_dependency_stats_query(
        self,
    ) -> typing.Optional["PowerpackWidgetSunburstDefinitionRequestQueryApmDependencyStatsQuery"]:
        '''apm_dependency_stats_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#apm_dependency_stats_query Powerpack#apm_dependency_stats_query}
        '''
        result = self._values.get("apm_dependency_stats_query")
        return typing.cast(typing.Optional["PowerpackWidgetSunburstDefinitionRequestQueryApmDependencyStatsQuery"], result)

    @builtins.property
    def apm_resource_stats_query(
        self,
    ) -> typing.Optional["PowerpackWidgetSunburstDefinitionRequestQueryApmResourceStatsQuery"]:
        '''apm_resource_stats_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#apm_resource_stats_query Powerpack#apm_resource_stats_query}
        '''
        result = self._values.get("apm_resource_stats_query")
        return typing.cast(typing.Optional["PowerpackWidgetSunburstDefinitionRequestQueryApmResourceStatsQuery"], result)

    @builtins.property
    def cloud_cost_query(
        self,
    ) -> typing.Optional["PowerpackWidgetSunburstDefinitionRequestQueryCloudCostQuery"]:
        '''cloud_cost_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cloud_cost_query Powerpack#cloud_cost_query}
        '''
        result = self._values.get("cloud_cost_query")
        return typing.cast(typing.Optional["PowerpackWidgetSunburstDefinitionRequestQueryCloudCostQuery"], result)

    @builtins.property
    def event_query(
        self,
    ) -> typing.Optional["PowerpackWidgetSunburstDefinitionRequestQueryEventQuery"]:
        '''event_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#event_query Powerpack#event_query}
        '''
        result = self._values.get("event_query")
        return typing.cast(typing.Optional["PowerpackWidgetSunburstDefinitionRequestQueryEventQuery"], result)

    @builtins.property
    def metric_query(
        self,
    ) -> typing.Optional["PowerpackWidgetSunburstDefinitionRequestQueryMetricQuery"]:
        '''metric_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric_query Powerpack#metric_query}
        '''
        result = self._values.get("metric_query")
        return typing.cast(typing.Optional["PowerpackWidgetSunburstDefinitionRequestQueryMetricQuery"], result)

    @builtins.property
    def process_query(
        self,
    ) -> typing.Optional["PowerpackWidgetSunburstDefinitionRequestQueryProcessQuery"]:
        '''process_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#process_query Powerpack#process_query}
        '''
        result = self._values.get("process_query")
        return typing.cast(typing.Optional["PowerpackWidgetSunburstDefinitionRequestQueryProcessQuery"], result)

    @builtins.property
    def slo_query(
        self,
    ) -> typing.Optional["PowerpackWidgetSunburstDefinitionRequestQuerySloQuery"]:
        '''slo_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#slo_query Powerpack#slo_query}
        '''
        result = self._values.get("slo_query")
        return typing.cast(typing.Optional["PowerpackWidgetSunburstDefinitionRequestQuerySloQuery"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetSunburstDefinitionRequestQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestQueryApmDependencyStatsQuery",
    jsii_struct_bases=[],
    name_mapping={
        "data_source": "dataSource",
        "env": "env",
        "name": "name",
        "operation_name": "operationName",
        "resource_name": "resourceName",
        "service": "service",
        "stat": "stat",
        "cross_org_uuids": "crossOrgUuids",
        "is_upstream": "isUpstream",
        "primary_tag_name": "primaryTagName",
        "primary_tag_value": "primaryTagValue",
    },
)
class PowerpackWidgetSunburstDefinitionRequestQueryApmDependencyStatsQuery:
    def __init__(
        self,
        *,
        data_source: builtins.str,
        env: builtins.str,
        name: builtins.str,
        operation_name: builtins.str,
        resource_name: builtins.str,
        service: builtins.str,
        stat: builtins.str,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        is_upstream: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        primary_tag_name: typing.Optional[builtins.str] = None,
        primary_tag_value: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param data_source: The data source for APM Dependency Stats queries. Valid values are ``apm_dependency_stats``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param env: APM environment. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#env Powerpack#env}
        :param name: The name of query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param operation_name: Name of operation on service. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#operation_name Powerpack#operation_name}
        :param resource_name: APM resource. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#resource_name Powerpack#resource_name}
        :param service: APM service. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#service Powerpack#service}
        :param stat: APM statistic. Valid values are ``avg_duration``, ``avg_root_duration``, ``avg_spans_per_trace``, ``error_rate``, ``pct_exec_time``, ``pct_of_traces``, ``total_traces_count``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#stat Powerpack#stat}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param is_upstream: Determines whether stats for upstream or downstream dependencies should be queried. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#is_upstream Powerpack#is_upstream}
        :param primary_tag_name: The name of the second primary tag used within APM; required when ``primary_tag_value`` is specified. See https://docs.datadoghq.com/tracing/guide/setting_primary_tags_to_scope/#add-a-second-primary-tag-in-datadog. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_name Powerpack#primary_tag_name}
        :param primary_tag_value: Filter APM data by the second primary tag. ``primary_tag_name`` must also be specified. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_value Powerpack#primary_tag_value}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cb5a1a5fcf3e88a44555344f4ec0734e2a3f7d68028620b409b5bd79cd03c307)
            check_type(argname="argument data_source", value=data_source, expected_type=type_hints["data_source"])
            check_type(argname="argument env", value=env, expected_type=type_hints["env"])
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument operation_name", value=operation_name, expected_type=type_hints["operation_name"])
            check_type(argname="argument resource_name", value=resource_name, expected_type=type_hints["resource_name"])
            check_type(argname="argument service", value=service, expected_type=type_hints["service"])
            check_type(argname="argument stat", value=stat, expected_type=type_hints["stat"])
            check_type(argname="argument cross_org_uuids", value=cross_org_uuids, expected_type=type_hints["cross_org_uuids"])
            check_type(argname="argument is_upstream", value=is_upstream, expected_type=type_hints["is_upstream"])
            check_type(argname="argument primary_tag_name", value=primary_tag_name, expected_type=type_hints["primary_tag_name"])
            check_type(argname="argument primary_tag_value", value=primary_tag_value, expected_type=type_hints["primary_tag_value"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "data_source": data_source,
            "env": env,
            "name": name,
            "operation_name": operation_name,
            "resource_name": resource_name,
            "service": service,
            "stat": stat,
        }
        if cross_org_uuids is not None:
            self._values["cross_org_uuids"] = cross_org_uuids
        if is_upstream is not None:
            self._values["is_upstream"] = is_upstream
        if primary_tag_name is not None:
            self._values["primary_tag_name"] = primary_tag_name
        if primary_tag_value is not None:
            self._values["primary_tag_value"] = primary_tag_value

    @builtins.property
    def data_source(self) -> builtins.str:
        '''The data source for APM Dependency Stats queries. Valid values are ``apm_dependency_stats``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        '''
        result = self._values.get("data_source")
        assert result is not None, "Required property 'data_source' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def env(self) -> builtins.str:
        '''APM environment.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#env Powerpack#env}
        '''
        result = self._values.get("env")
        assert result is not None, "Required property 'env' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def name(self) -> builtins.str:
        '''The name of query for use in formulas.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        '''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def operation_name(self) -> builtins.str:
        '''Name of operation on service.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#operation_name Powerpack#operation_name}
        '''
        result = self._values.get("operation_name")
        assert result is not None, "Required property 'operation_name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def resource_name(self) -> builtins.str:
        '''APM resource.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#resource_name Powerpack#resource_name}
        '''
        result = self._values.get("resource_name")
        assert result is not None, "Required property 'resource_name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def service(self) -> builtins.str:
        '''APM service.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#service Powerpack#service}
        '''
        result = self._values.get("service")
        assert result is not None, "Required property 'service' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def stat(self) -> builtins.str:
        '''APM statistic. Valid values are ``avg_duration``, ``avg_root_duration``, ``avg_spans_per_trace``, ``error_rate``, ``pct_exec_time``, ``pct_of_traces``, ``total_traces_count``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#stat Powerpack#stat}
        '''
        result = self._values.get("stat")
        assert result is not None, "Required property 'stat' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def cross_org_uuids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''The source organization UUID for cross organization queries. Feature in Private Beta.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        '''
        result = self._values.get("cross_org_uuids")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def is_upstream(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        '''Determines whether stats for upstream or downstream dependencies should be queried.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#is_upstream Powerpack#is_upstream}
        '''
        result = self._values.get("is_upstream")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)

    @builtins.property
    def primary_tag_name(self) -> typing.Optional[builtins.str]:
        '''The name of the second primary tag used within APM; required when ``primary_tag_value`` is specified. See https://docs.datadoghq.com/tracing/guide/setting_primary_tags_to_scope/#add-a-second-primary-tag-in-datadog.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_name Powerpack#primary_tag_name}
        '''
        result = self._values.get("primary_tag_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def primary_tag_value(self) -> typing.Optional[builtins.str]:
        '''Filter APM data by the second primary tag. ``primary_tag_name`` must also be specified.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_value Powerpack#primary_tag_value}
        '''
        result = self._values.get("primary_tag_value")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetSunburstDefinitionRequestQueryApmDependencyStatsQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetSunburstDefinitionRequestQueryApmDependencyStatsQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestQueryApmDependencyStatsQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4605f1492e3d76f983a6bf70a3a1439797f815a6894db58a4a4d060ab1e3c53f)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetCrossOrgUuids")
    def reset_cross_org_uuids(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCrossOrgUuids", []))

    @jsii.member(jsii_name="resetIsUpstream")
    def reset_is_upstream(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetIsUpstream", []))

    @jsii.member(jsii_name="resetPrimaryTagName")
    def reset_primary_tag_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPrimaryTagName", []))

    @jsii.member(jsii_name="resetPrimaryTagValue")
    def reset_primary_tag_value(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPrimaryTagValue", []))

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuidsInput")
    def cross_org_uuids_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "crossOrgUuidsInput"))

    @builtins.property
    @jsii.member(jsii_name="dataSourceInput")
    def data_source_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "dataSourceInput"))

    @builtins.property
    @jsii.member(jsii_name="envInput")
    def env_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "envInput"))

    @builtins.property
    @jsii.member(jsii_name="isUpstreamInput")
    def is_upstream_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "isUpstreamInput"))

    @builtins.property
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property
    @jsii.member(jsii_name="operationNameInput")
    def operation_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "operationNameInput"))

    @builtins.property
    @jsii.member(jsii_name="primaryTagNameInput")
    def primary_tag_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "primaryTagNameInput"))

    @builtins.property
    @jsii.member(jsii_name="primaryTagValueInput")
    def primary_tag_value_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "primaryTagValueInput"))

    @builtins.property
    @jsii.member(jsii_name="resourceNameInput")
    def resource_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "resourceNameInput"))

    @builtins.property
    @jsii.member(jsii_name="serviceInput")
    def service_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "serviceInput"))

    @builtins.property
    @jsii.member(jsii_name="statInput")
    def stat_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "statInput"))

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuids")
    def cross_org_uuids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "crossOrgUuids"))

    @cross_org_uuids.setter
    def cross_org_uuids(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8c9fe6a9baad8fd6eb052789cfa6b51bda6624166c6892870b8586f423ed260b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "crossOrgUuids", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="dataSource")
    def data_source(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "dataSource"))

    @data_source.setter
    def data_source(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0478b0656184566ac14645379b01a7731fc874f014f5bc03866214995923e9a5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "dataSource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="env")
    def env(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "env"))

    @env.setter
    def env(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__025b7900c2d58e96912c15007f00736dc926a49b26e00142e5f1f383d84e7520)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "env", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="isUpstream")
    def is_upstream(self) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "isUpstream"))

    @is_upstream.setter
    def is_upstream(
        self,
        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7230e3b1979c84eee87351072130fe2a7afa0c9b5db0d1af0661e55a4e17e6e8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "isUpstream", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a4f01f46b6d62af14a283a9c123689e08e6f8b8d3ea44bfd6124fb015660ba99)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "name", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="operationName")
    def operation_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "operationName"))

    @operation_name.setter
    def operation_name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6d6ac9e369941adf59ce10e40bb23d89d3f66599506989ff3b7c4cb5c0ddfbe9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "operationName", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="primaryTagName")
    def primary_tag_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "primaryTagName"))

    @primary_tag_name.setter
    def primary_tag_name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f09cd6db12bfc23921bf86ca772287eda9e08cbfae46eb3855089a3dda042930)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "primaryTagName", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="primaryTagValue")
    def primary_tag_value(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "primaryTagValue"))

    @primary_tag_value.setter
    def primary_tag_value(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6127dfa478b348fa46870a1efa4164b4628fdf1ba3ac0b4a1a1091260ebdaf47)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "primaryTagValue", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="resourceName")
    def resource_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "resourceName"))

    @resource_name.setter
    def resource_name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4972f467057c85274890da58b8c949e2648c53136de19a7548ac587a1696f085)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "resourceName", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="service")
    def service(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "service"))

    @service.setter
    def service(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e712e560bf7c96920dfc4865260d0e3220f3f3142510e4913ca396879827c616)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "service", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="stat")
    def stat(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "stat"))

    @stat.setter
    def stat(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ff54d60893a07681a5436bf6f6af0cc5999c6420bbbd7b4905d965166680bcad)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "stat", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetSunburstDefinitionRequestQueryApmDependencyStatsQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetSunburstDefinitionRequestQueryApmDependencyStatsQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetSunburstDefinitionRequestQueryApmDependencyStatsQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__72a0ad8dbdaf6613f062ea4f787492474aebaafd3b59a847b8fb964ddbe1b8a8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestQueryApmResourceStatsQuery",
    jsii_struct_bases=[],
    name_mapping={
        "data_source": "dataSource",
        "env": "env",
        "name": "name",
        "service": "service",
        "stat": "stat",
        "cross_org_uuids": "crossOrgUuids",
        "group_by": "groupBy",
        "operation_name": "operationName",
        "primary_tag_name": "primaryTagName",
        "primary_tag_value": "primaryTagValue",
        "resource_name": "resourceName",
    },
)
class PowerpackWidgetSunburstDefinitionRequestQueryApmResourceStatsQuery:
    def __init__(
        self,
        *,
        data_source: builtins.str,
        env: builtins.str,
        name: builtins.str,
        service: builtins.str,
        stat: builtins.str,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        group_by: typing.Optional[typing.Sequence[builtins.str]] = None,
        operation_name: typing.Optional[builtins.str] = None,
        primary_tag_name: typing.Optional[builtins.str] = None,
        primary_tag_value: typing.Optional[builtins.str] = None,
        resource_name: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param data_source: The data source for APM Resource Stats queries. Valid values are ``apm_resource_stats``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param env: APM environment. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#env Powerpack#env}
        :param name: The name of query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param service: APM service. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#service Powerpack#service}
        :param stat: APM statistic. Valid values are ``errors``, ``error_rate``, ``hits``, ``latency_avg``, ``latency_distribution``, ``latency_max``, ``latency_p50``, ``latency_p75``, ``latency_p90``, ``latency_p95``, ``latency_p99``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#stat Powerpack#stat}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param group_by: Array of fields to group results by. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param operation_name: Name of operation on service. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#operation_name Powerpack#operation_name}
        :param primary_tag_name: The name of the second primary tag used within APM; required when ``primary_tag_value`` is specified. See https://docs.datadoghq.com/tracing/guide/setting_primary_tags_to_scope/#add-a-second-primary-tag-in-datadog. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_name Powerpack#primary_tag_name}
        :param primary_tag_value: Filter APM data by the second primary tag. ``primary_tag_name`` must also be specified. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_value Powerpack#primary_tag_value}
        :param resource_name: APM resource. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#resource_name Powerpack#resource_name}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__718d5358613b1d893fc109f1a83f979ac7e0668c0bc792f82995b4105d5536d2)
            check_type(argname="argument data_source", value=data_source, expected_type=type_hints["data_source"])
            check_type(argname="argument env", value=env, expected_type=type_hints["env"])
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument service", value=service, expected_type=type_hints["service"])
            check_type(argname="argument stat", value=stat, expected_type=type_hints["stat"])
            check_type(argname="argument cross_org_uuids", value=cross_org_uuids, expected_type=type_hints["cross_org_uuids"])
            check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
            check_type(argname="argument operation_name", value=operation_name, expected_type=type_hints["operation_name"])
            check_type(argname="argument primary_tag_name", value=primary_tag_name, expected_type=type_hints["primary_tag_name"])
            check_type(argname="argument primary_tag_value", value=primary_tag_value, expected_type=type_hints["primary_tag_value"])
            check_type(argname="argument resource_name", value=resource_name, expected_type=type_hints["resource_name"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "data_source": data_source,
            "env": env,
            "name": name,
            "service": service,
            "stat": stat,
        }
        if cross_org_uuids is not None:
            self._values["cross_org_uuids"] = cross_org_uuids
        if group_by is not None:
            self._values["group_by"] = group_by
        if operation_name is not None:
            self._values["operation_name"] = operation_name
        if primary_tag_name is not None:
            self._values["primary_tag_name"] = primary_tag_name
        if primary_tag_value is not None:
            self._values["primary_tag_value"] = primary_tag_value
        if resource_name is not None:
            self._values["resource_name"] = resource_name

    @builtins.property
    def data_source(self) -> builtins.str:
        '''The data source for APM Resource Stats queries. Valid values are ``apm_resource_stats``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        '''
        result = self._values.get("data_source")
        assert result is not None, "Required property 'data_source' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def env(self) -> builtins.str:
        '''APM environment.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#env Powerpack#env}
        '''
        result = self._values.get("env")
        assert result is not None, "Required property 'env' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def name(self) -> builtins.str:
        '''The name of query for use in formulas.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        '''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def service(self) -> builtins.str:
        '''APM service.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#service Powerpack#service}
        '''
        result = self._values.get("service")
        assert result is not None, "Required property 'service' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def stat(self) -> builtins.str:
        '''APM statistic. Valid values are ``errors``, ``error_rate``, ``hits``, ``latency_avg``, ``latency_distribution``, ``latency_max``, ``latency_p50``, ``latency_p75``, ``latency_p90``, ``latency_p95``, ``latency_p99``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#stat Powerpack#stat}
        '''
        result = self._values.get("stat")
        assert result is not None, "Required property 'stat' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def cross_org_uuids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''The source organization UUID for cross organization queries. Feature in Private Beta.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        '''
        result = self._values.get("cross_org_uuids")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def group_by(self) -> typing.Optional[typing.List[builtins.str]]:
        '''Array of fields to group results by.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        '''
        result = self._values.get("group_by")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def operation_name(self) -> typing.Optional[builtins.str]:
        '''Name of operation on service.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#operation_name Powerpack#operation_name}
        '''
        result = self._values.get("operation_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def primary_tag_name(self) -> typing.Optional[builtins.str]:
        '''The name of the second primary tag used within APM; required when ``primary_tag_value`` is specified. See https://docs.datadoghq.com/tracing/guide/setting_primary_tags_to_scope/#add-a-second-primary-tag-in-datadog.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_name Powerpack#primary_tag_name}
        '''
        result = self._values.get("primary_tag_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def primary_tag_value(self) -> typing.Optional[builtins.str]:
        '''Filter APM data by the second primary tag. ``primary_tag_name`` must also be specified.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_value Powerpack#primary_tag_value}
        '''
        result = self._values.get("primary_tag_value")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def resource_name(self) -> typing.Optional[builtins.str]:
        '''APM resource.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#resource_name Powerpack#resource_name}
        '''
        result = self._values.get("resource_name")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetSunburstDefinitionRequestQueryApmResourceStatsQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetSunburstDefinitionRequestQueryApmResourceStatsQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestQueryApmResourceStatsQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a851bc0426448245814dadf03bf716fa6d2341eb22367b9ed89b27a1c63fe5b8)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetCrossOrgUuids")
    def reset_cross_org_uuids(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCrossOrgUuids", []))

    @jsii.member(jsii_name="resetGroupBy")
    def reset_group_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGroupBy", []))

    @jsii.member(jsii_name="resetOperationName")
    def reset_operation_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetOperationName", []))

    @jsii.member(jsii_name="resetPrimaryTagName")
    def reset_primary_tag_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPrimaryTagName", []))

    @jsii.member(jsii_name="resetPrimaryTagValue")
    def reset_primary_tag_value(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPrimaryTagValue", []))

    @jsii.member(jsii_name="resetResourceName")
    def reset_resource_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetResourceName", []))

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuidsInput")
    def cross_org_uuids_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "crossOrgUuidsInput"))

    @builtins.property
    @jsii.member(jsii_name="dataSourceInput")
    def data_source_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "dataSourceInput"))

    @builtins.property
    @jsii.member(jsii_name="envInput")
    def env_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "envInput"))

    @builtins.property
    @jsii.member(jsii_name="groupByInput")
    def group_by_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "groupByInput"))

    @builtins.property
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property
    @jsii.member(jsii_name="operationNameInput")
    def operation_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "operationNameInput"))

    @builtins.property
    @jsii.member(jsii_name="primaryTagNameInput")
    def primary_tag_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "primaryTagNameInput"))

    @builtins.property
    @jsii.member(jsii_name="primaryTagValueInput")
    def primary_tag_value_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "primaryTagValueInput"))

    @builtins.property
    @jsii.member(jsii_name="resourceNameInput")
    def resource_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "resourceNameInput"))

    @builtins.property
    @jsii.member(jsii_name="serviceInput")
    def service_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "serviceInput"))

    @builtins.property
    @jsii.member(jsii_name="statInput")
    def stat_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "statInput"))

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuids")
    def cross_org_uuids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "crossOrgUuids"))

    @cross_org_uuids.setter
    def cross_org_uuids(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2f64de41a4432ca0fba627304f3dff347ecf652cb4a8a026eca1abcd718b66a0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "crossOrgUuids", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="dataSource")
    def data_source(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "dataSource"))

    @data_source.setter
    def data_source(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f09d12d93a41da8fbde23e26196f303f56a6394b59e0c55ca5b50f5ae9d5c5d2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "dataSource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="env")
    def env(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "env"))

    @env.setter
    def env(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9d9371559a8ab951fe6094e43fcaa7aea142be86ba9d30705e25794a85d9438f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "env", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="groupBy")
    def group_by(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "groupBy"))

    @group_by.setter
    def group_by(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e81f70ca7e366b78690e396c7ffea51f3aa5d8aa19883a60009a44aa18abd5a7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "groupBy", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5a327d8c80ab7fc09fee7e42ad5ead9e041a3a90483eaa8f7ac69cabcc91995b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "name", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="operationName")
    def operation_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "operationName"))

    @operation_name.setter
    def operation_name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8ca93d1831ddc0092500a23cf85d30097f2b901c1b2e7e8e613d9623b88740ca)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "operationName", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="primaryTagName")
    def primary_tag_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "primaryTagName"))

    @primary_tag_name.setter
    def primary_tag_name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__690d4dc486c0ccf5e602100bf6a998c713a4f366cd4c50e0c052ac7191a2d38e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "primaryTagName", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="primaryTagValue")
    def primary_tag_value(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "primaryTagValue"))

    @primary_tag_value.setter
    def primary_tag_value(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__87dadc09ffe5bcc31bc4f0068c13d945adf0768ea969a952ffebcee1aa33c388)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "primaryTagValue", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="resourceName")
    def resource_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "resourceName"))

    @resource_name.setter
    def resource_name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7cea2ec36c044590a395f170382fd4702a9a5811991b3bda87a014e42066f3a0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "resourceName", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="service")
    def service(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "service"))

    @service.setter
    def service(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__492966dc9c64be0fcb56f8299bd5c18c9d2fe38009a3a40133c1aedddfedb914)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "service", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="stat")
    def stat(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "stat"))

    @stat.setter
    def stat(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__30267ce0d1f8583f18033df555de25fa1aa693fc05be222ca16f84cc34713903)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "stat", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetSunburstDefinitionRequestQueryApmResourceStatsQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetSunburstDefinitionRequestQueryApmResourceStatsQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetSunburstDefinitionRequestQueryApmResourceStatsQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__03ff876fbc46afa23f297d07da21d7f2bcf6dd3907eddb43fa66111a3ce95682)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestQueryCloudCostQuery",
    jsii_struct_bases=[],
    name_mapping={
        "data_source": "dataSource",
        "name": "name",
        "query": "query",
        "aggregator": "aggregator",
        "cross_org_uuids": "crossOrgUuids",
    },
)
class PowerpackWidgetSunburstDefinitionRequestQueryCloudCostQuery:
    def __init__(
        self,
        *,
        data_source: builtins.str,
        name: builtins.str,
        query: builtins.str,
        aggregator: typing.Optional[builtins.str] = None,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
    ) -> None:
        '''
        :param data_source: The data source for cloud cost queries. Valid values are ``cloud_cost``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param name: The name of the query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param query: The cloud cost query definition. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        :param aggregator: The aggregation methods available for cloud cost queries. Valid values are ``avg``, ``last``, ``max``, ``min``, ``sum``, ``percentile``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregator Powerpack#aggregator}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c3a135839de4f328ae8109a4de9a21e4d00a4113cc8ef661e86ad9bcf6f358dd)
            check_type(argname="argument data_source", value=data_source, expected_type=type_hints["data_source"])
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument query", value=query, expected_type=type_hints["query"])
            check_type(argname="argument aggregator", value=aggregator, expected_type=type_hints["aggregator"])
            check_type(argname="argument cross_org_uuids", value=cross_org_uuids, expected_type=type_hints["cross_org_uuids"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "data_source": data_source,
            "name": name,
            "query": query,
        }
        if aggregator is not None:
            self._values["aggregator"] = aggregator
        if cross_org_uuids is not None:
            self._values["cross_org_uuids"] = cross_org_uuids

    @builtins.property
    def data_source(self) -> builtins.str:
        '''The data source for cloud cost queries. Valid values are ``cloud_cost``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        '''
        result = self._values.get("data_source")
        assert result is not None, "Required property 'data_source' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def name(self) -> builtins.str:
        '''The name of the query for use in formulas.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        '''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def query(self) -> builtins.str:
        '''The cloud cost query definition.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        '''
        result = self._values.get("query")
        assert result is not None, "Required property 'query' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def aggregator(self) -> typing.Optional[builtins.str]:
        '''The aggregation methods available for cloud cost queries. Valid values are ``avg``, ``last``, ``max``, ``min``, ``sum``, ``percentile``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregator Powerpack#aggregator}
        '''
        result = self._values.get("aggregator")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def cross_org_uuids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''The source organization UUID for cross organization queries. Feature in Private Beta.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        '''
        result = self._values.get("cross_org_uuids")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetSunburstDefinitionRequestQueryCloudCostQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetSunburstDefinitionRequestQueryCloudCostQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestQueryCloudCostQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bb4aed7f9bbc6836de5d824c471aece36da87ddb36409046d0a7f96ac1a9bc6b)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetAggregator")
    def reset_aggregator(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAggregator", []))

    @jsii.member(jsii_name="resetCrossOrgUuids")
    def reset_cross_org_uuids(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCrossOrgUuids", []))

    @builtins.property
    @jsii.member(jsii_name="aggregatorInput")
    def aggregator_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregatorInput"))

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuidsInput")
    def cross_org_uuids_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "crossOrgUuidsInput"))

    @builtins.property
    @jsii.member(jsii_name="dataSourceInput")
    def data_source_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "dataSourceInput"))

    @builtins.property
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property
    @jsii.member(jsii_name="queryInput")
    def query_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "queryInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregator")
    def aggregator(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregator"))

    @aggregator.setter
    def aggregator(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__38a5a7cfa1ea221373488cbf97feaddfa4aaa33e458f76a332a0d288391d20b5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregator", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuids")
    def cross_org_uuids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "crossOrgUuids"))

    @cross_org_uuids.setter
    def cross_org_uuids(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8f2bdb52515394561d4df72a043c6bec1a053d5e30e1102e3acfce368b7d10e0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "crossOrgUuids", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="dataSource")
    def data_source(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "dataSource"))

    @data_source.setter
    def data_source(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9e96dea6c95abe837807cde9a823abdb761b96d236e08934a943d2fa5b3fb6e3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "dataSource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a77a47ee0f97c2e463c0ebd5ad374763e2019977062c4e45e055a543be64ea5d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "name", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="query")
    def query(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "query"))

    @query.setter
    def query(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__57cc75e7e40ccebb6963aff98c885c2686aa64b06a5a6a2a0d64f1522e65bea7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "query", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetSunburstDefinitionRequestQueryCloudCostQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetSunburstDefinitionRequestQueryCloudCostQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetSunburstDefinitionRequestQueryCloudCostQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c64ed26d65a9935c06241de717db8d8b714d275211634b1942cd70be74abaf6b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestQueryEventQuery",
    jsii_struct_bases=[],
    name_mapping={
        "compute": "compute",
        "data_source": "dataSource",
        "name": "name",
        "cross_org_uuids": "crossOrgUuids",
        "group_by": "groupBy",
        "indexes": "indexes",
        "search": "search",
        "storage": "storage",
    },
)
class PowerpackWidgetSunburstDefinitionRequestQueryEventQuery:
    def __init__(
        self,
        *,
        compute: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetSunburstDefinitionRequestQueryEventQueryCompute", typing.Dict[builtins.str, typing.Any]]]],
        data_source: builtins.str,
        name: builtins.str,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetSunburstDefinitionRequestQueryEventQueryGroupBy", typing.Dict[builtins.str, typing.Any]]]]] = None,
        indexes: typing.Optional[typing.Sequence[builtins.str]] = None,
        search: typing.Optional[typing.Union["PowerpackWidgetSunburstDefinitionRequestQueryEventQuerySearch", typing.Dict[builtins.str, typing.Any]]] = None,
        storage: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param compute: compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute Powerpack#compute}
        :param data_source: The data source for event platform-based queries. Valid values are ``logs``, ``spans``, ``network``, ``rum``, ``security_signals``, ``profiles``, ``audit``, ``events``, ``ci_tests``, ``ci_pipelines``, ``incident_analytics``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param name: The name of query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param indexes: An array of index names to query in the stream. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#indexes Powerpack#indexes}
        :param search: search block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search Powerpack#search}
        :param storage: Storage location (private beta). Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#storage Powerpack#storage}
        '''
        if isinstance(search, dict):
            search = PowerpackWidgetSunburstDefinitionRequestQueryEventQuerySearch(**search)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__08c6c73402d23ab821a246ff11c920a19339ef686731abae55d6082254b8bdcf)
            check_type(argname="argument compute", value=compute, expected_type=type_hints["compute"])
            check_type(argname="argument data_source", value=data_source, expected_type=type_hints["data_source"])
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument cross_org_uuids", value=cross_org_uuids, expected_type=type_hints["cross_org_uuids"])
            check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
            check_type(argname="argument indexes", value=indexes, expected_type=type_hints["indexes"])
            check_type(argname="argument search", value=search, expected_type=type_hints["search"])
            check_type(argname="argument storage", value=storage, expected_type=type_hints["storage"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "compute": compute,
            "data_source": data_source,
            "name": name,
        }
        if cross_org_uuids is not None:
            self._values["cross_org_uuids"] = cross_org_uuids
        if group_by is not None:
            self._values["group_by"] = group_by
        if indexes is not None:
            self._values["indexes"] = indexes
        if search is not None:
            self._values["search"] = search
        if storage is not None:
            self._values["storage"] = storage

    @builtins.property
    def compute(
        self,
    ) -> typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetSunburstDefinitionRequestQueryEventQueryCompute"]]:
        '''compute block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute Powerpack#compute}
        '''
        result = self._values.get("compute")
        assert result is not None, "Required property 'compute' is missing"
        return typing.cast(typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetSunburstDefinitionRequestQueryEventQueryCompute"]], result)

    @builtins.property
    def data_source(self) -> builtins.str:
        '''The data source for event platform-based queries.

        Valid values are ``logs``, ``spans``, ``network``, ``rum``, ``security_signals``, ``profiles``, ``audit``, ``events``, ``ci_tests``, ``ci_pipelines``, ``incident_analytics``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        '''
        result = self._values.get("data_source")
        assert result is not None, "Required property 'data_source' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def name(self) -> builtins.str:
        '''The name of query for use in formulas.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        '''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def cross_org_uuids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''The source organization UUID for cross organization queries. Feature in Private Beta.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        '''
        result = self._values.get("cross_org_uuids")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def group_by(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetSunburstDefinitionRequestQueryEventQueryGroupBy"]]]:
        '''group_by block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        '''
        result = self._values.get("group_by")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetSunburstDefinitionRequestQueryEventQueryGroupBy"]]], result)

    @builtins.property
    def indexes(self) -> typing.Optional[typing.List[builtins.str]]:
        '''An array of index names to query in the stream.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#indexes Powerpack#indexes}
        '''
        result = self._values.get("indexes")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def search(
        self,
    ) -> typing.Optional["PowerpackWidgetSunburstDefinitionRequestQueryEventQuerySearch"]:
        '''search block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search Powerpack#search}
        '''
        result = self._values.get("search")
        return typing.cast(typing.Optional["PowerpackWidgetSunburstDefinitionRequestQueryEventQuerySearch"], result)

    @builtins.property
    def storage(self) -> typing.Optional[builtins.str]:
        '''Storage location (private beta).

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#storage Powerpack#storage}
        '''
        result = self._values.get("storage")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetSunburstDefinitionRequestQueryEventQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestQueryEventQueryCompute",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "interval": "interval",
        "metric": "metric",
    },
)
class PowerpackWidgetSunburstDefinitionRequestQueryEventQueryCompute:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        interval: typing.Optional[jsii.Number] = None,
        metric: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation methods for event platform queries. Valid values are ``count``, ``cardinality``, ``median``, ``pc75``, ``pc90``, ``pc95``, ``pc98``, ``pc99``, ``sum``, ``min``, ``max``, ``avg``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param interval: A time interval in milliseconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        :param metric: The measurable attribute to compute. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__11e119990accc4c6d0c22048cafb7ce4cdcb78ed1e9360ce01b1448f25ad8211)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
            check_type(argname="argument metric", value=metric, expected_type=type_hints["metric"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if interval is not None:
            self._values["interval"] = interval
        if metric is not None:
            self._values["metric"] = metric

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation methods for event platform queries.

        Valid values are ``count``, ``cardinality``, ``median``, ``pc75``, ``pc90``, ``pc95``, ``pc98``, ``pc99``, ``sum``, ``min``, ``max``, ``avg``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''A time interval in milliseconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def metric(self) -> typing.Optional[builtins.str]:
        '''The measurable attribute to compute.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        '''
        result = self._values.get("metric")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetSunburstDefinitionRequestQueryEventQueryCompute(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetSunburstDefinitionRequestQueryEventQueryComputeList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestQueryEventQueryComputeList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6b94cfb445dc9ff1deb183702adea4108ff391ec616728e7c0eb994d77825b8f)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetSunburstDefinitionRequestQueryEventQueryComputeOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__836d0a4cc4e23e718e1370b66eb1972ed70464d71334f774a831c8deafdd305f)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetSunburstDefinitionRequestQueryEventQueryComputeOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__932483abde8b2c9e3f5867e8d19405f22bd26a05daef6761569ff8f1bb6dde93)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__50c7b6d46f61ffe3b7ebbf487fd6cd3daaf3cb71dc84a0da1834fb21be6f5e39)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e42b51294f285671d6edf9817abc8b84be7993e3f523a7a33f12abfa5475ae97)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequestQueryEventQueryCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequestQueryEventQueryCompute]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequestQueryEventQueryCompute]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e081a7de5f577d9cf9a3ca1f755d2de8cbc5ecb94e618a4ad8edbc4cc0d23d48)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetSunburstDefinitionRequestQueryEventQueryComputeOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestQueryEventQueryComputeOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__05944d86d9aae4b5a1afa1327a810b4b7bf58bfcf33d878becb813c75daf6c64)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @jsii.member(jsii_name="resetMetric")
    def reset_metric(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMetric", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="metricInput")
    def metric_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "metricInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__adbdc3c715eeb264c086ff7c94dcd86c38d7338356af956133717b718ebdeb0b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a6cde24d232959c0c24214315f32af995aab81cecaca5c23fd8817b9061459d7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="metric")
    def metric(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "metric"))

    @metric.setter
    def metric(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9b18ca6b2d71e3e65107ba31e8e8cf850836f50bb1848adae8e05861fca2577d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "metric", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetSunburstDefinitionRequestQueryEventQueryCompute]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetSunburstDefinitionRequestQueryEventQueryCompute]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetSunburstDefinitionRequestQueryEventQueryCompute]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c430c2b2d8c07127ec13ecbc810df52bf00c0a28b2e15195d137a25aa04bdeec)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestQueryEventQueryGroupBy",
    jsii_struct_bases=[],
    name_mapping={"facet": "facet", "limit": "limit", "sort": "sort"},
)
class PowerpackWidgetSunburstDefinitionRequestQueryEventQueryGroupBy:
    def __init__(
        self,
        *,
        facet: builtins.str,
        limit: typing.Optional[jsii.Number] = None,
        sort: typing.Optional[typing.Union["PowerpackWidgetSunburstDefinitionRequestQueryEventQueryGroupBySort", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param facet: The event facet. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param limit: The number of groups to return. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param sort: sort block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort Powerpack#sort}
        '''
        if isinstance(sort, dict):
            sort = PowerpackWidgetSunburstDefinitionRequestQueryEventQueryGroupBySort(**sort)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1a48dbdb53a22ee96af221ec0c973649937aef67ee5520f32664c81a23e30f88)
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
            check_type(argname="argument sort", value=sort, expected_type=type_hints["sort"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "facet": facet,
        }
        if limit is not None:
            self._values["limit"] = limit
        if sort is not None:
            self._values["sort"] = sort

    @builtins.property
    def facet(self) -> builtins.str:
        '''The event facet.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        assert result is not None, "Required property 'facet' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def limit(self) -> typing.Optional[jsii.Number]:
        '''The number of groups to return.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        '''
        result = self._values.get("limit")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def sort(
        self,
    ) -> typing.Optional["PowerpackWidgetSunburstDefinitionRequestQueryEventQueryGroupBySort"]:
        '''sort block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort Powerpack#sort}
        '''
        result = self._values.get("sort")
        return typing.cast(typing.Optional["PowerpackWidgetSunburstDefinitionRequestQueryEventQueryGroupBySort"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetSunburstDefinitionRequestQueryEventQueryGroupBy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetSunburstDefinitionRequestQueryEventQueryGroupByList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestQueryEventQueryGroupByList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c9225f31dfe24a9e4bc594adfa801da80e67785bfc71e9017150a3e5ee8eb9fe)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetSunburstDefinitionRequestQueryEventQueryGroupByOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a8c589d54757e73f6a870ab69d26286c8e4bcda7e0d567d963d37e0b91dffdfa)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetSunburstDefinitionRequestQueryEventQueryGroupByOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4e313192aa15ffe234565fb67a0a3222f414d7a4067ef26848517dbfc3b0694e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6bd41c499f8363c1b0330aea6de1112ff79dd554b550002cd2850cf01f62fba4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5ee00e0f4fc16550913ebaca75d4485d5a1886f82b4111a8c789942491ead3ac)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequestQueryEventQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequestQueryEventQueryGroupBy]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequestQueryEventQueryGroupBy]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7de276ab3e782fd62719ec7fbbaaaafe569cd025cc96872b728bed456a1f27e0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetSunburstDefinitionRequestQueryEventQueryGroupByOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestQueryEventQueryGroupByOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8f27d315abc07c51678b22a5e1a7d6b38cc451efbc411e420a45ebc40c60b767)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putSort")
    def put_sort(
        self,
        *,
        aggregation: builtins.str,
        metric: typing.Optional[builtins.str] = None,
        order: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation methods for the event platform queries. Valid values are ``count``, ``cardinality``, ``median``, ``pc75``, ``pc90``, ``pc95``, ``pc98``, ``pc99``, ``sum``, ``min``, ``max``, ``avg``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param metric: The metric used for sorting group by results. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        :param order: Direction of sort. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        value = PowerpackWidgetSunburstDefinitionRequestQueryEventQueryGroupBySort(
            aggregation=aggregation, metric=metric, order=order
        )

        return typing.cast(None, jsii.invoke(self, "putSort", [value]))

    @jsii.member(jsii_name="resetLimit")
    def reset_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLimit", []))

    @jsii.member(jsii_name="resetSort")
    def reset_sort(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSort", []))

    @builtins.property
    @jsii.member(jsii_name="sort")
    def sort(
        self,
    ) -> "PowerpackWidgetSunburstDefinitionRequestQueryEventQueryGroupBySortOutputReference":
        return typing.cast("PowerpackWidgetSunburstDefinitionRequestQueryEventQueryGroupBySortOutputReference", jsii.get(self, "sort"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="limitInput")
    def limit_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "limitInput"))

    @builtins.property
    @jsii.member(jsii_name="sortInput")
    def sort_input(
        self,
    ) -> typing.Optional["PowerpackWidgetSunburstDefinitionRequestQueryEventQueryGroupBySort"]:
        return typing.cast(typing.Optional["PowerpackWidgetSunburstDefinitionRequestQueryEventQueryGroupBySort"], jsii.get(self, "sortInput"))

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4354bf813bfba7b8f8c400e37b0b9bd43666661d95ed232d1bcf8dde862403cf)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="limit")
    def limit(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "limit"))

    @limit.setter
    def limit(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__774b1b353753efaf66fce237c0899c011488645128c25ebc033bbbc50f688311)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "limit", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetSunburstDefinitionRequestQueryEventQueryGroupBy]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetSunburstDefinitionRequestQueryEventQueryGroupBy]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetSunburstDefinitionRequestQueryEventQueryGroupBy]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__66c5cfb3c9cf67c2d1bf0a26bbd16ea3cc381b8c68512c6e4eb7cb2964758847)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestQueryEventQueryGroupBySort",
    jsii_struct_bases=[],
    name_mapping={"aggregation": "aggregation", "metric": "metric", "order": "order"},
)
class PowerpackWidgetSunburstDefinitionRequestQueryEventQueryGroupBySort:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        metric: typing.Optional[builtins.str] = None,
        order: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation methods for the event platform queries. Valid values are ``count``, ``cardinality``, ``median``, ``pc75``, ``pc90``, ``pc95``, ``pc98``, ``pc99``, ``sum``, ``min``, ``max``, ``avg``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param metric: The metric used for sorting group by results. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        :param order: Direction of sort. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b65ff12b2e1d777fc5a874e2e47affe1a00c2684019de739a1a8895d4fd36143)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument metric", value=metric, expected_type=type_hints["metric"])
            check_type(argname="argument order", value=order, expected_type=type_hints["order"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if metric is not None:
            self._values["metric"] = metric
        if order is not None:
            self._values["order"] = order

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation methods for the event platform queries.

        Valid values are ``count``, ``cardinality``, ``median``, ``pc75``, ``pc90``, ``pc95``, ``pc98``, ``pc99``, ``sum``, ``min``, ``max``, ``avg``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def metric(self) -> typing.Optional[builtins.str]:
        '''The metric used for sorting group by results.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        '''
        result = self._values.get("metric")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def order(self) -> typing.Optional[builtins.str]:
        '''Direction of sort. Valid values are ``asc``, ``desc``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        result = self._values.get("order")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetSunburstDefinitionRequestQueryEventQueryGroupBySort(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetSunburstDefinitionRequestQueryEventQueryGroupBySortOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestQueryEventQueryGroupBySortOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a401b25afc8a7361d0cadf0d002b2c4db55d2636fadcbb6335085529b7721de8)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetMetric")
    def reset_metric(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMetric", []))

    @jsii.member(jsii_name="resetOrder")
    def reset_order(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetOrder", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="metricInput")
    def metric_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "metricInput"))

    @builtins.property
    @jsii.member(jsii_name="orderInput")
    def order_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "orderInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4ecf941b997bba27e32bbbadbf19bed89dfa86d902a0b541592bb7b0e1467225)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="metric")
    def metric(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "metric"))

    @metric.setter
    def metric(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f4bd16661843e7747c86eb84b13a6d3aec9606700b38dd20a5889f861ba83d8b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "metric", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="order")
    def order(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "order"))

    @order.setter
    def order(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__efed57c6d52d7731d457d902cf1844dfc6c150b9ffd8800dd7fa1890a116f47f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "order", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetSunburstDefinitionRequestQueryEventQueryGroupBySort]:
        return typing.cast(typing.Optional[PowerpackWidgetSunburstDefinitionRequestQueryEventQueryGroupBySort], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetSunburstDefinitionRequestQueryEventQueryGroupBySort],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0ad32fda348e8b4a6ea81da0208f8510aa31450eceddd20c70bd26e63a8795cb)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetSunburstDefinitionRequestQueryEventQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestQueryEventQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f2c696534c0f3512d87bb13259fb1f0fe424cfdb12e7302dfc85c57feb73c7e5)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putCompute")
    def put_compute(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetSunburstDefinitionRequestQueryEventQueryCompute, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e5b7424b706da62137a623086e4995b83463e168e46b6ded330c0859522563ff)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putCompute", [value]))

    @jsii.member(jsii_name="putGroupBy")
    def put_group_by(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetSunburstDefinitionRequestQueryEventQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3bad93e091674257ad67f4d349b8d5f78c3d57471474169cef4f68950feeee43)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putGroupBy", [value]))

    @jsii.member(jsii_name="putSearch")
    def put_search(self, *, query: builtins.str) -> None:
        '''
        :param query: The events search string. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        '''
        value = PowerpackWidgetSunburstDefinitionRequestQueryEventQuerySearch(
            query=query
        )

        return typing.cast(None, jsii.invoke(self, "putSearch", [value]))

    @jsii.member(jsii_name="resetCrossOrgUuids")
    def reset_cross_org_uuids(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCrossOrgUuids", []))

    @jsii.member(jsii_name="resetGroupBy")
    def reset_group_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGroupBy", []))

    @jsii.member(jsii_name="resetIndexes")
    def reset_indexes(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetIndexes", []))

    @jsii.member(jsii_name="resetSearch")
    def reset_search(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSearch", []))

    @jsii.member(jsii_name="resetStorage")
    def reset_storage(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetStorage", []))

    @builtins.property
    @jsii.member(jsii_name="compute")
    def compute(
        self,
    ) -> PowerpackWidgetSunburstDefinitionRequestQueryEventQueryComputeList:
        return typing.cast(PowerpackWidgetSunburstDefinitionRequestQueryEventQueryComputeList, jsii.get(self, "compute"))

    @builtins.property
    @jsii.member(jsii_name="groupBy")
    def group_by(
        self,
    ) -> PowerpackWidgetSunburstDefinitionRequestQueryEventQueryGroupByList:
        return typing.cast(PowerpackWidgetSunburstDefinitionRequestQueryEventQueryGroupByList, jsii.get(self, "groupBy"))

    @builtins.property
    @jsii.member(jsii_name="search")
    def search(
        self,
    ) -> "PowerpackWidgetSunburstDefinitionRequestQueryEventQuerySearchOutputReference":
        return typing.cast("PowerpackWidgetSunburstDefinitionRequestQueryEventQuerySearchOutputReference", jsii.get(self, "search"))

    @builtins.property
    @jsii.member(jsii_name="computeInput")
    def compute_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequestQueryEventQueryCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequestQueryEventQueryCompute]]], jsii.get(self, "computeInput"))

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuidsInput")
    def cross_org_uuids_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "crossOrgUuidsInput"))

    @builtins.property
    @jsii.member(jsii_name="dataSourceInput")
    def data_source_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "dataSourceInput"))

    @builtins.property
    @jsii.member(jsii_name="groupByInput")
    def group_by_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequestQueryEventQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequestQueryEventQueryGroupBy]]], jsii.get(self, "groupByInput"))

    @builtins.property
    @jsii.member(jsii_name="indexesInput")
    def indexes_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "indexesInput"))

    @builtins.property
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property
    @jsii.member(jsii_name="searchInput")
    def search_input(
        self,
    ) -> typing.Optional["PowerpackWidgetSunburstDefinitionRequestQueryEventQuerySearch"]:
        return typing.cast(typing.Optional["PowerpackWidgetSunburstDefinitionRequestQueryEventQuerySearch"], jsii.get(self, "searchInput"))

    @builtins.property
    @jsii.member(jsii_name="storageInput")
    def storage_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "storageInput"))

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuids")
    def cross_org_uuids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "crossOrgUuids"))

    @cross_org_uuids.setter
    def cross_org_uuids(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8961cc4f1c798c7342813b6a5a3107588933f55c3aca2f0aada1fd0150253473)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "crossOrgUuids", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="dataSource")
    def data_source(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "dataSource"))

    @data_source.setter
    def data_source(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ab966700bd32d6f3c228ac93a402ef7c54c10b04741770fa8fb758cb1a2d67a2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "dataSource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="indexes")
    def indexes(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "indexes"))

    @indexes.setter
    def indexes(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6b95d02718f3c487d4d2a47c1cd67a42e065db494b3d845d6ee5202c5b778aea)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "indexes", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ae6f793488f7eb4844b4c60907e62b0a5f1982b3daa79cde69a84e1f573af176)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "name", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="storage")
    def storage(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "storage"))

    @storage.setter
    def storage(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5cedab61a1daaea0668becdcea8d313466cc74f82b2d107141fe328265963646)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "storage", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetSunburstDefinitionRequestQueryEventQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetSunburstDefinitionRequestQueryEventQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetSunburstDefinitionRequestQueryEventQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7356cb86df03ae918af8fa9f5b281fa4ef108af10a5b2b3cf9d3846f868e3ea7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestQueryEventQuerySearch",
    jsii_struct_bases=[],
    name_mapping={"query": "query"},
)
class PowerpackWidgetSunburstDefinitionRequestQueryEventQuerySearch:
    def __init__(self, *, query: builtins.str) -> None:
        '''
        :param query: The events search string. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2c83d094817dac37cba130d6cd7501b69b0b8e16493aadea2666963cc1610796)
            check_type(argname="argument query", value=query, expected_type=type_hints["query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "query": query,
        }

    @builtins.property
    def query(self) -> builtins.str:
        '''The events search string.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        '''
        result = self._values.get("query")
        assert result is not None, "Required property 'query' is missing"
        return typing.cast(builtins.str, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetSunburstDefinitionRequestQueryEventQuerySearch(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetSunburstDefinitionRequestQueryEventQuerySearchOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestQueryEventQuerySearchOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8ef6d2645145e81febc8a8005e42e20f27aaee9b6bf399324017fc353e57fa00)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @builtins.property
    @jsii.member(jsii_name="queryInput")
    def query_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "queryInput"))

    @builtins.property
    @jsii.member(jsii_name="query")
    def query(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "query"))

    @query.setter
    def query(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__39a427f7fe2778e2879f02242dab7237f7e423d4d92a83e37fd80e745ffc5f0a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "query", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetSunburstDefinitionRequestQueryEventQuerySearch]:
        return typing.cast(typing.Optional[PowerpackWidgetSunburstDefinitionRequestQueryEventQuerySearch], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetSunburstDefinitionRequestQueryEventQuerySearch],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a8a33300d756c53fc357022925ef133c59fed450d6f76dbc61c07c89b4e5fd47)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetSunburstDefinitionRequestQueryList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestQueryList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__50bf811863a8f2b509901e7eb15d861ddcf9cfeab82e426eaefa5b1d59ecae2e)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetSunburstDefinitionRequestQueryOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__54979cf5c811e2f56fcd03d949f117a8764967ab24c7c3725dda90ef29a66dab)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetSunburstDefinitionRequestQueryOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c2fedae5dab36089d2a7e95ae8a6385967709ebe94a702aa031c39f087660987)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3d563ce78c9855ce12629f620a2ac4a7aa49b046c0047d1e77ff9e4c37b1462a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3c8d4b51d5da1355a4901e7d01fdd714d97e747cce5dea917e3b45f2d28fa017)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequestQuery]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequestQuery]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequestQuery]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8bc0e08da3928af9ea3aeed8ae4d1675e8d944fe192c236a156d989e25e2015b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestQueryMetricQuery",
    jsii_struct_bases=[],
    name_mapping={
        "name": "name",
        "query": "query",
        "aggregator": "aggregator",
        "cross_org_uuids": "crossOrgUuids",
        "data_source": "dataSource",
    },
)
class PowerpackWidgetSunburstDefinitionRequestQueryMetricQuery:
    def __init__(
        self,
        *,
        name: builtins.str,
        query: builtins.str,
        aggregator: typing.Optional[builtins.str] = None,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        data_source: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param name: The name of the query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param query: The metrics query definition. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        :param aggregator: The aggregation methods available for metrics queries. Valid values are ``avg``, ``min``, ``max``, ``sum``, ``last``, ``area``, ``l2norm``, ``percentile``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregator Powerpack#aggregator}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param data_source: The data source for metrics queries. Defaults to ``"metrics"``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1b90fa9f5e8273c148184b013e7687f504b6123b1bf5934f20fb25e13d8a28a7)
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument query", value=query, expected_type=type_hints["query"])
            check_type(argname="argument aggregator", value=aggregator, expected_type=type_hints["aggregator"])
            check_type(argname="argument cross_org_uuids", value=cross_org_uuids, expected_type=type_hints["cross_org_uuids"])
            check_type(argname="argument data_source", value=data_source, expected_type=type_hints["data_source"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "name": name,
            "query": query,
        }
        if aggregator is not None:
            self._values["aggregator"] = aggregator
        if cross_org_uuids is not None:
            self._values["cross_org_uuids"] = cross_org_uuids
        if data_source is not None:
            self._values["data_source"] = data_source

    @builtins.property
    def name(self) -> builtins.str:
        '''The name of the query for use in formulas.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        '''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def query(self) -> builtins.str:
        '''The metrics query definition.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        '''
        result = self._values.get("query")
        assert result is not None, "Required property 'query' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def aggregator(self) -> typing.Optional[builtins.str]:
        '''The aggregation methods available for metrics queries. Valid values are ``avg``, ``min``, ``max``, ``sum``, ``last``, ``area``, ``l2norm``, ``percentile``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregator Powerpack#aggregator}
        '''
        result = self._values.get("aggregator")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def cross_org_uuids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''The source organization UUID for cross organization queries. Feature in Private Beta.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        '''
        result = self._values.get("cross_org_uuids")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def data_source(self) -> typing.Optional[builtins.str]:
        '''The data source for metrics queries. Defaults to ``"metrics"``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        '''
        result = self._values.get("data_source")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetSunburstDefinitionRequestQueryMetricQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetSunburstDefinitionRequestQueryMetricQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestQueryMetricQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__532f66992f397f073c0fd2caae3ff74efa0b093179607a5beb5d893a9056784b)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetAggregator")
    def reset_aggregator(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAggregator", []))

    @jsii.member(jsii_name="resetCrossOrgUuids")
    def reset_cross_org_uuids(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCrossOrgUuids", []))

    @jsii.member(jsii_name="resetDataSource")
    def reset_data_source(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDataSource", []))

    @builtins.property
    @jsii.member(jsii_name="aggregatorInput")
    def aggregator_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregatorInput"))

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuidsInput")
    def cross_org_uuids_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "crossOrgUuidsInput"))

    @builtins.property
    @jsii.member(jsii_name="dataSourceInput")
    def data_source_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "dataSourceInput"))

    @builtins.property
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property
    @jsii.member(jsii_name="queryInput")
    def query_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "queryInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregator")
    def aggregator(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregator"))

    @aggregator.setter
    def aggregator(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__041011815057b99cfc32995e1f46d673e749190a5d77a07e9ab1e135faac96d0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregator", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuids")
    def cross_org_uuids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "crossOrgUuids"))

    @cross_org_uuids.setter
    def cross_org_uuids(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__75bcdab0defa3d76cc2c40b23c0e3e5ba27e3854e5fd7df2523f813f46c10886)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "crossOrgUuids", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="dataSource")
    def data_source(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "dataSource"))

    @data_source.setter
    def data_source(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__24d67cbbe7574184a617b9e12fe7a1b919326beb0ae8c4f8950d2549296dc107)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "dataSource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__81eab4b277abaf0e2a95a516529187816a515d72210c756d86b884b0305dd836)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "name", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="query")
    def query(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "query"))

    @query.setter
    def query(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c4c135be7d2c5bf9fad97f5a67599eeca909e9dded93afda03e9798c98a353af)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "query", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetSunburstDefinitionRequestQueryMetricQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetSunburstDefinitionRequestQueryMetricQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetSunburstDefinitionRequestQueryMetricQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8b3c9e9939634b9913394d3362902c0dae40a893d169280a21b3ef5c92d0922e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetSunburstDefinitionRequestQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7ad645bb7b5ec593de291baf0221707b7307bc2c672c5bb561cdfc346af14df3)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putApmDependencyStatsQuery")
    def put_apm_dependency_stats_query(
        self,
        *,
        data_source: builtins.str,
        env: builtins.str,
        name: builtins.str,
        operation_name: builtins.str,
        resource_name: builtins.str,
        service: builtins.str,
        stat: builtins.str,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        is_upstream: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        primary_tag_name: typing.Optional[builtins.str] = None,
        primary_tag_value: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param data_source: The data source for APM Dependency Stats queries. Valid values are ``apm_dependency_stats``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param env: APM environment. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#env Powerpack#env}
        :param name: The name of query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param operation_name: Name of operation on service. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#operation_name Powerpack#operation_name}
        :param resource_name: APM resource. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#resource_name Powerpack#resource_name}
        :param service: APM service. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#service Powerpack#service}
        :param stat: APM statistic. Valid values are ``avg_duration``, ``avg_root_duration``, ``avg_spans_per_trace``, ``error_rate``, ``pct_exec_time``, ``pct_of_traces``, ``total_traces_count``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#stat Powerpack#stat}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param is_upstream: Determines whether stats for upstream or downstream dependencies should be queried. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#is_upstream Powerpack#is_upstream}
        :param primary_tag_name: The name of the second primary tag used within APM; required when ``primary_tag_value`` is specified. See https://docs.datadoghq.com/tracing/guide/setting_primary_tags_to_scope/#add-a-second-primary-tag-in-datadog. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_name Powerpack#primary_tag_name}
        :param primary_tag_value: Filter APM data by the second primary tag. ``primary_tag_name`` must also be specified. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_value Powerpack#primary_tag_value}
        '''
        value = PowerpackWidgetSunburstDefinitionRequestQueryApmDependencyStatsQuery(
            data_source=data_source,
            env=env,
            name=name,
            operation_name=operation_name,
            resource_name=resource_name,
            service=service,
            stat=stat,
            cross_org_uuids=cross_org_uuids,
            is_upstream=is_upstream,
            primary_tag_name=primary_tag_name,
            primary_tag_value=primary_tag_value,
        )

        return typing.cast(None, jsii.invoke(self, "putApmDependencyStatsQuery", [value]))

    @jsii.member(jsii_name="putApmResourceStatsQuery")
    def put_apm_resource_stats_query(
        self,
        *,
        data_source: builtins.str,
        env: builtins.str,
        name: builtins.str,
        service: builtins.str,
        stat: builtins.str,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        group_by: typing.Optional[typing.Sequence[builtins.str]] = None,
        operation_name: typing.Optional[builtins.str] = None,
        primary_tag_name: typing.Optional[builtins.str] = None,
        primary_tag_value: typing.Optional[builtins.str] = None,
        resource_name: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param data_source: The data source for APM Resource Stats queries. Valid values are ``apm_resource_stats``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param env: APM environment. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#env Powerpack#env}
        :param name: The name of query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param service: APM service. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#service Powerpack#service}
        :param stat: APM statistic. Valid values are ``errors``, ``error_rate``, ``hits``, ``latency_avg``, ``latency_distribution``, ``latency_max``, ``latency_p50``, ``latency_p75``, ``latency_p90``, ``latency_p95``, ``latency_p99``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#stat Powerpack#stat}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param group_by: Array of fields to group results by. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param operation_name: Name of operation on service. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#operation_name Powerpack#operation_name}
        :param primary_tag_name: The name of the second primary tag used within APM; required when ``primary_tag_value`` is specified. See https://docs.datadoghq.com/tracing/guide/setting_primary_tags_to_scope/#add-a-second-primary-tag-in-datadog. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_name Powerpack#primary_tag_name}
        :param primary_tag_value: Filter APM data by the second primary tag. ``primary_tag_name`` must also be specified. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_value Powerpack#primary_tag_value}
        :param resource_name: APM resource. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#resource_name Powerpack#resource_name}
        '''
        value = PowerpackWidgetSunburstDefinitionRequestQueryApmResourceStatsQuery(
            data_source=data_source,
            env=env,
            name=name,
            service=service,
            stat=stat,
            cross_org_uuids=cross_org_uuids,
            group_by=group_by,
            operation_name=operation_name,
            primary_tag_name=primary_tag_name,
            primary_tag_value=primary_tag_value,
            resource_name=resource_name,
        )

        return typing.cast(None, jsii.invoke(self, "putApmResourceStatsQuery", [value]))

    @jsii.member(jsii_name="putCloudCostQuery")
    def put_cloud_cost_query(
        self,
        *,
        data_source: builtins.str,
        name: builtins.str,
        query: builtins.str,
        aggregator: typing.Optional[builtins.str] = None,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
    ) -> None:
        '''
        :param data_source: The data source for cloud cost queries. Valid values are ``cloud_cost``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param name: The name of the query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param query: The cloud cost query definition. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        :param aggregator: The aggregation methods available for cloud cost queries. Valid values are ``avg``, ``last``, ``max``, ``min``, ``sum``, ``percentile``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregator Powerpack#aggregator}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        '''
        value = PowerpackWidgetSunburstDefinitionRequestQueryCloudCostQuery(
            data_source=data_source,
            name=name,
            query=query,
            aggregator=aggregator,
            cross_org_uuids=cross_org_uuids,
        )

        return typing.cast(None, jsii.invoke(self, "putCloudCostQuery", [value]))

    @jsii.member(jsii_name="putEventQuery")
    def put_event_query(
        self,
        *,
        compute: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetSunburstDefinitionRequestQueryEventQueryCompute, typing.Dict[builtins.str, typing.Any]]]],
        data_source: builtins.str,
        name: builtins.str,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetSunburstDefinitionRequestQueryEventQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
        indexes: typing.Optional[typing.Sequence[builtins.str]] = None,
        search: typing.Optional[typing.Union[PowerpackWidgetSunburstDefinitionRequestQueryEventQuerySearch, typing.Dict[builtins.str, typing.Any]]] = None,
        storage: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param compute: compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute Powerpack#compute}
        :param data_source: The data source for event platform-based queries. Valid values are ``logs``, ``spans``, ``network``, ``rum``, ``security_signals``, ``profiles``, ``audit``, ``events``, ``ci_tests``, ``ci_pipelines``, ``incident_analytics``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param name: The name of query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param indexes: An array of index names to query in the stream. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#indexes Powerpack#indexes}
        :param search: search block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search Powerpack#search}
        :param storage: Storage location (private beta). Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#storage Powerpack#storage}
        '''
        value = PowerpackWidgetSunburstDefinitionRequestQueryEventQuery(
            compute=compute,
            data_source=data_source,
            name=name,
            cross_org_uuids=cross_org_uuids,
            group_by=group_by,
            indexes=indexes,
            search=search,
            storage=storage,
        )

        return typing.cast(None, jsii.invoke(self, "putEventQuery", [value]))

    @jsii.member(jsii_name="putMetricQuery")
    def put_metric_query(
        self,
        *,
        name: builtins.str,
        query: builtins.str,
        aggregator: typing.Optional[builtins.str] = None,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        data_source: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param name: The name of the query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param query: The metrics query definition. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        :param aggregator: The aggregation methods available for metrics queries. Valid values are ``avg``, ``min``, ``max``, ``sum``, ``last``, ``area``, ``l2norm``, ``percentile``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregator Powerpack#aggregator}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param data_source: The data source for metrics queries. Defaults to ``"metrics"``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        '''
        value = PowerpackWidgetSunburstDefinitionRequestQueryMetricQuery(
            name=name,
            query=query,
            aggregator=aggregator,
            cross_org_uuids=cross_org_uuids,
            data_source=data_source,
        )

        return typing.cast(None, jsii.invoke(self, "putMetricQuery", [value]))

    @jsii.member(jsii_name="putProcessQuery")
    def put_process_query(
        self,
        *,
        data_source: builtins.str,
        metric: builtins.str,
        name: builtins.str,
        aggregator: typing.Optional[builtins.str] = None,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        is_normalized_cpu: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        limit: typing.Optional[jsii.Number] = None,
        sort: typing.Optional[builtins.str] = None,
        tag_filters: typing.Optional[typing.Sequence[builtins.str]] = None,
        text_filter: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param data_source: The data source for process queries. Valid values are ``process``, ``container``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param metric: The process metric name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        :param name: The name of query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param aggregator: The aggregation methods available for metrics queries. Valid values are ``avg``, ``min``, ``max``, ``sum``, ``last``, ``area``, ``l2norm``, ``percentile``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregator Powerpack#aggregator}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param is_normalized_cpu: Whether to normalize the CPU percentages. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#is_normalized_cpu Powerpack#is_normalized_cpu}
        :param limit: The number of hits to return. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param sort: The direction of the sort. Valid values are ``asc``, ``desc``. Defaults to ``"desc"``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort Powerpack#sort}
        :param tag_filters: An array of tags to filter by. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#tag_filters Powerpack#tag_filters}
        :param text_filter: The text to use as a filter. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#text_filter Powerpack#text_filter}
        '''
        value = PowerpackWidgetSunburstDefinitionRequestQueryProcessQuery(
            data_source=data_source,
            metric=metric,
            name=name,
            aggregator=aggregator,
            cross_org_uuids=cross_org_uuids,
            is_normalized_cpu=is_normalized_cpu,
            limit=limit,
            sort=sort,
            tag_filters=tag_filters,
            text_filter=text_filter,
        )

        return typing.cast(None, jsii.invoke(self, "putProcessQuery", [value]))

    @jsii.member(jsii_name="putSloQuery")
    def put_slo_query(
        self,
        *,
        data_source: builtins.str,
        measure: builtins.str,
        slo_id: builtins.str,
        additional_query_filters: typing.Optional[builtins.str] = None,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        group_mode: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
        slo_query_type: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param data_source: The data source for SLO queries. Valid values are ``slo``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param measure: SLO measures queries. Valid values are ``good_events``, ``bad_events``, ``good_minutes``, ``bad_minutes``, ``slo_status``, ``error_budget_remaining``, ``burn_rate``, ``error_budget_burndown``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#measure Powerpack#measure}
        :param slo_id: ID of an SLO to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#slo_id Powerpack#slo_id}
        :param additional_query_filters: Additional filters applied to the SLO query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#additional_query_filters Powerpack#additional_query_filters}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param group_mode: Group mode to query measures. Valid values are ``overall``, ``components``. Defaults to ``"overall"``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_mode Powerpack#group_mode}
        :param name: The name of query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param slo_query_type: type of the SLO to query. Valid values are ``metric``, ``monitor``, ``time_slice``. Defaults to ``"metric"``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#slo_query_type Powerpack#slo_query_type}
        '''
        value = PowerpackWidgetSunburstDefinitionRequestQuerySloQuery(
            data_source=data_source,
            measure=measure,
            slo_id=slo_id,
            additional_query_filters=additional_query_filters,
            cross_org_uuids=cross_org_uuids,
            group_mode=group_mode,
            name=name,
            slo_query_type=slo_query_type,
        )

        return typing.cast(None, jsii.invoke(self, "putSloQuery", [value]))

    @jsii.member(jsii_name="resetApmDependencyStatsQuery")
    def reset_apm_dependency_stats_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetApmDependencyStatsQuery", []))

    @jsii.member(jsii_name="resetApmResourceStatsQuery")
    def reset_apm_resource_stats_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetApmResourceStatsQuery", []))

    @jsii.member(jsii_name="resetCloudCostQuery")
    def reset_cloud_cost_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCloudCostQuery", []))

    @jsii.member(jsii_name="resetEventQuery")
    def reset_event_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetEventQuery", []))

    @jsii.member(jsii_name="resetMetricQuery")
    def reset_metric_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMetricQuery", []))

    @jsii.member(jsii_name="resetProcessQuery")
    def reset_process_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetProcessQuery", []))

    @jsii.member(jsii_name="resetSloQuery")
    def reset_slo_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSloQuery", []))

    @builtins.property
    @jsii.member(jsii_name="apmDependencyStatsQuery")
    def apm_dependency_stats_query(
        self,
    ) -> PowerpackWidgetSunburstDefinitionRequestQueryApmDependencyStatsQueryOutputReference:
        return typing.cast(PowerpackWidgetSunburstDefinitionRequestQueryApmDependencyStatsQueryOutputReference, jsii.get(self, "apmDependencyStatsQuery"))

    @builtins.property
    @jsii.member(jsii_name="apmResourceStatsQuery")
    def apm_resource_stats_query(
        self,
    ) -> PowerpackWidgetSunburstDefinitionRequestQueryApmResourceStatsQueryOutputReference:
        return typing.cast(PowerpackWidgetSunburstDefinitionRequestQueryApmResourceStatsQueryOutputReference, jsii.get(self, "apmResourceStatsQuery"))

    @builtins.property
    @jsii.member(jsii_name="cloudCostQuery")
    def cloud_cost_query(
        self,
    ) -> PowerpackWidgetSunburstDefinitionRequestQueryCloudCostQueryOutputReference:
        return typing.cast(PowerpackWidgetSunburstDefinitionRequestQueryCloudCostQueryOutputReference, jsii.get(self, "cloudCostQuery"))

    @builtins.property
    @jsii.member(jsii_name="eventQuery")
    def event_query(
        self,
    ) -> PowerpackWidgetSunburstDefinitionRequestQueryEventQueryOutputReference:
        return typing.cast(PowerpackWidgetSunburstDefinitionRequestQueryEventQueryOutputReference, jsii.get(self, "eventQuery"))

    @builtins.property
    @jsii.member(jsii_name="metricQuery")
    def metric_query(
        self,
    ) -> PowerpackWidgetSunburstDefinitionRequestQueryMetricQueryOutputReference:
        return typing.cast(PowerpackWidgetSunburstDefinitionRequestQueryMetricQueryOutputReference, jsii.get(self, "metricQuery"))

    @builtins.property
    @jsii.member(jsii_name="processQuery")
    def process_query(
        self,
    ) -> "PowerpackWidgetSunburstDefinitionRequestQueryProcessQueryOutputReference":
        return typing.cast("PowerpackWidgetSunburstDefinitionRequestQueryProcessQueryOutputReference", jsii.get(self, "processQuery"))

    @builtins.property
    @jsii.member(jsii_name="sloQuery")
    def slo_query(
        self,
    ) -> "PowerpackWidgetSunburstDefinitionRequestQuerySloQueryOutputReference":
        return typing.cast("PowerpackWidgetSunburstDefinitionRequestQuerySloQueryOutputReference", jsii.get(self, "sloQuery"))

    @builtins.property
    @jsii.member(jsii_name="apmDependencyStatsQueryInput")
    def apm_dependency_stats_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetSunburstDefinitionRequestQueryApmDependencyStatsQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetSunburstDefinitionRequestQueryApmDependencyStatsQuery], jsii.get(self, "apmDependencyStatsQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="apmResourceStatsQueryInput")
    def apm_resource_stats_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetSunburstDefinitionRequestQueryApmResourceStatsQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetSunburstDefinitionRequestQueryApmResourceStatsQuery], jsii.get(self, "apmResourceStatsQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="cloudCostQueryInput")
    def cloud_cost_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetSunburstDefinitionRequestQueryCloudCostQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetSunburstDefinitionRequestQueryCloudCostQuery], jsii.get(self, "cloudCostQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="eventQueryInput")
    def event_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetSunburstDefinitionRequestQueryEventQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetSunburstDefinitionRequestQueryEventQuery], jsii.get(self, "eventQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="metricQueryInput")
    def metric_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetSunburstDefinitionRequestQueryMetricQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetSunburstDefinitionRequestQueryMetricQuery], jsii.get(self, "metricQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="processQueryInput")
    def process_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetSunburstDefinitionRequestQueryProcessQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetSunburstDefinitionRequestQueryProcessQuery"], jsii.get(self, "processQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="sloQueryInput")
    def slo_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetSunburstDefinitionRequestQuerySloQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetSunburstDefinitionRequestQuerySloQuery"], jsii.get(self, "sloQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetSunburstDefinitionRequestQuery]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetSunburstDefinitionRequestQuery]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetSunburstDefinitionRequestQuery]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fe01f39fe3e084503daeba320906b5ab40b9d58204b5271e99873ee444621705)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestQueryProcessQuery",
    jsii_struct_bases=[],
    name_mapping={
        "data_source": "dataSource",
        "metric": "metric",
        "name": "name",
        "aggregator": "aggregator",
        "cross_org_uuids": "crossOrgUuids",
        "is_normalized_cpu": "isNormalizedCpu",
        "limit": "limit",
        "sort": "sort",
        "tag_filters": "tagFilters",
        "text_filter": "textFilter",
    },
)
class PowerpackWidgetSunburstDefinitionRequestQueryProcessQuery:
    def __init__(
        self,
        *,
        data_source: builtins.str,
        metric: builtins.str,
        name: builtins.str,
        aggregator: typing.Optional[builtins.str] = None,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        is_normalized_cpu: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        limit: typing.Optional[jsii.Number] = None,
        sort: typing.Optional[builtins.str] = None,
        tag_filters: typing.Optional[typing.Sequence[builtins.str]] = None,
        text_filter: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param data_source: The data source for process queries. Valid values are ``process``, ``container``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param metric: The process metric name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        :param name: The name of query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param aggregator: The aggregation methods available for metrics queries. Valid values are ``avg``, ``min``, ``max``, ``sum``, ``last``, ``area``, ``l2norm``, ``percentile``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregator Powerpack#aggregator}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param is_normalized_cpu: Whether to normalize the CPU percentages. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#is_normalized_cpu Powerpack#is_normalized_cpu}
        :param limit: The number of hits to return. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param sort: The direction of the sort. Valid values are ``asc``, ``desc``. Defaults to ``"desc"``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort Powerpack#sort}
        :param tag_filters: An array of tags to filter by. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#tag_filters Powerpack#tag_filters}
        :param text_filter: The text to use as a filter. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#text_filter Powerpack#text_filter}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__76abacb3eb67fd12364fbb5d5a82c140c864bc2487bfe0ba24c127b00529257a)
            check_type(argname="argument data_source", value=data_source, expected_type=type_hints["data_source"])
            check_type(argname="argument metric", value=metric, expected_type=type_hints["metric"])
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument aggregator", value=aggregator, expected_type=type_hints["aggregator"])
            check_type(argname="argument cross_org_uuids", value=cross_org_uuids, expected_type=type_hints["cross_org_uuids"])
            check_type(argname="argument is_normalized_cpu", value=is_normalized_cpu, expected_type=type_hints["is_normalized_cpu"])
            check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
            check_type(argname="argument sort", value=sort, expected_type=type_hints["sort"])
            check_type(argname="argument tag_filters", value=tag_filters, expected_type=type_hints["tag_filters"])
            check_type(argname="argument text_filter", value=text_filter, expected_type=type_hints["text_filter"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "data_source": data_source,
            "metric": metric,
            "name": name,
        }
        if aggregator is not None:
            self._values["aggregator"] = aggregator
        if cross_org_uuids is not None:
            self._values["cross_org_uuids"] = cross_org_uuids
        if is_normalized_cpu is not None:
            self._values["is_normalized_cpu"] = is_normalized_cpu
        if limit is not None:
            self._values["limit"] = limit
        if sort is not None:
            self._values["sort"] = sort
        if tag_filters is not None:
            self._values["tag_filters"] = tag_filters
        if text_filter is not None:
            self._values["text_filter"] = text_filter

    @builtins.property
    def data_source(self) -> builtins.str:
        '''The data source for process queries. Valid values are ``process``, ``container``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        '''
        result = self._values.get("data_source")
        assert result is not None, "Required property 'data_source' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def metric(self) -> builtins.str:
        '''The process metric name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        '''
        result = self._values.get("metric")
        assert result is not None, "Required property 'metric' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def name(self) -> builtins.str:
        '''The name of query for use in formulas.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        '''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def aggregator(self) -> typing.Optional[builtins.str]:
        '''The aggregation methods available for metrics queries. Valid values are ``avg``, ``min``, ``max``, ``sum``, ``last``, ``area``, ``l2norm``, ``percentile``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregator Powerpack#aggregator}
        '''
        result = self._values.get("aggregator")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def cross_org_uuids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''The source organization UUID for cross organization queries. Feature in Private Beta.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        '''
        result = self._values.get("cross_org_uuids")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def is_normalized_cpu(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        '''Whether to normalize the CPU percentages.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#is_normalized_cpu Powerpack#is_normalized_cpu}
        '''
        result = self._values.get("is_normalized_cpu")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)

    @builtins.property
    def limit(self) -> typing.Optional[jsii.Number]:
        '''The number of hits to return.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        '''
        result = self._values.get("limit")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def sort(self) -> typing.Optional[builtins.str]:
        '''The direction of the sort. Valid values are ``asc``, ``desc``. Defaults to ``"desc"``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort Powerpack#sort}
        '''
        result = self._values.get("sort")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def tag_filters(self) -> typing.Optional[typing.List[builtins.str]]:
        '''An array of tags to filter by.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#tag_filters Powerpack#tag_filters}
        '''
        result = self._values.get("tag_filters")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def text_filter(self) -> typing.Optional[builtins.str]:
        '''The text to use as a filter.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#text_filter Powerpack#text_filter}
        '''
        result = self._values.get("text_filter")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetSunburstDefinitionRequestQueryProcessQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetSunburstDefinitionRequestQueryProcessQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestQueryProcessQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7f41c955a6510db40f2baac1de99c21709666e6ee36a37e954b1b8883352b869)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetAggregator")
    def reset_aggregator(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAggregator", []))

    @jsii.member(jsii_name="resetCrossOrgUuids")
    def reset_cross_org_uuids(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCrossOrgUuids", []))

    @jsii.member(jsii_name="resetIsNormalizedCpu")
    def reset_is_normalized_cpu(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetIsNormalizedCpu", []))

    @jsii.member(jsii_name="resetLimit")
    def reset_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLimit", []))

    @jsii.member(jsii_name="resetSort")
    def reset_sort(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSort", []))

    @jsii.member(jsii_name="resetTagFilters")
    def reset_tag_filters(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTagFilters", []))

    @jsii.member(jsii_name="resetTextFilter")
    def reset_text_filter(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTextFilter", []))

    @builtins.property
    @jsii.member(jsii_name="aggregatorInput")
    def aggregator_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregatorInput"))

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuidsInput")
    def cross_org_uuids_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "crossOrgUuidsInput"))

    @builtins.property
    @jsii.member(jsii_name="dataSourceInput")
    def data_source_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "dataSourceInput"))

    @builtins.property
    @jsii.member(jsii_name="isNormalizedCpuInput")
    def is_normalized_cpu_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "isNormalizedCpuInput"))

    @builtins.property
    @jsii.member(jsii_name="limitInput")
    def limit_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "limitInput"))

    @builtins.property
    @jsii.member(jsii_name="metricInput")
    def metric_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "metricInput"))

    @builtins.property
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property
    @jsii.member(jsii_name="sortInput")
    def sort_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "sortInput"))

    @builtins.property
    @jsii.member(jsii_name="tagFiltersInput")
    def tag_filters_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "tagFiltersInput"))

    @builtins.property
    @jsii.member(jsii_name="textFilterInput")
    def text_filter_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "textFilterInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregator")
    def aggregator(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregator"))

    @aggregator.setter
    def aggregator(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__35c39831f41b993a83a74986ca989ca8991e463971971bc13f929a346507614d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregator", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuids")
    def cross_org_uuids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "crossOrgUuids"))

    @cross_org_uuids.setter
    def cross_org_uuids(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4f518407e4b848d8b69fe9295ddbbc81e5af82ac93b5e0506a0a20c153638eae)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "crossOrgUuids", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="dataSource")
    def data_source(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "dataSource"))

    @data_source.setter
    def data_source(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ca219c3ec31a558ee28aa056862ab5cf08eee76a347663355ce229dee99067e8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "dataSource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="isNormalizedCpu")
    def is_normalized_cpu(
        self,
    ) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "isNormalizedCpu"))

    @is_normalized_cpu.setter
    def is_normalized_cpu(
        self,
        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8496219aebc8c109bfdef9db97c38d0a08e31b951f1782f2808ebc2cdc40eaee)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "isNormalizedCpu", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="limit")
    def limit(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "limit"))

    @limit.setter
    def limit(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__08c5d60cdd25e34c91893f5cd0bec44f9087acf8b6268e94edcd2ad97a1fd3c8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "limit", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="metric")
    def metric(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "metric"))

    @metric.setter
    def metric(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e86c1ba89dd156585042b7608a813ed6a23a98fe9adfe40a2e33e51cee26f6b0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "metric", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__323c21449ef8d3b08f9d9315b10d0f366b68a535a20d9f6165134d59415a152f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "name", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="sort")
    def sort(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "sort"))

    @sort.setter
    def sort(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d4df6bbdae683cd340ad95a0eaf67a24fae7a174ee9caa344b26b96d4b3c9442)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "sort", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="tagFilters")
    def tag_filters(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "tagFilters"))

    @tag_filters.setter
    def tag_filters(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__756262986b65a35c3d95a9bd8b431ac87e752e8765b21c88e0390587a17dcfda)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "tagFilters", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="textFilter")
    def text_filter(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "textFilter"))

    @text_filter.setter
    def text_filter(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4781eab37fe2adebcead06b312d8339136584f9faf43129676b38bfc9c7637c3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "textFilter", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetSunburstDefinitionRequestQueryProcessQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetSunburstDefinitionRequestQueryProcessQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetSunburstDefinitionRequestQueryProcessQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7c922acc779735e24bc10d06a365fc2387d499951233065c330accde829458d3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestQuerySloQuery",
    jsii_struct_bases=[],
    name_mapping={
        "data_source": "dataSource",
        "measure": "measure",
        "slo_id": "sloId",
        "additional_query_filters": "additionalQueryFilters",
        "cross_org_uuids": "crossOrgUuids",
        "group_mode": "groupMode",
        "name": "name",
        "slo_query_type": "sloQueryType",
    },
)
class PowerpackWidgetSunburstDefinitionRequestQuerySloQuery:
    def __init__(
        self,
        *,
        data_source: builtins.str,
        measure: builtins.str,
        slo_id: builtins.str,
        additional_query_filters: typing.Optional[builtins.str] = None,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        group_mode: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
        slo_query_type: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param data_source: The data source for SLO queries. Valid values are ``slo``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param measure: SLO measures queries. Valid values are ``good_events``, ``bad_events``, ``good_minutes``, ``bad_minutes``, ``slo_status``, ``error_budget_remaining``, ``burn_rate``, ``error_budget_burndown``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#measure Powerpack#measure}
        :param slo_id: ID of an SLO to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#slo_id Powerpack#slo_id}
        :param additional_query_filters: Additional filters applied to the SLO query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#additional_query_filters Powerpack#additional_query_filters}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param group_mode: Group mode to query measures. Valid values are ``overall``, ``components``. Defaults to ``"overall"``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_mode Powerpack#group_mode}
        :param name: The name of query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param slo_query_type: type of the SLO to query. Valid values are ``metric``, ``monitor``, ``time_slice``. Defaults to ``"metric"``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#slo_query_type Powerpack#slo_query_type}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b4f7fc708f6b356f1810f2c4440611ac8c60f7a0357e97520a6e2d9713997a8c)
            check_type(argname="argument data_source", value=data_source, expected_type=type_hints["data_source"])
            check_type(argname="argument measure", value=measure, expected_type=type_hints["measure"])
            check_type(argname="argument slo_id", value=slo_id, expected_type=type_hints["slo_id"])
            check_type(argname="argument additional_query_filters", value=additional_query_filters, expected_type=type_hints["additional_query_filters"])
            check_type(argname="argument cross_org_uuids", value=cross_org_uuids, expected_type=type_hints["cross_org_uuids"])
            check_type(argname="argument group_mode", value=group_mode, expected_type=type_hints["group_mode"])
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument slo_query_type", value=slo_query_type, expected_type=type_hints["slo_query_type"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "data_source": data_source,
            "measure": measure,
            "slo_id": slo_id,
        }
        if additional_query_filters is not None:
            self._values["additional_query_filters"] = additional_query_filters
        if cross_org_uuids is not None:
            self._values["cross_org_uuids"] = cross_org_uuids
        if group_mode is not None:
            self._values["group_mode"] = group_mode
        if name is not None:
            self._values["name"] = name
        if slo_query_type is not None:
            self._values["slo_query_type"] = slo_query_type

    @builtins.property
    def data_source(self) -> builtins.str:
        '''The data source for SLO queries. Valid values are ``slo``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        '''
        result = self._values.get("data_source")
        assert result is not None, "Required property 'data_source' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def measure(self) -> builtins.str:
        '''SLO measures queries. Valid values are ``good_events``, ``bad_events``, ``good_minutes``, ``bad_minutes``, ``slo_status``, ``error_budget_remaining``, ``burn_rate``, ``error_budget_burndown``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#measure Powerpack#measure}
        '''
        result = self._values.get("measure")
        assert result is not None, "Required property 'measure' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def slo_id(self) -> builtins.str:
        '''ID of an SLO to query.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#slo_id Powerpack#slo_id}
        '''
        result = self._values.get("slo_id")
        assert result is not None, "Required property 'slo_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def additional_query_filters(self) -> typing.Optional[builtins.str]:
        '''Additional filters applied to the SLO query.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#additional_query_filters Powerpack#additional_query_filters}
        '''
        result = self._values.get("additional_query_filters")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def cross_org_uuids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''The source organization UUID for cross organization queries. Feature in Private Beta.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        '''
        result = self._values.get("cross_org_uuids")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def group_mode(self) -> typing.Optional[builtins.str]:
        '''Group mode to query measures. Valid values are ``overall``, ``components``. Defaults to ``"overall"``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_mode Powerpack#group_mode}
        '''
        result = self._values.get("group_mode")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''The name of query for use in formulas.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        '''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def slo_query_type(self) -> typing.Optional[builtins.str]:
        '''type of the SLO to query. Valid values are ``metric``, ``monitor``, ``time_slice``. Defaults to ``"metric"``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#slo_query_type Powerpack#slo_query_type}
        '''
        result = self._values.get("slo_query_type")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetSunburstDefinitionRequestQuerySloQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetSunburstDefinitionRequestQuerySloQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestQuerySloQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__19d452287f22692201dc34a2438d547f5c759b7dd4eb13c5e51d932731185354)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetAdditionalQueryFilters")
    def reset_additional_query_filters(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAdditionalQueryFilters", []))

    @jsii.member(jsii_name="resetCrossOrgUuids")
    def reset_cross_org_uuids(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCrossOrgUuids", []))

    @jsii.member(jsii_name="resetGroupMode")
    def reset_group_mode(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGroupMode", []))

    @jsii.member(jsii_name="resetName")
    def reset_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetName", []))

    @jsii.member(jsii_name="resetSloQueryType")
    def reset_slo_query_type(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSloQueryType", []))

    @builtins.property
    @jsii.member(jsii_name="additionalQueryFiltersInput")
    def additional_query_filters_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "additionalQueryFiltersInput"))

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuidsInput")
    def cross_org_uuids_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "crossOrgUuidsInput"))

    @builtins.property
    @jsii.member(jsii_name="dataSourceInput")
    def data_source_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "dataSourceInput"))

    @builtins.property
    @jsii.member(jsii_name="groupModeInput")
    def group_mode_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "groupModeInput"))

    @builtins.property
    @jsii.member(jsii_name="measureInput")
    def measure_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "measureInput"))

    @builtins.property
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property
    @jsii.member(jsii_name="sloIdInput")
    def slo_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "sloIdInput"))

    @builtins.property
    @jsii.member(jsii_name="sloQueryTypeInput")
    def slo_query_type_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "sloQueryTypeInput"))

    @builtins.property
    @jsii.member(jsii_name="additionalQueryFilters")
    def additional_query_filters(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "additionalQueryFilters"))

    @additional_query_filters.setter
    def additional_query_filters(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ab4a0930a559b2f90b61075eaefc008bdef09463cd57242ba27b95ffc5a2944d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "additionalQueryFilters", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuids")
    def cross_org_uuids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "crossOrgUuids"))

    @cross_org_uuids.setter
    def cross_org_uuids(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__43253afc1c8fce39150b9e6cc2c9e914e24e426168d7618bc72b807decc57968)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "crossOrgUuids", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="dataSource")
    def data_source(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "dataSource"))

    @data_source.setter
    def data_source(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f2ca53637a1224eba15b133d28ea40532736af7d0fc7210d54e337f0cffb25f8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "dataSource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="groupMode")
    def group_mode(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "groupMode"))

    @group_mode.setter
    def group_mode(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bdefd88fc1d84244afb4a8cd4c12cf61b482a2dc57528231ee716a54577b45cf)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "groupMode", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="measure")
    def measure(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "measure"))

    @measure.setter
    def measure(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b8fadc724459d9f5763ff03d1dd027d51ac96cd7df235733e60fc20334e1c31e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "measure", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__179a5150e3ebd72cfa808c9ce020ad95ad07e9b1293e8c201329f39ccbb74db2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "name", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="sloId")
    def slo_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "sloId"))

    @slo_id.setter
    def slo_id(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7b93c122865946bc459cbc9be2b006ab56ff00c696d076d0bbe67f79f1a94c53)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "sloId", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="sloQueryType")
    def slo_query_type(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "sloQueryType"))

    @slo_query_type.setter
    def slo_query_type(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a6cd6a90d50b37439b4ae60ca56e3aa60e0e11bb51d4e2b43c6f084416626473)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "sloQueryType", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetSunburstDefinitionRequestQuerySloQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetSunburstDefinitionRequestQuerySloQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetSunburstDefinitionRequestQuerySloQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__359aed28db95a37cedc0fbe9d882c4cf8b722de82826a6a1c103848d32a5b8e5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestRumQuery",
    jsii_struct_bases=[],
    name_mapping={
        "index": "index",
        "compute_query": "computeQuery",
        "group_by": "groupBy",
        "multi_compute": "multiCompute",
        "search_query": "searchQuery",
    },
)
class PowerpackWidgetSunburstDefinitionRequestRumQuery:
    def __init__(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union["PowerpackWidgetSunburstDefinitionRequestRumQueryComputeQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetSunburstDefinitionRequestRumQueryGroupBy", typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetSunburstDefinitionRequestRumQueryMultiCompute", typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        if isinstance(compute_query, dict):
            compute_query = PowerpackWidgetSunburstDefinitionRequestRumQueryComputeQuery(**compute_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2bed6ad97309f413a71cf589e657f3f3cedc0ac8408a702db33bd20de5c174f9)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
            check_type(argname="argument compute_query", value=compute_query, expected_type=type_hints["compute_query"])
            check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
            check_type(argname="argument multi_compute", value=multi_compute, expected_type=type_hints["multi_compute"])
            check_type(argname="argument search_query", value=search_query, expected_type=type_hints["search_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "index": index,
        }
        if compute_query is not None:
            self._values["compute_query"] = compute_query
        if group_by is not None:
            self._values["group_by"] = group_by
        if multi_compute is not None:
            self._values["multi_compute"] = multi_compute
        if search_query is not None:
            self._values["search_query"] = search_query

    @builtins.property
    def index(self) -> builtins.str:
        '''The name of the index to query.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        '''
        result = self._values.get("index")
        assert result is not None, "Required property 'index' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def compute_query(
        self,
    ) -> typing.Optional["PowerpackWidgetSunburstDefinitionRequestRumQueryComputeQuery"]:
        '''compute_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        '''
        result = self._values.get("compute_query")
        return typing.cast(typing.Optional["PowerpackWidgetSunburstDefinitionRequestRumQueryComputeQuery"], result)

    @builtins.property
    def group_by(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetSunburstDefinitionRequestRumQueryGroupBy"]]]:
        '''group_by block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        '''
        result = self._values.get("group_by")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetSunburstDefinitionRequestRumQueryGroupBy"]]], result)

    @builtins.property
    def multi_compute(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetSunburstDefinitionRequestRumQueryMultiCompute"]]]:
        '''multi_compute block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        '''
        result = self._values.get("multi_compute")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetSunburstDefinitionRequestRumQueryMultiCompute"]]], result)

    @builtins.property
    def search_query(self) -> typing.Optional[builtins.str]:
        '''The search query to use.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        result = self._values.get("search_query")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetSunburstDefinitionRequestRumQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestRumQueryComputeQuery",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetSunburstDefinitionRequestRumQueryComputeQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__07cdea11356ffec7cfd4730002582217201c01656ee169a68cba7af812bf6bb3)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetSunburstDefinitionRequestRumQueryComputeQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetSunburstDefinitionRequestRumQueryComputeQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestRumQueryComputeQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__69791ee536eb167ccf35026b0e461e9944aacd0cd12e8b7f116d2497a61e53ad)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__aa214227b50d784bc5be40be3bde9c93f1742ff4477c607cee1505e0168d7216)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c54468a42bde2ce30ffc5428c2d3da8814e7fc6573406d3d2eeb6cba9c801d53)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5ce4231f38876de26fed28dd4df93688886489becaa8dc958e00a860393674d3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetSunburstDefinitionRequestRumQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetSunburstDefinitionRequestRumQueryComputeQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetSunburstDefinitionRequestRumQueryComputeQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b9a24a99c8d4012c278a55247745ad97c033f872781f41889044ab38996789b9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestRumQueryGroupBy",
    jsii_struct_bases=[],
    name_mapping={"facet": "facet", "limit": "limit", "sort_query": "sortQuery"},
)
class PowerpackWidgetSunburstDefinitionRequestRumQueryGroupBy:
    def __init__(
        self,
        *,
        facet: typing.Optional[builtins.str] = None,
        limit: typing.Optional[jsii.Number] = None,
        sort_query: typing.Optional[typing.Union["PowerpackWidgetSunburstDefinitionRequestRumQueryGroupBySortQuery", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param limit: The maximum number of items in the group. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param sort_query: sort_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        if isinstance(sort_query, dict):
            sort_query = PowerpackWidgetSunburstDefinitionRequestRumQueryGroupBySortQuery(**sort_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a93ba6668d7b4a15c232c15db79654736256131b68cc63b4ae9a97e4fa389b64)
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
            check_type(argname="argument sort_query", value=sort_query, expected_type=type_hints["sort_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if facet is not None:
            self._values["facet"] = facet
        if limit is not None:
            self._values["limit"] = limit
        if sort_query is not None:
            self._values["sort_query"] = sort_query

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def limit(self) -> typing.Optional[jsii.Number]:
        '''The maximum number of items in the group.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        '''
        result = self._values.get("limit")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def sort_query(
        self,
    ) -> typing.Optional["PowerpackWidgetSunburstDefinitionRequestRumQueryGroupBySortQuery"]:
        '''sort_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        result = self._values.get("sort_query")
        return typing.cast(typing.Optional["PowerpackWidgetSunburstDefinitionRequestRumQueryGroupBySortQuery"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetSunburstDefinitionRequestRumQueryGroupBy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetSunburstDefinitionRequestRumQueryGroupByList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestRumQueryGroupByList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5cf63e4e598d97ea3d47587278071f91e7de5698072f3c9442ba58e090b9e33b)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetSunburstDefinitionRequestRumQueryGroupByOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__47fee7435b4e980e0008dd34b830f14f2995be886a7d92d6746a67697ff01426)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetSunburstDefinitionRequestRumQueryGroupByOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7ef5c54341ae8bd0eb86d385155d074a962d550a0c8dd00043a81a49248291f7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__627be6df0f006d101c24773104cd22f2d9b417922b21d2d06e19c2a16b221e5b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8a183de43c06dbd7caaf2fad7709798e766d727736eb9b2f7f948b809e22dbfc)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequestRumQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequestRumQueryGroupBy]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequestRumQueryGroupBy]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__12133f4c2782473c00e19e4028d73ee0167c2092ca268288898326fc46b961d1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetSunburstDefinitionRequestRumQueryGroupByOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestRumQueryGroupByOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b13f76411c2e665f4b99cbb1dc6f8edbc317e76d1349fc8c977acd8ac38f3a6a)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putSortQuery")
    def put_sort_query(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        value = PowerpackWidgetSunburstDefinitionRequestRumQueryGroupBySortQuery(
            aggregation=aggregation, order=order, facet=facet
        )

        return typing.cast(None, jsii.invoke(self, "putSortQuery", [value]))

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetLimit")
    def reset_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLimit", []))

    @jsii.member(jsii_name="resetSortQuery")
    def reset_sort_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSortQuery", []))

    @builtins.property
    @jsii.member(jsii_name="sortQuery")
    def sort_query(
        self,
    ) -> "PowerpackWidgetSunburstDefinitionRequestRumQueryGroupBySortQueryOutputReference":
        return typing.cast("PowerpackWidgetSunburstDefinitionRequestRumQueryGroupBySortQueryOutputReference", jsii.get(self, "sortQuery"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="limitInput")
    def limit_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "limitInput"))

    @builtins.property
    @jsii.member(jsii_name="sortQueryInput")
    def sort_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetSunburstDefinitionRequestRumQueryGroupBySortQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetSunburstDefinitionRequestRumQueryGroupBySortQuery"], jsii.get(self, "sortQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__564f1651b6c649056d30988eb5d613064081aad9b254200fd08d83792b23b62b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="limit")
    def limit(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "limit"))

    @limit.setter
    def limit(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f11681a8b3757af3ebb046292fc046c0dc3394b62a631896494bd4087b9ce3b9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "limit", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetSunburstDefinitionRequestRumQueryGroupBy]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetSunburstDefinitionRequestRumQueryGroupBy]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetSunburstDefinitionRequestRumQueryGroupBy]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c1a47a51f9e340e3da8e587a4dbd3aba668afd5cc37eb9ecef6afeec736bd245)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestRumQueryGroupBySortQuery",
    jsii_struct_bases=[],
    name_mapping={"aggregation": "aggregation", "order": "order", "facet": "facet"},
)
class PowerpackWidgetSunburstDefinitionRequestRumQueryGroupBySortQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ca026c5842e713b7863a0f4dca4c69ca60554327c1337316ad34982ec9e854d3)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument order", value=order, expected_type=type_hints["order"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
            "order": order,
        }
        if facet is not None:
            self._values["facet"] = facet

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def order(self) -> builtins.str:
        '''Widget sorting methods. Valid values are ``asc``, ``desc``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        result = self._values.get("order")
        assert result is not None, "Required property 'order' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetSunburstDefinitionRequestRumQueryGroupBySortQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetSunburstDefinitionRequestRumQueryGroupBySortQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestRumQueryGroupBySortQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a3cc6cb7b22f73ba3321b2963c172df9f9d0e54e8d1cd3869a24e3caa40f3722)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="orderInput")
    def order_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "orderInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a460df5e95422707ca3e4bad0e8f80e1a6af3315beb09ec00fcff99dba269dc2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f9ff0d8cef0bd672e31397f0a02158a0685c9bf823cadfc020745ea0c93aa54c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="order")
    def order(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "order"))

    @order.setter
    def order(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4f45ad4a42a732c2b4c0cbc46bf759390cfeadebea1852882bbc5271ee1cff29)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "order", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetSunburstDefinitionRequestRumQueryGroupBySortQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetSunburstDefinitionRequestRumQueryGroupBySortQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetSunburstDefinitionRequestRumQueryGroupBySortQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d29637d05401349d3000332b099faac88625bc2865d775da8775fb84ff93bc9a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestRumQueryMultiCompute",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetSunburstDefinitionRequestRumQueryMultiCompute:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2ae3290fe1bc97a95da50e2a9dbff0ec0d538e3bbfd5191df4ce347fd5148ef5)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetSunburstDefinitionRequestRumQueryMultiCompute(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetSunburstDefinitionRequestRumQueryMultiComputeList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestRumQueryMultiComputeList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7414aebc9679ad7e01e209bf44c1827ded1979776b9969d7c42857f510d8f441)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetSunburstDefinitionRequestRumQueryMultiComputeOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__12bf8b2c97245a3aeadc0739217afb1827d3c86a5788b28774f44d246cb6575c)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetSunburstDefinitionRequestRumQueryMultiComputeOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d115337d22f8b1d28aad69eff12ee8f72c61a114e4302b593159d616b5198e1c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ce069b75fcba2e9a0f9c4ea5bb6c83195eee88844035e4f5daf3cb313523e79b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a2d65af1ec059369a7f038c98fb539239787464289910e748fd99bcf6da1c20e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequestRumQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequestRumQueryMultiCompute]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequestRumQueryMultiCompute]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__10596dcfc5ac174d316de43296730ef389a211c258f1a678f1d155cf84dffe65)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetSunburstDefinitionRequestRumQueryMultiComputeOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestRumQueryMultiComputeOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c521dd7b9bbe3ed4f60bbb7747c3212b75d3f78732656bcf6e12133c77864bda)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__637d1697fb5bf533cf76c85fc14c6bef6208559c6f4133fd9b18e8b4583604bc)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b3443a471f50b9d42a77001bdd2c7b126656ddce2d277c47764129728d9c2478)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__da08516cfe50db6ae69031cd8606e367f294bfc9d0f05f4036f73b31d429ab73)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetSunburstDefinitionRequestRumQueryMultiCompute]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetSunburstDefinitionRequestRumQueryMultiCompute]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetSunburstDefinitionRequestRumQueryMultiCompute]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__58107392fd67d51112321fda370907b7761e7f8d501d5b15ad61f39b10815e3e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetSunburstDefinitionRequestRumQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestRumQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d57e02afa66db56e7b60ea072aa1e88cdde8039924450b401b6673b80661f98c)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putComputeQuery")
    def put_compute_query(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        value = PowerpackWidgetSunburstDefinitionRequestRumQueryComputeQuery(
            aggregation=aggregation, facet=facet, interval=interval
        )

        return typing.cast(None, jsii.invoke(self, "putComputeQuery", [value]))

    @jsii.member(jsii_name="putGroupBy")
    def put_group_by(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetSunburstDefinitionRequestRumQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__110140832e178572bfa5ffe8035424a7418061da85249b63b4dfe5303fcc07fa)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putGroupBy", [value]))

    @jsii.member(jsii_name="putMultiCompute")
    def put_multi_compute(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetSunburstDefinitionRequestRumQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d31cef6482bf5ee8e356c354b071b2c7e3daa7047b442dd6867eb9ea6aa1f7a5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putMultiCompute", [value]))

    @jsii.member(jsii_name="resetComputeQuery")
    def reset_compute_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetComputeQuery", []))

    @jsii.member(jsii_name="resetGroupBy")
    def reset_group_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGroupBy", []))

    @jsii.member(jsii_name="resetMultiCompute")
    def reset_multi_compute(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMultiCompute", []))

    @jsii.member(jsii_name="resetSearchQuery")
    def reset_search_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSearchQuery", []))

    @builtins.property
    @jsii.member(jsii_name="computeQuery")
    def compute_query(
        self,
    ) -> PowerpackWidgetSunburstDefinitionRequestRumQueryComputeQueryOutputReference:
        return typing.cast(PowerpackWidgetSunburstDefinitionRequestRumQueryComputeQueryOutputReference, jsii.get(self, "computeQuery"))

    @builtins.property
    @jsii.member(jsii_name="groupBy")
    def group_by(self) -> PowerpackWidgetSunburstDefinitionRequestRumQueryGroupByList:
        return typing.cast(PowerpackWidgetSunburstDefinitionRequestRumQueryGroupByList, jsii.get(self, "groupBy"))

    @builtins.property
    @jsii.member(jsii_name="multiCompute")
    def multi_compute(
        self,
    ) -> PowerpackWidgetSunburstDefinitionRequestRumQueryMultiComputeList:
        return typing.cast(PowerpackWidgetSunburstDefinitionRequestRumQueryMultiComputeList, jsii.get(self, "multiCompute"))

    @builtins.property
    @jsii.member(jsii_name="computeQueryInput")
    def compute_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetSunburstDefinitionRequestRumQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetSunburstDefinitionRequestRumQueryComputeQuery], jsii.get(self, "computeQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="groupByInput")
    def group_by_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequestRumQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequestRumQueryGroupBy]]], jsii.get(self, "groupByInput"))

    @builtins.property
    @jsii.member(jsii_name="indexInput")
    def index_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "indexInput"))

    @builtins.property
    @jsii.member(jsii_name="multiComputeInput")
    def multi_compute_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequestRumQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequestRumQueryMultiCompute]]], jsii.get(self, "multiComputeInput"))

    @builtins.property
    @jsii.member(jsii_name="searchQueryInput")
    def search_query_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "searchQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="index")
    def index(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "index"))

    @index.setter
    def index(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f89fb947cad135eb923bea0063e9421233a4d3bedeccbdb83d9e645ce6afa028)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "index", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="searchQuery")
    def search_query(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "searchQuery"))

    @search_query.setter
    def search_query(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d6e692b0a70f9981d2cc6a040543a86602b85b0c472669c452e25c536764f992)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "searchQuery", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetSunburstDefinitionRequestRumQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetSunburstDefinitionRequestRumQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetSunburstDefinitionRequestRumQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bd4c2ca915e1dea3407001741a75169d93d25260fdf4503bc08c306355bf8e03)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestSecurityQuery",
    jsii_struct_bases=[],
    name_mapping={
        "index": "index",
        "compute_query": "computeQuery",
        "group_by": "groupBy",
        "multi_compute": "multiCompute",
        "search_query": "searchQuery",
    },
)
class PowerpackWidgetSunburstDefinitionRequestSecurityQuery:
    def __init__(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union["PowerpackWidgetSunburstDefinitionRequestSecurityQueryComputeQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetSunburstDefinitionRequestSecurityQueryGroupBy", typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetSunburstDefinitionRequestSecurityQueryMultiCompute", typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        if isinstance(compute_query, dict):
            compute_query = PowerpackWidgetSunburstDefinitionRequestSecurityQueryComputeQuery(**compute_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ffd81982d2aa490b362256783c48e043fd5b00a041c52fe3dfa8074733166fb5)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
            check_type(argname="argument compute_query", value=compute_query, expected_type=type_hints["compute_query"])
            check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
            check_type(argname="argument multi_compute", value=multi_compute, expected_type=type_hints["multi_compute"])
            check_type(argname="argument search_query", value=search_query, expected_type=type_hints["search_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "index": index,
        }
        if compute_query is not None:
            self._values["compute_query"] = compute_query
        if group_by is not None:
            self._values["group_by"] = group_by
        if multi_compute is not None:
            self._values["multi_compute"] = multi_compute
        if search_query is not None:
            self._values["search_query"] = search_query

    @builtins.property
    def index(self) -> builtins.str:
        '''The name of the index to query.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        '''
        result = self._values.get("index")
        assert result is not None, "Required property 'index' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def compute_query(
        self,
    ) -> typing.Optional["PowerpackWidgetSunburstDefinitionRequestSecurityQueryComputeQuery"]:
        '''compute_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        '''
        result = self._values.get("compute_query")
        return typing.cast(typing.Optional["PowerpackWidgetSunburstDefinitionRequestSecurityQueryComputeQuery"], result)

    @builtins.property
    def group_by(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetSunburstDefinitionRequestSecurityQueryGroupBy"]]]:
        '''group_by block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        '''
        result = self._values.get("group_by")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetSunburstDefinitionRequestSecurityQueryGroupBy"]]], result)

    @builtins.property
    def multi_compute(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetSunburstDefinitionRequestSecurityQueryMultiCompute"]]]:
        '''multi_compute block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        '''
        result = self._values.get("multi_compute")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetSunburstDefinitionRequestSecurityQueryMultiCompute"]]], result)

    @builtins.property
    def search_query(self) -> typing.Optional[builtins.str]:
        '''The search query to use.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        result = self._values.get("search_query")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetSunburstDefinitionRequestSecurityQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestSecurityQueryComputeQuery",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetSunburstDefinitionRequestSecurityQueryComputeQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f829e655f12402e301c9d0dddf3501563c9432e45e02c07ace1ecd98fec09a99)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetSunburstDefinitionRequestSecurityQueryComputeQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetSunburstDefinitionRequestSecurityQueryComputeQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestSecurityQueryComputeQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2a3fb5407b92f6f85b1662f96f1a7e868cb5e4a0670fe575dc77e18f26170188)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3640aeba7aebfcb27043b6674f85a85619a31f4c6e8fc222438cc74179badbc3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0ef6a8c355359bc3d454bed9203bf8a7b0a9fc418c237ca8bc78336681a10561)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b9d57a8174c7619bce1f8c3b64ed0b820865a959523c7f788a70684e60ed7be1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetSunburstDefinitionRequestSecurityQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetSunburstDefinitionRequestSecurityQueryComputeQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetSunburstDefinitionRequestSecurityQueryComputeQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4417220ef7a56baa520099a215b6286a1b6524c6b70c0b6d05f02e4192228186)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestSecurityQueryGroupBy",
    jsii_struct_bases=[],
    name_mapping={"facet": "facet", "limit": "limit", "sort_query": "sortQuery"},
)
class PowerpackWidgetSunburstDefinitionRequestSecurityQueryGroupBy:
    def __init__(
        self,
        *,
        facet: typing.Optional[builtins.str] = None,
        limit: typing.Optional[jsii.Number] = None,
        sort_query: typing.Optional[typing.Union["PowerpackWidgetSunburstDefinitionRequestSecurityQueryGroupBySortQuery", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param limit: The maximum number of items in the group. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param sort_query: sort_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        if isinstance(sort_query, dict):
            sort_query = PowerpackWidgetSunburstDefinitionRequestSecurityQueryGroupBySortQuery(**sort_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0947002a008e1ecdf6f95b402c98cb4f73c571ec20f0bc7564f89023ebfc42df)
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
            check_type(argname="argument sort_query", value=sort_query, expected_type=type_hints["sort_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if facet is not None:
            self._values["facet"] = facet
        if limit is not None:
            self._values["limit"] = limit
        if sort_query is not None:
            self._values["sort_query"] = sort_query

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def limit(self) -> typing.Optional[jsii.Number]:
        '''The maximum number of items in the group.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        '''
        result = self._values.get("limit")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def sort_query(
        self,
    ) -> typing.Optional["PowerpackWidgetSunburstDefinitionRequestSecurityQueryGroupBySortQuery"]:
        '''sort_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        result = self._values.get("sort_query")
        return typing.cast(typing.Optional["PowerpackWidgetSunburstDefinitionRequestSecurityQueryGroupBySortQuery"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetSunburstDefinitionRequestSecurityQueryGroupBy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetSunburstDefinitionRequestSecurityQueryGroupByList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestSecurityQueryGroupByList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__26a480d445b74d3778c895b1b42ec80a4ffe5e0ef9c85a98c63bb401ffa9d2ac)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetSunburstDefinitionRequestSecurityQueryGroupByOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c40081a4252056b7aa4de163f980efbf9e80c62ca2ac3dfbf392fb38fca62cab)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetSunburstDefinitionRequestSecurityQueryGroupByOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6d6cb535b42e176071c27b94477ef469802069d875a3204b337119fbc838a0fb)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__da25223bdf3c5e8207722b151b756d158f2413ba89f397b7936ab8dd11a36b1f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__237399e9842904be98ebf2685f6aefbaf41934f7322b0cc592734f257c9c4a8f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequestSecurityQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequestSecurityQueryGroupBy]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequestSecurityQueryGroupBy]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7573cc72f6ccffcffabd26a63fe246521175b2dc91fad4a642cdfb7e6f7f846b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetSunburstDefinitionRequestSecurityQueryGroupByOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestSecurityQueryGroupByOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__39ef8f60242f39ad2a78bedb9df821c3ea103f44cff7cbdae453ed10ccb6ae72)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putSortQuery")
    def put_sort_query(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        value = PowerpackWidgetSunburstDefinitionRequestSecurityQueryGroupBySortQuery(
            aggregation=aggregation, order=order, facet=facet
        )

        return typing.cast(None, jsii.invoke(self, "putSortQuery", [value]))

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetLimit")
    def reset_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLimit", []))

    @jsii.member(jsii_name="resetSortQuery")
    def reset_sort_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSortQuery", []))

    @builtins.property
    @jsii.member(jsii_name="sortQuery")
    def sort_query(
        self,
    ) -> "PowerpackWidgetSunburstDefinitionRequestSecurityQueryGroupBySortQueryOutputReference":
        return typing.cast("PowerpackWidgetSunburstDefinitionRequestSecurityQueryGroupBySortQueryOutputReference", jsii.get(self, "sortQuery"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="limitInput")
    def limit_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "limitInput"))

    @builtins.property
    @jsii.member(jsii_name="sortQueryInput")
    def sort_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetSunburstDefinitionRequestSecurityQueryGroupBySortQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetSunburstDefinitionRequestSecurityQueryGroupBySortQuery"], jsii.get(self, "sortQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__08776dde3b3f567390244fba2a3068a65c08da6c066c52cc534ddce6f38419cd)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="limit")
    def limit(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "limit"))

    @limit.setter
    def limit(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a65ebae2e234ff7e0c29ae6ae7570cc98c71773eed1c335042d0077ffc5159b1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "limit", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetSunburstDefinitionRequestSecurityQueryGroupBy]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetSunburstDefinitionRequestSecurityQueryGroupBy]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetSunburstDefinitionRequestSecurityQueryGroupBy]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c409d2a1d50947b082f76061f2922a2866aa3d05ce75bc27b5af4c8fcee05edf)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestSecurityQueryGroupBySortQuery",
    jsii_struct_bases=[],
    name_mapping={"aggregation": "aggregation", "order": "order", "facet": "facet"},
)
class PowerpackWidgetSunburstDefinitionRequestSecurityQueryGroupBySortQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__449f2c55e78cf11ee573febbf5f45b14c0af6ee5f34b5416414f40f8bf1b52a8)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument order", value=order, expected_type=type_hints["order"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
            "order": order,
        }
        if facet is not None:
            self._values["facet"] = facet

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def order(self) -> builtins.str:
        '''Widget sorting methods. Valid values are ``asc``, ``desc``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        result = self._values.get("order")
        assert result is not None, "Required property 'order' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetSunburstDefinitionRequestSecurityQueryGroupBySortQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetSunburstDefinitionRequestSecurityQueryGroupBySortQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestSecurityQueryGroupBySortQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e12df5206d6bbad41f45fd1891679fe29e460f6d9d5f5beab6f7fec77d78675e)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="orderInput")
    def order_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "orderInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__532c189f96a7baea778ab741f9977c8b463c9c75e2222937c99908fcc35e5fe2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0b5029b9f0157df88a966284274d672744b2df32481acc8956127c7f0e80490d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="order")
    def order(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "order"))

    @order.setter
    def order(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__eafcbffe2543cd7ccc7d296dddf3ef07f859a27926910e6a4891fd62a3c8a952)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "order", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetSunburstDefinitionRequestSecurityQueryGroupBySortQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetSunburstDefinitionRequestSecurityQueryGroupBySortQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetSunburstDefinitionRequestSecurityQueryGroupBySortQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5e069a43a4f2eefc9052cad5be88b8e40408b4d4c14c735873c2a36d277a331f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestSecurityQueryMultiCompute",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetSunburstDefinitionRequestSecurityQueryMultiCompute:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fcc2b80b334202141d8523d7ce75e6765ff7d04dca165ed44d2a9d628ab90cb2)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetSunburstDefinitionRequestSecurityQueryMultiCompute(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetSunburstDefinitionRequestSecurityQueryMultiComputeList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestSecurityQueryMultiComputeList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1907d8e3a0cf4560e6e0311d1de449b01b44fc3260828cbefa96a64b920e3490)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetSunburstDefinitionRequestSecurityQueryMultiComputeOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fa1c495926b817f61ac125a41ce253600df26e4cfcb0170e94f1ec8214303979)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetSunburstDefinitionRequestSecurityQueryMultiComputeOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__611b58923fbedb688c5553c547b5210dd32f90ee0f971158a2c6b950d0717df2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2cb9142c697977bb093fec9d87e70d6321ffa33405b5a817130e1239f2ed2dce)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dfb8757e37bdc8f57ff54d5004c3d9e8a24f52f87260d3b71c0bfb6e7a97fc34)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequestSecurityQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequestSecurityQueryMultiCompute]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequestSecurityQueryMultiCompute]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4dbe0a0aa65d18625466a8b14dc27b70ad4c62efe043b77d27986c18e45b8dd7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetSunburstDefinitionRequestSecurityQueryMultiComputeOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestSecurityQueryMultiComputeOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d22522135ccde47a1aacc138266f43956053552d9075c2f76ce4848678c4d2d9)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e15077de356a0fef7640b9b6a731516563cb431b11127d484ba5555db919ec0f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1cdfe32e145a464eee419b428b0c46d89ad23d9fdd17a4c46b153df6004a4f1e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9b63b6e766295f60f16a10ea43275082f4db6dd2738559ddf554d2df5fcee3d5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetSunburstDefinitionRequestSecurityQueryMultiCompute]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetSunburstDefinitionRequestSecurityQueryMultiCompute]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetSunburstDefinitionRequestSecurityQueryMultiCompute]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7bedbefc9528b6b642bdba9cbf0ebf1d16eaf457425f41aa27ba23fe3fd21155)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetSunburstDefinitionRequestSecurityQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestSecurityQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2810f259159240142e2714126847776ee0243810b78330bdc1b394fbd67814e6)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putComputeQuery")
    def put_compute_query(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        value = PowerpackWidgetSunburstDefinitionRequestSecurityQueryComputeQuery(
            aggregation=aggregation, facet=facet, interval=interval
        )

        return typing.cast(None, jsii.invoke(self, "putComputeQuery", [value]))

    @jsii.member(jsii_name="putGroupBy")
    def put_group_by(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetSunburstDefinitionRequestSecurityQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b9fcc65242eff67574af1a05c816719559eb8cdc1a4c077ede34c05e23308d4f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putGroupBy", [value]))

    @jsii.member(jsii_name="putMultiCompute")
    def put_multi_compute(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetSunburstDefinitionRequestSecurityQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__78939730c250c3852cde0eb4131ab35f1bec3745e1a6ba127989202e258261ce)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putMultiCompute", [value]))

    @jsii.member(jsii_name="resetComputeQuery")
    def reset_compute_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetComputeQuery", []))

    @jsii.member(jsii_name="resetGroupBy")
    def reset_group_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGroupBy", []))

    @jsii.member(jsii_name="resetMultiCompute")
    def reset_multi_compute(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMultiCompute", []))

    @jsii.member(jsii_name="resetSearchQuery")
    def reset_search_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSearchQuery", []))

    @builtins.property
    @jsii.member(jsii_name="computeQuery")
    def compute_query(
        self,
    ) -> PowerpackWidgetSunburstDefinitionRequestSecurityQueryComputeQueryOutputReference:
        return typing.cast(PowerpackWidgetSunburstDefinitionRequestSecurityQueryComputeQueryOutputReference, jsii.get(self, "computeQuery"))

    @builtins.property
    @jsii.member(jsii_name="groupBy")
    def group_by(
        self,
    ) -> PowerpackWidgetSunburstDefinitionRequestSecurityQueryGroupByList:
        return typing.cast(PowerpackWidgetSunburstDefinitionRequestSecurityQueryGroupByList, jsii.get(self, "groupBy"))

    @builtins.property
    @jsii.member(jsii_name="multiCompute")
    def multi_compute(
        self,
    ) -> PowerpackWidgetSunburstDefinitionRequestSecurityQueryMultiComputeList:
        return typing.cast(PowerpackWidgetSunburstDefinitionRequestSecurityQueryMultiComputeList, jsii.get(self, "multiCompute"))

    @builtins.property
    @jsii.member(jsii_name="computeQueryInput")
    def compute_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetSunburstDefinitionRequestSecurityQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetSunburstDefinitionRequestSecurityQueryComputeQuery], jsii.get(self, "computeQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="groupByInput")
    def group_by_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequestSecurityQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequestSecurityQueryGroupBy]]], jsii.get(self, "groupByInput"))

    @builtins.property
    @jsii.member(jsii_name="indexInput")
    def index_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "indexInput"))

    @builtins.property
    @jsii.member(jsii_name="multiComputeInput")
    def multi_compute_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequestSecurityQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequestSecurityQueryMultiCompute]]], jsii.get(self, "multiComputeInput"))

    @builtins.property
    @jsii.member(jsii_name="searchQueryInput")
    def search_query_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "searchQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="index")
    def index(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "index"))

    @index.setter
    def index(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2e31fbfbc4cdd2c875dbe45df2d14080aaf8521dac9561e1a15b69324c332996)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "index", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="searchQuery")
    def search_query(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "searchQuery"))

    @search_query.setter
    def search_query(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__39e7173bdc00be608e605078a6ea6d46917659ba683ce5e1f749f97c81bfd19c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "searchQuery", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetSunburstDefinitionRequestSecurityQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetSunburstDefinitionRequestSecurityQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetSunburstDefinitionRequestSecurityQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3d5103a27fb33cc25a69f0be7e85553f92938f09dc1ccde67ad059b2f7774299)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestStyle",
    jsii_struct_bases=[],
    name_mapping={"palette": "palette"},
)
class PowerpackWidgetSunburstDefinitionRequestStyle:
    def __init__(self, *, palette: typing.Optional[builtins.str] = None) -> None:
        '''
        :param palette: A color palette to apply to the widget. The available options are available at: https://docs.datadoghq.com/dashboards/widgets/timeseries/#appearance. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette Powerpack#palette}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0c0229909a64d616505a57efc0bada262e87c4955b5ed1b8aa2a5548baf0d07e)
            check_type(argname="argument palette", value=palette, expected_type=type_hints["palette"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if palette is not None:
            self._values["palette"] = palette

    @builtins.property
    def palette(self) -> typing.Optional[builtins.str]:
        '''A color palette to apply to the widget. The available options are available at: https://docs.datadoghq.com/dashboards/widgets/timeseries/#appearance.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette Powerpack#palette}
        '''
        result = self._values.get("palette")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetSunburstDefinitionRequestStyle(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetSunburstDefinitionRequestStyleOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetSunburstDefinitionRequestStyleOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__58304e0f234eed552c3813182d9993ca64556b78c6e4cd89222a73bde79df1b7)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetPalette")
    def reset_palette(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPalette", []))

    @builtins.property
    @jsii.member(jsii_name="paletteInput")
    def palette_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "paletteInput"))

    @builtins.property
    @jsii.member(jsii_name="palette")
    def palette(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "palette"))

    @palette.setter
    def palette(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9cc6136cc27b8432561f48293b8f6e86663484345cad3dd93c973c41b02b5ce5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "palette", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetSunburstDefinitionRequestStyle]:
        return typing.cast(typing.Optional[PowerpackWidgetSunburstDefinitionRequestStyle], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetSunburstDefinitionRequestStyle],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8cce65acab2409a3d7f3c2d1bc84023bcc87e80659f9861ff66d4ef8e20dd6b1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinition",
    jsii_struct_bases=[],
    name_mapping={
        "custom_link": "customLink",
        "event": "event",
        "legend_columns": "legendColumns",
        "legend_layout": "legendLayout",
        "legend_size": "legendSize",
        "live_span": "liveSpan",
        "marker": "marker",
        "request": "request",
        "right_yaxis": "rightYaxis",
        "show_legend": "showLegend",
        "title": "title",
        "title_align": "titleAlign",
        "title_size": "titleSize",
        "yaxis": "yaxis",
    },
)
class PowerpackWidgetTimeseriesDefinition:
    def __init__(
        self,
        *,
        custom_link: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetTimeseriesDefinitionCustomLink", typing.Dict[builtins.str, typing.Any]]]]] = None,
        event: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetTimeseriesDefinitionEvent", typing.Dict[builtins.str, typing.Any]]]]] = None,
        legend_columns: typing.Optional[typing.Sequence[builtins.str]] = None,
        legend_layout: typing.Optional[builtins.str] = None,
        legend_size: typing.Optional[builtins.str] = None,
        live_span: typing.Optional[builtins.str] = None,
        marker: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetTimeseriesDefinitionMarker", typing.Dict[builtins.str, typing.Any]]]]] = None,
        request: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetTimeseriesDefinitionRequest", typing.Dict[builtins.str, typing.Any]]]]] = None,
        right_yaxis: typing.Optional[typing.Union["PowerpackWidgetTimeseriesDefinitionRightYaxis", typing.Dict[builtins.str, typing.Any]]] = None,
        show_legend: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        title: typing.Optional[builtins.str] = None,
        title_align: typing.Optional[builtins.str] = None,
        title_size: typing.Optional[builtins.str] = None,
        yaxis: typing.Optional[typing.Union["PowerpackWidgetTimeseriesDefinitionYaxis", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param custom_link: custom_link block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom_link Powerpack#custom_link}
        :param event: event block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#event Powerpack#event}
        :param legend_columns: A list of columns to display in the legend. Valid values are ``value``, ``avg``, ``sum``, ``min``, ``max``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#legend_columns Powerpack#legend_columns}
        :param legend_layout: The layout of the legend displayed in the widget. Valid values are ``auto``, ``horizontal``, ``vertical``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#legend_layout Powerpack#legend_layout}
        :param legend_size: The size of the legend displayed in the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#legend_size Powerpack#legend_size}
        :param live_span: The timeframe to use when displaying the widget. Valid values are ``1m``, ``5m``, ``10m``, ``15m``, ``30m``, ``1h``, ``4h``, ``1d``, ``2d``, ``1w``, ``1mo``, ``3mo``, ``6mo``, ``week_to_date``, ``month_to_date``, ``1y``, ``alert``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#live_span Powerpack#live_span}
        :param marker: marker block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#marker Powerpack#marker}
        :param request: request block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#request Powerpack#request}
        :param right_yaxis: right_yaxis block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#right_yaxis Powerpack#right_yaxis}
        :param show_legend: Whether or not to show the legend on this widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#show_legend Powerpack#show_legend}
        :param title: The title of the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title Powerpack#title}
        :param title_align: The alignment of the widget's title. Valid values are ``center``, ``left``, ``right``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_align Powerpack#title_align}
        :param title_size: The size of the widget's title (defaults to 16). Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_size Powerpack#title_size}
        :param yaxis: yaxis block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#yaxis Powerpack#yaxis}
        '''
        if isinstance(right_yaxis, dict):
            right_yaxis = PowerpackWidgetTimeseriesDefinitionRightYaxis(**right_yaxis)
        if isinstance(yaxis, dict):
            yaxis = PowerpackWidgetTimeseriesDefinitionYaxis(**yaxis)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__212514e36da37dd5ecfd44742511b30072b67cf97daf6aa5f4704eb2cc08de4f)
            check_type(argname="argument custom_link", value=custom_link, expected_type=type_hints["custom_link"])
            check_type(argname="argument event", value=event, expected_type=type_hints["event"])
            check_type(argname="argument legend_columns", value=legend_columns, expected_type=type_hints["legend_columns"])
            check_type(argname="argument legend_layout", value=legend_layout, expected_type=type_hints["legend_layout"])
            check_type(argname="argument legend_size", value=legend_size, expected_type=type_hints["legend_size"])
            check_type(argname="argument live_span", value=live_span, expected_type=type_hints["live_span"])
            check_type(argname="argument marker", value=marker, expected_type=type_hints["marker"])
            check_type(argname="argument request", value=request, expected_type=type_hints["request"])
            check_type(argname="argument right_yaxis", value=right_yaxis, expected_type=type_hints["right_yaxis"])
            check_type(argname="argument show_legend", value=show_legend, expected_type=type_hints["show_legend"])
            check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            check_type(argname="argument title_align", value=title_align, expected_type=type_hints["title_align"])
            check_type(argname="argument title_size", value=title_size, expected_type=type_hints["title_size"])
            check_type(argname="argument yaxis", value=yaxis, expected_type=type_hints["yaxis"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if custom_link is not None:
            self._values["custom_link"] = custom_link
        if event is not None:
            self._values["event"] = event
        if legend_columns is not None:
            self._values["legend_columns"] = legend_columns
        if legend_layout is not None:
            self._values["legend_layout"] = legend_layout
        if legend_size is not None:
            self._values["legend_size"] = legend_size
        if live_span is not None:
            self._values["live_span"] = live_span
        if marker is not None:
            self._values["marker"] = marker
        if request is not None:
            self._values["request"] = request
        if right_yaxis is not None:
            self._values["right_yaxis"] = right_yaxis
        if show_legend is not None:
            self._values["show_legend"] = show_legend
        if title is not None:
            self._values["title"] = title
        if title_align is not None:
            self._values["title_align"] = title_align
        if title_size is not None:
            self._values["title_size"] = title_size
        if yaxis is not None:
            self._values["yaxis"] = yaxis

    @builtins.property
    def custom_link(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetTimeseriesDefinitionCustomLink"]]]:
        '''custom_link block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom_link Powerpack#custom_link}
        '''
        result = self._values.get("custom_link")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetTimeseriesDefinitionCustomLink"]]], result)

    @builtins.property
    def event(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetTimeseriesDefinitionEvent"]]]:
        '''event block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#event Powerpack#event}
        '''
        result = self._values.get("event")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetTimeseriesDefinitionEvent"]]], result)

    @builtins.property
    def legend_columns(self) -> typing.Optional[typing.List[builtins.str]]:
        '''A list of columns to display in the legend. Valid values are ``value``, ``avg``, ``sum``, ``min``, ``max``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#legend_columns Powerpack#legend_columns}
        '''
        result = self._values.get("legend_columns")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def legend_layout(self) -> typing.Optional[builtins.str]:
        '''The layout of the legend displayed in the widget. Valid values are ``auto``, ``horizontal``, ``vertical``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#legend_layout Powerpack#legend_layout}
        '''
        result = self._values.get("legend_layout")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def legend_size(self) -> typing.Optional[builtins.str]:
        '''The size of the legend displayed in the widget.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#legend_size Powerpack#legend_size}
        '''
        result = self._values.get("legend_size")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def live_span(self) -> typing.Optional[builtins.str]:
        '''The timeframe to use when displaying the widget.

        Valid values are ``1m``, ``5m``, ``10m``, ``15m``, ``30m``, ``1h``, ``4h``, ``1d``, ``2d``, ``1w``, ``1mo``, ``3mo``, ``6mo``, ``week_to_date``, ``month_to_date``, ``1y``, ``alert``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#live_span Powerpack#live_span}
        '''
        result = self._values.get("live_span")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def marker(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetTimeseriesDefinitionMarker"]]]:
        '''marker block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#marker Powerpack#marker}
        '''
        result = self._values.get("marker")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetTimeseriesDefinitionMarker"]]], result)

    @builtins.property
    def request(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetTimeseriesDefinitionRequest"]]]:
        '''request block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#request Powerpack#request}
        '''
        result = self._values.get("request")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetTimeseriesDefinitionRequest"]]], result)

    @builtins.property
    def right_yaxis(
        self,
    ) -> typing.Optional["PowerpackWidgetTimeseriesDefinitionRightYaxis"]:
        '''right_yaxis block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#right_yaxis Powerpack#right_yaxis}
        '''
        result = self._values.get("right_yaxis")
        return typing.cast(typing.Optional["PowerpackWidgetTimeseriesDefinitionRightYaxis"], result)

    @builtins.property
    def show_legend(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        '''Whether or not to show the legend on this widget.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#show_legend Powerpack#show_legend}
        '''
        result = self._values.get("show_legend")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)

    @builtins.property
    def title(self) -> typing.Optional[builtins.str]:
        '''The title of the widget.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title Powerpack#title}
        '''
        result = self._values.get("title")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def title_align(self) -> typing.Optional[builtins.str]:
        '''The alignment of the widget's title. Valid values are ``center``, ``left``, ``right``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_align Powerpack#title_align}
        '''
        result = self._values.get("title_align")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def title_size(self) -> typing.Optional[builtins.str]:
        '''The size of the widget's title (defaults to 16).

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_size Powerpack#title_size}
        '''
        result = self._values.get("title_size")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def yaxis(self) -> typing.Optional["PowerpackWidgetTimeseriesDefinitionYaxis"]:
        '''yaxis block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#yaxis Powerpack#yaxis}
        '''
        result = self._values.get("yaxis")
        return typing.cast(typing.Optional["PowerpackWidgetTimeseriesDefinitionYaxis"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetTimeseriesDefinition(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionCustomLink",
    jsii_struct_bases=[],
    name_mapping={
        "is_hidden": "isHidden",
        "label": "label",
        "link": "link",
        "override_label": "overrideLabel",
    },
)
class PowerpackWidgetTimeseriesDefinitionCustomLink:
    def __init__(
        self,
        *,
        is_hidden: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        label: typing.Optional[builtins.str] = None,
        link: typing.Optional[builtins.str] = None,
        override_label: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param is_hidden: The flag for toggling context menu link visibility. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#is_hidden Powerpack#is_hidden}
        :param label: The label for the custom link URL. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#label Powerpack#label}
        :param link: The URL of the custom link. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#link Powerpack#link}
        :param override_label: The label ID that refers to a context menu link item. When ``override_label`` is provided, the client request omits the label field. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#override_label Powerpack#override_label}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6b564c9105c6a17e6291bcb70f7d08d02504041ff31bf950a580adae348cd538)
            check_type(argname="argument is_hidden", value=is_hidden, expected_type=type_hints["is_hidden"])
            check_type(argname="argument label", value=label, expected_type=type_hints["label"])
            check_type(argname="argument link", value=link, expected_type=type_hints["link"])
            check_type(argname="argument override_label", value=override_label, expected_type=type_hints["override_label"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if is_hidden is not None:
            self._values["is_hidden"] = is_hidden
        if label is not None:
            self._values["label"] = label
        if link is not None:
            self._values["link"] = link
        if override_label is not None:
            self._values["override_label"] = override_label

    @builtins.property
    def is_hidden(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        '''The flag for toggling context menu link visibility.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#is_hidden Powerpack#is_hidden}
        '''
        result = self._values.get("is_hidden")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)

    @builtins.property
    def label(self) -> typing.Optional[builtins.str]:
        '''The label for the custom link URL.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#label Powerpack#label}
        '''
        result = self._values.get("label")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def link(self) -> typing.Optional[builtins.str]:
        '''The URL of the custom link.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#link Powerpack#link}
        '''
        result = self._values.get("link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def override_label(self) -> typing.Optional[builtins.str]:
        '''The label ID that refers to a context menu link item.

        When ``override_label`` is provided, the client request omits the label field.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#override_label Powerpack#override_label}
        '''
        result = self._values.get("override_label")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetTimeseriesDefinitionCustomLink(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetTimeseriesDefinitionCustomLinkList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionCustomLinkList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a7e7a2366ff6d4e032d6935590188626bb5bb5550627aee153ae6d5b86acb438)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetTimeseriesDefinitionCustomLinkOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1cf15fa75703bf0767fd03b71238d1d09e94680b894544f0a6a983d1b790d836)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetTimeseriesDefinitionCustomLinkOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7d8d0def77a7e3d67305767e47563b32b1152f8ece1683f7b84b8307c3ca7caa)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__854f87675e4a28243c486a2ec21045ab77d4c3dc9ff0d098c4311549d889fdf5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__51044f09c7489ffd8239b5d7ba4c146cd7890327f5c99d8ada96a765d2891c42)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionCustomLink]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionCustomLink]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionCustomLink]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ea3bbc3369c545486603eba93970535d2fac3b6b435328be7ee69e1d5da2f8ec)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetTimeseriesDefinitionCustomLinkOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionCustomLinkOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6a7836909ff5326e8527bb06bd5d956e90254db09b13ade964666d278d191f56)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetIsHidden")
    def reset_is_hidden(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetIsHidden", []))

    @jsii.member(jsii_name="resetLabel")
    def reset_label(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLabel", []))

    @jsii.member(jsii_name="resetLink")
    def reset_link(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLink", []))

    @jsii.member(jsii_name="resetOverrideLabel")
    def reset_override_label(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetOverrideLabel", []))

    @builtins.property
    @jsii.member(jsii_name="isHiddenInput")
    def is_hidden_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "isHiddenInput"))

    @builtins.property
    @jsii.member(jsii_name="labelInput")
    def label_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "labelInput"))

    @builtins.property
    @jsii.member(jsii_name="linkInput")
    def link_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "linkInput"))

    @builtins.property
    @jsii.member(jsii_name="overrideLabelInput")
    def override_label_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "overrideLabelInput"))

    @builtins.property
    @jsii.member(jsii_name="isHidden")
    def is_hidden(self) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "isHidden"))

    @is_hidden.setter
    def is_hidden(
        self,
        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0ec0f9436c4867353d076657c5c2d9baf0ec74c83268c7a9d6b64752d3fbce7f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "isHidden", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="label")
    def label(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "label"))

    @label.setter
    def label(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4d5f3610166fdae73a8a852e58b5bf94efa49d547567b79b946f8470d33ae3ec)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "label", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="link")
    def link(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "link"))

    @link.setter
    def link(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8a26d96b2aefe37d826d9be374b56ebce7d5e7be7d59711a934e0b88441d7bf6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "link", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="overrideLabel")
    def override_label(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "overrideLabel"))

    @override_label.setter
    def override_label(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ec2874e08572ba2c40d5eb10a6d80782e9040729838b25a48d0bc367008826ca)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "overrideLabel", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTimeseriesDefinitionCustomLink]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTimeseriesDefinitionCustomLink]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTimeseriesDefinitionCustomLink]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cece3b00dd4487e03a14c82dea66898b6435271dfbd727b67815c9e165d36c39)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionEvent",
    jsii_struct_bases=[],
    name_mapping={"q": "q", "tags_execution": "tagsExecution"},
)
class PowerpackWidgetTimeseriesDefinitionEvent:
    def __init__(
        self,
        *,
        q: builtins.str,
        tags_execution: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param q: The event query to use in the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#q Powerpack#q}
        :param tags_execution: The execution method for multi-value filters. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#tags_execution Powerpack#tags_execution}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6a8094a04d46466ad8729111ffebbe226a3c81839eb19c281f5dc38b6f9af38f)
            check_type(argname="argument q", value=q, expected_type=type_hints["q"])
            check_type(argname="argument tags_execution", value=tags_execution, expected_type=type_hints["tags_execution"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "q": q,
        }
        if tags_execution is not None:
            self._values["tags_execution"] = tags_execution

    @builtins.property
    def q(self) -> builtins.str:
        '''The event query to use in the widget.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#q Powerpack#q}
        '''
        result = self._values.get("q")
        assert result is not None, "Required property 'q' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def tags_execution(self) -> typing.Optional[builtins.str]:
        '''The execution method for multi-value filters.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#tags_execution Powerpack#tags_execution}
        '''
        result = self._values.get("tags_execution")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetTimeseriesDefinitionEvent(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetTimeseriesDefinitionEventList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionEventList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__87f14fae1756227628b30c6943f3334b00f00af11c744dc9e65f59443fe8631f)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetTimeseriesDefinitionEventOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__335aef13525479145c1353e06312e84b1464620927569c10038a260ceb2a2ccd)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetTimeseriesDefinitionEventOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__97d81a01d8ed0d109ebb6d9e25cb95638b52d8b824e676a0fca56bd23ee7448c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9d8723e03704bb47e4612749a8f5463b25f2b6267fe2ca8540c6c62f3b715f12)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__95ef9a084c39228f4bf6088933a5dfd684a56101c38d6122335aca2bcfba1373)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionEvent]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionEvent]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionEvent]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__35e3b9ff4c480d845fb61f1d87b4c6d9a949050cb6f6be993dbf78ba9bb4129e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetTimeseriesDefinitionEventOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionEventOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5ec9633110bb9f20a4823842d2884196a6acbd281bbbd6968c4c550d4bb9b7f9)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetTagsExecution")
    def reset_tags_execution(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTagsExecution", []))

    @builtins.property
    @jsii.member(jsii_name="qInput")
    def q_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "qInput"))

    @builtins.property
    @jsii.member(jsii_name="tagsExecutionInput")
    def tags_execution_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "tagsExecutionInput"))

    @builtins.property
    @jsii.member(jsii_name="q")
    def q(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "q"))

    @q.setter
    def q(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__900f1fb5fb2311a72eb9b572f14dde8deab455061e928b10c4b18af6dc3180a4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "q", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="tagsExecution")
    def tags_execution(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "tagsExecution"))

    @tags_execution.setter
    def tags_execution(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4e38434825f2565854a147ce45d6b98d4e0455817d24c8c26bcb3bef7549975f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "tagsExecution", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTimeseriesDefinitionEvent]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTimeseriesDefinitionEvent]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTimeseriesDefinitionEvent]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__51572665df03881946cfaafa3a3c01b53def6c2a582b818ba368b33e350ae02b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionMarker",
    jsii_struct_bases=[],
    name_mapping={"value": "value", "display_type": "displayType", "label": "label"},
)
class PowerpackWidgetTimeseriesDefinitionMarker:
    def __init__(
        self,
        *,
        value: builtins.str,
        display_type: typing.Optional[builtins.str] = None,
        label: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param value: A mathematical expression describing the marker, for example: ``y > 1``, ``-5 < y < 0``, ``y = 19``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#value Powerpack#value}
        :param display_type: How the marker lines are displayed, options are one of {``error``, ``warning``, ``info``, ``ok``} combined with one of {``dashed``, ``solid``, ``bold``}. Example: ``error dashed``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#display_type Powerpack#display_type}
        :param label: A label for the line or range. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#label Powerpack#label}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__31b127ea58c69015a84fb5e86dd636976aab4feb4fcc333d3b201d0b64931154)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument display_type", value=display_type, expected_type=type_hints["display_type"])
            check_type(argname="argument label", value=label, expected_type=type_hints["label"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "value": value,
        }
        if display_type is not None:
            self._values["display_type"] = display_type
        if label is not None:
            self._values["label"] = label

    @builtins.property
    def value(self) -> builtins.str:
        '''A mathematical expression describing the marker, for example: ``y > 1``, ``-5 < y < 0``, ``y = 19``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#value Powerpack#value}
        '''
        result = self._values.get("value")
        assert result is not None, "Required property 'value' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def display_type(self) -> typing.Optional[builtins.str]:
        '''How the marker lines are displayed, options are one of {``error``, ``warning``, ``info``, ``ok``} combined with one of {``dashed``, ``solid``, ``bold``}.

        Example: ``error dashed``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#display_type Powerpack#display_type}
        '''
        result = self._values.get("display_type")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def label(self) -> typing.Optional[builtins.str]:
        '''A label for the line or range.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#label Powerpack#label}
        '''
        result = self._values.get("label")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetTimeseriesDefinitionMarker(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetTimeseriesDefinitionMarkerList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionMarkerList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__35e6ee182e61ff197c4cdf7ae1ff218b5e91374140f25ce132f724571b6759e2)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetTimeseriesDefinitionMarkerOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__578575fcf43d862dea7937201638b43b72c7794d882412359537e4289996300b)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetTimeseriesDefinitionMarkerOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6880b1603f1eb4ea56d8f3df0b25bcc244b29e13438ff925cf56ff02fd1087a2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ef5a5fbce663ccd8f8e5185df6ca63cb9f7149aa37c641ee0739b1a4a046c5f9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__72f7c6417b8ad24ecdd825cad509251302e7e430aff112625dc1e754f3a838b9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionMarker]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionMarker]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionMarker]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__119d482c5225e700945e63d8eb885e89ded2bd0703677afdc32462009fced8d7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetTimeseriesDefinitionMarkerOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionMarkerOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3001633cad02dc36d21cff9441a6d762e346719c9bdf77318e3315831b5081ea)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetDisplayType")
    def reset_display_type(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDisplayType", []))

    @jsii.member(jsii_name="resetLabel")
    def reset_label(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLabel", []))

    @builtins.property
    @jsii.member(jsii_name="displayTypeInput")
    def display_type_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "displayTypeInput"))

    @builtins.property
    @jsii.member(jsii_name="labelInput")
    def label_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "labelInput"))

    @builtins.property
    @jsii.member(jsii_name="valueInput")
    def value_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "valueInput"))

    @builtins.property
    @jsii.member(jsii_name="displayType")
    def display_type(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "displayType"))

    @display_type.setter
    def display_type(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b194f6a2c69f9d96a400ea05e5f0d23e4ba40dc8e9732fc762e1d291c8f06488)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "displayType", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="label")
    def label(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "label"))

    @label.setter
    def label(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3c3bfd4f7b285041739c40e442f090fcb80d6fab3cf8ae3fcb776f36d27fd6e9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "label", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="value")
    def value(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "value"))

    @value.setter
    def value(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__690fd691a54ba1784f67a9d8e5b5bf7b85cd1a9d1873e25fe3881993e5c39114)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "value", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTimeseriesDefinitionMarker]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTimeseriesDefinitionMarker]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTimeseriesDefinitionMarker]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1f08b223d22c2c2d10d75db47138b6afb2cb669185ae6d631c7571ecf5baaaf2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetTimeseriesDefinitionOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__85c31423bb14cb599bbec230ea24809cc78ce88a25b8d698c407b4dd9dc2f947)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putCustomLink")
    def put_custom_link(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetTimeseriesDefinitionCustomLink, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e33e04993cd66e09f022c362ac48397bfd1dc6a58e674d02117ca62d869b7dda)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putCustomLink", [value]))

    @jsii.member(jsii_name="putEvent")
    def put_event(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetTimeseriesDefinitionEvent, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d617740f80b1bd1ebc7722856c8e5bebb83de725ce91f91a7c9a9e5d0a9a13aa)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putEvent", [value]))

    @jsii.member(jsii_name="putMarker")
    def put_marker(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetTimeseriesDefinitionMarker, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__205defc0b613a3e4ef9bf3a97d8f241393454bb3c9e24e19ee35e7b34b0dce31)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putMarker", [value]))

    @jsii.member(jsii_name="putRequest")
    def put_request(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetTimeseriesDefinitionRequest", typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__601616dc08df6f7e8a029186dc35e13f86e035be62303adff74e04ee92acdf62)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putRequest", [value]))

    @jsii.member(jsii_name="putRightYaxis")
    def put_right_yaxis(
        self,
        *,
        include_zero: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        label: typing.Optional[builtins.str] = None,
        max: typing.Optional[builtins.str] = None,
        min: typing.Optional[builtins.str] = None,
        scale: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param include_zero: Always include zero or fit the axis to the data range. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#include_zero Powerpack#include_zero}
        :param label: The label of the axis to display on the graph. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#label Powerpack#label}
        :param max: Specify the maximum value to show on the Y-axis. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#max Powerpack#max}
        :param min: Specify the minimum value to show on the Y-axis. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#min Powerpack#min}
        :param scale: Specify the scale type, options: ``linear``, ``log``, ``pow``, ``sqrt``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#scale Powerpack#scale}
        '''
        value = PowerpackWidgetTimeseriesDefinitionRightYaxis(
            include_zero=include_zero, label=label, max=max, min=min, scale=scale
        )

        return typing.cast(None, jsii.invoke(self, "putRightYaxis", [value]))

    @jsii.member(jsii_name="putYaxis")
    def put_yaxis(
        self,
        *,
        include_zero: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        label: typing.Optional[builtins.str] = None,
        max: typing.Optional[builtins.str] = None,
        min: typing.Optional[builtins.str] = None,
        scale: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param include_zero: Always include zero or fit the axis to the data range. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#include_zero Powerpack#include_zero}
        :param label: The label of the axis to display on the graph. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#label Powerpack#label}
        :param max: Specify the maximum value to show on the Y-axis. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#max Powerpack#max}
        :param min: Specify the minimum value to show on the Y-axis. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#min Powerpack#min}
        :param scale: Specify the scale type, options: ``linear``, ``log``, ``pow``, ``sqrt``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#scale Powerpack#scale}
        '''
        value = PowerpackWidgetTimeseriesDefinitionYaxis(
            include_zero=include_zero, label=label, max=max, min=min, scale=scale
        )

        return typing.cast(None, jsii.invoke(self, "putYaxis", [value]))

    @jsii.member(jsii_name="resetCustomLink")
    def reset_custom_link(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCustomLink", []))

    @jsii.member(jsii_name="resetEvent")
    def reset_event(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetEvent", []))

    @jsii.member(jsii_name="resetLegendColumns")
    def reset_legend_columns(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLegendColumns", []))

    @jsii.member(jsii_name="resetLegendLayout")
    def reset_legend_layout(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLegendLayout", []))

    @jsii.member(jsii_name="resetLegendSize")
    def reset_legend_size(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLegendSize", []))

    @jsii.member(jsii_name="resetLiveSpan")
    def reset_live_span(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLiveSpan", []))

    @jsii.member(jsii_name="resetMarker")
    def reset_marker(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMarker", []))

    @jsii.member(jsii_name="resetRequest")
    def reset_request(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetRequest", []))

    @jsii.member(jsii_name="resetRightYaxis")
    def reset_right_yaxis(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetRightYaxis", []))

    @jsii.member(jsii_name="resetShowLegend")
    def reset_show_legend(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetShowLegend", []))

    @jsii.member(jsii_name="resetTitle")
    def reset_title(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTitle", []))

    @jsii.member(jsii_name="resetTitleAlign")
    def reset_title_align(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTitleAlign", []))

    @jsii.member(jsii_name="resetTitleSize")
    def reset_title_size(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTitleSize", []))

    @jsii.member(jsii_name="resetYaxis")
    def reset_yaxis(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetYaxis", []))

    @builtins.property
    @jsii.member(jsii_name="customLink")
    def custom_link(self) -> PowerpackWidgetTimeseriesDefinitionCustomLinkList:
        return typing.cast(PowerpackWidgetTimeseriesDefinitionCustomLinkList, jsii.get(self, "customLink"))

    @builtins.property
    @jsii.member(jsii_name="event")
    def event(self) -> PowerpackWidgetTimeseriesDefinitionEventList:
        return typing.cast(PowerpackWidgetTimeseriesDefinitionEventList, jsii.get(self, "event"))

    @builtins.property
    @jsii.member(jsii_name="marker")
    def marker(self) -> PowerpackWidgetTimeseriesDefinitionMarkerList:
        return typing.cast(PowerpackWidgetTimeseriesDefinitionMarkerList, jsii.get(self, "marker"))

    @builtins.property
    @jsii.member(jsii_name="request")
    def request(self) -> "PowerpackWidgetTimeseriesDefinitionRequestList":
        return typing.cast("PowerpackWidgetTimeseriesDefinitionRequestList", jsii.get(self, "request"))

    @builtins.property
    @jsii.member(jsii_name="rightYaxis")
    def right_yaxis(
        self,
    ) -> "PowerpackWidgetTimeseriesDefinitionRightYaxisOutputReference":
        return typing.cast("PowerpackWidgetTimeseriesDefinitionRightYaxisOutputReference", jsii.get(self, "rightYaxis"))

    @builtins.property
    @jsii.member(jsii_name="yaxis")
    def yaxis(self) -> "PowerpackWidgetTimeseriesDefinitionYaxisOutputReference":
        return typing.cast("PowerpackWidgetTimeseriesDefinitionYaxisOutputReference", jsii.get(self, "yaxis"))

    @builtins.property
    @jsii.member(jsii_name="customLinkInput")
    def custom_link_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionCustomLink]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionCustomLink]]], jsii.get(self, "customLinkInput"))

    @builtins.property
    @jsii.member(jsii_name="eventInput")
    def event_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionEvent]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionEvent]]], jsii.get(self, "eventInput"))

    @builtins.property
    @jsii.member(jsii_name="legendColumnsInput")
    def legend_columns_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "legendColumnsInput"))

    @builtins.property
    @jsii.member(jsii_name="legendLayoutInput")
    def legend_layout_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "legendLayoutInput"))

    @builtins.property
    @jsii.member(jsii_name="legendSizeInput")
    def legend_size_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "legendSizeInput"))

    @builtins.property
    @jsii.member(jsii_name="liveSpanInput")
    def live_span_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "liveSpanInput"))

    @builtins.property
    @jsii.member(jsii_name="markerInput")
    def marker_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionMarker]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionMarker]]], jsii.get(self, "markerInput"))

    @builtins.property
    @jsii.member(jsii_name="requestInput")
    def request_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetTimeseriesDefinitionRequest"]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetTimeseriesDefinitionRequest"]]], jsii.get(self, "requestInput"))

    @builtins.property
    @jsii.member(jsii_name="rightYaxisInput")
    def right_yaxis_input(
        self,
    ) -> typing.Optional["PowerpackWidgetTimeseriesDefinitionRightYaxis"]:
        return typing.cast(typing.Optional["PowerpackWidgetTimeseriesDefinitionRightYaxis"], jsii.get(self, "rightYaxisInput"))

    @builtins.property
    @jsii.member(jsii_name="showLegendInput")
    def show_legend_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "showLegendInput"))

    @builtins.property
    @jsii.member(jsii_name="titleAlignInput")
    def title_align_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "titleAlignInput"))

    @builtins.property
    @jsii.member(jsii_name="titleInput")
    def title_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "titleInput"))

    @builtins.property
    @jsii.member(jsii_name="titleSizeInput")
    def title_size_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "titleSizeInput"))

    @builtins.property
    @jsii.member(jsii_name="yaxisInput")
    def yaxis_input(
        self,
    ) -> typing.Optional["PowerpackWidgetTimeseriesDefinitionYaxis"]:
        return typing.cast(typing.Optional["PowerpackWidgetTimeseriesDefinitionYaxis"], jsii.get(self, "yaxisInput"))

    @builtins.property
    @jsii.member(jsii_name="legendColumns")
    def legend_columns(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "legendColumns"))

    @legend_columns.setter
    def legend_columns(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6d5dcc2900bb4b931714ce7339cdf3db9b228b03bbb7cc26e6ca16b922284712)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "legendColumns", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="legendLayout")
    def legend_layout(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "legendLayout"))

    @legend_layout.setter
    def legend_layout(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ff721530ea7816b88485ea925566c2d23da7c272b1aa366b03c1f72ad95d608c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "legendLayout", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="legendSize")
    def legend_size(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "legendSize"))

    @legend_size.setter
    def legend_size(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3aeb0b28c1bb2357be6584e1fd9b9c5ae6f7934e3a24a41deb75fe7157bc8f14)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "legendSize", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="liveSpan")
    def live_span(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "liveSpan"))

    @live_span.setter
    def live_span(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d47fcfc4947b705da6dcb7a8b1f8c8a3b2a8f2627456144b2321c0d155c7a987)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "liveSpan", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="showLegend")
    def show_legend(self) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "showLegend"))

    @show_legend.setter
    def show_legend(
        self,
        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__43f3466f30e67ea19232489349879bbb8aa4e045b7df30cead7068b703e48675)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "showLegend", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="title")
    def title(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "title"))

    @title.setter
    def title(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__44f5847c8e9a51a47d26f83b451ec8e1fcc74d11d95fa9a2078d91bc0360aa49)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "title", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="titleAlign")
    def title_align(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "titleAlign"))

    @title_align.setter
    def title_align(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__855994fc3798c957fd5eb11ce5c2ec598c0b10d380d894cd2099d1a15d16f7b7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "titleAlign", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="titleSize")
    def title_size(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "titleSize"))

    @title_size.setter
    def title_size(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__41601bbac7784acdfede7501e2f97bcad40d4186d7424f1441700e8216cb2cf9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "titleSize", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[PowerpackWidgetTimeseriesDefinition]:
        return typing.cast(typing.Optional[PowerpackWidgetTimeseriesDefinition], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetTimeseriesDefinition],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ce192962cab670d708600950369031ca2965e5dd0b56145c27f6b2be4efa8587)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequest",
    jsii_struct_bases=[],
    name_mapping={
        "apm_query": "apmQuery",
        "audit_query": "auditQuery",
        "display_type": "displayType",
        "formula": "formula",
        "log_query": "logQuery",
        "metadata": "metadata",
        "network_query": "networkQuery",
        "on_right_yaxis": "onRightYaxis",
        "process_query": "processQuery",
        "q": "q",
        "query": "query",
        "rum_query": "rumQuery",
        "security_query": "securityQuery",
        "style": "style",
    },
)
class PowerpackWidgetTimeseriesDefinitionRequest:
    def __init__(
        self,
        *,
        apm_query: typing.Optional[typing.Union["PowerpackWidgetTimeseriesDefinitionRequestApmQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        audit_query: typing.Optional[typing.Union["PowerpackWidgetTimeseriesDefinitionRequestAuditQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        display_type: typing.Optional[builtins.str] = None,
        formula: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetTimeseriesDefinitionRequestFormula", typing.Dict[builtins.str, typing.Any]]]]] = None,
        log_query: typing.Optional[typing.Union["PowerpackWidgetTimeseriesDefinitionRequestLogQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        metadata: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetTimeseriesDefinitionRequestMetadata", typing.Dict[builtins.str, typing.Any]]]]] = None,
        network_query: typing.Optional[typing.Union["PowerpackWidgetTimeseriesDefinitionRequestNetworkQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        on_right_yaxis: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        process_query: typing.Optional[typing.Union["PowerpackWidgetTimeseriesDefinitionRequestProcessQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        q: typing.Optional[builtins.str] = None,
        query: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetTimeseriesDefinitionRequestQuery", typing.Dict[builtins.str, typing.Any]]]]] = None,
        rum_query: typing.Optional[typing.Union["PowerpackWidgetTimeseriesDefinitionRequestRumQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        security_query: typing.Optional[typing.Union["PowerpackWidgetTimeseriesDefinitionRequestSecurityQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        style: typing.Optional[typing.Union["PowerpackWidgetTimeseriesDefinitionRequestStyle", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param apm_query: apm_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#apm_query Powerpack#apm_query}
        :param audit_query: audit_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#audit_query Powerpack#audit_query}
        :param display_type: How to display the marker lines. Valid values are ``area``, ``bars``, ``line``, ``overlay``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#display_type Powerpack#display_type}
        :param formula: formula block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#formula Powerpack#formula}
        :param log_query: log_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#log_query Powerpack#log_query}
        :param metadata: metadata block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metadata Powerpack#metadata}
        :param network_query: network_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#network_query Powerpack#network_query}
        :param on_right_yaxis: A Boolean indicating whether the request uses the right or left Y-Axis. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#on_right_yaxis Powerpack#on_right_yaxis}
        :param process_query: process_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#process_query Powerpack#process_query}
        :param q: The metric query to use for this widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#q Powerpack#q}
        :param query: query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        :param rum_query: rum_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#rum_query Powerpack#rum_query}
        :param security_query: security_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#security_query Powerpack#security_query}
        :param style: style block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#style Powerpack#style}
        '''
        if isinstance(apm_query, dict):
            apm_query = PowerpackWidgetTimeseriesDefinitionRequestApmQuery(**apm_query)
        if isinstance(audit_query, dict):
            audit_query = PowerpackWidgetTimeseriesDefinitionRequestAuditQuery(**audit_query)
        if isinstance(log_query, dict):
            log_query = PowerpackWidgetTimeseriesDefinitionRequestLogQuery(**log_query)
        if isinstance(network_query, dict):
            network_query = PowerpackWidgetTimeseriesDefinitionRequestNetworkQuery(**network_query)
        if isinstance(process_query, dict):
            process_query = PowerpackWidgetTimeseriesDefinitionRequestProcessQuery(**process_query)
        if isinstance(rum_query, dict):
            rum_query = PowerpackWidgetTimeseriesDefinitionRequestRumQuery(**rum_query)
        if isinstance(security_query, dict):
            security_query = PowerpackWidgetTimeseriesDefinitionRequestSecurityQuery(**security_query)
        if isinstance(style, dict):
            style = PowerpackWidgetTimeseriesDefinitionRequestStyle(**style)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__77f4eb4971ebe03ae017bbc1cad2031bb7680c65a68e4d0aa6780c9f1c086b28)
            check_type(argname="argument apm_query", value=apm_query, expected_type=type_hints["apm_query"])
            check_type(argname="argument audit_query", value=audit_query, expected_type=type_hints["audit_query"])
            check_type(argname="argument display_type", value=display_type, expected_type=type_hints["display_type"])
            check_type(argname="argument formula", value=formula, expected_type=type_hints["formula"])
            check_type(argname="argument log_query", value=log_query, expected_type=type_hints["log_query"])
            check_type(argname="argument metadata", value=metadata, expected_type=type_hints["metadata"])
            check_type(argname="argument network_query", value=network_query, expected_type=type_hints["network_query"])
            check_type(argname="argument on_right_yaxis", value=on_right_yaxis, expected_type=type_hints["on_right_yaxis"])
            check_type(argname="argument process_query", value=process_query, expected_type=type_hints["process_query"])
            check_type(argname="argument q", value=q, expected_type=type_hints["q"])
            check_type(argname="argument query", value=query, expected_type=type_hints["query"])
            check_type(argname="argument rum_query", value=rum_query, expected_type=type_hints["rum_query"])
            check_type(argname="argument security_query", value=security_query, expected_type=type_hints["security_query"])
            check_type(argname="argument style", value=style, expected_type=type_hints["style"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if apm_query is not None:
            self._values["apm_query"] = apm_query
        if audit_query is not None:
            self._values["audit_query"] = audit_query
        if display_type is not None:
            self._values["display_type"] = display_type
        if formula is not None:
            self._values["formula"] = formula
        if log_query is not None:
            self._values["log_query"] = log_query
        if metadata is not None:
            self._values["metadata"] = metadata
        if network_query is not None:
            self._values["network_query"] = network_query
        if on_right_yaxis is not None:
            self._values["on_right_yaxis"] = on_right_yaxis
        if process_query is not None:
            self._values["process_query"] = process_query
        if q is not None:
            self._values["q"] = q
        if query is not None:
            self._values["query"] = query
        if rum_query is not None:
            self._values["rum_query"] = rum_query
        if security_query is not None:
            self._values["security_query"] = security_query
        if style is not None:
            self._values["style"] = style

    @builtins.property
    def apm_query(
        self,
    ) -> typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestApmQuery"]:
        '''apm_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#apm_query Powerpack#apm_query}
        '''
        result = self._values.get("apm_query")
        return typing.cast(typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestApmQuery"], result)

    @builtins.property
    def audit_query(
        self,
    ) -> typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestAuditQuery"]:
        '''audit_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#audit_query Powerpack#audit_query}
        '''
        result = self._values.get("audit_query")
        return typing.cast(typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestAuditQuery"], result)

    @builtins.property
    def display_type(self) -> typing.Optional[builtins.str]:
        '''How to display the marker lines. Valid values are ``area``, ``bars``, ``line``, ``overlay``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#display_type Powerpack#display_type}
        '''
        result = self._values.get("display_type")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def formula(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetTimeseriesDefinitionRequestFormula"]]]:
        '''formula block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#formula Powerpack#formula}
        '''
        result = self._values.get("formula")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetTimeseriesDefinitionRequestFormula"]]], result)

    @builtins.property
    def log_query(
        self,
    ) -> typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestLogQuery"]:
        '''log_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#log_query Powerpack#log_query}
        '''
        result = self._values.get("log_query")
        return typing.cast(typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestLogQuery"], result)

    @builtins.property
    def metadata(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetTimeseriesDefinitionRequestMetadata"]]]:
        '''metadata block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metadata Powerpack#metadata}
        '''
        result = self._values.get("metadata")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetTimeseriesDefinitionRequestMetadata"]]], result)

    @builtins.property
    def network_query(
        self,
    ) -> typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestNetworkQuery"]:
        '''network_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#network_query Powerpack#network_query}
        '''
        result = self._values.get("network_query")
        return typing.cast(typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestNetworkQuery"], result)

    @builtins.property
    def on_right_yaxis(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        '''A Boolean indicating whether the request uses the right or left Y-Axis.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#on_right_yaxis Powerpack#on_right_yaxis}
        '''
        result = self._values.get("on_right_yaxis")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)

    @builtins.property
    def process_query(
        self,
    ) -> typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestProcessQuery"]:
        '''process_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#process_query Powerpack#process_query}
        '''
        result = self._values.get("process_query")
        return typing.cast(typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestProcessQuery"], result)

    @builtins.property
    def q(self) -> typing.Optional[builtins.str]:
        '''The metric query to use for this widget.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#q Powerpack#q}
        '''
        result = self._values.get("q")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def query(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetTimeseriesDefinitionRequestQuery"]]]:
        '''query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        '''
        result = self._values.get("query")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetTimeseriesDefinitionRequestQuery"]]], result)

    @builtins.property
    def rum_query(
        self,
    ) -> typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestRumQuery"]:
        '''rum_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#rum_query Powerpack#rum_query}
        '''
        result = self._values.get("rum_query")
        return typing.cast(typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestRumQuery"], result)

    @builtins.property
    def security_query(
        self,
    ) -> typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestSecurityQuery"]:
        '''security_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#security_query Powerpack#security_query}
        '''
        result = self._values.get("security_query")
        return typing.cast(typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestSecurityQuery"], result)

    @builtins.property
    def style(
        self,
    ) -> typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestStyle"]:
        '''style block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#style Powerpack#style}
        '''
        result = self._values.get("style")
        return typing.cast(typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestStyle"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetTimeseriesDefinitionRequest(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestApmQuery",
    jsii_struct_bases=[],
    name_mapping={
        "index": "index",
        "compute_query": "computeQuery",
        "group_by": "groupBy",
        "multi_compute": "multiCompute",
        "search_query": "searchQuery",
    },
)
class PowerpackWidgetTimeseriesDefinitionRequestApmQuery:
    def __init__(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union["PowerpackWidgetTimeseriesDefinitionRequestApmQueryComputeQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetTimeseriesDefinitionRequestApmQueryGroupBy", typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetTimeseriesDefinitionRequestApmQueryMultiCompute", typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        if isinstance(compute_query, dict):
            compute_query = PowerpackWidgetTimeseriesDefinitionRequestApmQueryComputeQuery(**compute_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b073382e6be165caac1893023f48820fad1540e7cc8ff0a0256834dd76d7432c)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
            check_type(argname="argument compute_query", value=compute_query, expected_type=type_hints["compute_query"])
            check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
            check_type(argname="argument multi_compute", value=multi_compute, expected_type=type_hints["multi_compute"])
            check_type(argname="argument search_query", value=search_query, expected_type=type_hints["search_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "index": index,
        }
        if compute_query is not None:
            self._values["compute_query"] = compute_query
        if group_by is not None:
            self._values["group_by"] = group_by
        if multi_compute is not None:
            self._values["multi_compute"] = multi_compute
        if search_query is not None:
            self._values["search_query"] = search_query

    @builtins.property
    def index(self) -> builtins.str:
        '''The name of the index to query.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        '''
        result = self._values.get("index")
        assert result is not None, "Required property 'index' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def compute_query(
        self,
    ) -> typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestApmQueryComputeQuery"]:
        '''compute_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        '''
        result = self._values.get("compute_query")
        return typing.cast(typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestApmQueryComputeQuery"], result)

    @builtins.property
    def group_by(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetTimeseriesDefinitionRequestApmQueryGroupBy"]]]:
        '''group_by block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        '''
        result = self._values.get("group_by")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetTimeseriesDefinitionRequestApmQueryGroupBy"]]], result)

    @builtins.property
    def multi_compute(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetTimeseriesDefinitionRequestApmQueryMultiCompute"]]]:
        '''multi_compute block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        '''
        result = self._values.get("multi_compute")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetTimeseriesDefinitionRequestApmQueryMultiCompute"]]], result)

    @builtins.property
    def search_query(self) -> typing.Optional[builtins.str]:
        '''The search query to use.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        result = self._values.get("search_query")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetTimeseriesDefinitionRequestApmQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestApmQueryComputeQuery",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetTimeseriesDefinitionRequestApmQueryComputeQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4383e706bc455b38b134715870424f4c754f8f8f1ed5e137d6406501fa4972ed)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetTimeseriesDefinitionRequestApmQueryComputeQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetTimeseriesDefinitionRequestApmQueryComputeQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestApmQueryComputeQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__74f594ba6003d3ea7dea2f335352b1b4392dd61b7f1e72bebd187904fbc5e5fa)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__765aed441fe6684fd28fb926d85ae24beb3cff389da2ebcec499022270eea436)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__86c8799e44f1ea341003fadb56faa74cee217e5c5ffc1608ba3b0a220b82c89d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__12149c3b68b7ab3551801fc5449f1b927d7d0684b61d9a9c6a7f2a5ff792b5f5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestApmQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestApmQueryComputeQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestApmQueryComputeQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__00d92cbb3f3d537604ce696cf871fed02054b2da748f7e94905222f6732d5c95)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestApmQueryGroupBy",
    jsii_struct_bases=[],
    name_mapping={"facet": "facet", "limit": "limit", "sort_query": "sortQuery"},
)
class PowerpackWidgetTimeseriesDefinitionRequestApmQueryGroupBy:
    def __init__(
        self,
        *,
        facet: typing.Optional[builtins.str] = None,
        limit: typing.Optional[jsii.Number] = None,
        sort_query: typing.Optional[typing.Union["PowerpackWidgetTimeseriesDefinitionRequestApmQueryGroupBySortQuery", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param limit: The maximum number of items in the group. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param sort_query: sort_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        if isinstance(sort_query, dict):
            sort_query = PowerpackWidgetTimeseriesDefinitionRequestApmQueryGroupBySortQuery(**sort_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0340811879c1cc7e9ebd68fc1b42114f9e9d33412d01114a77df9368bd8ca357)
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
            check_type(argname="argument sort_query", value=sort_query, expected_type=type_hints["sort_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if facet is not None:
            self._values["facet"] = facet
        if limit is not None:
            self._values["limit"] = limit
        if sort_query is not None:
            self._values["sort_query"] = sort_query

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def limit(self) -> typing.Optional[jsii.Number]:
        '''The maximum number of items in the group.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        '''
        result = self._values.get("limit")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def sort_query(
        self,
    ) -> typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestApmQueryGroupBySortQuery"]:
        '''sort_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        result = self._values.get("sort_query")
        return typing.cast(typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestApmQueryGroupBySortQuery"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetTimeseriesDefinitionRequestApmQueryGroupBy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetTimeseriesDefinitionRequestApmQueryGroupByList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestApmQueryGroupByList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8fdf33cfdac341648918234731dbcc47c2412d79ce2420689f87f578a7f2b292)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetTimeseriesDefinitionRequestApmQueryGroupByOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a360d822d82c1bb89a74ca734aa469de3dfe63929a84ec3b4b1dc28535d91c6e)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetTimeseriesDefinitionRequestApmQueryGroupByOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__94fe1eff36f58d57440ee5c17c2b310a55d35c7a1412d8e357f6fe520e18e618)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__066731e2da8e31cc10306780dbce3633305e05d4cccc3019019485e24d4cedd1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e7ec5789339105ae4ad8194146d175435666d963d834026603c1aa4b0ee68df5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestApmQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestApmQueryGroupBy]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestApmQueryGroupBy]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__360f4a82da2097261a455d0dc0892467400b12d2ae4ef4e8da8c909e5a16021f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetTimeseriesDefinitionRequestApmQueryGroupByOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestApmQueryGroupByOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__20001c2f33aeb3ca5bb9ead8dc834746ce23c5e478b72e872149bd4e2ea291da)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putSortQuery")
    def put_sort_query(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        value = PowerpackWidgetTimeseriesDefinitionRequestApmQueryGroupBySortQuery(
            aggregation=aggregation, order=order, facet=facet
        )

        return typing.cast(None, jsii.invoke(self, "putSortQuery", [value]))

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetLimit")
    def reset_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLimit", []))

    @jsii.member(jsii_name="resetSortQuery")
    def reset_sort_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSortQuery", []))

    @builtins.property
    @jsii.member(jsii_name="sortQuery")
    def sort_query(
        self,
    ) -> "PowerpackWidgetTimeseriesDefinitionRequestApmQueryGroupBySortQueryOutputReference":
        return typing.cast("PowerpackWidgetTimeseriesDefinitionRequestApmQueryGroupBySortQueryOutputReference", jsii.get(self, "sortQuery"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="limitInput")
    def limit_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "limitInput"))

    @builtins.property
    @jsii.member(jsii_name="sortQueryInput")
    def sort_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestApmQueryGroupBySortQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestApmQueryGroupBySortQuery"], jsii.get(self, "sortQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ab20959a61a6513cbd65f2e15e5d738b0c405fe04dc0900ed41ab0c4857d6bb2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="limit")
    def limit(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "limit"))

    @limit.setter
    def limit(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__affdea3970429d1f8f3b37e955c5a4c72aca302357fd45572e3e46a2c84ee4b2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "limit", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTimeseriesDefinitionRequestApmQueryGroupBy]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTimeseriesDefinitionRequestApmQueryGroupBy]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTimeseriesDefinitionRequestApmQueryGroupBy]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__54f18579dac28a9133d0afbc5f46b86d59669c2b40c26b0db88b486277acf9e1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestApmQueryGroupBySortQuery",
    jsii_struct_bases=[],
    name_mapping={"aggregation": "aggregation", "order": "order", "facet": "facet"},
)
class PowerpackWidgetTimeseriesDefinitionRequestApmQueryGroupBySortQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__65ad10a33293fb2e50b4d7ade12df4b25cfb8795686e6e0dd34ae022c17bd33b)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument order", value=order, expected_type=type_hints["order"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
            "order": order,
        }
        if facet is not None:
            self._values["facet"] = facet

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def order(self) -> builtins.str:
        '''Widget sorting methods. Valid values are ``asc``, ``desc``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        result = self._values.get("order")
        assert result is not None, "Required property 'order' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetTimeseriesDefinitionRequestApmQueryGroupBySortQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetTimeseriesDefinitionRequestApmQueryGroupBySortQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestApmQueryGroupBySortQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f698c69c048424688865afc2df0a54fb75343da66053d200b8ad6e16a31c3bac)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="orderInput")
    def order_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "orderInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__00df37f0e3e89a70ba3e6a4a1985617a01a9e54a5158b0eb38a991a7d6395859)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e76a2dd44bb094911282b3d60d638b67137028ec25c4d05460907e6ecf401c4f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="order")
    def order(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "order"))

    @order.setter
    def order(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__068d11661f813c714f92aed258a00fdb2ff445f8740f0bac17236d41408c8a74)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "order", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestApmQueryGroupBySortQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestApmQueryGroupBySortQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestApmQueryGroupBySortQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2d333ffa90b4ae771106709b0b5db40a19ce035521baa7c10ec67892edbcc112)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestApmQueryMultiCompute",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetTimeseriesDefinitionRequestApmQueryMultiCompute:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0ecf83d2607a55f1f360f56a40b2671d9c26762343cafead6ee49429dee10f98)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetTimeseriesDefinitionRequestApmQueryMultiCompute(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetTimeseriesDefinitionRequestApmQueryMultiComputeList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestApmQueryMultiComputeList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f7755376e6a71b39789e569a30fdedbe6399140b52e0cd9e106d22d728d26f97)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetTimeseriesDefinitionRequestApmQueryMultiComputeOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1fa147d7a9272052493e65a6e8c851e38e6f382115c101cbeac00ef7b59f74d7)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetTimeseriesDefinitionRequestApmQueryMultiComputeOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0d283abb9745a7bb04c71d45796187f5778ab93517c01cd4cea5ccd236759063)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__221de27f7f3be7d06a5002a987414196062c39072d679654590a2313b37873a7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fe3a2c5cf659ce32251c86f782b7098e5f9bf2d98e08a8ae37336465611c5e88)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestApmQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestApmQueryMultiCompute]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestApmQueryMultiCompute]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e90c5d6629f9a6536dafd1daf50a075c13bef225be14f733435133965cbbb05c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetTimeseriesDefinitionRequestApmQueryMultiComputeOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestApmQueryMultiComputeOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__32168bfd10cf6c6f127d1b0e7d90efaa7225a9c1d4fae2b0d29a249c5aad3cfb)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5f4898f6ebbd5053258cb9157e5ad87f56049fdd5069075fe5762418fcec762b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f99e85d7ad8f1e654fd329c48e5aae93d8b9623a15df2dc57b77fa5b1f6aa5e5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b7f21587cf819def326ca18169a32bbb8e0b70a655bad1779debdeb101cc4f81)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTimeseriesDefinitionRequestApmQueryMultiCompute]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTimeseriesDefinitionRequestApmQueryMultiCompute]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTimeseriesDefinitionRequestApmQueryMultiCompute]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fa0a7944307d3272ba016bde6f7dc63e167e80d372d9ba027e5b24d15cabab8e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetTimeseriesDefinitionRequestApmQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestApmQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__30c3b3ee96462680955956596eb45d495634de405aa92bd59e64b1f851bc151d)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putComputeQuery")
    def put_compute_query(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        value = PowerpackWidgetTimeseriesDefinitionRequestApmQueryComputeQuery(
            aggregation=aggregation, facet=facet, interval=interval
        )

        return typing.cast(None, jsii.invoke(self, "putComputeQuery", [value]))

    @jsii.member(jsii_name="putGroupBy")
    def put_group_by(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestApmQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__caa9e1d9dd7576f4c7c67900698d75a1aaa3dde09cdcd5a82908958f12772711)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putGroupBy", [value]))

    @jsii.member(jsii_name="putMultiCompute")
    def put_multi_compute(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestApmQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__06b954d90c7e80136156bdccbcf1c4a65643e47b21b6a2d81a845abe90d20ea8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putMultiCompute", [value]))

    @jsii.member(jsii_name="resetComputeQuery")
    def reset_compute_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetComputeQuery", []))

    @jsii.member(jsii_name="resetGroupBy")
    def reset_group_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGroupBy", []))

    @jsii.member(jsii_name="resetMultiCompute")
    def reset_multi_compute(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMultiCompute", []))

    @jsii.member(jsii_name="resetSearchQuery")
    def reset_search_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSearchQuery", []))

    @builtins.property
    @jsii.member(jsii_name="computeQuery")
    def compute_query(
        self,
    ) -> PowerpackWidgetTimeseriesDefinitionRequestApmQueryComputeQueryOutputReference:
        return typing.cast(PowerpackWidgetTimeseriesDefinitionRequestApmQueryComputeQueryOutputReference, jsii.get(self, "computeQuery"))

    @builtins.property
    @jsii.member(jsii_name="groupBy")
    def group_by(self) -> PowerpackWidgetTimeseriesDefinitionRequestApmQueryGroupByList:
        return typing.cast(PowerpackWidgetTimeseriesDefinitionRequestApmQueryGroupByList, jsii.get(self, "groupBy"))

    @builtins.property
    @jsii.member(jsii_name="multiCompute")
    def multi_compute(
        self,
    ) -> PowerpackWidgetTimeseriesDefinitionRequestApmQueryMultiComputeList:
        return typing.cast(PowerpackWidgetTimeseriesDefinitionRequestApmQueryMultiComputeList, jsii.get(self, "multiCompute"))

    @builtins.property
    @jsii.member(jsii_name="computeQueryInput")
    def compute_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestApmQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestApmQueryComputeQuery], jsii.get(self, "computeQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="groupByInput")
    def group_by_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestApmQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestApmQueryGroupBy]]], jsii.get(self, "groupByInput"))

    @builtins.property
    @jsii.member(jsii_name="indexInput")
    def index_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "indexInput"))

    @builtins.property
    @jsii.member(jsii_name="multiComputeInput")
    def multi_compute_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestApmQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestApmQueryMultiCompute]]], jsii.get(self, "multiComputeInput"))

    @builtins.property
    @jsii.member(jsii_name="searchQueryInput")
    def search_query_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "searchQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="index")
    def index(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "index"))

    @index.setter
    def index(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3a2c45d210e0f854e2f7b46bfc761055f85fa4ce9f2fa3b73ba98191c2cae3ac)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "index", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="searchQuery")
    def search_query(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "searchQuery"))

    @search_query.setter
    def search_query(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__daf1f2af896bfa5cb6576b5fa1b471fa30fa8e0bd76273a82b6bdb1c52e00ff9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "searchQuery", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestApmQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestApmQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestApmQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__df3a1acc8303de429654b6db8597ca0bf27f7744a91cb58a124e0a67c005ccee)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestAuditQuery",
    jsii_struct_bases=[],
    name_mapping={
        "index": "index",
        "compute_query": "computeQuery",
        "group_by": "groupBy",
        "multi_compute": "multiCompute",
        "search_query": "searchQuery",
    },
)
class PowerpackWidgetTimeseriesDefinitionRequestAuditQuery:
    def __init__(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union["PowerpackWidgetTimeseriesDefinitionRequestAuditQueryComputeQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetTimeseriesDefinitionRequestAuditQueryGroupBy", typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetTimeseriesDefinitionRequestAuditQueryMultiCompute", typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        if isinstance(compute_query, dict):
            compute_query = PowerpackWidgetTimeseriesDefinitionRequestAuditQueryComputeQuery(**compute_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e9d30e3f45dd3bc02092efba03e260f51bd31ba3cc0a1156d011bda70fe711b2)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
            check_type(argname="argument compute_query", value=compute_query, expected_type=type_hints["compute_query"])
            check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
            check_type(argname="argument multi_compute", value=multi_compute, expected_type=type_hints["multi_compute"])
            check_type(argname="argument search_query", value=search_query, expected_type=type_hints["search_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "index": index,
        }
        if compute_query is not None:
            self._values["compute_query"] = compute_query
        if group_by is not None:
            self._values["group_by"] = group_by
        if multi_compute is not None:
            self._values["multi_compute"] = multi_compute
        if search_query is not None:
            self._values["search_query"] = search_query

    @builtins.property
    def index(self) -> builtins.str:
        '''The name of the index to query.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        '''
        result = self._values.get("index")
        assert result is not None, "Required property 'index' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def compute_query(
        self,
    ) -> typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestAuditQueryComputeQuery"]:
        '''compute_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        '''
        result = self._values.get("compute_query")
        return typing.cast(typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestAuditQueryComputeQuery"], result)

    @builtins.property
    def group_by(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetTimeseriesDefinitionRequestAuditQueryGroupBy"]]]:
        '''group_by block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        '''
        result = self._values.get("group_by")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetTimeseriesDefinitionRequestAuditQueryGroupBy"]]], result)

    @builtins.property
    def multi_compute(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetTimeseriesDefinitionRequestAuditQueryMultiCompute"]]]:
        '''multi_compute block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        '''
        result = self._values.get("multi_compute")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetTimeseriesDefinitionRequestAuditQueryMultiCompute"]]], result)

    @builtins.property
    def search_query(self) -> typing.Optional[builtins.str]:
        '''The search query to use.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        result = self._values.get("search_query")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetTimeseriesDefinitionRequestAuditQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestAuditQueryComputeQuery",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetTimeseriesDefinitionRequestAuditQueryComputeQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__93e4a5295e2f17331097c879c013e67210ef946c2e4a1077be8344abd2e5a900)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetTimeseriesDefinitionRequestAuditQueryComputeQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetTimeseriesDefinitionRequestAuditQueryComputeQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestAuditQueryComputeQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__999563dd2c8f64502d07b3df0e0a778d81cea4a119ae5f308ce2c27c45568c9f)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3ee0524cf8974ba0511a7ba4d28947266d62d098a5caf6fb29e85fe3b2268214)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c44a6b6999d44cc82be5eacd9bfb3fa9354c8ca943b8813ce5e3bf977c787165)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b77a37640034765cc4f8744c0e1ea90cee897d80720626f7c20fabe2cac29d10)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestAuditQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestAuditQueryComputeQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestAuditQueryComputeQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a924b8c632c06b61b9e18542750fbdb22e7a36505a7b25ee44af54a2cb3720c9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestAuditQueryGroupBy",
    jsii_struct_bases=[],
    name_mapping={"facet": "facet", "limit": "limit", "sort_query": "sortQuery"},
)
class PowerpackWidgetTimeseriesDefinitionRequestAuditQueryGroupBy:
    def __init__(
        self,
        *,
        facet: typing.Optional[builtins.str] = None,
        limit: typing.Optional[jsii.Number] = None,
        sort_query: typing.Optional[typing.Union["PowerpackWidgetTimeseriesDefinitionRequestAuditQueryGroupBySortQuery", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param limit: The maximum number of items in the group. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param sort_query: sort_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        if isinstance(sort_query, dict):
            sort_query = PowerpackWidgetTimeseriesDefinitionRequestAuditQueryGroupBySortQuery(**sort_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b077e358fbb395143384f4c7398348862cb1e2d22e8cdb36133a30f08b53f36a)
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
            check_type(argname="argument sort_query", value=sort_query, expected_type=type_hints["sort_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if facet is not None:
            self._values["facet"] = facet
        if limit is not None:
            self._values["limit"] = limit
        if sort_query is not None:
            self._values["sort_query"] = sort_query

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def limit(self) -> typing.Optional[jsii.Number]:
        '''The maximum number of items in the group.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        '''
        result = self._values.get("limit")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def sort_query(
        self,
    ) -> typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestAuditQueryGroupBySortQuery"]:
        '''sort_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        result = self._values.get("sort_query")
        return typing.cast(typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestAuditQueryGroupBySortQuery"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetTimeseriesDefinitionRequestAuditQueryGroupBy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetTimeseriesDefinitionRequestAuditQueryGroupByList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestAuditQueryGroupByList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d5bf7c674a4855c323b17c5bb4abb5e7489a232211526e4d3bcc0b140ae6185a)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetTimeseriesDefinitionRequestAuditQueryGroupByOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8f2f625eb3343bfc380379fa2b6777685249e5f6f316eb19f42f7770d828fdd2)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetTimeseriesDefinitionRequestAuditQueryGroupByOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bc9bd1e1bcc0d1d51d97dbffcdc85191d3eff9b97d16a3af7e19891f915b765e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d2380ffc29d5cd9a3d096acf1b3a8baa68197b2292bc7c55ffc1f92587e64aa1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d9a837cf91f79397348d37bcafbea8b0546f8e9e4d8d6d1df3daa522d86cadd0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestAuditQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestAuditQueryGroupBy]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestAuditQueryGroupBy]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2cf9b90db9be344151530194bfe68938436f84303d5e5a715265ceeb3a5c37d5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetTimeseriesDefinitionRequestAuditQueryGroupByOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestAuditQueryGroupByOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5e99c37798e46944d63d624f1c034f9fadaa831a5b2fe57a00870ddc72ae3bc7)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putSortQuery")
    def put_sort_query(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        value = PowerpackWidgetTimeseriesDefinitionRequestAuditQueryGroupBySortQuery(
            aggregation=aggregation, order=order, facet=facet
        )

        return typing.cast(None, jsii.invoke(self, "putSortQuery", [value]))

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetLimit")
    def reset_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLimit", []))

    @jsii.member(jsii_name="resetSortQuery")
    def reset_sort_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSortQuery", []))

    @builtins.property
    @jsii.member(jsii_name="sortQuery")
    def sort_query(
        self,
    ) -> "PowerpackWidgetTimeseriesDefinitionRequestAuditQueryGroupBySortQueryOutputReference":
        return typing.cast("PowerpackWidgetTimeseriesDefinitionRequestAuditQueryGroupBySortQueryOutputReference", jsii.get(self, "sortQuery"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="limitInput")
    def limit_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "limitInput"))

    @builtins.property
    @jsii.member(jsii_name="sortQueryInput")
    def sort_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestAuditQueryGroupBySortQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestAuditQueryGroupBySortQuery"], jsii.get(self, "sortQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__149a882a66760b0c9712e5aa3a488d53c4197e759915a5649c5f0e6533c2768c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="limit")
    def limit(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "limit"))

    @limit.setter
    def limit(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f7d51cad01305caffeed1850865d73ac88725a2a7d9d1aa4063fb2db740469b4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "limit", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTimeseriesDefinitionRequestAuditQueryGroupBy]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTimeseriesDefinitionRequestAuditQueryGroupBy]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTimeseriesDefinitionRequestAuditQueryGroupBy]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__306d20cd30f3b49c15f8923912ebda076772ad5d09e48d5e2fe38f3f0d0f5936)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestAuditQueryGroupBySortQuery",
    jsii_struct_bases=[],
    name_mapping={"aggregation": "aggregation", "order": "order", "facet": "facet"},
)
class PowerpackWidgetTimeseriesDefinitionRequestAuditQueryGroupBySortQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7f6399711209552518a87b6f442c326abc51dfbee86c854a3084b80347766961)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument order", value=order, expected_type=type_hints["order"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
            "order": order,
        }
        if facet is not None:
            self._values["facet"] = facet

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def order(self) -> builtins.str:
        '''Widget sorting methods. Valid values are ``asc``, ``desc``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        result = self._values.get("order")
        assert result is not None, "Required property 'order' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetTimeseriesDefinitionRequestAuditQueryGroupBySortQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetTimeseriesDefinitionRequestAuditQueryGroupBySortQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestAuditQueryGroupBySortQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9778b8d5718f7eeea40ea0941a09119e44176a0c9c788bf495f00651124a599e)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="orderInput")
    def order_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "orderInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3afc82f79b77e06e09f18e3d13c347b4065034790c7c505983d2631a50d75019)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bca53703edc925ad7f6b556e355a6893efd1a23a37c7e804afd90b1348fd2f0e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="order")
    def order(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "order"))

    @order.setter
    def order(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b60d5b3d9dce9df9ded5a15704028d989eb7b2d2aadf1c6c797300c3725632e5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "order", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestAuditQueryGroupBySortQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestAuditQueryGroupBySortQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestAuditQueryGroupBySortQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1a3366f18c02fd25b711a24166f17436f863bdadb455803104f3621fd065f82f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestAuditQueryMultiCompute",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetTimeseriesDefinitionRequestAuditQueryMultiCompute:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__285b1354bf51b64d0ecbfdefc3f78a1a35bd62d51e94a01ca5258afa0afb870b)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetTimeseriesDefinitionRequestAuditQueryMultiCompute(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetTimeseriesDefinitionRequestAuditQueryMultiComputeList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestAuditQueryMultiComputeList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e545d99d6112f0aa113867e3572d6ed7f01ba06c8e741db744a65e4e2f22d691)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetTimeseriesDefinitionRequestAuditQueryMultiComputeOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c403c0cf103da2f267581ce1486c4dc46839d6ce4cdf56be016c98261b4a3920)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetTimeseriesDefinitionRequestAuditQueryMultiComputeOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5a2f4c0391a2b277087c9557a8cba5cedc308eab89f22c18e13b32033f37c7ab)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f169bede196f32682c181e546702589cad8409c26062d5f806ed5d951f7d475c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5f8d35254ad1e642ef35bad8b01093b5774177ae4ca10a86aadcba160693684e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestAuditQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestAuditQueryMultiCompute]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestAuditQueryMultiCompute]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f9674f74a8ca2839c462f7459355957ae8251a2ebedab88aac749f8f01e9e6d5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetTimeseriesDefinitionRequestAuditQueryMultiComputeOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestAuditQueryMultiComputeOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__608504259e6893d4455e16ac7adf076e846d6e093df2f31da8a4ba448c7f28dc)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fabbba5c95ae1d3db58a87e78c2c888ab292d66fb042631487582975dfd4f7eb)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a1a3763e6a2ede6bacf5d6b3927f47655166ba8778a14293eb95d7372f630f1e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__071fd641abaa73851e71351c227fff66eeae268331e8fbb17651e5fb5015584b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTimeseriesDefinitionRequestAuditQueryMultiCompute]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTimeseriesDefinitionRequestAuditQueryMultiCompute]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTimeseriesDefinitionRequestAuditQueryMultiCompute]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__83f7310446cf961656b24a7ffbf3c3d780df7a6009a6e773a4d25fa2f0203869)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetTimeseriesDefinitionRequestAuditQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestAuditQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__be30173ac3765b8586a0408a31d8a4a0def2e472033d0e017a89ffe6a25753e5)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putComputeQuery")
    def put_compute_query(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        value = PowerpackWidgetTimeseriesDefinitionRequestAuditQueryComputeQuery(
            aggregation=aggregation, facet=facet, interval=interval
        )

        return typing.cast(None, jsii.invoke(self, "putComputeQuery", [value]))

    @jsii.member(jsii_name="putGroupBy")
    def put_group_by(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestAuditQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e700268480e6fd3f33c5d2c19248de9e85f2b6729ded0f171525add054b9c34c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putGroupBy", [value]))

    @jsii.member(jsii_name="putMultiCompute")
    def put_multi_compute(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestAuditQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__250c0620c13cd41d72c3eb88649e742e8bd79516222b94ebd2346dc398c64ff7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putMultiCompute", [value]))

    @jsii.member(jsii_name="resetComputeQuery")
    def reset_compute_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetComputeQuery", []))

    @jsii.member(jsii_name="resetGroupBy")
    def reset_group_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGroupBy", []))

    @jsii.member(jsii_name="resetMultiCompute")
    def reset_multi_compute(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMultiCompute", []))

    @jsii.member(jsii_name="resetSearchQuery")
    def reset_search_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSearchQuery", []))

    @builtins.property
    @jsii.member(jsii_name="computeQuery")
    def compute_query(
        self,
    ) -> PowerpackWidgetTimeseriesDefinitionRequestAuditQueryComputeQueryOutputReference:
        return typing.cast(PowerpackWidgetTimeseriesDefinitionRequestAuditQueryComputeQueryOutputReference, jsii.get(self, "computeQuery"))

    @builtins.property
    @jsii.member(jsii_name="groupBy")
    def group_by(
        self,
    ) -> PowerpackWidgetTimeseriesDefinitionRequestAuditQueryGroupByList:
        return typing.cast(PowerpackWidgetTimeseriesDefinitionRequestAuditQueryGroupByList, jsii.get(self, "groupBy"))

    @builtins.property
    @jsii.member(jsii_name="multiCompute")
    def multi_compute(
        self,
    ) -> PowerpackWidgetTimeseriesDefinitionRequestAuditQueryMultiComputeList:
        return typing.cast(PowerpackWidgetTimeseriesDefinitionRequestAuditQueryMultiComputeList, jsii.get(self, "multiCompute"))

    @builtins.property
    @jsii.member(jsii_name="computeQueryInput")
    def compute_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestAuditQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestAuditQueryComputeQuery], jsii.get(self, "computeQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="groupByInput")
    def group_by_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestAuditQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestAuditQueryGroupBy]]], jsii.get(self, "groupByInput"))

    @builtins.property
    @jsii.member(jsii_name="indexInput")
    def index_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "indexInput"))

    @builtins.property
    @jsii.member(jsii_name="multiComputeInput")
    def multi_compute_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestAuditQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestAuditQueryMultiCompute]]], jsii.get(self, "multiComputeInput"))

    @builtins.property
    @jsii.member(jsii_name="searchQueryInput")
    def search_query_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "searchQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="index")
    def index(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "index"))

    @index.setter
    def index(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f07fe74eb188401027353ae7088496e77533e7f65a9c080deb6230d8353fddf7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "index", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="searchQuery")
    def search_query(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "searchQuery"))

    @search_query.setter
    def search_query(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0867b53aeb6e3e15b74d45558275c25fb587f6513274644553406347979dc4ef)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "searchQuery", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestAuditQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestAuditQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestAuditQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b13c8ff115ad787e8ac6eee1f4792acda61f465dc452870af3064b15f5ce37cf)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestFormula",
    jsii_struct_bases=[],
    name_mapping={
        "formula_expression": "formulaExpression",
        "alias": "alias",
        "cell_display_mode": "cellDisplayMode",
        "conditional_formats": "conditionalFormats",
        "limit": "limit",
        "number_format": "numberFormat",
        "style": "style",
    },
)
class PowerpackWidgetTimeseriesDefinitionRequestFormula:
    def __init__(
        self,
        *,
        formula_expression: builtins.str,
        alias: typing.Optional[builtins.str] = None,
        cell_display_mode: typing.Optional[builtins.str] = None,
        conditional_formats: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetTimeseriesDefinitionRequestFormulaConditionalFormats", typing.Dict[builtins.str, typing.Any]]]]] = None,
        limit: typing.Optional[typing.Union["PowerpackWidgetTimeseriesDefinitionRequestFormulaLimit", typing.Dict[builtins.str, typing.Any]]] = None,
        number_format: typing.Optional[typing.Union["PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormat", typing.Dict[builtins.str, typing.Any]]] = None,
        style: typing.Optional[typing.Union["PowerpackWidgetTimeseriesDefinitionRequestFormulaStyle", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param formula_expression: A string expression built from queries, formulas, and functions. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#formula_expression Powerpack#formula_expression}
        :param alias: An expression alias. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#alias Powerpack#alias}
        :param cell_display_mode: A list of display modes for each table cell. Valid values are ``number``, ``bar``, ``trend``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cell_display_mode Powerpack#cell_display_mode}
        :param conditional_formats: conditional_formats block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#conditional_formats Powerpack#conditional_formats}
        :param limit: limit block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param number_format: number_format block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#number_format Powerpack#number_format}
        :param style: style block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#style Powerpack#style}
        '''
        if isinstance(limit, dict):
            limit = PowerpackWidgetTimeseriesDefinitionRequestFormulaLimit(**limit)
        if isinstance(number_format, dict):
            number_format = PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormat(**number_format)
        if isinstance(style, dict):
            style = PowerpackWidgetTimeseriesDefinitionRequestFormulaStyle(**style)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7653cda5be9a13171b7817712fe1c7eb967116d96b16048843e43b85ba0dd330)
            check_type(argname="argument formula_expression", value=formula_expression, expected_type=type_hints["formula_expression"])
            check_type(argname="argument alias", value=alias, expected_type=type_hints["alias"])
            check_type(argname="argument cell_display_mode", value=cell_display_mode, expected_type=type_hints["cell_display_mode"])
            check_type(argname="argument conditional_formats", value=conditional_formats, expected_type=type_hints["conditional_formats"])
            check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
            check_type(argname="argument number_format", value=number_format, expected_type=type_hints["number_format"])
            check_type(argname="argument style", value=style, expected_type=type_hints["style"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "formula_expression": formula_expression,
        }
        if alias is not None:
            self._values["alias"] = alias
        if cell_display_mode is not None:
            self._values["cell_display_mode"] = cell_display_mode
        if conditional_formats is not None:
            self._values["conditional_formats"] = conditional_formats
        if limit is not None:
            self._values["limit"] = limit
        if number_format is not None:
            self._values["number_format"] = number_format
        if style is not None:
            self._values["style"] = style

    @builtins.property
    def formula_expression(self) -> builtins.str:
        '''A string expression built from queries, formulas, and functions.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#formula_expression Powerpack#formula_expression}
        '''
        result = self._values.get("formula_expression")
        assert result is not None, "Required property 'formula_expression' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def alias(self) -> typing.Optional[builtins.str]:
        '''An expression alias.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#alias Powerpack#alias}
        '''
        result = self._values.get("alias")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def cell_display_mode(self) -> typing.Optional[builtins.str]:
        '''A list of display modes for each table cell. Valid values are ``number``, ``bar``, ``trend``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cell_display_mode Powerpack#cell_display_mode}
        '''
        result = self._values.get("cell_display_mode")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def conditional_formats(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetTimeseriesDefinitionRequestFormulaConditionalFormats"]]]:
        '''conditional_formats block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#conditional_formats Powerpack#conditional_formats}
        '''
        result = self._values.get("conditional_formats")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetTimeseriesDefinitionRequestFormulaConditionalFormats"]]], result)

    @builtins.property
    def limit(
        self,
    ) -> typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestFormulaLimit"]:
        '''limit block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        '''
        result = self._values.get("limit")
        return typing.cast(typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestFormulaLimit"], result)

    @builtins.property
    def number_format(
        self,
    ) -> typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormat"]:
        '''number_format block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#number_format Powerpack#number_format}
        '''
        result = self._values.get("number_format")
        return typing.cast(typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormat"], result)

    @builtins.property
    def style(
        self,
    ) -> typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestFormulaStyle"]:
        '''style block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#style Powerpack#style}
        '''
        result = self._values.get("style")
        return typing.cast(typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestFormulaStyle"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetTimeseriesDefinitionRequestFormula(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestFormulaConditionalFormats",
    jsii_struct_bases=[],
    name_mapping={
        "comparator": "comparator",
        "palette": "palette",
        "value": "value",
        "custom_bg_color": "customBgColor",
        "custom_fg_color": "customFgColor",
        "hide_value": "hideValue",
        "image_url": "imageUrl",
        "metric": "metric",
        "timeframe": "timeframe",
    },
)
class PowerpackWidgetTimeseriesDefinitionRequestFormulaConditionalFormats:
    def __init__(
        self,
        *,
        comparator: builtins.str,
        palette: builtins.str,
        value: jsii.Number,
        custom_bg_color: typing.Optional[builtins.str] = None,
        custom_fg_color: typing.Optional[builtins.str] = None,
        hide_value: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        image_url: typing.Optional[builtins.str] = None,
        metric: typing.Optional[builtins.str] = None,
        timeframe: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param comparator: The comparator to use. Valid values are ``=``, ``>``, ``>=``, ``<``, ``<=``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#comparator Powerpack#comparator}
        :param palette: The color palette to apply. Valid values are ``blue``, ``custom_bg``, ``custom_image``, ``custom_text``, ``gray_on_white``, ``grey``, ``green``, ``orange``, ``red``, ``red_on_white``, ``white_on_gray``, ``white_on_green``, ``green_on_white``, ``white_on_red``, ``white_on_yellow``, ``yellow_on_white``, ``black_on_light_yellow``, ``black_on_light_green``, ``black_on_light_red``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette Powerpack#palette}
        :param value: A value for the comparator. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#value Powerpack#value}
        :param custom_bg_color: The color palette to apply to the background, same values available as palette. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom_bg_color Powerpack#custom_bg_color}
        :param custom_fg_color: The color palette to apply to the foreground, same values available as palette. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom_fg_color Powerpack#custom_fg_color}
        :param hide_value: Setting this to True hides values. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#hide_value Powerpack#hide_value}
        :param image_url: Displays an image as the background. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#image_url Powerpack#image_url}
        :param metric: The metric from the request to correlate with this conditional format. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        :param timeframe: Defines the displayed timeframe. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#timeframe Powerpack#timeframe}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5eab865caec75a7853f691aec2f7e7a878f597b17de83a5a8f8d9697a9d32514)
            check_type(argname="argument comparator", value=comparator, expected_type=type_hints["comparator"])
            check_type(argname="argument palette", value=palette, expected_type=type_hints["palette"])
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument custom_bg_color", value=custom_bg_color, expected_type=type_hints["custom_bg_color"])
            check_type(argname="argument custom_fg_color", value=custom_fg_color, expected_type=type_hints["custom_fg_color"])
            check_type(argname="argument hide_value", value=hide_value, expected_type=type_hints["hide_value"])
            check_type(argname="argument image_url", value=image_url, expected_type=type_hints["image_url"])
            check_type(argname="argument metric", value=metric, expected_type=type_hints["metric"])
            check_type(argname="argument timeframe", value=timeframe, expected_type=type_hints["timeframe"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "comparator": comparator,
            "palette": palette,
            "value": value,
        }
        if custom_bg_color is not None:
            self._values["custom_bg_color"] = custom_bg_color
        if custom_fg_color is not None:
            self._values["custom_fg_color"] = custom_fg_color
        if hide_value is not None:
            self._values["hide_value"] = hide_value
        if image_url is not None:
            self._values["image_url"] = image_url
        if metric is not None:
            self._values["metric"] = metric
        if timeframe is not None:
            self._values["timeframe"] = timeframe

    @builtins.property
    def comparator(self) -> builtins.str:
        '''The comparator to use. Valid values are ``=``, ``>``, ``>=``, ``<``, ``<=``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#comparator Powerpack#comparator}
        '''
        result = self._values.get("comparator")
        assert result is not None, "Required property 'comparator' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def palette(self) -> builtins.str:
        '''The color palette to apply.

        Valid values are ``blue``, ``custom_bg``, ``custom_image``, ``custom_text``, ``gray_on_white``, ``grey``, ``green``, ``orange``, ``red``, ``red_on_white``, ``white_on_gray``, ``white_on_green``, ``green_on_white``, ``white_on_red``, ``white_on_yellow``, ``yellow_on_white``, ``black_on_light_yellow``, ``black_on_light_green``, ``black_on_light_red``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette Powerpack#palette}
        '''
        result = self._values.get("palette")
        assert result is not None, "Required property 'palette' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def value(self) -> jsii.Number:
        '''A value for the comparator.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#value Powerpack#value}
        '''
        result = self._values.get("value")
        assert result is not None, "Required property 'value' is missing"
        return typing.cast(jsii.Number, result)

    @builtins.property
    def custom_bg_color(self) -> typing.Optional[builtins.str]:
        '''The color palette to apply to the background, same values available as palette.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom_bg_color Powerpack#custom_bg_color}
        '''
        result = self._values.get("custom_bg_color")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def custom_fg_color(self) -> typing.Optional[builtins.str]:
        '''The color palette to apply to the foreground, same values available as palette.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom_fg_color Powerpack#custom_fg_color}
        '''
        result = self._values.get("custom_fg_color")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def hide_value(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        '''Setting this to True hides values.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#hide_value Powerpack#hide_value}
        '''
        result = self._values.get("hide_value")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)

    @builtins.property
    def image_url(self) -> typing.Optional[builtins.str]:
        '''Displays an image as the background.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#image_url Powerpack#image_url}
        '''
        result = self._values.get("image_url")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def metric(self) -> typing.Optional[builtins.str]:
        '''The metric from the request to correlate with this conditional format.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        '''
        result = self._values.get("metric")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def timeframe(self) -> typing.Optional[builtins.str]:
        '''Defines the displayed timeframe.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#timeframe Powerpack#timeframe}
        '''
        result = self._values.get("timeframe")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetTimeseriesDefinitionRequestFormulaConditionalFormats(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetTimeseriesDefinitionRequestFormulaConditionalFormatsList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestFormulaConditionalFormatsList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__165dc3a8a6a4d98327056c96ba7988efa772ad98837a6bf8e0a6173ed8a183ef)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetTimeseriesDefinitionRequestFormulaConditionalFormatsOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__461a6c4ec632bca97bc69b31723d55133cc07b48d899ece76e7a691465807f6d)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetTimeseriesDefinitionRequestFormulaConditionalFormatsOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8e0bf43e2cdd44229b1370879396e3f8fed9efdc1d98038ed81a330548312437)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__152c39b1a67f33b6c6d85c710f29029c88f77b1d059111708bb583a5d84b83ec)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cdf366b05cbc7ebeaedfc32187e773563781bc95735403d5b07046fa75303044)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestFormulaConditionalFormats]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestFormulaConditionalFormats]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestFormulaConditionalFormats]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3cc55763ae4f8fe78006aafd6e4f2e004afbc6e589d68f5cce0ffb0bb25d70c7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetTimeseriesDefinitionRequestFormulaConditionalFormatsOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestFormulaConditionalFormatsOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6e62b1c700fb8cdf39b583802fda2ad5b8f0a96f899effc229b92260ce1b589a)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetCustomBgColor")
    def reset_custom_bg_color(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCustomBgColor", []))

    @jsii.member(jsii_name="resetCustomFgColor")
    def reset_custom_fg_color(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCustomFgColor", []))

    @jsii.member(jsii_name="resetHideValue")
    def reset_hide_value(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHideValue", []))

    @jsii.member(jsii_name="resetImageUrl")
    def reset_image_url(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetImageUrl", []))

    @jsii.member(jsii_name="resetMetric")
    def reset_metric(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMetric", []))

    @jsii.member(jsii_name="resetTimeframe")
    def reset_timeframe(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTimeframe", []))

    @builtins.property
    @jsii.member(jsii_name="comparatorInput")
    def comparator_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "comparatorInput"))

    @builtins.property
    @jsii.member(jsii_name="customBgColorInput")
    def custom_bg_color_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "customBgColorInput"))

    @builtins.property
    @jsii.member(jsii_name="customFgColorInput")
    def custom_fg_color_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "customFgColorInput"))

    @builtins.property
    @jsii.member(jsii_name="hideValueInput")
    def hide_value_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "hideValueInput"))

    @builtins.property
    @jsii.member(jsii_name="imageUrlInput")
    def image_url_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "imageUrlInput"))

    @builtins.property
    @jsii.member(jsii_name="metricInput")
    def metric_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "metricInput"))

    @builtins.property
    @jsii.member(jsii_name="paletteInput")
    def palette_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "paletteInput"))

    @builtins.property
    @jsii.member(jsii_name="timeframeInput")
    def timeframe_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "timeframeInput"))

    @builtins.property
    @jsii.member(jsii_name="valueInput")
    def value_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "valueInput"))

    @builtins.property
    @jsii.member(jsii_name="comparator")
    def comparator(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "comparator"))

    @comparator.setter
    def comparator(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__181751f7ea2c81900a9c17cf960a2a7cba0b2f8292155f0500e0761d4dcf15f5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "comparator", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="customBgColor")
    def custom_bg_color(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "customBgColor"))

    @custom_bg_color.setter
    def custom_bg_color(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4d9f1e1c12f857331c96370bf9fae1ff6b31835b1ec7e81a9f2e577c60b2f681)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "customBgColor", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="customFgColor")
    def custom_fg_color(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "customFgColor"))

    @custom_fg_color.setter
    def custom_fg_color(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__071b06217061c0d9732fcd23a9df3bc6d1f78ae20fef3aa26422b51e5eda576f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "customFgColor", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="hideValue")
    def hide_value(self) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "hideValue"))

    @hide_value.setter
    def hide_value(
        self,
        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__02275be4494d180d30ec663151cec5f710d7995c0dffbfb9c2775f09760b8545)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "hideValue", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="imageUrl")
    def image_url(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "imageUrl"))

    @image_url.setter
    def image_url(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6d684a52dd03576043cb102df30717ea22d09ff3a7eac57b1caf261597eafad0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "imageUrl", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="metric")
    def metric(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "metric"))

    @metric.setter
    def metric(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__231b0cc20aa0da5056d508592e6d9451c05e71193623f70736422b004422327c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "metric", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="palette")
    def palette(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "palette"))

    @palette.setter
    def palette(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3699cd874cc978f62cd65c4d0acd94af5be7ac0003a61848ba104f29e602047d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "palette", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="timeframe")
    def timeframe(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "timeframe"))

    @timeframe.setter
    def timeframe(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__714449cb82fb127b021fb798a2dd7a3f123f24d16f28cf637f4954b57968164e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "timeframe", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="value")
    def value(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "value"))

    @value.setter
    def value(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dce813db640a54537a2fbbe13baa00dba082905204e770e27280c63190b72425)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "value", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTimeseriesDefinitionRequestFormulaConditionalFormats]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTimeseriesDefinitionRequestFormulaConditionalFormats]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTimeseriesDefinitionRequestFormulaConditionalFormats]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cecb7c0c4f215ac1b502bdded8d3a084643890ae4c5a969cb240144762599f01)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestFormulaLimit",
    jsii_struct_bases=[],
    name_mapping={"count": "count", "order": "order"},
)
class PowerpackWidgetTimeseriesDefinitionRequestFormulaLimit:
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        order: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param count: The number of results to return. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#count Powerpack#count}
        :param order: The direction of the sort. Valid values are ``asc``, ``desc``. Defaults to ``"desc"``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a374d8ae0af9c7622eacdb4cdb254ca79204674262782a617e31df0aedfddc55)
            check_type(argname="argument count", value=count, expected_type=type_hints["count"])
            check_type(argname="argument order", value=order, expected_type=type_hints["order"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if count is not None:
            self._values["count"] = count
        if order is not None:
            self._values["order"] = order

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''The number of results to return.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#count Powerpack#count}
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def order(self) -> typing.Optional[builtins.str]:
        '''The direction of the sort. Valid values are ``asc``, ``desc``. Defaults to ``"desc"``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        result = self._values.get("order")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetTimeseriesDefinitionRequestFormulaLimit(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetTimeseriesDefinitionRequestFormulaLimitOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestFormulaLimitOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8b72c514031539c4bb7ab41808d7f584e102e432eac529015f9448ed2c790da5)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetCount")
    def reset_count(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCount", []))

    @jsii.member(jsii_name="resetOrder")
    def reset_order(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetOrder", []))

    @builtins.property
    @jsii.member(jsii_name="countInput")
    def count_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "countInput"))

    @builtins.property
    @jsii.member(jsii_name="orderInput")
    def order_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "orderInput"))

    @builtins.property
    @jsii.member(jsii_name="count")
    def count(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "count"))

    @count.setter
    def count(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a579bb9f698df6f49bb9fbfca2ae8da515cef51d18a1b9c0adb1c0c22231436a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "count", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="order")
    def order(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "order"))

    @order.setter
    def order(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7c38957a81d25628a5fd2c060984cc5391459bddce41c8986ca53c89aecb5f98)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "order", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestFormulaLimit]:
        return typing.cast(typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestFormulaLimit], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestFormulaLimit],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4991fe820fdfaea4f9a7ebe7034cf7d1bee36fa2b49b5aae3f50d60422f7efab)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetTimeseriesDefinitionRequestFormulaList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestFormulaList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__800f3fadc24dc187a0d07aa1b7ad07362f003e3d5d91c2511c583820a549a955)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetTimeseriesDefinitionRequestFormulaOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__75ff498066645588b3dec789ce9b9cb78380e8bef4a685ba9a79c850fa75224b)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetTimeseriesDefinitionRequestFormulaOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__612ac1eabdee6d8250562351ed2f6bd16e0a9449759f6f12958fb86c10de57f8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__aedee0c7622ee74a3e516cbd3b5eb8b8d9c0794ef3fcb4846bb92e9f49c0c221)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d1ffd0563f54a7d38ee591531763093bfb3ed221348ec8c6d0d301dc12dc35e2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestFormula]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestFormula]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestFormula]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__abad77d5db70b92399f4e6c686639e99ad238063f9e6f58f0385ad6e4b07e3a1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormat",
    jsii_struct_bases=[],
    name_mapping={"unit": "unit", "unit_scale": "unitScale"},
)
class PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormat:
    def __init__(
        self,
        *,
        unit: typing.Union["PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormatUnit", typing.Dict[builtins.str, typing.Any]],
        unit_scale: typing.Optional[typing.Union["PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormatUnitScale", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param unit: unit block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit Powerpack#unit}
        :param unit_scale: unit_scale block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit_scale Powerpack#unit_scale}
        '''
        if isinstance(unit, dict):
            unit = PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormatUnit(**unit)
        if isinstance(unit_scale, dict):
            unit_scale = PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormatUnitScale(**unit_scale)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9b2d759908b7509d1ca4a6b2ec508331f4d3233290232d5527d85463b826c04d)
            check_type(argname="argument unit", value=unit, expected_type=type_hints["unit"])
            check_type(argname="argument unit_scale", value=unit_scale, expected_type=type_hints["unit_scale"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "unit": unit,
        }
        if unit_scale is not None:
            self._values["unit_scale"] = unit_scale

    @builtins.property
    def unit(
        self,
    ) -> "PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormatUnit":
        '''unit block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit Powerpack#unit}
        '''
        result = self._values.get("unit")
        assert result is not None, "Required property 'unit' is missing"
        return typing.cast("PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormatUnit", result)

    @builtins.property
    def unit_scale(
        self,
    ) -> typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormatUnitScale"]:
        '''unit_scale block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit_scale Powerpack#unit_scale}
        '''
        result = self._values.get("unit_scale")
        return typing.cast(typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormatUnitScale"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormat(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormatOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormatOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__67fdabdd896cb9bfcd95eb4be2a87cbb77e2c4b15770ab386f80abc36fe52d04)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putUnit")
    def put_unit(
        self,
        *,
        canonical: typing.Optional[typing.Union["PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormatUnitCanonical", typing.Dict[builtins.str, typing.Any]]] = None,
        custom: typing.Optional[typing.Union["PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormatUnitCustom", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param canonical: canonical block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#canonical Powerpack#canonical}
        :param custom: custom block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom Powerpack#custom}
        '''
        value = PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormatUnit(
            canonical=canonical, custom=custom
        )

        return typing.cast(None, jsii.invoke(self, "putUnit", [value]))

    @jsii.member(jsii_name="putUnitScale")
    def put_unit_scale(self, *, unit_name: builtins.str) -> None:
        '''
        :param unit_name: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit_name Powerpack#unit_name}.
        '''
        value = PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormatUnitScale(
            unit_name=unit_name
        )

        return typing.cast(None, jsii.invoke(self, "putUnitScale", [value]))

    @jsii.member(jsii_name="resetUnitScale")
    def reset_unit_scale(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetUnitScale", []))

    @builtins.property
    @jsii.member(jsii_name="unit")
    def unit(
        self,
    ) -> "PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormatUnitOutputReference":
        return typing.cast("PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormatUnitOutputReference", jsii.get(self, "unit"))

    @builtins.property
    @jsii.member(jsii_name="unitScale")
    def unit_scale(
        self,
    ) -> "PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormatUnitScaleOutputReference":
        return typing.cast("PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormatUnitScaleOutputReference", jsii.get(self, "unitScale"))

    @builtins.property
    @jsii.member(jsii_name="unitInput")
    def unit_input(
        self,
    ) -> typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormatUnit"]:
        return typing.cast(typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormatUnit"], jsii.get(self, "unitInput"))

    @builtins.property
    @jsii.member(jsii_name="unitScaleInput")
    def unit_scale_input(
        self,
    ) -> typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormatUnitScale"]:
        return typing.cast(typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormatUnitScale"], jsii.get(self, "unitScaleInput"))

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormat]:
        return typing.cast(typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormat], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormat],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__827f97ea9bcb800a3bc72ac89078772d0510bc9ef93e55b6075196f03c1dc5a8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormatUnit",
    jsii_struct_bases=[],
    name_mapping={"canonical": "canonical", "custom": "custom"},
)
class PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormatUnit:
    def __init__(
        self,
        *,
        canonical: typing.Optional[typing.Union["PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormatUnitCanonical", typing.Dict[builtins.str, typing.Any]]] = None,
        custom: typing.Optional[typing.Union["PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormatUnitCustom", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param canonical: canonical block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#canonical Powerpack#canonical}
        :param custom: custom block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom Powerpack#custom}
        '''
        if isinstance(canonical, dict):
            canonical = PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormatUnitCanonical(**canonical)
        if isinstance(custom, dict):
            custom = PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormatUnitCustom(**custom)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__78939b797104febd123ecf87b6fb4a86b8697178839ad11deec04ba4b4f0b2bc)
            check_type(argname="argument canonical", value=canonical, expected_type=type_hints["canonical"])
            check_type(argname="argument custom", value=custom, expected_type=type_hints["custom"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if canonical is not None:
            self._values["canonical"] = canonical
        if custom is not None:
            self._values["custom"] = custom

    @builtins.property
    def canonical(
        self,
    ) -> typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormatUnitCanonical"]:
        '''canonical block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#canonical Powerpack#canonical}
        '''
        result = self._values.get("canonical")
        return typing.cast(typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormatUnitCanonical"], result)

    @builtins.property
    def custom(
        self,
    ) -> typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormatUnitCustom"]:
        '''custom block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom Powerpack#custom}
        '''
        result = self._values.get("custom")
        return typing.cast(typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormatUnitCustom"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormatUnit(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormatUnitCanonical",
    jsii_struct_bases=[],
    name_mapping={"unit_name": "unitName", "per_unit_name": "perUnitName"},
)
class PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormatUnitCanonical:
    def __init__(
        self,
        *,
        unit_name: builtins.str,
        per_unit_name: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param unit_name: Unit name. It should be in singular form ('megabyte' and not 'megabytes'). Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit_name Powerpack#unit_name}
        :param per_unit_name: per unit name. If you want to represent megabytes/s, you set 'unit_name' = 'megabyte' and 'per_unit_name = 'second'. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#per_unit_name Powerpack#per_unit_name}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7395ebb2d8809fc79fed955db8281dc12f636d010da67ebb4707a4e56fb9a242)
            check_type(argname="argument unit_name", value=unit_name, expected_type=type_hints["unit_name"])
            check_type(argname="argument per_unit_name", value=per_unit_name, expected_type=type_hints["per_unit_name"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "unit_name": unit_name,
        }
        if per_unit_name is not None:
            self._values["per_unit_name"] = per_unit_name

    @builtins.property
    def unit_name(self) -> builtins.str:
        '''Unit name. It should be in singular form ('megabyte' and not 'megabytes').

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit_name Powerpack#unit_name}
        '''
        result = self._values.get("unit_name")
        assert result is not None, "Required property 'unit_name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def per_unit_name(self) -> typing.Optional[builtins.str]:
        '''per unit name. If you want to represent megabytes/s, you set 'unit_name' = 'megabyte' and 'per_unit_name = 'second'.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#per_unit_name Powerpack#per_unit_name}
        '''
        result = self._values.get("per_unit_name")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormatUnitCanonical(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormatUnitCanonicalOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormatUnitCanonicalOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c20fb3af26613994bb8c64f8bc74ba0aac1ac91a44fb4f1f8276620c1a86b2e7)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetPerUnitName")
    def reset_per_unit_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPerUnitName", []))

    @builtins.property
    @jsii.member(jsii_name="perUnitNameInput")
    def per_unit_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "perUnitNameInput"))

    @builtins.property
    @jsii.member(jsii_name="unitNameInput")
    def unit_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "unitNameInput"))

    @builtins.property
    @jsii.member(jsii_name="perUnitName")
    def per_unit_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "perUnitName"))

    @per_unit_name.setter
    def per_unit_name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e2bdba4bfe270df8f585043cdf896cb1e52c839854077ff78080cea6d2b92d8b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "perUnitName", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="unitName")
    def unit_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "unitName"))

    @unit_name.setter
    def unit_name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3fd79bb90e8bcfb20dfeb0d5bb0fba8b84a36353a60bf98c7b698d98147b92c5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "unitName", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormatUnitCanonical]:
        return typing.cast(typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormatUnitCanonical], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormatUnitCanonical],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f714aeb58a7fc6d5e03e398dff8f6359ae50878b40305429758ac576e0c29665)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormatUnitCustom",
    jsii_struct_bases=[],
    name_mapping={"label": "label"},
)
class PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormatUnitCustom:
    def __init__(self, *, label: builtins.str) -> None:
        '''
        :param label: Unit label. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#label Powerpack#label}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7f4847784cef9439900c6d0b8ebc61ced40d670bc8a29111e14a9ab7ce31eac1)
            check_type(argname="argument label", value=label, expected_type=type_hints["label"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "label": label,
        }

    @builtins.property
    def label(self) -> builtins.str:
        '''Unit label.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#label Powerpack#label}
        '''
        result = self._values.get("label")
        assert result is not None, "Required property 'label' is missing"
        return typing.cast(builtins.str, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormatUnitCustom(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormatUnitCustomOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormatUnitCustomOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__18ce09e5913b2fbb9911d64d630566eca06dd34c1cec0b24662eb7f1b7dbd4ba)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @builtins.property
    @jsii.member(jsii_name="labelInput")
    def label_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "labelInput"))

    @builtins.property
    @jsii.member(jsii_name="label")
    def label(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "label"))

    @label.setter
    def label(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__25f7cb38dd6246952773b36a097fe4e96fb035b750c1a3d30321e40b86af5dd8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "label", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormatUnitCustom]:
        return typing.cast(typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormatUnitCustom], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormatUnitCustom],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0a9dd2d4a7171f2cf0d0075498ee26bed1bfc775ddf20ae06c533704db6f5521)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormatUnitOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormatUnitOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d56686067885d2b12b89ab8cfb1a8b665dfc3975df81905e21df2219875a2195)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putCanonical")
    def put_canonical(
        self,
        *,
        unit_name: builtins.str,
        per_unit_name: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param unit_name: Unit name. It should be in singular form ('megabyte' and not 'megabytes'). Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit_name Powerpack#unit_name}
        :param per_unit_name: per unit name. If you want to represent megabytes/s, you set 'unit_name' = 'megabyte' and 'per_unit_name = 'second'. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#per_unit_name Powerpack#per_unit_name}
        '''
        value = PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormatUnitCanonical(
            unit_name=unit_name, per_unit_name=per_unit_name
        )

        return typing.cast(None, jsii.invoke(self, "putCanonical", [value]))

    @jsii.member(jsii_name="putCustom")
    def put_custom(self, *, label: builtins.str) -> None:
        '''
        :param label: Unit label. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#label Powerpack#label}
        '''
        value = PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormatUnitCustom(
            label=label
        )

        return typing.cast(None, jsii.invoke(self, "putCustom", [value]))

    @jsii.member(jsii_name="resetCanonical")
    def reset_canonical(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCanonical", []))

    @jsii.member(jsii_name="resetCustom")
    def reset_custom(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCustom", []))

    @builtins.property
    @jsii.member(jsii_name="canonical")
    def canonical(
        self,
    ) -> PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormatUnitCanonicalOutputReference:
        return typing.cast(PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormatUnitCanonicalOutputReference, jsii.get(self, "canonical"))

    @builtins.property
    @jsii.member(jsii_name="custom")
    def custom(
        self,
    ) -> PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormatUnitCustomOutputReference:
        return typing.cast(PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormatUnitCustomOutputReference, jsii.get(self, "custom"))

    @builtins.property
    @jsii.member(jsii_name="canonicalInput")
    def canonical_input(
        self,
    ) -> typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormatUnitCanonical]:
        return typing.cast(typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormatUnitCanonical], jsii.get(self, "canonicalInput"))

    @builtins.property
    @jsii.member(jsii_name="customInput")
    def custom_input(
        self,
    ) -> typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormatUnitCustom]:
        return typing.cast(typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormatUnitCustom], jsii.get(self, "customInput"))

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormatUnit]:
        return typing.cast(typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormatUnit], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormatUnit],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fe29a5b791ba95e818aee088f62904bc2718acc5d49b7fbb4c3e05e908ab3590)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormatUnitScale",
    jsii_struct_bases=[],
    name_mapping={"unit_name": "unitName"},
)
class PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormatUnitScale:
    def __init__(self, *, unit_name: builtins.str) -> None:
        '''
        :param unit_name: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit_name Powerpack#unit_name}.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__164cd7a2de9d1ec1528de4abce63782966bc21ebcc13c0057bdbdf35219953fc)
            check_type(argname="argument unit_name", value=unit_name, expected_type=type_hints["unit_name"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "unit_name": unit_name,
        }

    @builtins.property
    def unit_name(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit_name Powerpack#unit_name}.'''
        result = self._values.get("unit_name")
        assert result is not None, "Required property 'unit_name' is missing"
        return typing.cast(builtins.str, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormatUnitScale(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormatUnitScaleOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormatUnitScaleOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f33ae3b1706ce24a4c1aa30360fa92845eca0a6bab6dc15571381522d23fe366)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @builtins.property
    @jsii.member(jsii_name="unitNameInput")
    def unit_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "unitNameInput"))

    @builtins.property
    @jsii.member(jsii_name="unitName")
    def unit_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "unitName"))

    @unit_name.setter
    def unit_name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a69d44810052848d3497db2fe346add8f2d474492ecdf019c093333f010bf00c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "unitName", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormatUnitScale]:
        return typing.cast(typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormatUnitScale], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormatUnitScale],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8952ffe81745070df91a63ee8d2241388768e65e665c1a00fc3d09623346a970)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetTimeseriesDefinitionRequestFormulaOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestFormulaOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c3b0579f480944a66086eccc76909846877d511aa16be269517c4ef85df95c99)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putConditionalFormats")
    def put_conditional_formats(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestFormulaConditionalFormats, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__28644ff11d38c38720723624d8bf77e0b1400b374a949a2da8e35f962159afca)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putConditionalFormats", [value]))

    @jsii.member(jsii_name="putLimit")
    def put_limit(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        order: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param count: The number of results to return. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#count Powerpack#count}
        :param order: The direction of the sort. Valid values are ``asc``, ``desc``. Defaults to ``"desc"``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        value = PowerpackWidgetTimeseriesDefinitionRequestFormulaLimit(
            count=count, order=order
        )

        return typing.cast(None, jsii.invoke(self, "putLimit", [value]))

    @jsii.member(jsii_name="putNumberFormat")
    def put_number_format(
        self,
        *,
        unit: typing.Union[PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormatUnit, typing.Dict[builtins.str, typing.Any]],
        unit_scale: typing.Optional[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormatUnitScale, typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param unit: unit block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit Powerpack#unit}
        :param unit_scale: unit_scale block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit_scale Powerpack#unit_scale}
        '''
        value = PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormat(
            unit=unit, unit_scale=unit_scale
        )

        return typing.cast(None, jsii.invoke(self, "putNumberFormat", [value]))

    @jsii.member(jsii_name="putStyle")
    def put_style(
        self,
        *,
        palette: typing.Optional[builtins.str] = None,
        palette_index: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param palette: The color palette used to display the formula. A guide to the available color palettes can be found at https://docs.datadoghq.com/dashboards/guide/widget_colors. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette Powerpack#palette}
        :param palette_index: Index specifying which color to use within the palette. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette_index Powerpack#palette_index}
        '''
        value = PowerpackWidgetTimeseriesDefinitionRequestFormulaStyle(
            palette=palette, palette_index=palette_index
        )

        return typing.cast(None, jsii.invoke(self, "putStyle", [value]))

    @jsii.member(jsii_name="resetAlias")
    def reset_alias(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAlias", []))

    @jsii.member(jsii_name="resetCellDisplayMode")
    def reset_cell_display_mode(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCellDisplayMode", []))

    @jsii.member(jsii_name="resetConditionalFormats")
    def reset_conditional_formats(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetConditionalFormats", []))

    @jsii.member(jsii_name="resetLimit")
    def reset_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLimit", []))

    @jsii.member(jsii_name="resetNumberFormat")
    def reset_number_format(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetNumberFormat", []))

    @jsii.member(jsii_name="resetStyle")
    def reset_style(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetStyle", []))

    @builtins.property
    @jsii.member(jsii_name="conditionalFormats")
    def conditional_formats(
        self,
    ) -> PowerpackWidgetTimeseriesDefinitionRequestFormulaConditionalFormatsList:
        return typing.cast(PowerpackWidgetTimeseriesDefinitionRequestFormulaConditionalFormatsList, jsii.get(self, "conditionalFormats"))

    @builtins.property
    @jsii.member(jsii_name="limit")
    def limit(
        self,
    ) -> PowerpackWidgetTimeseriesDefinitionRequestFormulaLimitOutputReference:
        return typing.cast(PowerpackWidgetTimeseriesDefinitionRequestFormulaLimitOutputReference, jsii.get(self, "limit"))

    @builtins.property
    @jsii.member(jsii_name="numberFormat")
    def number_format(
        self,
    ) -> PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormatOutputReference:
        return typing.cast(PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormatOutputReference, jsii.get(self, "numberFormat"))

    @builtins.property
    @jsii.member(jsii_name="style")
    def style(
        self,
    ) -> "PowerpackWidgetTimeseriesDefinitionRequestFormulaStyleOutputReference":
        return typing.cast("PowerpackWidgetTimeseriesDefinitionRequestFormulaStyleOutputReference", jsii.get(self, "style"))

    @builtins.property
    @jsii.member(jsii_name="aliasInput")
    def alias_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aliasInput"))

    @builtins.property
    @jsii.member(jsii_name="cellDisplayModeInput")
    def cell_display_mode_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "cellDisplayModeInput"))

    @builtins.property
    @jsii.member(jsii_name="conditionalFormatsInput")
    def conditional_formats_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestFormulaConditionalFormats]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestFormulaConditionalFormats]]], jsii.get(self, "conditionalFormatsInput"))

    @builtins.property
    @jsii.member(jsii_name="formulaExpressionInput")
    def formula_expression_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "formulaExpressionInput"))

    @builtins.property
    @jsii.member(jsii_name="limitInput")
    def limit_input(
        self,
    ) -> typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestFormulaLimit]:
        return typing.cast(typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestFormulaLimit], jsii.get(self, "limitInput"))

    @builtins.property
    @jsii.member(jsii_name="numberFormatInput")
    def number_format_input(
        self,
    ) -> typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormat]:
        return typing.cast(typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormat], jsii.get(self, "numberFormatInput"))

    @builtins.property
    @jsii.member(jsii_name="styleInput")
    def style_input(
        self,
    ) -> typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestFormulaStyle"]:
        return typing.cast(typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestFormulaStyle"], jsii.get(self, "styleInput"))

    @builtins.property
    @jsii.member(jsii_name="alias")
    def alias(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "alias"))

    @alias.setter
    def alias(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4af3eda8fd07911ec64742a6c3cffea7cc6c40c52c1086b508bcf02de625082e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "alias", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="cellDisplayMode")
    def cell_display_mode(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "cellDisplayMode"))

    @cell_display_mode.setter
    def cell_display_mode(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4600ada5dafb4e4af7a1b5b8a6059ddd388ac719737c401c8ae3767d9aa6d621)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "cellDisplayMode", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="formulaExpression")
    def formula_expression(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "formulaExpression"))

    @formula_expression.setter
    def formula_expression(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5e833ef04f22d0bda6312bddee077d8c28d03cc2de3df0e7df6a05707d9f3a11)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "formulaExpression", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTimeseriesDefinitionRequestFormula]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTimeseriesDefinitionRequestFormula]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTimeseriesDefinitionRequestFormula]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8edd30d2c74039ae9933df48b74f4fd954ea6c52d101a45068be87c18543150b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestFormulaStyle",
    jsii_struct_bases=[],
    name_mapping={"palette": "palette", "palette_index": "paletteIndex"},
)
class PowerpackWidgetTimeseriesDefinitionRequestFormulaStyle:
    def __init__(
        self,
        *,
        palette: typing.Optional[builtins.str] = None,
        palette_index: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param palette: The color palette used to display the formula. A guide to the available color palettes can be found at https://docs.datadoghq.com/dashboards/guide/widget_colors. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette Powerpack#palette}
        :param palette_index: Index specifying which color to use within the palette. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette_index Powerpack#palette_index}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d278537f23c8e3e6652afda82388717a851b7c699717a2d74e2c504be5623963)
            check_type(argname="argument palette", value=palette, expected_type=type_hints["palette"])
            check_type(argname="argument palette_index", value=palette_index, expected_type=type_hints["palette_index"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if palette is not None:
            self._values["palette"] = palette
        if palette_index is not None:
            self._values["palette_index"] = palette_index

    @builtins.property
    def palette(self) -> typing.Optional[builtins.str]:
        '''The color palette used to display the formula.

        A guide to the available color palettes can be found at https://docs.datadoghq.com/dashboards/guide/widget_colors.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette Powerpack#palette}
        '''
        result = self._values.get("palette")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def palette_index(self) -> typing.Optional[jsii.Number]:
        '''Index specifying which color to use within the palette.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette_index Powerpack#palette_index}
        '''
        result = self._values.get("palette_index")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetTimeseriesDefinitionRequestFormulaStyle(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetTimeseriesDefinitionRequestFormulaStyleOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestFormulaStyleOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3a5db7610eeacd3f6c43cef472f30e8d4fc5daad67a7d141577462baf9f50ea4)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetPalette")
    def reset_palette(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPalette", []))

    @jsii.member(jsii_name="resetPaletteIndex")
    def reset_palette_index(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPaletteIndex", []))

    @builtins.property
    @jsii.member(jsii_name="paletteIndexInput")
    def palette_index_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "paletteIndexInput"))

    @builtins.property
    @jsii.member(jsii_name="paletteInput")
    def palette_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "paletteInput"))

    @builtins.property
    @jsii.member(jsii_name="palette")
    def palette(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "palette"))

    @palette.setter
    def palette(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7c96967c737d5b1fc80a83746e935f4b008b595fa4969b9c128b29927ba1943a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "palette", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="paletteIndex")
    def palette_index(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "paletteIndex"))

    @palette_index.setter
    def palette_index(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9f6e2437c8769feaabe753d53918ef8489d6d826b105861a5fa9d017f8b76fe0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "paletteIndex", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestFormulaStyle]:
        return typing.cast(typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestFormulaStyle], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestFormulaStyle],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ee143716940aba631bf7910dda8abf852860d2bf87c5b7d7d738aa494d6a185b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetTimeseriesDefinitionRequestList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c0841d1629196d8320f732195d19276eef79c8f59b678ee8725e4c1db3055ca0)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetTimeseriesDefinitionRequestOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7bf866c39444071562ed877769c60f1f18a61341a350c15c4b607da1fc2c5b01)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetTimeseriesDefinitionRequestOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__539a7d51a6edb7d1d1db17f90ed6a7f5607b2d1157d3f8795781c35e44bed784)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f57aecaa5a4963e81fb6ba17d587dd5eeeec872f5093bc8d9c119127df7236c7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__adada9827ada4c574303b7f586a423177e7510920f26ad504c1fc723ae9c3bfa)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequest]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequest]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequest]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b2a2225e86bc3d13439fdea6e62c7e374983306ffa6edf38f716b694ee04da0f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestLogQuery",
    jsii_struct_bases=[],
    name_mapping={
        "index": "index",
        "compute_query": "computeQuery",
        "group_by": "groupBy",
        "multi_compute": "multiCompute",
        "search_query": "searchQuery",
    },
)
class PowerpackWidgetTimeseriesDefinitionRequestLogQuery:
    def __init__(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union["PowerpackWidgetTimeseriesDefinitionRequestLogQueryComputeQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetTimeseriesDefinitionRequestLogQueryGroupBy", typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetTimeseriesDefinitionRequestLogQueryMultiCompute", typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        if isinstance(compute_query, dict):
            compute_query = PowerpackWidgetTimeseriesDefinitionRequestLogQueryComputeQuery(**compute_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__52133ab88def608ad3c64b5dad8cf49548fb036aeddecb94b044ea9bda6c11bd)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
            check_type(argname="argument compute_query", value=compute_query, expected_type=type_hints["compute_query"])
            check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
            check_type(argname="argument multi_compute", value=multi_compute, expected_type=type_hints["multi_compute"])
            check_type(argname="argument search_query", value=search_query, expected_type=type_hints["search_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "index": index,
        }
        if compute_query is not None:
            self._values["compute_query"] = compute_query
        if group_by is not None:
            self._values["group_by"] = group_by
        if multi_compute is not None:
            self._values["multi_compute"] = multi_compute
        if search_query is not None:
            self._values["search_query"] = search_query

    @builtins.property
    def index(self) -> builtins.str:
        '''The name of the index to query.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        '''
        result = self._values.get("index")
        assert result is not None, "Required property 'index' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def compute_query(
        self,
    ) -> typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestLogQueryComputeQuery"]:
        '''compute_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        '''
        result = self._values.get("compute_query")
        return typing.cast(typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestLogQueryComputeQuery"], result)

    @builtins.property
    def group_by(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetTimeseriesDefinitionRequestLogQueryGroupBy"]]]:
        '''group_by block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        '''
        result = self._values.get("group_by")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetTimeseriesDefinitionRequestLogQueryGroupBy"]]], result)

    @builtins.property
    def multi_compute(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetTimeseriesDefinitionRequestLogQueryMultiCompute"]]]:
        '''multi_compute block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        '''
        result = self._values.get("multi_compute")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetTimeseriesDefinitionRequestLogQueryMultiCompute"]]], result)

    @builtins.property
    def search_query(self) -> typing.Optional[builtins.str]:
        '''The search query to use.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        result = self._values.get("search_query")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetTimeseriesDefinitionRequestLogQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestLogQueryComputeQuery",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetTimeseriesDefinitionRequestLogQueryComputeQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a1bb754573c745cbb9393876834dd6663eb13dab086ace00ba7582de01890bcd)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetTimeseriesDefinitionRequestLogQueryComputeQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetTimeseriesDefinitionRequestLogQueryComputeQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestLogQueryComputeQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8ae387b63b7e0fb717763d93c850c92c6a720fdab4a9e6e2af4bda458a92191f)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__07bb1b53a409c6df082f7f3e29a6674c6f8b9a2f7dfb264ba2bb08373c9acc5d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4d0429e9208904efe758f3927806381fbb8eb61ccfa3e3bf265129a076cc36e3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1a08aef1b7ff0d9ddf70f28dd5e2a4b9a8928bff7fb74073e8a31befebd3b2a7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestLogQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestLogQueryComputeQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestLogQueryComputeQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e85fac70c9892c7022d52a11d39f957642b93fca885895135cf0bdc2c4167f57)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestLogQueryGroupBy",
    jsii_struct_bases=[],
    name_mapping={"facet": "facet", "limit": "limit", "sort_query": "sortQuery"},
)
class PowerpackWidgetTimeseriesDefinitionRequestLogQueryGroupBy:
    def __init__(
        self,
        *,
        facet: typing.Optional[builtins.str] = None,
        limit: typing.Optional[jsii.Number] = None,
        sort_query: typing.Optional[typing.Union["PowerpackWidgetTimeseriesDefinitionRequestLogQueryGroupBySortQuery", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param limit: The maximum number of items in the group. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param sort_query: sort_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        if isinstance(sort_query, dict):
            sort_query = PowerpackWidgetTimeseriesDefinitionRequestLogQueryGroupBySortQuery(**sort_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__19291b1bd68994b8f061bef8c7a245e601f111c641e3afdfda47b76d5adc8fe3)
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
            check_type(argname="argument sort_query", value=sort_query, expected_type=type_hints["sort_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if facet is not None:
            self._values["facet"] = facet
        if limit is not None:
            self._values["limit"] = limit
        if sort_query is not None:
            self._values["sort_query"] = sort_query

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def limit(self) -> typing.Optional[jsii.Number]:
        '''The maximum number of items in the group.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        '''
        result = self._values.get("limit")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def sort_query(
        self,
    ) -> typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestLogQueryGroupBySortQuery"]:
        '''sort_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        result = self._values.get("sort_query")
        return typing.cast(typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestLogQueryGroupBySortQuery"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetTimeseriesDefinitionRequestLogQueryGroupBy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetTimeseriesDefinitionRequestLogQueryGroupByList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestLogQueryGroupByList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__df2c4b753e935242ddd3dc03ef527f02fcb3df76a2d19eae269ab10a57cbd193)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetTimeseriesDefinitionRequestLogQueryGroupByOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b7b11f5b8b1bd205331fc06d505eb1e9aca02347e3439d3a809829aff2f064a5)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetTimeseriesDefinitionRequestLogQueryGroupByOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b8e379ca1f1440e35fd2265e8ceb183c238df223a7525506a256d9d74dea1d52)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c04b6c97a1bad91bbc534afac17f7487e5dd97b23facaf922e2643f88a7fc8e5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a8a7da04cb7355b32175e04b96a1bdf6d8c4ef73d88e6d7ab3f23a8644a03832)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestLogQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestLogQueryGroupBy]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestLogQueryGroupBy]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__101e84a4dbd17d7f5d7bc85dee0787959c97c226f48e5948ef723dbe341d4d50)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetTimeseriesDefinitionRequestLogQueryGroupByOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestLogQueryGroupByOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1c193cb7bdafb96affb806ed03749c74d7736c6bbdeabf53522da3244e29cbc9)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putSortQuery")
    def put_sort_query(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        value = PowerpackWidgetTimeseriesDefinitionRequestLogQueryGroupBySortQuery(
            aggregation=aggregation, order=order, facet=facet
        )

        return typing.cast(None, jsii.invoke(self, "putSortQuery", [value]))

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetLimit")
    def reset_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLimit", []))

    @jsii.member(jsii_name="resetSortQuery")
    def reset_sort_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSortQuery", []))

    @builtins.property
    @jsii.member(jsii_name="sortQuery")
    def sort_query(
        self,
    ) -> "PowerpackWidgetTimeseriesDefinitionRequestLogQueryGroupBySortQueryOutputReference":
        return typing.cast("PowerpackWidgetTimeseriesDefinitionRequestLogQueryGroupBySortQueryOutputReference", jsii.get(self, "sortQuery"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="limitInput")
    def limit_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "limitInput"))

    @builtins.property
    @jsii.member(jsii_name="sortQueryInput")
    def sort_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestLogQueryGroupBySortQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestLogQueryGroupBySortQuery"], jsii.get(self, "sortQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__db6fecad84344a6cb4cbd06ddf8179e3b41db75854fe2b1f61eccc3201de40e1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="limit")
    def limit(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "limit"))

    @limit.setter
    def limit(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dd654df66eac694be073c53cce2dd9265273741d9638d465aabe912b9b9a9500)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "limit", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTimeseriesDefinitionRequestLogQueryGroupBy]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTimeseriesDefinitionRequestLogQueryGroupBy]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTimeseriesDefinitionRequestLogQueryGroupBy]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8e8c67ce36da2da4f1a5abfd30499cf75618a7cde000a4d22a048a32ac58cbd5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestLogQueryGroupBySortQuery",
    jsii_struct_bases=[],
    name_mapping={"aggregation": "aggregation", "order": "order", "facet": "facet"},
)
class PowerpackWidgetTimeseriesDefinitionRequestLogQueryGroupBySortQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__049ab23e5f05d26efe6673a1fe0d7253d6b2a7e1e6edefb4d2deca22bb777c6c)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument order", value=order, expected_type=type_hints["order"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
            "order": order,
        }
        if facet is not None:
            self._values["facet"] = facet

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def order(self) -> builtins.str:
        '''Widget sorting methods. Valid values are ``asc``, ``desc``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        result = self._values.get("order")
        assert result is not None, "Required property 'order' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetTimeseriesDefinitionRequestLogQueryGroupBySortQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetTimeseriesDefinitionRequestLogQueryGroupBySortQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestLogQueryGroupBySortQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__603e9192ea3006134d9f38f6bd5c89faefd9bce2ffcc892c7c294b31c7a83489)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="orderInput")
    def order_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "orderInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b39a86462cfc391360e9b8595ac80770e9fa6e7742de06681017cd10c3ea89e4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fe89a9cb95b8d74d43a83cdfa0091341d508468655eaa7bb524fd11e6c4def4a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="order")
    def order(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "order"))

    @order.setter
    def order(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__de83d41efcd1c3fc6f714a01909cb0a8101dcdf232cc858639389cd0f2debfb3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "order", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestLogQueryGroupBySortQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestLogQueryGroupBySortQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestLogQueryGroupBySortQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f4d502ab30c21c2c2b1040bab9344de2495f4da9fed3643f3112856767eeb577)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestLogQueryMultiCompute",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetTimeseriesDefinitionRequestLogQueryMultiCompute:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2890cd2f696b7a0166ae0944e9b5d04d00ef3a71d806b67bfdaa89806a323c56)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetTimeseriesDefinitionRequestLogQueryMultiCompute(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetTimeseriesDefinitionRequestLogQueryMultiComputeList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestLogQueryMultiComputeList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__747fcbe482a2489cf814ae135da139dd24a1495d7e87c8c32de215988e309cbb)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetTimeseriesDefinitionRequestLogQueryMultiComputeOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__73d48cf282ce80f5d0ecda6f51d3c28d86d4cf80f388a24b7cb8fecd220ac40f)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetTimeseriesDefinitionRequestLogQueryMultiComputeOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__90befe1e939f6ca58184ceee40ea0573c1769df4dee5d1aabfe6be17acdd1158)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__49066df1029edb337c0851dbc25734fe066be10f2abee167d67350c7dd799f72)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a99f309a770050671c18fd3e7fa3c2b15fd78080d43d0a6f118b86cbb2732155)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestLogQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestLogQueryMultiCompute]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestLogQueryMultiCompute]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c1ee9cd606c493bde41598b498d32a55ace5b07fdf027a9886bd864fcadc2263)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetTimeseriesDefinitionRequestLogQueryMultiComputeOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestLogQueryMultiComputeOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f1e5cdcefc090df55d883e36423da5564500c99b2a07fb2a361478878a43f17a)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ba16fa141ff0a1b1d533478ccda83138dfaebc1edcb919fb98b5e777d0250bb5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__11f5aee0a7e110829fb75229ba22ac71473ea7a42dafe718585b91feca907945)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bacd97c9c3b81da6ab5b63458c80a07310c0c5f8caa38076bd28ab6b05fb46c2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTimeseriesDefinitionRequestLogQueryMultiCompute]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTimeseriesDefinitionRequestLogQueryMultiCompute]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTimeseriesDefinitionRequestLogQueryMultiCompute]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__39da9fc5cb291f3cbb842b3abfff3b8a311d1aca8d82c1376dff65e3e9af0081)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetTimeseriesDefinitionRequestLogQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestLogQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__72a1ba865fef546a46012484ef715711a4c3d96850947d9e5f0a5045f3f53043)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putComputeQuery")
    def put_compute_query(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        value = PowerpackWidgetTimeseriesDefinitionRequestLogQueryComputeQuery(
            aggregation=aggregation, facet=facet, interval=interval
        )

        return typing.cast(None, jsii.invoke(self, "putComputeQuery", [value]))

    @jsii.member(jsii_name="putGroupBy")
    def put_group_by(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestLogQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__457daacedf9cd210ba43f5af1a5117c96072e330f51c5a2c5f0c6ff086c1f9e5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putGroupBy", [value]))

    @jsii.member(jsii_name="putMultiCompute")
    def put_multi_compute(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestLogQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__869637830c16fba707551dacdc2626df5fa8e765034f562d9e4b27deb1be6d54)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putMultiCompute", [value]))

    @jsii.member(jsii_name="resetComputeQuery")
    def reset_compute_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetComputeQuery", []))

    @jsii.member(jsii_name="resetGroupBy")
    def reset_group_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGroupBy", []))

    @jsii.member(jsii_name="resetMultiCompute")
    def reset_multi_compute(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMultiCompute", []))

    @jsii.member(jsii_name="resetSearchQuery")
    def reset_search_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSearchQuery", []))

    @builtins.property
    @jsii.member(jsii_name="computeQuery")
    def compute_query(
        self,
    ) -> PowerpackWidgetTimeseriesDefinitionRequestLogQueryComputeQueryOutputReference:
        return typing.cast(PowerpackWidgetTimeseriesDefinitionRequestLogQueryComputeQueryOutputReference, jsii.get(self, "computeQuery"))

    @builtins.property
    @jsii.member(jsii_name="groupBy")
    def group_by(self) -> PowerpackWidgetTimeseriesDefinitionRequestLogQueryGroupByList:
        return typing.cast(PowerpackWidgetTimeseriesDefinitionRequestLogQueryGroupByList, jsii.get(self, "groupBy"))

    @builtins.property
    @jsii.member(jsii_name="multiCompute")
    def multi_compute(
        self,
    ) -> PowerpackWidgetTimeseriesDefinitionRequestLogQueryMultiComputeList:
        return typing.cast(PowerpackWidgetTimeseriesDefinitionRequestLogQueryMultiComputeList, jsii.get(self, "multiCompute"))

    @builtins.property
    @jsii.member(jsii_name="computeQueryInput")
    def compute_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestLogQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestLogQueryComputeQuery], jsii.get(self, "computeQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="groupByInput")
    def group_by_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestLogQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestLogQueryGroupBy]]], jsii.get(self, "groupByInput"))

    @builtins.property
    @jsii.member(jsii_name="indexInput")
    def index_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "indexInput"))

    @builtins.property
    @jsii.member(jsii_name="multiComputeInput")
    def multi_compute_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestLogQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestLogQueryMultiCompute]]], jsii.get(self, "multiComputeInput"))

    @builtins.property
    @jsii.member(jsii_name="searchQueryInput")
    def search_query_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "searchQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="index")
    def index(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "index"))

    @index.setter
    def index(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__be3a4fad8543b694e126c915bb2984bc1fe1e338f8a9c07bfacfe8f59bd6162b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "index", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="searchQuery")
    def search_query(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "searchQuery"))

    @search_query.setter
    def search_query(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__21eb6664de1fdd69e362a6f22949cbf96af862a87c2048e219c7ff6b621013e2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "searchQuery", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestLogQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestLogQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestLogQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c794d29acfffb2a170dc403ff71c0bdd0be96f9c5476760f3a5da71e32e216a7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestMetadata",
    jsii_struct_bases=[],
    name_mapping={"expression": "expression", "alias_name": "aliasName"},
)
class PowerpackWidgetTimeseriesDefinitionRequestMetadata:
    def __init__(
        self,
        *,
        expression: builtins.str,
        alias_name: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param expression: The expression name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#expression Powerpack#expression}
        :param alias_name: The expression alias. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#alias_name Powerpack#alias_name}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f46795b9a56f01dd5f329d9253eb3a23adfce0e5effe2a13fa44a627901d81c1)
            check_type(argname="argument expression", value=expression, expected_type=type_hints["expression"])
            check_type(argname="argument alias_name", value=alias_name, expected_type=type_hints["alias_name"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "expression": expression,
        }
        if alias_name is not None:
            self._values["alias_name"] = alias_name

    @builtins.property
    def expression(self) -> builtins.str:
        '''The expression name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#expression Powerpack#expression}
        '''
        result = self._values.get("expression")
        assert result is not None, "Required property 'expression' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def alias_name(self) -> typing.Optional[builtins.str]:
        '''The expression alias.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#alias_name Powerpack#alias_name}
        '''
        result = self._values.get("alias_name")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetTimeseriesDefinitionRequestMetadata(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetTimeseriesDefinitionRequestMetadataList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestMetadataList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2641e4a131366bd1392b35e5502cc2215f9b0e32c368aae5ed647cc16ab35943)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetTimeseriesDefinitionRequestMetadataOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__51280bd890dc53245cd7fceb3098fc9a3690665936e9ee1f568a2404487928b5)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetTimeseriesDefinitionRequestMetadataOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__97da60ee31d5182fb934cb6b28e2d77bd6793360939c1313d0eaf044b3e59cb5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__234eb2a67a4954ce0be7964856e04920f7c1a71faccb21fb45080389d4855821)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0a346c9da70b67e9a997f1df3351a8dacc72220a69802f55382be4d4ce90efd4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestMetadata]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestMetadata]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestMetadata]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f5afe327e8399c68d4c6b27672bca8d4e9ee72a7d9e84a7a09bdee86dac374c3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetTimeseriesDefinitionRequestMetadataOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestMetadataOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9b3a78ab8eedc2b7adf458c6a7b983b7f5a280850e30caa67861cadf0d808b23)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetAliasName")
    def reset_alias_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAliasName", []))

    @builtins.property
    @jsii.member(jsii_name="aliasNameInput")
    def alias_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aliasNameInput"))

    @builtins.property
    @jsii.member(jsii_name="expressionInput")
    def expression_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "expressionInput"))

    @builtins.property
    @jsii.member(jsii_name="aliasName")
    def alias_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aliasName"))

    @alias_name.setter
    def alias_name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__281b3296570050948f28015b7c7c016a0a1a1f9b05dc6263c373e09c5f658717)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aliasName", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="expression")
    def expression(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "expression"))

    @expression.setter
    def expression(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4ea63df48e04c2e468efb65ebc877c6da6ad869114dbd86df2d95929cb3e8807)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "expression", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTimeseriesDefinitionRequestMetadata]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTimeseriesDefinitionRequestMetadata]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTimeseriesDefinitionRequestMetadata]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a2064f9f3e17e82c03f0bfceb6b58aa0e5de0745b5a1186ae45695b25e4dc2a5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestNetworkQuery",
    jsii_struct_bases=[],
    name_mapping={
        "index": "index",
        "compute_query": "computeQuery",
        "group_by": "groupBy",
        "multi_compute": "multiCompute",
        "search_query": "searchQuery",
    },
)
class PowerpackWidgetTimeseriesDefinitionRequestNetworkQuery:
    def __init__(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union["PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryComputeQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryGroupBy", typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryMultiCompute", typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        if isinstance(compute_query, dict):
            compute_query = PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryComputeQuery(**compute_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__db315b47af8a7a1f85105ed2df45c7fc4e475c85591d830222ff11bb9f449c29)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
            check_type(argname="argument compute_query", value=compute_query, expected_type=type_hints["compute_query"])
            check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
            check_type(argname="argument multi_compute", value=multi_compute, expected_type=type_hints["multi_compute"])
            check_type(argname="argument search_query", value=search_query, expected_type=type_hints["search_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "index": index,
        }
        if compute_query is not None:
            self._values["compute_query"] = compute_query
        if group_by is not None:
            self._values["group_by"] = group_by
        if multi_compute is not None:
            self._values["multi_compute"] = multi_compute
        if search_query is not None:
            self._values["search_query"] = search_query

    @builtins.property
    def index(self) -> builtins.str:
        '''The name of the index to query.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        '''
        result = self._values.get("index")
        assert result is not None, "Required property 'index' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def compute_query(
        self,
    ) -> typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryComputeQuery"]:
        '''compute_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        '''
        result = self._values.get("compute_query")
        return typing.cast(typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryComputeQuery"], result)

    @builtins.property
    def group_by(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryGroupBy"]]]:
        '''group_by block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        '''
        result = self._values.get("group_by")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryGroupBy"]]], result)

    @builtins.property
    def multi_compute(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryMultiCompute"]]]:
        '''multi_compute block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        '''
        result = self._values.get("multi_compute")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryMultiCompute"]]], result)

    @builtins.property
    def search_query(self) -> typing.Optional[builtins.str]:
        '''The search query to use.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        result = self._values.get("search_query")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetTimeseriesDefinitionRequestNetworkQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryComputeQuery",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryComputeQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7ffb1c9531eb1194b96c4b6a8e122cade1b6378e9e6ff902565cf1a52964f709)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryComputeQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryComputeQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryComputeQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4f197a6596234dad31469198f17ad549caea8340b9d0f29849541b37ba0a9be7)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2d1cb9d5ad0b59561de95ed628e0af5e517f8a19fa8eac27aff7a799a17d3a42)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d7cd3d999ed49cb7adce5f80bb0229182e89f33fd67544dd29cd838e44771d97)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__62de95fc9c49faa42ba5ad207dd9fef5d856b37b3f70702393e49e4446c22fc6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryComputeQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryComputeQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__27dfb301e46c4530bc340eb12725f32e024f135686994499fe902b13c1ad777a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryGroupBy",
    jsii_struct_bases=[],
    name_mapping={"facet": "facet", "limit": "limit", "sort_query": "sortQuery"},
)
class PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryGroupBy:
    def __init__(
        self,
        *,
        facet: typing.Optional[builtins.str] = None,
        limit: typing.Optional[jsii.Number] = None,
        sort_query: typing.Optional[typing.Union["PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryGroupBySortQuery", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param limit: The maximum number of items in the group. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param sort_query: sort_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        if isinstance(sort_query, dict):
            sort_query = PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryGroupBySortQuery(**sort_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d31db44e62968f10ea0849bbc7097f091380c2b8ae055159213d53f7f6a7ada3)
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
            check_type(argname="argument sort_query", value=sort_query, expected_type=type_hints["sort_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if facet is not None:
            self._values["facet"] = facet
        if limit is not None:
            self._values["limit"] = limit
        if sort_query is not None:
            self._values["sort_query"] = sort_query

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def limit(self) -> typing.Optional[jsii.Number]:
        '''The maximum number of items in the group.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        '''
        result = self._values.get("limit")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def sort_query(
        self,
    ) -> typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryGroupBySortQuery"]:
        '''sort_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        result = self._values.get("sort_query")
        return typing.cast(typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryGroupBySortQuery"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryGroupBy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryGroupByList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryGroupByList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__49cba8caf6b38a10b2c4e6749f72b7c18fc34b479343001563464fa35a9b457c)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryGroupByOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d1a7c822ed4b23728cf73a725748acdd228e9f665e8416741a9630f826df0df7)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryGroupByOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__99b6250c6d552459fb3893ccc53fbb8542297ef7b10e1a3153c7dd10a6d5c931)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f3a028f55f6f2af46ae19b4aab4ac1966ac875acfcd25760854ba669c8a16c05)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4f8f512a5ae62066953a5fe80ed7609845e9285c8dda71ad39cdf04f9189cf71)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryGroupBy]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryGroupBy]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a8abf72eaa119dbcc291e355d74f021560aceeaed3002675e629d04b9324d61b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryGroupByOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryGroupByOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ac79bfe5a19011e3197d1435347f00ab8a5a02c548fc9ef9585829379ff90e58)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putSortQuery")
    def put_sort_query(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        value = PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryGroupBySortQuery(
            aggregation=aggregation, order=order, facet=facet
        )

        return typing.cast(None, jsii.invoke(self, "putSortQuery", [value]))

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetLimit")
    def reset_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLimit", []))

    @jsii.member(jsii_name="resetSortQuery")
    def reset_sort_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSortQuery", []))

    @builtins.property
    @jsii.member(jsii_name="sortQuery")
    def sort_query(
        self,
    ) -> "PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryGroupBySortQueryOutputReference":
        return typing.cast("PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryGroupBySortQueryOutputReference", jsii.get(self, "sortQuery"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="limitInput")
    def limit_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "limitInput"))

    @builtins.property
    @jsii.member(jsii_name="sortQueryInput")
    def sort_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryGroupBySortQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryGroupBySortQuery"], jsii.get(self, "sortQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__323b60a6e0b2a603b8ccb490c9d2c1438167f49e5e65fa9b56b8fa70e82299d4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="limit")
    def limit(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "limit"))

    @limit.setter
    def limit(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8f8ebb9672077e6dea12fafbe836b5ed2f48328fa7a926a8409adef686b2bafb)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "limit", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryGroupBy]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryGroupBy]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryGroupBy]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e361fed3baa191cda028bf058dd11b472606ef2f2c7dc975c568e82764c7105a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryGroupBySortQuery",
    jsii_struct_bases=[],
    name_mapping={"aggregation": "aggregation", "order": "order", "facet": "facet"},
)
class PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryGroupBySortQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__643744eac577dfc1e9699ae4332d1ccc2b24d74c9cf4f6ae8385790d4d038700)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument order", value=order, expected_type=type_hints["order"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
            "order": order,
        }
        if facet is not None:
            self._values["facet"] = facet

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def order(self) -> builtins.str:
        '''Widget sorting methods. Valid values are ``asc``, ``desc``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        result = self._values.get("order")
        assert result is not None, "Required property 'order' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryGroupBySortQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryGroupBySortQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryGroupBySortQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e57c3fc762e91ee67aed84ff018a445399e0e24c8c5884a29a0b83a4f637867d)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="orderInput")
    def order_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "orderInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d9cb4b9207c86c239d1f77332b3bf0e7d1044505a9435a109b1275b7f809e086)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__95339482c5f2c2d8abb0c26eec7cba91e31567d0d0e18f0fa24c1f843bc1b805)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="order")
    def order(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "order"))

    @order.setter
    def order(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9ef0a64db8679ef78852be1536735ab1bac488b51643513efc405e74fa529be5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "order", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryGroupBySortQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryGroupBySortQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryGroupBySortQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9d963e1b691aacac1677204cbbd1e6e97dc3197a30d45b1ec3535b6f9bd686eb)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryMultiCompute",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryMultiCompute:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a3b6d131cc370df6551ba9e2632d1673cbbf6143f22f461913213a1329e2ea4c)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryMultiCompute(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryMultiComputeList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryMultiComputeList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a772196a659697b2a280477d1a3c9534607e2096fa4b8a08154b4adf9cf9f6ec)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryMultiComputeOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1a41d8d61418cc0157d0b711c7eed476cccc96fcf1ebc6f1ff1797c173127eab)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryMultiComputeOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e008bfc89c02260efbced9f59ac824a90dc2dee3ab77f43376c1ae8bc1a45854)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7c8328d72299d58a81945d9c2e60221fbbaa5b50c201ec979b3f31aa7c2a6fd4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__098baed21d0f6837fdff4efa8c5ddcb4a5b9d682721066eb91a998cbba324597)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryMultiCompute]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryMultiCompute]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__df2c6e489320390b5092e7d4db1fde3dc6634dcf917799da43b03818372b31ae)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryMultiComputeOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryMultiComputeOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__72dca084ff31e3dc4d4e30c07f5d4f0ce8192639cb85ed4ad50a5e9d1db4f0e7)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5de19c0b1a61054e737f74edfa73a26f073d2cdc66333951898127c8798f1bf0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1f2fd29b4e7aaedaf1729963e355f023e187d1a20571f0c66a89f606c097a478)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__855938f082c5b9eb8ea0bf2585f7549a73368d8c11295d6912758332ded5e272)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryMultiCompute]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryMultiCompute]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryMultiCompute]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__28221648204b7aa448b3bd30e275a023c0adebc028e0dbe9953f0840b6f2b6a1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__62bfac1c98383d1d1662dc880e9b5ea90a811415e822964c132ec51d3a6827b0)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putComputeQuery")
    def put_compute_query(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        value = PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryComputeQuery(
            aggregation=aggregation, facet=facet, interval=interval
        )

        return typing.cast(None, jsii.invoke(self, "putComputeQuery", [value]))

    @jsii.member(jsii_name="putGroupBy")
    def put_group_by(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d734df955c13c560cef863f99cc83324b03359d16156918316318dde225b016f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putGroupBy", [value]))

    @jsii.member(jsii_name="putMultiCompute")
    def put_multi_compute(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__39294d1c0448c4ff7a919dd475279aa9f9f421b54329213052707cf259690c44)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putMultiCompute", [value]))

    @jsii.member(jsii_name="resetComputeQuery")
    def reset_compute_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetComputeQuery", []))

    @jsii.member(jsii_name="resetGroupBy")
    def reset_group_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGroupBy", []))

    @jsii.member(jsii_name="resetMultiCompute")
    def reset_multi_compute(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMultiCompute", []))

    @jsii.member(jsii_name="resetSearchQuery")
    def reset_search_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSearchQuery", []))

    @builtins.property
    @jsii.member(jsii_name="computeQuery")
    def compute_query(
        self,
    ) -> PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryComputeQueryOutputReference:
        return typing.cast(PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryComputeQueryOutputReference, jsii.get(self, "computeQuery"))

    @builtins.property
    @jsii.member(jsii_name="groupBy")
    def group_by(
        self,
    ) -> PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryGroupByList:
        return typing.cast(PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryGroupByList, jsii.get(self, "groupBy"))

    @builtins.property
    @jsii.member(jsii_name="multiCompute")
    def multi_compute(
        self,
    ) -> PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryMultiComputeList:
        return typing.cast(PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryMultiComputeList, jsii.get(self, "multiCompute"))

    @builtins.property
    @jsii.member(jsii_name="computeQueryInput")
    def compute_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryComputeQuery], jsii.get(self, "computeQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="groupByInput")
    def group_by_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryGroupBy]]], jsii.get(self, "groupByInput"))

    @builtins.property
    @jsii.member(jsii_name="indexInput")
    def index_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "indexInput"))

    @builtins.property
    @jsii.member(jsii_name="multiComputeInput")
    def multi_compute_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryMultiCompute]]], jsii.get(self, "multiComputeInput"))

    @builtins.property
    @jsii.member(jsii_name="searchQueryInput")
    def search_query_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "searchQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="index")
    def index(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "index"))

    @index.setter
    def index(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c6f8e5b25f9034eff7beb3447d93a35fffc01d946917e5863187ce9f9a3d43a1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "index", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="searchQuery")
    def search_query(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "searchQuery"))

    @search_query.setter
    def search_query(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__62fc2dc618b7d7ca43a6511801c7112a134b1b0d805597fdc85b815fb0718b23)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "searchQuery", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestNetworkQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestNetworkQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestNetworkQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c4f332607909f639bfd9bcdf793827913f7eecbec661a97b4f6dc55c6eb963d9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetTimeseriesDefinitionRequestOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7ba780e4937e6fec5274a49bbcedb533686897bb1fc00f4381402090fe6f7a1c)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putApmQuery")
    def put_apm_query(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestApmQueryComputeQuery, typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestApmQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestApmQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        value = PowerpackWidgetTimeseriesDefinitionRequestApmQuery(
            index=index,
            compute_query=compute_query,
            group_by=group_by,
            multi_compute=multi_compute,
            search_query=search_query,
        )

        return typing.cast(None, jsii.invoke(self, "putApmQuery", [value]))

    @jsii.member(jsii_name="putAuditQuery")
    def put_audit_query(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestAuditQueryComputeQuery, typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestAuditQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestAuditQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        value = PowerpackWidgetTimeseriesDefinitionRequestAuditQuery(
            index=index,
            compute_query=compute_query,
            group_by=group_by,
            multi_compute=multi_compute,
            search_query=search_query,
        )

        return typing.cast(None, jsii.invoke(self, "putAuditQuery", [value]))

    @jsii.member(jsii_name="putFormula")
    def put_formula(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestFormula, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6f78d1aa4c79a19752309a2b53f84462d303da0ed99dd048af759b73a5bd2acf)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putFormula", [value]))

    @jsii.member(jsii_name="putLogQuery")
    def put_log_query(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestLogQueryComputeQuery, typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestLogQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestLogQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        value = PowerpackWidgetTimeseriesDefinitionRequestLogQuery(
            index=index,
            compute_query=compute_query,
            group_by=group_by,
            multi_compute=multi_compute,
            search_query=search_query,
        )

        return typing.cast(None, jsii.invoke(self, "putLogQuery", [value]))

    @jsii.member(jsii_name="putMetadata")
    def put_metadata(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestMetadata, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5b5f0bb7d8ffdbf8784e3cee813d575f6098b8ba8febe947e8ed2005f14218c4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putMetadata", [value]))

    @jsii.member(jsii_name="putNetworkQuery")
    def put_network_query(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryComputeQuery, typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        value = PowerpackWidgetTimeseriesDefinitionRequestNetworkQuery(
            index=index,
            compute_query=compute_query,
            group_by=group_by,
            multi_compute=multi_compute,
            search_query=search_query,
        )

        return typing.cast(None, jsii.invoke(self, "putNetworkQuery", [value]))

    @jsii.member(jsii_name="putProcessQuery")
    def put_process_query(
        self,
        *,
        metric: builtins.str,
        filter_by: typing.Optional[typing.Sequence[builtins.str]] = None,
        limit: typing.Optional[jsii.Number] = None,
        search_by: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param metric: Your chosen metric. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        :param filter_by: A list of processes. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#filter_by Powerpack#filter_by}
        :param limit: The max number of items in the filter list. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param search_by: Your chosen search term. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_by Powerpack#search_by}
        '''
        value = PowerpackWidgetTimeseriesDefinitionRequestProcessQuery(
            metric=metric, filter_by=filter_by, limit=limit, search_by=search_by
        )

        return typing.cast(None, jsii.invoke(self, "putProcessQuery", [value]))

    @jsii.member(jsii_name="putQuery")
    def put_query(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetTimeseriesDefinitionRequestQuery", typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f206091f9693165ce966ee5340f207592e5b804246dba9c35491fab0ad9f7a5d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putQuery", [value]))

    @jsii.member(jsii_name="putRumQuery")
    def put_rum_query(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union["PowerpackWidgetTimeseriesDefinitionRequestRumQueryComputeQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetTimeseriesDefinitionRequestRumQueryGroupBy", typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetTimeseriesDefinitionRequestRumQueryMultiCompute", typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        value = PowerpackWidgetTimeseriesDefinitionRequestRumQuery(
            index=index,
            compute_query=compute_query,
            group_by=group_by,
            multi_compute=multi_compute,
            search_query=search_query,
        )

        return typing.cast(None, jsii.invoke(self, "putRumQuery", [value]))

    @jsii.member(jsii_name="putSecurityQuery")
    def put_security_query(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union["PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryComputeQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryGroupBy", typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryMultiCompute", typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        value = PowerpackWidgetTimeseriesDefinitionRequestSecurityQuery(
            index=index,
            compute_query=compute_query,
            group_by=group_by,
            multi_compute=multi_compute,
            search_query=search_query,
        )

        return typing.cast(None, jsii.invoke(self, "putSecurityQuery", [value]))

    @jsii.member(jsii_name="putStyle")
    def put_style(
        self,
        *,
        line_type: typing.Optional[builtins.str] = None,
        line_width: typing.Optional[builtins.str] = None,
        palette: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param line_type: The type of lines displayed. Valid values are ``dashed``, ``dotted``, ``solid``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#line_type Powerpack#line_type}
        :param line_width: The width of line displayed. Valid values are ``normal``, ``thick``, ``thin``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#line_width Powerpack#line_width}
        :param palette: A color palette to apply to the widget. The available options are available at: https://docs.datadoghq.com/dashboards/widgets/timeseries/#appearance. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette Powerpack#palette}
        '''
        value = PowerpackWidgetTimeseriesDefinitionRequestStyle(
            line_type=line_type, line_width=line_width, palette=palette
        )

        return typing.cast(None, jsii.invoke(self, "putStyle", [value]))

    @jsii.member(jsii_name="resetApmQuery")
    def reset_apm_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetApmQuery", []))

    @jsii.member(jsii_name="resetAuditQuery")
    def reset_audit_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAuditQuery", []))

    @jsii.member(jsii_name="resetDisplayType")
    def reset_display_type(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDisplayType", []))

    @jsii.member(jsii_name="resetFormula")
    def reset_formula(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFormula", []))

    @jsii.member(jsii_name="resetLogQuery")
    def reset_log_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLogQuery", []))

    @jsii.member(jsii_name="resetMetadata")
    def reset_metadata(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMetadata", []))

    @jsii.member(jsii_name="resetNetworkQuery")
    def reset_network_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetNetworkQuery", []))

    @jsii.member(jsii_name="resetOnRightYaxis")
    def reset_on_right_yaxis(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetOnRightYaxis", []))

    @jsii.member(jsii_name="resetProcessQuery")
    def reset_process_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetProcessQuery", []))

    @jsii.member(jsii_name="resetQ")
    def reset_q(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetQ", []))

    @jsii.member(jsii_name="resetQuery")
    def reset_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetQuery", []))

    @jsii.member(jsii_name="resetRumQuery")
    def reset_rum_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetRumQuery", []))

    @jsii.member(jsii_name="resetSecurityQuery")
    def reset_security_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSecurityQuery", []))

    @jsii.member(jsii_name="resetStyle")
    def reset_style(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetStyle", []))

    @builtins.property
    @jsii.member(jsii_name="apmQuery")
    def apm_query(
        self,
    ) -> PowerpackWidgetTimeseriesDefinitionRequestApmQueryOutputReference:
        return typing.cast(PowerpackWidgetTimeseriesDefinitionRequestApmQueryOutputReference, jsii.get(self, "apmQuery"))

    @builtins.property
    @jsii.member(jsii_name="auditQuery")
    def audit_query(
        self,
    ) -> PowerpackWidgetTimeseriesDefinitionRequestAuditQueryOutputReference:
        return typing.cast(PowerpackWidgetTimeseriesDefinitionRequestAuditQueryOutputReference, jsii.get(self, "auditQuery"))

    @builtins.property
    @jsii.member(jsii_name="formula")
    def formula(self) -> PowerpackWidgetTimeseriesDefinitionRequestFormulaList:
        return typing.cast(PowerpackWidgetTimeseriesDefinitionRequestFormulaList, jsii.get(self, "formula"))

    @builtins.property
    @jsii.member(jsii_name="logQuery")
    def log_query(
        self,
    ) -> PowerpackWidgetTimeseriesDefinitionRequestLogQueryOutputReference:
        return typing.cast(PowerpackWidgetTimeseriesDefinitionRequestLogQueryOutputReference, jsii.get(self, "logQuery"))

    @builtins.property
    @jsii.member(jsii_name="metadata")
    def metadata(self) -> PowerpackWidgetTimeseriesDefinitionRequestMetadataList:
        return typing.cast(PowerpackWidgetTimeseriesDefinitionRequestMetadataList, jsii.get(self, "metadata"))

    @builtins.property
    @jsii.member(jsii_name="networkQuery")
    def network_query(
        self,
    ) -> PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryOutputReference:
        return typing.cast(PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryOutputReference, jsii.get(self, "networkQuery"))

    @builtins.property
    @jsii.member(jsii_name="processQuery")
    def process_query(
        self,
    ) -> "PowerpackWidgetTimeseriesDefinitionRequestProcessQueryOutputReference":
        return typing.cast("PowerpackWidgetTimeseriesDefinitionRequestProcessQueryOutputReference", jsii.get(self, "processQuery"))

    @builtins.property
    @jsii.member(jsii_name="query")
    def query(self) -> "PowerpackWidgetTimeseriesDefinitionRequestQueryList":
        return typing.cast("PowerpackWidgetTimeseriesDefinitionRequestQueryList", jsii.get(self, "query"))

    @builtins.property
    @jsii.member(jsii_name="rumQuery")
    def rum_query(
        self,
    ) -> "PowerpackWidgetTimeseriesDefinitionRequestRumQueryOutputReference":
        return typing.cast("PowerpackWidgetTimeseriesDefinitionRequestRumQueryOutputReference", jsii.get(self, "rumQuery"))

    @builtins.property
    @jsii.member(jsii_name="securityQuery")
    def security_query(
        self,
    ) -> "PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryOutputReference":
        return typing.cast("PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryOutputReference", jsii.get(self, "securityQuery"))

    @builtins.property
    @jsii.member(jsii_name="style")
    def style(self) -> "PowerpackWidgetTimeseriesDefinitionRequestStyleOutputReference":
        return typing.cast("PowerpackWidgetTimeseriesDefinitionRequestStyleOutputReference", jsii.get(self, "style"))

    @builtins.property
    @jsii.member(jsii_name="apmQueryInput")
    def apm_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestApmQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestApmQuery], jsii.get(self, "apmQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="auditQueryInput")
    def audit_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestAuditQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestAuditQuery], jsii.get(self, "auditQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="displayTypeInput")
    def display_type_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "displayTypeInput"))

    @builtins.property
    @jsii.member(jsii_name="formulaInput")
    def formula_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestFormula]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestFormula]]], jsii.get(self, "formulaInput"))

    @builtins.property
    @jsii.member(jsii_name="logQueryInput")
    def log_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestLogQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestLogQuery], jsii.get(self, "logQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="metadataInput")
    def metadata_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestMetadata]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestMetadata]]], jsii.get(self, "metadataInput"))

    @builtins.property
    @jsii.member(jsii_name="networkQueryInput")
    def network_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestNetworkQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestNetworkQuery], jsii.get(self, "networkQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="onRightYaxisInput")
    def on_right_yaxis_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "onRightYaxisInput"))

    @builtins.property
    @jsii.member(jsii_name="processQueryInput")
    def process_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestProcessQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestProcessQuery"], jsii.get(self, "processQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="qInput")
    def q_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "qInput"))

    @builtins.property
    @jsii.member(jsii_name="queryInput")
    def query_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetTimeseriesDefinitionRequestQuery"]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetTimeseriesDefinitionRequestQuery"]]], jsii.get(self, "queryInput"))

    @builtins.property
    @jsii.member(jsii_name="rumQueryInput")
    def rum_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestRumQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestRumQuery"], jsii.get(self, "rumQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="securityQueryInput")
    def security_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestSecurityQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestSecurityQuery"], jsii.get(self, "securityQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="styleInput")
    def style_input(
        self,
    ) -> typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestStyle"]:
        return typing.cast(typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestStyle"], jsii.get(self, "styleInput"))

    @builtins.property
    @jsii.member(jsii_name="displayType")
    def display_type(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "displayType"))

    @display_type.setter
    def display_type(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__33b36199dbe83047bf7556ecd336eb7169c19aca3f5b1c4d01eeb6cdaf8f0a08)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "displayType", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="onRightYaxis")
    def on_right_yaxis(
        self,
    ) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "onRightYaxis"))

    @on_right_yaxis.setter
    def on_right_yaxis(
        self,
        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c0d1e1259b648c7b5c3450c202c381cb6ac8952e4b22eeafd5a01d82e28e14bb)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "onRightYaxis", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="q")
    def q(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "q"))

    @q.setter
    def q(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1c6f85de59c76da0e8bdbe0c37c5f256008d79b34bd833d04578c6aa51b52ae7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "q", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTimeseriesDefinitionRequest]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTimeseriesDefinitionRequest]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTimeseriesDefinitionRequest]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__53dc7ec96ccf71d1137afc953e1d134f509cc0ac3138c2630489b4cf92105967)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestProcessQuery",
    jsii_struct_bases=[],
    name_mapping={
        "metric": "metric",
        "filter_by": "filterBy",
        "limit": "limit",
        "search_by": "searchBy",
    },
)
class PowerpackWidgetTimeseriesDefinitionRequestProcessQuery:
    def __init__(
        self,
        *,
        metric: builtins.str,
        filter_by: typing.Optional[typing.Sequence[builtins.str]] = None,
        limit: typing.Optional[jsii.Number] = None,
        search_by: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param metric: Your chosen metric. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        :param filter_by: A list of processes. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#filter_by Powerpack#filter_by}
        :param limit: The max number of items in the filter list. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param search_by: Your chosen search term. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_by Powerpack#search_by}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2f199fc7a58dcafd5bf6edb7f0cb3a80f7cfc16ff7d50b0db5d48850aaaefe74)
            check_type(argname="argument metric", value=metric, expected_type=type_hints["metric"])
            check_type(argname="argument filter_by", value=filter_by, expected_type=type_hints["filter_by"])
            check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
            check_type(argname="argument search_by", value=search_by, expected_type=type_hints["search_by"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "metric": metric,
        }
        if filter_by is not None:
            self._values["filter_by"] = filter_by
        if limit is not None:
            self._values["limit"] = limit
        if search_by is not None:
            self._values["search_by"] = search_by

    @builtins.property
    def metric(self) -> builtins.str:
        '''Your chosen metric.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        '''
        result = self._values.get("metric")
        assert result is not None, "Required property 'metric' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def filter_by(self) -> typing.Optional[typing.List[builtins.str]]:
        '''A list of processes.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#filter_by Powerpack#filter_by}
        '''
        result = self._values.get("filter_by")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def limit(self) -> typing.Optional[jsii.Number]:
        '''The max number of items in the filter list.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        '''
        result = self._values.get("limit")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def search_by(self) -> typing.Optional[builtins.str]:
        '''Your chosen search term.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_by Powerpack#search_by}
        '''
        result = self._values.get("search_by")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetTimeseriesDefinitionRequestProcessQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetTimeseriesDefinitionRequestProcessQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestProcessQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0719ca38e6cca84a6c661e632a0739dbc4c42b77e46f60f50e4d97dac2f28932)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFilterBy")
    def reset_filter_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFilterBy", []))

    @jsii.member(jsii_name="resetLimit")
    def reset_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLimit", []))

    @jsii.member(jsii_name="resetSearchBy")
    def reset_search_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSearchBy", []))

    @builtins.property
    @jsii.member(jsii_name="filterByInput")
    def filter_by_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "filterByInput"))

    @builtins.property
    @jsii.member(jsii_name="limitInput")
    def limit_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "limitInput"))

    @builtins.property
    @jsii.member(jsii_name="metricInput")
    def metric_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "metricInput"))

    @builtins.property
    @jsii.member(jsii_name="searchByInput")
    def search_by_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "searchByInput"))

    @builtins.property
    @jsii.member(jsii_name="filterBy")
    def filter_by(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "filterBy"))

    @filter_by.setter
    def filter_by(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ff726fba186e60133e648e52e5cfa38e284be64b5a7a16e1c01e105474979088)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "filterBy", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="limit")
    def limit(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "limit"))

    @limit.setter
    def limit(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__57c763b2bd87ed8246725907c1911cc7f1a3d75a6c4f21a6983f0e7541fd625c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "limit", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="metric")
    def metric(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "metric"))

    @metric.setter
    def metric(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__05656f026dbfdbef64ab8d0f6a71f3ae8af1976e74e503eabec6ff9c34717006)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "metric", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="searchBy")
    def search_by(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "searchBy"))

    @search_by.setter
    def search_by(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__10805b90d89178bc1e1a5853658e6a6e47da117847b6b1a8631fb3c8b3c41b61)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "searchBy", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestProcessQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestProcessQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestProcessQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b6cdb06df284de6b28bf2876b1d1a9877b120340465b2d4139624efc158b12b6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestQuery",
    jsii_struct_bases=[],
    name_mapping={
        "apm_dependency_stats_query": "apmDependencyStatsQuery",
        "apm_resource_stats_query": "apmResourceStatsQuery",
        "cloud_cost_query": "cloudCostQuery",
        "event_query": "eventQuery",
        "metric_query": "metricQuery",
        "process_query": "processQuery",
        "slo_query": "sloQuery",
    },
)
class PowerpackWidgetTimeseriesDefinitionRequestQuery:
    def __init__(
        self,
        *,
        apm_dependency_stats_query: typing.Optional[typing.Union["PowerpackWidgetTimeseriesDefinitionRequestQueryApmDependencyStatsQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        apm_resource_stats_query: typing.Optional[typing.Union["PowerpackWidgetTimeseriesDefinitionRequestQueryApmResourceStatsQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        cloud_cost_query: typing.Optional[typing.Union["PowerpackWidgetTimeseriesDefinitionRequestQueryCloudCostQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        event_query: typing.Optional[typing.Union["PowerpackWidgetTimeseriesDefinitionRequestQueryEventQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        metric_query: typing.Optional[typing.Union["PowerpackWidgetTimeseriesDefinitionRequestQueryMetricQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        process_query: typing.Optional[typing.Union["PowerpackWidgetTimeseriesDefinitionRequestQueryProcessQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        slo_query: typing.Optional[typing.Union["PowerpackWidgetTimeseriesDefinitionRequestQuerySloQuery", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param apm_dependency_stats_query: apm_dependency_stats_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#apm_dependency_stats_query Powerpack#apm_dependency_stats_query}
        :param apm_resource_stats_query: apm_resource_stats_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#apm_resource_stats_query Powerpack#apm_resource_stats_query}
        :param cloud_cost_query: cloud_cost_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cloud_cost_query Powerpack#cloud_cost_query}
        :param event_query: event_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#event_query Powerpack#event_query}
        :param metric_query: metric_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric_query Powerpack#metric_query}
        :param process_query: process_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#process_query Powerpack#process_query}
        :param slo_query: slo_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#slo_query Powerpack#slo_query}
        '''
        if isinstance(apm_dependency_stats_query, dict):
            apm_dependency_stats_query = PowerpackWidgetTimeseriesDefinitionRequestQueryApmDependencyStatsQuery(**apm_dependency_stats_query)
        if isinstance(apm_resource_stats_query, dict):
            apm_resource_stats_query = PowerpackWidgetTimeseriesDefinitionRequestQueryApmResourceStatsQuery(**apm_resource_stats_query)
        if isinstance(cloud_cost_query, dict):
            cloud_cost_query = PowerpackWidgetTimeseriesDefinitionRequestQueryCloudCostQuery(**cloud_cost_query)
        if isinstance(event_query, dict):
            event_query = PowerpackWidgetTimeseriesDefinitionRequestQueryEventQuery(**event_query)
        if isinstance(metric_query, dict):
            metric_query = PowerpackWidgetTimeseriesDefinitionRequestQueryMetricQuery(**metric_query)
        if isinstance(process_query, dict):
            process_query = PowerpackWidgetTimeseriesDefinitionRequestQueryProcessQuery(**process_query)
        if isinstance(slo_query, dict):
            slo_query = PowerpackWidgetTimeseriesDefinitionRequestQuerySloQuery(**slo_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__583205c621acfee22b30891d3dd7903789381c55d5440ce772dad06776e08bd0)
            check_type(argname="argument apm_dependency_stats_query", value=apm_dependency_stats_query, expected_type=type_hints["apm_dependency_stats_query"])
            check_type(argname="argument apm_resource_stats_query", value=apm_resource_stats_query, expected_type=type_hints["apm_resource_stats_query"])
            check_type(argname="argument cloud_cost_query", value=cloud_cost_query, expected_type=type_hints["cloud_cost_query"])
            check_type(argname="argument event_query", value=event_query, expected_type=type_hints["event_query"])
            check_type(argname="argument metric_query", value=metric_query, expected_type=type_hints["metric_query"])
            check_type(argname="argument process_query", value=process_query, expected_type=type_hints["process_query"])
            check_type(argname="argument slo_query", value=slo_query, expected_type=type_hints["slo_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if apm_dependency_stats_query is not None:
            self._values["apm_dependency_stats_query"] = apm_dependency_stats_query
        if apm_resource_stats_query is not None:
            self._values["apm_resource_stats_query"] = apm_resource_stats_query
        if cloud_cost_query is not None:
            self._values["cloud_cost_query"] = cloud_cost_query
        if event_query is not None:
            self._values["event_query"] = event_query
        if metric_query is not None:
            self._values["metric_query"] = metric_query
        if process_query is not None:
            self._values["process_query"] = process_query
        if slo_query is not None:
            self._values["slo_query"] = slo_query

    @builtins.property
    def apm_dependency_stats_query(
        self,
    ) -> typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestQueryApmDependencyStatsQuery"]:
        '''apm_dependency_stats_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#apm_dependency_stats_query Powerpack#apm_dependency_stats_query}
        '''
        result = self._values.get("apm_dependency_stats_query")
        return typing.cast(typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestQueryApmDependencyStatsQuery"], result)

    @builtins.property
    def apm_resource_stats_query(
        self,
    ) -> typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestQueryApmResourceStatsQuery"]:
        '''apm_resource_stats_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#apm_resource_stats_query Powerpack#apm_resource_stats_query}
        '''
        result = self._values.get("apm_resource_stats_query")
        return typing.cast(typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestQueryApmResourceStatsQuery"], result)

    @builtins.property
    def cloud_cost_query(
        self,
    ) -> typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestQueryCloudCostQuery"]:
        '''cloud_cost_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cloud_cost_query Powerpack#cloud_cost_query}
        '''
        result = self._values.get("cloud_cost_query")
        return typing.cast(typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestQueryCloudCostQuery"], result)

    @builtins.property
    def event_query(
        self,
    ) -> typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestQueryEventQuery"]:
        '''event_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#event_query Powerpack#event_query}
        '''
        result = self._values.get("event_query")
        return typing.cast(typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestQueryEventQuery"], result)

    @builtins.property
    def metric_query(
        self,
    ) -> typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestQueryMetricQuery"]:
        '''metric_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric_query Powerpack#metric_query}
        '''
        result = self._values.get("metric_query")
        return typing.cast(typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestQueryMetricQuery"], result)

    @builtins.property
    def process_query(
        self,
    ) -> typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestQueryProcessQuery"]:
        '''process_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#process_query Powerpack#process_query}
        '''
        result = self._values.get("process_query")
        return typing.cast(typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestQueryProcessQuery"], result)

    @builtins.property
    def slo_query(
        self,
    ) -> typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestQuerySloQuery"]:
        '''slo_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#slo_query Powerpack#slo_query}
        '''
        result = self._values.get("slo_query")
        return typing.cast(typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestQuerySloQuery"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetTimeseriesDefinitionRequestQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestQueryApmDependencyStatsQuery",
    jsii_struct_bases=[],
    name_mapping={
        "data_source": "dataSource",
        "env": "env",
        "name": "name",
        "operation_name": "operationName",
        "resource_name": "resourceName",
        "service": "service",
        "stat": "stat",
        "cross_org_uuids": "crossOrgUuids",
        "is_upstream": "isUpstream",
        "primary_tag_name": "primaryTagName",
        "primary_tag_value": "primaryTagValue",
    },
)
class PowerpackWidgetTimeseriesDefinitionRequestQueryApmDependencyStatsQuery:
    def __init__(
        self,
        *,
        data_source: builtins.str,
        env: builtins.str,
        name: builtins.str,
        operation_name: builtins.str,
        resource_name: builtins.str,
        service: builtins.str,
        stat: builtins.str,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        is_upstream: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        primary_tag_name: typing.Optional[builtins.str] = None,
        primary_tag_value: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param data_source: The data source for APM Dependency Stats queries. Valid values are ``apm_dependency_stats``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param env: APM environment. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#env Powerpack#env}
        :param name: The name of query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param operation_name: Name of operation on service. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#operation_name Powerpack#operation_name}
        :param resource_name: APM resource. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#resource_name Powerpack#resource_name}
        :param service: APM service. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#service Powerpack#service}
        :param stat: APM statistic. Valid values are ``avg_duration``, ``avg_root_duration``, ``avg_spans_per_trace``, ``error_rate``, ``pct_exec_time``, ``pct_of_traces``, ``total_traces_count``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#stat Powerpack#stat}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param is_upstream: Determines whether stats for upstream or downstream dependencies should be queried. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#is_upstream Powerpack#is_upstream}
        :param primary_tag_name: The name of the second primary tag used within APM; required when ``primary_tag_value`` is specified. See https://docs.datadoghq.com/tracing/guide/setting_primary_tags_to_scope/#add-a-second-primary-tag-in-datadog. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_name Powerpack#primary_tag_name}
        :param primary_tag_value: Filter APM data by the second primary tag. ``primary_tag_name`` must also be specified. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_value Powerpack#primary_tag_value}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__328a3d7bfb2c37b6652b7aca13648d7eaafc7f39e6a3d9606cb9a4540b847238)
            check_type(argname="argument data_source", value=data_source, expected_type=type_hints["data_source"])
            check_type(argname="argument env", value=env, expected_type=type_hints["env"])
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument operation_name", value=operation_name, expected_type=type_hints["operation_name"])
            check_type(argname="argument resource_name", value=resource_name, expected_type=type_hints["resource_name"])
            check_type(argname="argument service", value=service, expected_type=type_hints["service"])
            check_type(argname="argument stat", value=stat, expected_type=type_hints["stat"])
            check_type(argname="argument cross_org_uuids", value=cross_org_uuids, expected_type=type_hints["cross_org_uuids"])
            check_type(argname="argument is_upstream", value=is_upstream, expected_type=type_hints["is_upstream"])
            check_type(argname="argument primary_tag_name", value=primary_tag_name, expected_type=type_hints["primary_tag_name"])
            check_type(argname="argument primary_tag_value", value=primary_tag_value, expected_type=type_hints["primary_tag_value"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "data_source": data_source,
            "env": env,
            "name": name,
            "operation_name": operation_name,
            "resource_name": resource_name,
            "service": service,
            "stat": stat,
        }
        if cross_org_uuids is not None:
            self._values["cross_org_uuids"] = cross_org_uuids
        if is_upstream is not None:
            self._values["is_upstream"] = is_upstream
        if primary_tag_name is not None:
            self._values["primary_tag_name"] = primary_tag_name
        if primary_tag_value is not None:
            self._values["primary_tag_value"] = primary_tag_value

    @builtins.property
    def data_source(self) -> builtins.str:
        '''The data source for APM Dependency Stats queries. Valid values are ``apm_dependency_stats``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        '''
        result = self._values.get("data_source")
        assert result is not None, "Required property 'data_source' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def env(self) -> builtins.str:
        '''APM environment.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#env Powerpack#env}
        '''
        result = self._values.get("env")
        assert result is not None, "Required property 'env' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def name(self) -> builtins.str:
        '''The name of query for use in formulas.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        '''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def operation_name(self) -> builtins.str:
        '''Name of operation on service.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#operation_name Powerpack#operation_name}
        '''
        result = self._values.get("operation_name")
        assert result is not None, "Required property 'operation_name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def resource_name(self) -> builtins.str:
        '''APM resource.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#resource_name Powerpack#resource_name}
        '''
        result = self._values.get("resource_name")
        assert result is not None, "Required property 'resource_name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def service(self) -> builtins.str:
        '''APM service.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#service Powerpack#service}
        '''
        result = self._values.get("service")
        assert result is not None, "Required property 'service' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def stat(self) -> builtins.str:
        '''APM statistic. Valid values are ``avg_duration``, ``avg_root_duration``, ``avg_spans_per_trace``, ``error_rate``, ``pct_exec_time``, ``pct_of_traces``, ``total_traces_count``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#stat Powerpack#stat}
        '''
        result = self._values.get("stat")
        assert result is not None, "Required property 'stat' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def cross_org_uuids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''The source organization UUID for cross organization queries. Feature in Private Beta.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        '''
        result = self._values.get("cross_org_uuids")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def is_upstream(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        '''Determines whether stats for upstream or downstream dependencies should be queried.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#is_upstream Powerpack#is_upstream}
        '''
        result = self._values.get("is_upstream")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)

    @builtins.property
    def primary_tag_name(self) -> typing.Optional[builtins.str]:
        '''The name of the second primary tag used within APM; required when ``primary_tag_value`` is specified. See https://docs.datadoghq.com/tracing/guide/setting_primary_tags_to_scope/#add-a-second-primary-tag-in-datadog.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_name Powerpack#primary_tag_name}
        '''
        result = self._values.get("primary_tag_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def primary_tag_value(self) -> typing.Optional[builtins.str]:
        '''Filter APM data by the second primary tag. ``primary_tag_name`` must also be specified.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_value Powerpack#primary_tag_value}
        '''
        result = self._values.get("primary_tag_value")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetTimeseriesDefinitionRequestQueryApmDependencyStatsQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetTimeseriesDefinitionRequestQueryApmDependencyStatsQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestQueryApmDependencyStatsQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5365260b71983ad6fa95545e915a8bb3d3353d6c5402d1eebe45126761d0d673)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetCrossOrgUuids")
    def reset_cross_org_uuids(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCrossOrgUuids", []))

    @jsii.member(jsii_name="resetIsUpstream")
    def reset_is_upstream(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetIsUpstream", []))

    @jsii.member(jsii_name="resetPrimaryTagName")
    def reset_primary_tag_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPrimaryTagName", []))

    @jsii.member(jsii_name="resetPrimaryTagValue")
    def reset_primary_tag_value(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPrimaryTagValue", []))

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuidsInput")
    def cross_org_uuids_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "crossOrgUuidsInput"))

    @builtins.property
    @jsii.member(jsii_name="dataSourceInput")
    def data_source_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "dataSourceInput"))

    @builtins.property
    @jsii.member(jsii_name="envInput")
    def env_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "envInput"))

    @builtins.property
    @jsii.member(jsii_name="isUpstreamInput")
    def is_upstream_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "isUpstreamInput"))

    @builtins.property
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property
    @jsii.member(jsii_name="operationNameInput")
    def operation_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "operationNameInput"))

    @builtins.property
    @jsii.member(jsii_name="primaryTagNameInput")
    def primary_tag_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "primaryTagNameInput"))

    @builtins.property
    @jsii.member(jsii_name="primaryTagValueInput")
    def primary_tag_value_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "primaryTagValueInput"))

    @builtins.property
    @jsii.member(jsii_name="resourceNameInput")
    def resource_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "resourceNameInput"))

    @builtins.property
    @jsii.member(jsii_name="serviceInput")
    def service_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "serviceInput"))

    @builtins.property
    @jsii.member(jsii_name="statInput")
    def stat_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "statInput"))

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuids")
    def cross_org_uuids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "crossOrgUuids"))

    @cross_org_uuids.setter
    def cross_org_uuids(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__919bdd0eff6d5ae3cb1da541e9e8cae9b392848b43d67414dd4a8ff3b5541f2f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "crossOrgUuids", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="dataSource")
    def data_source(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "dataSource"))

    @data_source.setter
    def data_source(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a20e32b855fe2ef717912e176e4803a100e58d55c6a0f745f9763309cdb4fa6b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "dataSource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="env")
    def env(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "env"))

    @env.setter
    def env(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__274e04c8d6bc61fa836910c31f718221ceab2b393c675c2d19eb21570aaf4f34)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "env", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="isUpstream")
    def is_upstream(self) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "isUpstream"))

    @is_upstream.setter
    def is_upstream(
        self,
        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9ba78c06461313989650a24718bf261b511bd31b713e85572d685fcbefbdb5a6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "isUpstream", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ad80098a82deb65c004f3e7dcf71988509f217d6ef5e9f57cc318e349601555b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "name", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="operationName")
    def operation_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "operationName"))

    @operation_name.setter
    def operation_name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__474aefd9578cdc4f4716147aa5269aa6b24296841229f1b2500abf642301b0f3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "operationName", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="primaryTagName")
    def primary_tag_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "primaryTagName"))

    @primary_tag_name.setter
    def primary_tag_name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3d825ba27e8b3dd5820605eaf0fad3cac251de7c2f5452c6eadc547ac14e2464)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "primaryTagName", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="primaryTagValue")
    def primary_tag_value(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "primaryTagValue"))

    @primary_tag_value.setter
    def primary_tag_value(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e1130609e8509369473c5ce8c35fe79e0784dce74baa382ca4d247d31ec0d59a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "primaryTagValue", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="resourceName")
    def resource_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "resourceName"))

    @resource_name.setter
    def resource_name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__642b74ee10536c54e1c414324ccdf4bd892de811e03be1e275667fe953205e17)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "resourceName", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="service")
    def service(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "service"))

    @service.setter
    def service(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c6362095944a813b8a722f51058647e46dadef3eb661772c04d7306c902d3acb)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "service", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="stat")
    def stat(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "stat"))

    @stat.setter
    def stat(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__aaa7cbbe5b9f35df3926a2e976f0c582a4ff9b6fcd2fbb8eeb6d06c352f4b8aa)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "stat", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestQueryApmDependencyStatsQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestQueryApmDependencyStatsQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestQueryApmDependencyStatsQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__048347471d676fd26c055cb1c6ec0d7b2109df2fbe062ec65b0b1fb05f96f627)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestQueryApmResourceStatsQuery",
    jsii_struct_bases=[],
    name_mapping={
        "data_source": "dataSource",
        "env": "env",
        "name": "name",
        "service": "service",
        "stat": "stat",
        "cross_org_uuids": "crossOrgUuids",
        "group_by": "groupBy",
        "operation_name": "operationName",
        "primary_tag_name": "primaryTagName",
        "primary_tag_value": "primaryTagValue",
        "resource_name": "resourceName",
    },
)
class PowerpackWidgetTimeseriesDefinitionRequestQueryApmResourceStatsQuery:
    def __init__(
        self,
        *,
        data_source: builtins.str,
        env: builtins.str,
        name: builtins.str,
        service: builtins.str,
        stat: builtins.str,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        group_by: typing.Optional[typing.Sequence[builtins.str]] = None,
        operation_name: typing.Optional[builtins.str] = None,
        primary_tag_name: typing.Optional[builtins.str] = None,
        primary_tag_value: typing.Optional[builtins.str] = None,
        resource_name: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param data_source: The data source for APM Resource Stats queries. Valid values are ``apm_resource_stats``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param env: APM environment. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#env Powerpack#env}
        :param name: The name of query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param service: APM service. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#service Powerpack#service}
        :param stat: APM statistic. Valid values are ``errors``, ``error_rate``, ``hits``, ``latency_avg``, ``latency_distribution``, ``latency_max``, ``latency_p50``, ``latency_p75``, ``latency_p90``, ``latency_p95``, ``latency_p99``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#stat Powerpack#stat}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param group_by: Array of fields to group results by. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param operation_name: Name of operation on service. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#operation_name Powerpack#operation_name}
        :param primary_tag_name: The name of the second primary tag used within APM; required when ``primary_tag_value`` is specified. See https://docs.datadoghq.com/tracing/guide/setting_primary_tags_to_scope/#add-a-second-primary-tag-in-datadog. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_name Powerpack#primary_tag_name}
        :param primary_tag_value: Filter APM data by the second primary tag. ``primary_tag_name`` must also be specified. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_value Powerpack#primary_tag_value}
        :param resource_name: APM resource. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#resource_name Powerpack#resource_name}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2d33e958a7bf0ccf01f6ab0c926e10acb53eada3a8f0c83021e3494bf2c03e73)
            check_type(argname="argument data_source", value=data_source, expected_type=type_hints["data_source"])
            check_type(argname="argument env", value=env, expected_type=type_hints["env"])
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument service", value=service, expected_type=type_hints["service"])
            check_type(argname="argument stat", value=stat, expected_type=type_hints["stat"])
            check_type(argname="argument cross_org_uuids", value=cross_org_uuids, expected_type=type_hints["cross_org_uuids"])
            check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
            check_type(argname="argument operation_name", value=operation_name, expected_type=type_hints["operation_name"])
            check_type(argname="argument primary_tag_name", value=primary_tag_name, expected_type=type_hints["primary_tag_name"])
            check_type(argname="argument primary_tag_value", value=primary_tag_value, expected_type=type_hints["primary_tag_value"])
            check_type(argname="argument resource_name", value=resource_name, expected_type=type_hints["resource_name"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "data_source": data_source,
            "env": env,
            "name": name,
            "service": service,
            "stat": stat,
        }
        if cross_org_uuids is not None:
            self._values["cross_org_uuids"] = cross_org_uuids
        if group_by is not None:
            self._values["group_by"] = group_by
        if operation_name is not None:
            self._values["operation_name"] = operation_name
        if primary_tag_name is not None:
            self._values["primary_tag_name"] = primary_tag_name
        if primary_tag_value is not None:
            self._values["primary_tag_value"] = primary_tag_value
        if resource_name is not None:
            self._values["resource_name"] = resource_name

    @builtins.property
    def data_source(self) -> builtins.str:
        '''The data source for APM Resource Stats queries. Valid values are ``apm_resource_stats``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        '''
        result = self._values.get("data_source")
        assert result is not None, "Required property 'data_source' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def env(self) -> builtins.str:
        '''APM environment.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#env Powerpack#env}
        '''
        result = self._values.get("env")
        assert result is not None, "Required property 'env' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def name(self) -> builtins.str:
        '''The name of query for use in formulas.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        '''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def service(self) -> builtins.str:
        '''APM service.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#service Powerpack#service}
        '''
        result = self._values.get("service")
        assert result is not None, "Required property 'service' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def stat(self) -> builtins.str:
        '''APM statistic. Valid values are ``errors``, ``error_rate``, ``hits``, ``latency_avg``, ``latency_distribution``, ``latency_max``, ``latency_p50``, ``latency_p75``, ``latency_p90``, ``latency_p95``, ``latency_p99``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#stat Powerpack#stat}
        '''
        result = self._values.get("stat")
        assert result is not None, "Required property 'stat' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def cross_org_uuids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''The source organization UUID for cross organization queries. Feature in Private Beta.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        '''
        result = self._values.get("cross_org_uuids")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def group_by(self) -> typing.Optional[typing.List[builtins.str]]:
        '''Array of fields to group results by.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        '''
        result = self._values.get("group_by")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def operation_name(self) -> typing.Optional[builtins.str]:
        '''Name of operation on service.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#operation_name Powerpack#operation_name}
        '''
        result = self._values.get("operation_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def primary_tag_name(self) -> typing.Optional[builtins.str]:
        '''The name of the second primary tag used within APM; required when ``primary_tag_value`` is specified. See https://docs.datadoghq.com/tracing/guide/setting_primary_tags_to_scope/#add-a-second-primary-tag-in-datadog.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_name Powerpack#primary_tag_name}
        '''
        result = self._values.get("primary_tag_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def primary_tag_value(self) -> typing.Optional[builtins.str]:
        '''Filter APM data by the second primary tag. ``primary_tag_name`` must also be specified.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_value Powerpack#primary_tag_value}
        '''
        result = self._values.get("primary_tag_value")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def resource_name(self) -> typing.Optional[builtins.str]:
        '''APM resource.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#resource_name Powerpack#resource_name}
        '''
        result = self._values.get("resource_name")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetTimeseriesDefinitionRequestQueryApmResourceStatsQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetTimeseriesDefinitionRequestQueryApmResourceStatsQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestQueryApmResourceStatsQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3b8de35f5a13921cd2cc8532e3f3a7dfff44cf96d27112e8b657ea19df39a931)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetCrossOrgUuids")
    def reset_cross_org_uuids(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCrossOrgUuids", []))

    @jsii.member(jsii_name="resetGroupBy")
    def reset_group_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGroupBy", []))

    @jsii.member(jsii_name="resetOperationName")
    def reset_operation_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetOperationName", []))

    @jsii.member(jsii_name="resetPrimaryTagName")
    def reset_primary_tag_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPrimaryTagName", []))

    @jsii.member(jsii_name="resetPrimaryTagValue")
    def reset_primary_tag_value(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPrimaryTagValue", []))

    @jsii.member(jsii_name="resetResourceName")
    def reset_resource_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetResourceName", []))

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuidsInput")
    def cross_org_uuids_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "crossOrgUuidsInput"))

    @builtins.property
    @jsii.member(jsii_name="dataSourceInput")
    def data_source_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "dataSourceInput"))

    @builtins.property
    @jsii.member(jsii_name="envInput")
    def env_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "envInput"))

    @builtins.property
    @jsii.member(jsii_name="groupByInput")
    def group_by_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "groupByInput"))

    @builtins.property
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property
    @jsii.member(jsii_name="operationNameInput")
    def operation_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "operationNameInput"))

    @builtins.property
    @jsii.member(jsii_name="primaryTagNameInput")
    def primary_tag_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "primaryTagNameInput"))

    @builtins.property
    @jsii.member(jsii_name="primaryTagValueInput")
    def primary_tag_value_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "primaryTagValueInput"))

    @builtins.property
    @jsii.member(jsii_name="resourceNameInput")
    def resource_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "resourceNameInput"))

    @builtins.property
    @jsii.member(jsii_name="serviceInput")
    def service_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "serviceInput"))

    @builtins.property
    @jsii.member(jsii_name="statInput")
    def stat_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "statInput"))

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuids")
    def cross_org_uuids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "crossOrgUuids"))

    @cross_org_uuids.setter
    def cross_org_uuids(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__92eee58b9805f3b27987c0e7a1dad4ff020849fca6464b620d0d4debf2ba0e9f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "crossOrgUuids", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="dataSource")
    def data_source(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "dataSource"))

    @data_source.setter
    def data_source(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b48683e9cbc6b168710f5e61be1dce490d9027104f903229c1132145eb7f42f5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "dataSource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="env")
    def env(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "env"))

    @env.setter
    def env(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5daa231bdce169c86b6dd364496cfeac2536893b7901aa86b743dfa0faf8583c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "env", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="groupBy")
    def group_by(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "groupBy"))

    @group_by.setter
    def group_by(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__baf29dbb44258fd53d3439d5021d2a24d281853203741892cd96e213002263af)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "groupBy", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__73d89b1ed63f552c94e67d13bea04b2199ef26b0310361ce2c8abca338198fc3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "name", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="operationName")
    def operation_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "operationName"))

    @operation_name.setter
    def operation_name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__be15fc95ff106424f4bc79379826d3a9015b3ba65ff26a58a85c5246bfa86626)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "operationName", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="primaryTagName")
    def primary_tag_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "primaryTagName"))

    @primary_tag_name.setter
    def primary_tag_name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__019f2bc837f06d394eedecef6f01cf48a56fff7e30a90a8a45b44c9e736f0f61)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "primaryTagName", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="primaryTagValue")
    def primary_tag_value(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "primaryTagValue"))

    @primary_tag_value.setter
    def primary_tag_value(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__843973aac82dd2b4406746a59a28a2671b00e2f2ac7c0b1e8bcf0454f144ae93)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "primaryTagValue", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="resourceName")
    def resource_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "resourceName"))

    @resource_name.setter
    def resource_name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dfa24ac15636c7214b0ba36ed7a929924d2d8838a606908bd71c7b7416588769)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "resourceName", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="service")
    def service(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "service"))

    @service.setter
    def service(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9dd61484e67703684d672a2c8124a563b008a1b4970b8a3b365692470e876fb2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "service", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="stat")
    def stat(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "stat"))

    @stat.setter
    def stat(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b95662f2de113762eedfabd49b3f8a5f2a2dba2d392ddc6f2f68b6541faa54a7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "stat", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestQueryApmResourceStatsQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestQueryApmResourceStatsQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestQueryApmResourceStatsQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__13e49b8cf88abab62bbabab8f422b00323c6c0a9987cf0d91e96db0c11c1af89)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestQueryCloudCostQuery",
    jsii_struct_bases=[],
    name_mapping={
        "data_source": "dataSource",
        "name": "name",
        "query": "query",
        "aggregator": "aggregator",
        "cross_org_uuids": "crossOrgUuids",
    },
)
class PowerpackWidgetTimeseriesDefinitionRequestQueryCloudCostQuery:
    def __init__(
        self,
        *,
        data_source: builtins.str,
        name: builtins.str,
        query: builtins.str,
        aggregator: typing.Optional[builtins.str] = None,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
    ) -> None:
        '''
        :param data_source: The data source for cloud cost queries. Valid values are ``cloud_cost``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param name: The name of the query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param query: The cloud cost query definition. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        :param aggregator: The aggregation methods available for cloud cost queries. Valid values are ``avg``, ``last``, ``max``, ``min``, ``sum``, ``percentile``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregator Powerpack#aggregator}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__681ff90e27784fa2203a0eeaea5305500124c2a9a7100f9b9b215a2945275093)
            check_type(argname="argument data_source", value=data_source, expected_type=type_hints["data_source"])
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument query", value=query, expected_type=type_hints["query"])
            check_type(argname="argument aggregator", value=aggregator, expected_type=type_hints["aggregator"])
            check_type(argname="argument cross_org_uuids", value=cross_org_uuids, expected_type=type_hints["cross_org_uuids"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "data_source": data_source,
            "name": name,
            "query": query,
        }
        if aggregator is not None:
            self._values["aggregator"] = aggregator
        if cross_org_uuids is not None:
            self._values["cross_org_uuids"] = cross_org_uuids

    @builtins.property
    def data_source(self) -> builtins.str:
        '''The data source for cloud cost queries. Valid values are ``cloud_cost``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        '''
        result = self._values.get("data_source")
        assert result is not None, "Required property 'data_source' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def name(self) -> builtins.str:
        '''The name of the query for use in formulas.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        '''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def query(self) -> builtins.str:
        '''The cloud cost query definition.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        '''
        result = self._values.get("query")
        assert result is not None, "Required property 'query' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def aggregator(self) -> typing.Optional[builtins.str]:
        '''The aggregation methods available for cloud cost queries. Valid values are ``avg``, ``last``, ``max``, ``min``, ``sum``, ``percentile``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregator Powerpack#aggregator}
        '''
        result = self._values.get("aggregator")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def cross_org_uuids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''The source organization UUID for cross organization queries. Feature in Private Beta.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        '''
        result = self._values.get("cross_org_uuids")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetTimeseriesDefinitionRequestQueryCloudCostQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetTimeseriesDefinitionRequestQueryCloudCostQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestQueryCloudCostQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dc330f1a4dd0ca374192159bdc4f8525c41ab3221a0b983fb672ab14d6b3a035)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetAggregator")
    def reset_aggregator(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAggregator", []))

    @jsii.member(jsii_name="resetCrossOrgUuids")
    def reset_cross_org_uuids(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCrossOrgUuids", []))

    @builtins.property
    @jsii.member(jsii_name="aggregatorInput")
    def aggregator_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregatorInput"))

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuidsInput")
    def cross_org_uuids_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "crossOrgUuidsInput"))

    @builtins.property
    @jsii.member(jsii_name="dataSourceInput")
    def data_source_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "dataSourceInput"))

    @builtins.property
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property
    @jsii.member(jsii_name="queryInput")
    def query_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "queryInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregator")
    def aggregator(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregator"))

    @aggregator.setter
    def aggregator(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8b28b82aec2b70dc9e59ec01c9cd59cfcff46969d55b5b8264b03f0c6e67e386)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregator", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuids")
    def cross_org_uuids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "crossOrgUuids"))

    @cross_org_uuids.setter
    def cross_org_uuids(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__04996a78facfe801f03c19d230f4d1d09cb894eec3baa515b04ed9cde2723f2c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "crossOrgUuids", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="dataSource")
    def data_source(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "dataSource"))

    @data_source.setter
    def data_source(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3ea9b945a09e834f733fe35110c739e4733c645ebe31d82477f37041345df34e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "dataSource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__546828245b8ae901cf63cee278f7e2223ace8440916fc6af9d00bac1179a7460)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "name", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="query")
    def query(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "query"))

    @query.setter
    def query(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e1316497666ddd0fdf923c105f92467b42b6b91728ff747ce670254839795554)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "query", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestQueryCloudCostQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestQueryCloudCostQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestQueryCloudCostQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2d0aa26fda6952dccc16ff33a843c0f1ddc9c86823f5487ba3fc3f938300625b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestQueryEventQuery",
    jsii_struct_bases=[],
    name_mapping={
        "compute": "compute",
        "data_source": "dataSource",
        "name": "name",
        "cross_org_uuids": "crossOrgUuids",
        "group_by": "groupBy",
        "indexes": "indexes",
        "search": "search",
        "storage": "storage",
    },
)
class PowerpackWidgetTimeseriesDefinitionRequestQueryEventQuery:
    def __init__(
        self,
        *,
        compute: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetTimeseriesDefinitionRequestQueryEventQueryCompute", typing.Dict[builtins.str, typing.Any]]]],
        data_source: builtins.str,
        name: builtins.str,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetTimeseriesDefinitionRequestQueryEventQueryGroupBy", typing.Dict[builtins.str, typing.Any]]]]] = None,
        indexes: typing.Optional[typing.Sequence[builtins.str]] = None,
        search: typing.Optional[typing.Union["PowerpackWidgetTimeseriesDefinitionRequestQueryEventQuerySearch", typing.Dict[builtins.str, typing.Any]]] = None,
        storage: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param compute: compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute Powerpack#compute}
        :param data_source: The data source for event platform-based queries. Valid values are ``logs``, ``spans``, ``network``, ``rum``, ``security_signals``, ``profiles``, ``audit``, ``events``, ``ci_tests``, ``ci_pipelines``, ``incident_analytics``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param name: The name of query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param indexes: An array of index names to query in the stream. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#indexes Powerpack#indexes}
        :param search: search block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search Powerpack#search}
        :param storage: Storage location (private beta). Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#storage Powerpack#storage}
        '''
        if isinstance(search, dict):
            search = PowerpackWidgetTimeseriesDefinitionRequestQueryEventQuerySearch(**search)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c92b31a6a48ff3d260c3be4c1c53134116184741ca7879088b2500af27bbb6e3)
            check_type(argname="argument compute", value=compute, expected_type=type_hints["compute"])
            check_type(argname="argument data_source", value=data_source, expected_type=type_hints["data_source"])
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument cross_org_uuids", value=cross_org_uuids, expected_type=type_hints["cross_org_uuids"])
            check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
            check_type(argname="argument indexes", value=indexes, expected_type=type_hints["indexes"])
            check_type(argname="argument search", value=search, expected_type=type_hints["search"])
            check_type(argname="argument storage", value=storage, expected_type=type_hints["storage"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "compute": compute,
            "data_source": data_source,
            "name": name,
        }
        if cross_org_uuids is not None:
            self._values["cross_org_uuids"] = cross_org_uuids
        if group_by is not None:
            self._values["group_by"] = group_by
        if indexes is not None:
            self._values["indexes"] = indexes
        if search is not None:
            self._values["search"] = search
        if storage is not None:
            self._values["storage"] = storage

    @builtins.property
    def compute(
        self,
    ) -> typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetTimeseriesDefinitionRequestQueryEventQueryCompute"]]:
        '''compute block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute Powerpack#compute}
        '''
        result = self._values.get("compute")
        assert result is not None, "Required property 'compute' is missing"
        return typing.cast(typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetTimeseriesDefinitionRequestQueryEventQueryCompute"]], result)

    @builtins.property
    def data_source(self) -> builtins.str:
        '''The data source for event platform-based queries.

        Valid values are ``logs``, ``spans``, ``network``, ``rum``, ``security_signals``, ``profiles``, ``audit``, ``events``, ``ci_tests``, ``ci_pipelines``, ``incident_analytics``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        '''
        result = self._values.get("data_source")
        assert result is not None, "Required property 'data_source' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def name(self) -> builtins.str:
        '''The name of query for use in formulas.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        '''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def cross_org_uuids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''The source organization UUID for cross organization queries. Feature in Private Beta.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        '''
        result = self._values.get("cross_org_uuids")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def group_by(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetTimeseriesDefinitionRequestQueryEventQueryGroupBy"]]]:
        '''group_by block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        '''
        result = self._values.get("group_by")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetTimeseriesDefinitionRequestQueryEventQueryGroupBy"]]], result)

    @builtins.property
    def indexes(self) -> typing.Optional[typing.List[builtins.str]]:
        '''An array of index names to query in the stream.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#indexes Powerpack#indexes}
        '''
        result = self._values.get("indexes")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def search(
        self,
    ) -> typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestQueryEventQuerySearch"]:
        '''search block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search Powerpack#search}
        '''
        result = self._values.get("search")
        return typing.cast(typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestQueryEventQuerySearch"], result)

    @builtins.property
    def storage(self) -> typing.Optional[builtins.str]:
        '''Storage location (private beta).

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#storage Powerpack#storage}
        '''
        result = self._values.get("storage")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetTimeseriesDefinitionRequestQueryEventQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestQueryEventQueryCompute",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "interval": "interval",
        "metric": "metric",
    },
)
class PowerpackWidgetTimeseriesDefinitionRequestQueryEventQueryCompute:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        interval: typing.Optional[jsii.Number] = None,
        metric: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation methods for event platform queries. Valid values are ``count``, ``cardinality``, ``median``, ``pc75``, ``pc90``, ``pc95``, ``pc98``, ``pc99``, ``sum``, ``min``, ``max``, ``avg``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param interval: A time interval in milliseconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        :param metric: The measurable attribute to compute. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5ecac23c84813a928e32a31d00197dc81e8ba2030b934a7b25426c25cef814a4)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
            check_type(argname="argument metric", value=metric, expected_type=type_hints["metric"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if interval is not None:
            self._values["interval"] = interval
        if metric is not None:
            self._values["metric"] = metric

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation methods for event platform queries.

        Valid values are ``count``, ``cardinality``, ``median``, ``pc75``, ``pc90``, ``pc95``, ``pc98``, ``pc99``, ``sum``, ``min``, ``max``, ``avg``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''A time interval in milliseconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def metric(self) -> typing.Optional[builtins.str]:
        '''The measurable attribute to compute.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        '''
        result = self._values.get("metric")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetTimeseriesDefinitionRequestQueryEventQueryCompute(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetTimeseriesDefinitionRequestQueryEventQueryComputeList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestQueryEventQueryComputeList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__178435041c9b8b339db20423c01318dbfcbdc1fb08b9d575d7a0ec42f6127a01)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetTimeseriesDefinitionRequestQueryEventQueryComputeOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e9ce5c5e1861b0ade25532adadff5bd12e60a9f2439db2cd2f1d68af314b113f)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetTimeseriesDefinitionRequestQueryEventQueryComputeOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__31e29c29afd2f328c36b03ed95a101fdff6c660dbac28ae1d3ba4281e8c59728)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0337f2423d2ed88e98b88368cb5ab700de814f1049179165ae4668f57ff3fcbf)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__472ef9a99bf2c878ecf79f8fc8e4ff681d6ee49559c095bf1f9cf6b573c54691)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestQueryEventQueryCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestQueryEventQueryCompute]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestQueryEventQueryCompute]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__17a01746802b84e49d652cc01de8aeb5f466eefa2a88167d42530c5d583fa0d8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetTimeseriesDefinitionRequestQueryEventQueryComputeOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestQueryEventQueryComputeOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3f6c2b8867fbcd45c976e2ee39099bfa805fdd7059302b2ff52413c43ebfcf27)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @jsii.member(jsii_name="resetMetric")
    def reset_metric(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMetric", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="metricInput")
    def metric_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "metricInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7759f3b69d78c68e6f16c884b31a4a45c7c7aaa00a155a805feebe48c9217f17)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4e3128fb613e9b9573b0e2ed348d7446fc7bbf8a14ae5a86abc74f003d50474a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="metric")
    def metric(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "metric"))

    @metric.setter
    def metric(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__229a1b3348647369e0cad775bd4e55f3c792cb316207e181d18986f75e87c144)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "metric", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTimeseriesDefinitionRequestQueryEventQueryCompute]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTimeseriesDefinitionRequestQueryEventQueryCompute]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTimeseriesDefinitionRequestQueryEventQueryCompute]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a8f9a2be69435b2467c495265235f0d43e415fc98efdd94bfa2a7550f8567b03)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestQueryEventQueryGroupBy",
    jsii_struct_bases=[],
    name_mapping={"facet": "facet", "limit": "limit", "sort": "sort"},
)
class PowerpackWidgetTimeseriesDefinitionRequestQueryEventQueryGroupBy:
    def __init__(
        self,
        *,
        facet: builtins.str,
        limit: typing.Optional[jsii.Number] = None,
        sort: typing.Optional[typing.Union["PowerpackWidgetTimeseriesDefinitionRequestQueryEventQueryGroupBySort", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param facet: The event facet. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param limit: The number of groups to return. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param sort: sort block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort Powerpack#sort}
        '''
        if isinstance(sort, dict):
            sort = PowerpackWidgetTimeseriesDefinitionRequestQueryEventQueryGroupBySort(**sort)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__53bcff6219a876712c6fa0e050ac8530deb447b1a107753bef74a2e915dc2c4f)
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
            check_type(argname="argument sort", value=sort, expected_type=type_hints["sort"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "facet": facet,
        }
        if limit is not None:
            self._values["limit"] = limit
        if sort is not None:
            self._values["sort"] = sort

    @builtins.property
    def facet(self) -> builtins.str:
        '''The event facet.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        assert result is not None, "Required property 'facet' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def limit(self) -> typing.Optional[jsii.Number]:
        '''The number of groups to return.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        '''
        result = self._values.get("limit")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def sort(
        self,
    ) -> typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestQueryEventQueryGroupBySort"]:
        '''sort block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort Powerpack#sort}
        '''
        result = self._values.get("sort")
        return typing.cast(typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestQueryEventQueryGroupBySort"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetTimeseriesDefinitionRequestQueryEventQueryGroupBy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetTimeseriesDefinitionRequestQueryEventQueryGroupByList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestQueryEventQueryGroupByList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e705b8407879ed1de5006fa7a690fbc19470c1bc341d44574aa02372952a27d2)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetTimeseriesDefinitionRequestQueryEventQueryGroupByOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c48fa8aa0548b9853a484848a85b31f4207aeb0f024213fbe6c5d7297991983d)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetTimeseriesDefinitionRequestQueryEventQueryGroupByOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1b8e96b1463b654d655475b5425970b006ed2fd39025198ae7357790798eea02)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3c2a3ad54a0c42fd2dc1124e937c14e4c27f16601ae0ba2149c35af47d77dab4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ecc86e453bb874d449bc5d4105cd313608c71845656c407fcb0d5ba2f9891570)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestQueryEventQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestQueryEventQueryGroupBy]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestQueryEventQueryGroupBy]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0510cd2017a3c0f3ca6b05277794e37d628c6248377f0db38b746eb7aa15936f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetTimeseriesDefinitionRequestQueryEventQueryGroupByOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestQueryEventQueryGroupByOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b862be40da8d672ade963c84ccb2f8e233f0c61975cdff8f8c1d31faa28b4669)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putSort")
    def put_sort(
        self,
        *,
        aggregation: builtins.str,
        metric: typing.Optional[builtins.str] = None,
        order: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation methods for the event platform queries. Valid values are ``count``, ``cardinality``, ``median``, ``pc75``, ``pc90``, ``pc95``, ``pc98``, ``pc99``, ``sum``, ``min``, ``max``, ``avg``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param metric: The metric used for sorting group by results. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        :param order: Direction of sort. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        value = PowerpackWidgetTimeseriesDefinitionRequestQueryEventQueryGroupBySort(
            aggregation=aggregation, metric=metric, order=order
        )

        return typing.cast(None, jsii.invoke(self, "putSort", [value]))

    @jsii.member(jsii_name="resetLimit")
    def reset_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLimit", []))

    @jsii.member(jsii_name="resetSort")
    def reset_sort(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSort", []))

    @builtins.property
    @jsii.member(jsii_name="sort")
    def sort(
        self,
    ) -> "PowerpackWidgetTimeseriesDefinitionRequestQueryEventQueryGroupBySortOutputReference":
        return typing.cast("PowerpackWidgetTimeseriesDefinitionRequestQueryEventQueryGroupBySortOutputReference", jsii.get(self, "sort"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="limitInput")
    def limit_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "limitInput"))

    @builtins.property
    @jsii.member(jsii_name="sortInput")
    def sort_input(
        self,
    ) -> typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestQueryEventQueryGroupBySort"]:
        return typing.cast(typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestQueryEventQueryGroupBySort"], jsii.get(self, "sortInput"))

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__75b48f302c19e3ac3e356369a7f5062691e23c8362c3d1fc8230f1dd7b039560)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="limit")
    def limit(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "limit"))

    @limit.setter
    def limit(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__867b59771ad4bbb7ead3a9a1165fbd060275e867436e9abbe812f1688a41d86c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "limit", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTimeseriesDefinitionRequestQueryEventQueryGroupBy]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTimeseriesDefinitionRequestQueryEventQueryGroupBy]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTimeseriesDefinitionRequestQueryEventQueryGroupBy]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__17d8739cc79e166e8e6f2030804fb62dc14dd820f7a999f534fe56480d297734)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestQueryEventQueryGroupBySort",
    jsii_struct_bases=[],
    name_mapping={"aggregation": "aggregation", "metric": "metric", "order": "order"},
)
class PowerpackWidgetTimeseriesDefinitionRequestQueryEventQueryGroupBySort:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        metric: typing.Optional[builtins.str] = None,
        order: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation methods for the event platform queries. Valid values are ``count``, ``cardinality``, ``median``, ``pc75``, ``pc90``, ``pc95``, ``pc98``, ``pc99``, ``sum``, ``min``, ``max``, ``avg``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param metric: The metric used for sorting group by results. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        :param order: Direction of sort. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__33a73f1f5874021947d96f98775cc2653195c932668adae727853c30acb911fa)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument metric", value=metric, expected_type=type_hints["metric"])
            check_type(argname="argument order", value=order, expected_type=type_hints["order"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if metric is not None:
            self._values["metric"] = metric
        if order is not None:
            self._values["order"] = order

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation methods for the event platform queries.

        Valid values are ``count``, ``cardinality``, ``median``, ``pc75``, ``pc90``, ``pc95``, ``pc98``, ``pc99``, ``sum``, ``min``, ``max``, ``avg``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def metric(self) -> typing.Optional[builtins.str]:
        '''The metric used for sorting group by results.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        '''
        result = self._values.get("metric")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def order(self) -> typing.Optional[builtins.str]:
        '''Direction of sort. Valid values are ``asc``, ``desc``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        result = self._values.get("order")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetTimeseriesDefinitionRequestQueryEventQueryGroupBySort(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetTimeseriesDefinitionRequestQueryEventQueryGroupBySortOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestQueryEventQueryGroupBySortOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2e4cfb3243386281fb2981850591e6ab0e9ff7f483ede4ebce566698e32de6b3)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetMetric")
    def reset_metric(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMetric", []))

    @jsii.member(jsii_name="resetOrder")
    def reset_order(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetOrder", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="metricInput")
    def metric_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "metricInput"))

    @builtins.property
    @jsii.member(jsii_name="orderInput")
    def order_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "orderInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__734e0cb8da99e0658c5948e1cd54667401612413ca90a04289f7af19d9399ea2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="metric")
    def metric(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "metric"))

    @metric.setter
    def metric(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e7b6f48aff788c738c0fbc09c2d1418ee75659246e2c9e845d05ceac95ed8a77)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "metric", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="order")
    def order(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "order"))

    @order.setter
    def order(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__77f4f339d6993a57cde7975c9ce69ae50fbcf4fca385b87ccb5cba92c51b5a9e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "order", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestQueryEventQueryGroupBySort]:
        return typing.cast(typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestQueryEventQueryGroupBySort], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestQueryEventQueryGroupBySort],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e353256b9778cdb4517cbb7295d480cee92a156d7bc4fd1c3e18b432a41ae984)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetTimeseriesDefinitionRequestQueryEventQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestQueryEventQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__192d41c5d89193788e8a1ba32125256de1a3fd750ef87dfe868029b21f19166a)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putCompute")
    def put_compute(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestQueryEventQueryCompute, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9443f5fdaa40277d07cfbea2ed80946e17bd80e196fb752d7727331cbaccb11c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putCompute", [value]))

    @jsii.member(jsii_name="putGroupBy")
    def put_group_by(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestQueryEventQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8d971beab43826ba3ecc9d012f83ba2bbb1a111296e02dc089825ed5b616ed69)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putGroupBy", [value]))

    @jsii.member(jsii_name="putSearch")
    def put_search(self, *, query: builtins.str) -> None:
        '''
        :param query: The events search string. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        '''
        value = PowerpackWidgetTimeseriesDefinitionRequestQueryEventQuerySearch(
            query=query
        )

        return typing.cast(None, jsii.invoke(self, "putSearch", [value]))

    @jsii.member(jsii_name="resetCrossOrgUuids")
    def reset_cross_org_uuids(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCrossOrgUuids", []))

    @jsii.member(jsii_name="resetGroupBy")
    def reset_group_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGroupBy", []))

    @jsii.member(jsii_name="resetIndexes")
    def reset_indexes(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetIndexes", []))

    @jsii.member(jsii_name="resetSearch")
    def reset_search(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSearch", []))

    @jsii.member(jsii_name="resetStorage")
    def reset_storage(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetStorage", []))

    @builtins.property
    @jsii.member(jsii_name="compute")
    def compute(
        self,
    ) -> PowerpackWidgetTimeseriesDefinitionRequestQueryEventQueryComputeList:
        return typing.cast(PowerpackWidgetTimeseriesDefinitionRequestQueryEventQueryComputeList, jsii.get(self, "compute"))

    @builtins.property
    @jsii.member(jsii_name="groupBy")
    def group_by(
        self,
    ) -> PowerpackWidgetTimeseriesDefinitionRequestQueryEventQueryGroupByList:
        return typing.cast(PowerpackWidgetTimeseriesDefinitionRequestQueryEventQueryGroupByList, jsii.get(self, "groupBy"))

    @builtins.property
    @jsii.member(jsii_name="search")
    def search(
        self,
    ) -> "PowerpackWidgetTimeseriesDefinitionRequestQueryEventQuerySearchOutputReference":
        return typing.cast("PowerpackWidgetTimeseriesDefinitionRequestQueryEventQuerySearchOutputReference", jsii.get(self, "search"))

    @builtins.property
    @jsii.member(jsii_name="computeInput")
    def compute_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestQueryEventQueryCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestQueryEventQueryCompute]]], jsii.get(self, "computeInput"))

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuidsInput")
    def cross_org_uuids_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "crossOrgUuidsInput"))

    @builtins.property
    @jsii.member(jsii_name="dataSourceInput")
    def data_source_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "dataSourceInput"))

    @builtins.property
    @jsii.member(jsii_name="groupByInput")
    def group_by_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestQueryEventQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestQueryEventQueryGroupBy]]], jsii.get(self, "groupByInput"))

    @builtins.property
    @jsii.member(jsii_name="indexesInput")
    def indexes_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "indexesInput"))

    @builtins.property
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property
    @jsii.member(jsii_name="searchInput")
    def search_input(
        self,
    ) -> typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestQueryEventQuerySearch"]:
        return typing.cast(typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestQueryEventQuerySearch"], jsii.get(self, "searchInput"))

    @builtins.property
    @jsii.member(jsii_name="storageInput")
    def storage_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "storageInput"))

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuids")
    def cross_org_uuids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "crossOrgUuids"))

    @cross_org_uuids.setter
    def cross_org_uuids(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7b9580396bf793d81c657cb13cdd6df10971a2305fd1b2b604787d0f4c561992)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "crossOrgUuids", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="dataSource")
    def data_source(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "dataSource"))

    @data_source.setter
    def data_source(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__99a0d0aeb99a91f3c4e0606b456a26f007fb3c45cb6d25f33d56b668f8f1c2c4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "dataSource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="indexes")
    def indexes(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "indexes"))

    @indexes.setter
    def indexes(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4e66be085b32aa619bccec810fbd4353e356679c942c038e11c571eda3018de2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "indexes", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__012aae014d52fe005a14555227c5a993235c51a279fb85b1afb502ccf6436ca2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "name", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="storage")
    def storage(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "storage"))

    @storage.setter
    def storage(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d81b90b9d0f14a656d06b5ef6651f4c76fd853b3f2b8019d27bf9a25ff7691fd)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "storage", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestQueryEventQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestQueryEventQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestQueryEventQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2bb1f4ba3de83eb63ab73958f2f7d29fc7c230a88797816aa57267466dfcbaee)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestQueryEventQuerySearch",
    jsii_struct_bases=[],
    name_mapping={"query": "query"},
)
class PowerpackWidgetTimeseriesDefinitionRequestQueryEventQuerySearch:
    def __init__(self, *, query: builtins.str) -> None:
        '''
        :param query: The events search string. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__637d3a9385fd07e0f18e27a8652cc23387c8894af24b5454e8ebb75b35afd546)
            check_type(argname="argument query", value=query, expected_type=type_hints["query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "query": query,
        }

    @builtins.property
    def query(self) -> builtins.str:
        '''The events search string.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        '''
        result = self._values.get("query")
        assert result is not None, "Required property 'query' is missing"
        return typing.cast(builtins.str, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetTimeseriesDefinitionRequestQueryEventQuerySearch(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetTimeseriesDefinitionRequestQueryEventQuerySearchOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestQueryEventQuerySearchOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__31689aa02810c33b2d838b600d5da847cc9f609ebcc9caf1147d5175017bd242)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @builtins.property
    @jsii.member(jsii_name="queryInput")
    def query_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "queryInput"))

    @builtins.property
    @jsii.member(jsii_name="query")
    def query(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "query"))

    @query.setter
    def query(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d13d41d5fba1a0a6c037413338fc63a6faec394b04009fb584057891e0d91ef5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "query", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestQueryEventQuerySearch]:
        return typing.cast(typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestQueryEventQuerySearch], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestQueryEventQuerySearch],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e87c1b828655bef331bdc3cca35af8f55669fa28186e76fb571ae277573ecb0e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetTimeseriesDefinitionRequestQueryList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestQueryList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__48e681a6f23118a936ce24c8fdb3a9b5d92f0cd1655cf2668a294220110d4882)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetTimeseriesDefinitionRequestQueryOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4ad5ee2bad233d38f137a69be735dbb8edfccae81176e5178bacf92a04af5906)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetTimeseriesDefinitionRequestQueryOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4e3ac3f600f959729cdbc3d4e5c20e0d6d406438027dcf42f968ffc423b9ee89)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f3b941372362bf31c67ea7dcd972caa802b03b609961f3fa46a27c37b6bc110e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2760b29f497d5a5934777fb57206c0c40d026a369186e2a07bd819cf37d566ac)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestQuery]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestQuery]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestQuery]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__edc5d83d29457b6a5029b10495696488b40aeb11d2ce09aa3a7dab4776475a48)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestQueryMetricQuery",
    jsii_struct_bases=[],
    name_mapping={
        "name": "name",
        "query": "query",
        "aggregator": "aggregator",
        "cross_org_uuids": "crossOrgUuids",
        "data_source": "dataSource",
    },
)
class PowerpackWidgetTimeseriesDefinitionRequestQueryMetricQuery:
    def __init__(
        self,
        *,
        name: builtins.str,
        query: builtins.str,
        aggregator: typing.Optional[builtins.str] = None,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        data_source: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param name: The name of the query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param query: The metrics query definition. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        :param aggregator: The aggregation methods available for metrics queries. Valid values are ``avg``, ``min``, ``max``, ``sum``, ``last``, ``area``, ``l2norm``, ``percentile``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregator Powerpack#aggregator}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param data_source: The data source for metrics queries. Defaults to ``"metrics"``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6e60b87bf51bcddab8e1588f37b1c027c847ae1e4f9bc77222ba057dde3a226d)
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument query", value=query, expected_type=type_hints["query"])
            check_type(argname="argument aggregator", value=aggregator, expected_type=type_hints["aggregator"])
            check_type(argname="argument cross_org_uuids", value=cross_org_uuids, expected_type=type_hints["cross_org_uuids"])
            check_type(argname="argument data_source", value=data_source, expected_type=type_hints["data_source"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "name": name,
            "query": query,
        }
        if aggregator is not None:
            self._values["aggregator"] = aggregator
        if cross_org_uuids is not None:
            self._values["cross_org_uuids"] = cross_org_uuids
        if data_source is not None:
            self._values["data_source"] = data_source

    @builtins.property
    def name(self) -> builtins.str:
        '''The name of the query for use in formulas.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        '''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def query(self) -> builtins.str:
        '''The metrics query definition.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        '''
        result = self._values.get("query")
        assert result is not None, "Required property 'query' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def aggregator(self) -> typing.Optional[builtins.str]:
        '''The aggregation methods available for metrics queries. Valid values are ``avg``, ``min``, ``max``, ``sum``, ``last``, ``area``, ``l2norm``, ``percentile``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregator Powerpack#aggregator}
        '''
        result = self._values.get("aggregator")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def cross_org_uuids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''The source organization UUID for cross organization queries. Feature in Private Beta.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        '''
        result = self._values.get("cross_org_uuids")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def data_source(self) -> typing.Optional[builtins.str]:
        '''The data source for metrics queries. Defaults to ``"metrics"``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        '''
        result = self._values.get("data_source")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetTimeseriesDefinitionRequestQueryMetricQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetTimeseriesDefinitionRequestQueryMetricQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestQueryMetricQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5a151e5bcfd0b155069a50e25d4e05c654b2de6cb5baad8c39b7a2c6c3df47c7)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetAggregator")
    def reset_aggregator(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAggregator", []))

    @jsii.member(jsii_name="resetCrossOrgUuids")
    def reset_cross_org_uuids(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCrossOrgUuids", []))

    @jsii.member(jsii_name="resetDataSource")
    def reset_data_source(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDataSource", []))

    @builtins.property
    @jsii.member(jsii_name="aggregatorInput")
    def aggregator_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregatorInput"))

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuidsInput")
    def cross_org_uuids_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "crossOrgUuidsInput"))

    @builtins.property
    @jsii.member(jsii_name="dataSourceInput")
    def data_source_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "dataSourceInput"))

    @builtins.property
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property
    @jsii.member(jsii_name="queryInput")
    def query_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "queryInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregator")
    def aggregator(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregator"))

    @aggregator.setter
    def aggregator(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__28ed05184e7839982839491cd8ee60def7804cd4096fb229f911380f62d2d17b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregator", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuids")
    def cross_org_uuids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "crossOrgUuids"))

    @cross_org_uuids.setter
    def cross_org_uuids(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__40581dc5b677f06fea0716bdb20973f85dabccdbb3fa499302587847baca593c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "crossOrgUuids", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="dataSource")
    def data_source(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "dataSource"))

    @data_source.setter
    def data_source(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__aa7d4c03792ef4bf83b048f2c6bf99c1bd28205bf9f6c930b1957147e048510e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "dataSource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f98fa6c27a043890faa341473dee0d9adfdf6b23944b21cc36f787ecedd1ed5b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "name", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="query")
    def query(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "query"))

    @query.setter
    def query(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d6ed8a583a4b715c675b4ebdc6d543aaddd8edfb3853afd8af207011a508f6bd)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "query", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestQueryMetricQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestQueryMetricQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestQueryMetricQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0dedbf294ca8782e872cac5dc27c87713e6d5b0a7b1ee2e8c7e3ffc639a8430a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetTimeseriesDefinitionRequestQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cb06bcc5f0b9697a419b250f081879661ac724faa6d1cf60e894d3c1f52b4e3d)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putApmDependencyStatsQuery")
    def put_apm_dependency_stats_query(
        self,
        *,
        data_source: builtins.str,
        env: builtins.str,
        name: builtins.str,
        operation_name: builtins.str,
        resource_name: builtins.str,
        service: builtins.str,
        stat: builtins.str,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        is_upstream: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        primary_tag_name: typing.Optional[builtins.str] = None,
        primary_tag_value: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param data_source: The data source for APM Dependency Stats queries. Valid values are ``apm_dependency_stats``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param env: APM environment. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#env Powerpack#env}
        :param name: The name of query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param operation_name: Name of operation on service. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#operation_name Powerpack#operation_name}
        :param resource_name: APM resource. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#resource_name Powerpack#resource_name}
        :param service: APM service. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#service Powerpack#service}
        :param stat: APM statistic. Valid values are ``avg_duration``, ``avg_root_duration``, ``avg_spans_per_trace``, ``error_rate``, ``pct_exec_time``, ``pct_of_traces``, ``total_traces_count``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#stat Powerpack#stat}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param is_upstream: Determines whether stats for upstream or downstream dependencies should be queried. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#is_upstream Powerpack#is_upstream}
        :param primary_tag_name: The name of the second primary tag used within APM; required when ``primary_tag_value`` is specified. See https://docs.datadoghq.com/tracing/guide/setting_primary_tags_to_scope/#add-a-second-primary-tag-in-datadog. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_name Powerpack#primary_tag_name}
        :param primary_tag_value: Filter APM data by the second primary tag. ``primary_tag_name`` must also be specified. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_value Powerpack#primary_tag_value}
        '''
        value = PowerpackWidgetTimeseriesDefinitionRequestQueryApmDependencyStatsQuery(
            data_source=data_source,
            env=env,
            name=name,
            operation_name=operation_name,
            resource_name=resource_name,
            service=service,
            stat=stat,
            cross_org_uuids=cross_org_uuids,
            is_upstream=is_upstream,
            primary_tag_name=primary_tag_name,
            primary_tag_value=primary_tag_value,
        )

        return typing.cast(None, jsii.invoke(self, "putApmDependencyStatsQuery", [value]))

    @jsii.member(jsii_name="putApmResourceStatsQuery")
    def put_apm_resource_stats_query(
        self,
        *,
        data_source: builtins.str,
        env: builtins.str,
        name: builtins.str,
        service: builtins.str,
        stat: builtins.str,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        group_by: typing.Optional[typing.Sequence[builtins.str]] = None,
        operation_name: typing.Optional[builtins.str] = None,
        primary_tag_name: typing.Optional[builtins.str] = None,
        primary_tag_value: typing.Optional[builtins.str] = None,
        resource_name: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param data_source: The data source for APM Resource Stats queries. Valid values are ``apm_resource_stats``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param env: APM environment. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#env Powerpack#env}
        :param name: The name of query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param service: APM service. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#service Powerpack#service}
        :param stat: APM statistic. Valid values are ``errors``, ``error_rate``, ``hits``, ``latency_avg``, ``latency_distribution``, ``latency_max``, ``latency_p50``, ``latency_p75``, ``latency_p90``, ``latency_p95``, ``latency_p99``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#stat Powerpack#stat}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param group_by: Array of fields to group results by. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param operation_name: Name of operation on service. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#operation_name Powerpack#operation_name}
        :param primary_tag_name: The name of the second primary tag used within APM; required when ``primary_tag_value`` is specified. See https://docs.datadoghq.com/tracing/guide/setting_primary_tags_to_scope/#add-a-second-primary-tag-in-datadog. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_name Powerpack#primary_tag_name}
        :param primary_tag_value: Filter APM data by the second primary tag. ``primary_tag_name`` must also be specified. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_value Powerpack#primary_tag_value}
        :param resource_name: APM resource. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#resource_name Powerpack#resource_name}
        '''
        value = PowerpackWidgetTimeseriesDefinitionRequestQueryApmResourceStatsQuery(
            data_source=data_source,
            env=env,
            name=name,
            service=service,
            stat=stat,
            cross_org_uuids=cross_org_uuids,
            group_by=group_by,
            operation_name=operation_name,
            primary_tag_name=primary_tag_name,
            primary_tag_value=primary_tag_value,
            resource_name=resource_name,
        )

        return typing.cast(None, jsii.invoke(self, "putApmResourceStatsQuery", [value]))

    @jsii.member(jsii_name="putCloudCostQuery")
    def put_cloud_cost_query(
        self,
        *,
        data_source: builtins.str,
        name: builtins.str,
        query: builtins.str,
        aggregator: typing.Optional[builtins.str] = None,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
    ) -> None:
        '''
        :param data_source: The data source for cloud cost queries. Valid values are ``cloud_cost``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param name: The name of the query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param query: The cloud cost query definition. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        :param aggregator: The aggregation methods available for cloud cost queries. Valid values are ``avg``, ``last``, ``max``, ``min``, ``sum``, ``percentile``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregator Powerpack#aggregator}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        '''
        value = PowerpackWidgetTimeseriesDefinitionRequestQueryCloudCostQuery(
            data_source=data_source,
            name=name,
            query=query,
            aggregator=aggregator,
            cross_org_uuids=cross_org_uuids,
        )

        return typing.cast(None, jsii.invoke(self, "putCloudCostQuery", [value]))

    @jsii.member(jsii_name="putEventQuery")
    def put_event_query(
        self,
        *,
        compute: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestQueryEventQueryCompute, typing.Dict[builtins.str, typing.Any]]]],
        data_source: builtins.str,
        name: builtins.str,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestQueryEventQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
        indexes: typing.Optional[typing.Sequence[builtins.str]] = None,
        search: typing.Optional[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestQueryEventQuerySearch, typing.Dict[builtins.str, typing.Any]]] = None,
        storage: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param compute: compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute Powerpack#compute}
        :param data_source: The data source for event platform-based queries. Valid values are ``logs``, ``spans``, ``network``, ``rum``, ``security_signals``, ``profiles``, ``audit``, ``events``, ``ci_tests``, ``ci_pipelines``, ``incident_analytics``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param name: The name of query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param indexes: An array of index names to query in the stream. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#indexes Powerpack#indexes}
        :param search: search block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search Powerpack#search}
        :param storage: Storage location (private beta). Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#storage Powerpack#storage}
        '''
        value = PowerpackWidgetTimeseriesDefinitionRequestQueryEventQuery(
            compute=compute,
            data_source=data_source,
            name=name,
            cross_org_uuids=cross_org_uuids,
            group_by=group_by,
            indexes=indexes,
            search=search,
            storage=storage,
        )

        return typing.cast(None, jsii.invoke(self, "putEventQuery", [value]))

    @jsii.member(jsii_name="putMetricQuery")
    def put_metric_query(
        self,
        *,
        name: builtins.str,
        query: builtins.str,
        aggregator: typing.Optional[builtins.str] = None,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        data_source: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param name: The name of the query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param query: The metrics query definition. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        :param aggregator: The aggregation methods available for metrics queries. Valid values are ``avg``, ``min``, ``max``, ``sum``, ``last``, ``area``, ``l2norm``, ``percentile``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregator Powerpack#aggregator}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param data_source: The data source for metrics queries. Defaults to ``"metrics"``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        '''
        value = PowerpackWidgetTimeseriesDefinitionRequestQueryMetricQuery(
            name=name,
            query=query,
            aggregator=aggregator,
            cross_org_uuids=cross_org_uuids,
            data_source=data_source,
        )

        return typing.cast(None, jsii.invoke(self, "putMetricQuery", [value]))

    @jsii.member(jsii_name="putProcessQuery")
    def put_process_query(
        self,
        *,
        data_source: builtins.str,
        metric: builtins.str,
        name: builtins.str,
        aggregator: typing.Optional[builtins.str] = None,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        is_normalized_cpu: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        limit: typing.Optional[jsii.Number] = None,
        sort: typing.Optional[builtins.str] = None,
        tag_filters: typing.Optional[typing.Sequence[builtins.str]] = None,
        text_filter: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param data_source: The data source for process queries. Valid values are ``process``, ``container``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param metric: The process metric name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        :param name: The name of query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param aggregator: The aggregation methods available for metrics queries. Valid values are ``avg``, ``min``, ``max``, ``sum``, ``last``, ``area``, ``l2norm``, ``percentile``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregator Powerpack#aggregator}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param is_normalized_cpu: Whether to normalize the CPU percentages. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#is_normalized_cpu Powerpack#is_normalized_cpu}
        :param limit: The number of hits to return. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param sort: The direction of the sort. Valid values are ``asc``, ``desc``. Defaults to ``"desc"``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort Powerpack#sort}
        :param tag_filters: An array of tags to filter by. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#tag_filters Powerpack#tag_filters}
        :param text_filter: The text to use as a filter. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#text_filter Powerpack#text_filter}
        '''
        value = PowerpackWidgetTimeseriesDefinitionRequestQueryProcessQuery(
            data_source=data_source,
            metric=metric,
            name=name,
            aggregator=aggregator,
            cross_org_uuids=cross_org_uuids,
            is_normalized_cpu=is_normalized_cpu,
            limit=limit,
            sort=sort,
            tag_filters=tag_filters,
            text_filter=text_filter,
        )

        return typing.cast(None, jsii.invoke(self, "putProcessQuery", [value]))

    @jsii.member(jsii_name="putSloQuery")
    def put_slo_query(
        self,
        *,
        data_source: builtins.str,
        measure: builtins.str,
        slo_id: builtins.str,
        additional_query_filters: typing.Optional[builtins.str] = None,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        group_mode: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
        slo_query_type: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param data_source: The data source for SLO queries. Valid values are ``slo``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param measure: SLO measures queries. Valid values are ``good_events``, ``bad_events``, ``good_minutes``, ``bad_minutes``, ``slo_status``, ``error_budget_remaining``, ``burn_rate``, ``error_budget_burndown``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#measure Powerpack#measure}
        :param slo_id: ID of an SLO to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#slo_id Powerpack#slo_id}
        :param additional_query_filters: Additional filters applied to the SLO query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#additional_query_filters Powerpack#additional_query_filters}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param group_mode: Group mode to query measures. Valid values are ``overall``, ``components``. Defaults to ``"overall"``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_mode Powerpack#group_mode}
        :param name: The name of query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param slo_query_type: type of the SLO to query. Valid values are ``metric``, ``monitor``, ``time_slice``. Defaults to ``"metric"``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#slo_query_type Powerpack#slo_query_type}
        '''
        value = PowerpackWidgetTimeseriesDefinitionRequestQuerySloQuery(
            data_source=data_source,
            measure=measure,
            slo_id=slo_id,
            additional_query_filters=additional_query_filters,
            cross_org_uuids=cross_org_uuids,
            group_mode=group_mode,
            name=name,
            slo_query_type=slo_query_type,
        )

        return typing.cast(None, jsii.invoke(self, "putSloQuery", [value]))

    @jsii.member(jsii_name="resetApmDependencyStatsQuery")
    def reset_apm_dependency_stats_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetApmDependencyStatsQuery", []))

    @jsii.member(jsii_name="resetApmResourceStatsQuery")
    def reset_apm_resource_stats_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetApmResourceStatsQuery", []))

    @jsii.member(jsii_name="resetCloudCostQuery")
    def reset_cloud_cost_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCloudCostQuery", []))

    @jsii.member(jsii_name="resetEventQuery")
    def reset_event_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetEventQuery", []))

    @jsii.member(jsii_name="resetMetricQuery")
    def reset_metric_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMetricQuery", []))

    @jsii.member(jsii_name="resetProcessQuery")
    def reset_process_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetProcessQuery", []))

    @jsii.member(jsii_name="resetSloQuery")
    def reset_slo_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSloQuery", []))

    @builtins.property
    @jsii.member(jsii_name="apmDependencyStatsQuery")
    def apm_dependency_stats_query(
        self,
    ) -> PowerpackWidgetTimeseriesDefinitionRequestQueryApmDependencyStatsQueryOutputReference:
        return typing.cast(PowerpackWidgetTimeseriesDefinitionRequestQueryApmDependencyStatsQueryOutputReference, jsii.get(self, "apmDependencyStatsQuery"))

    @builtins.property
    @jsii.member(jsii_name="apmResourceStatsQuery")
    def apm_resource_stats_query(
        self,
    ) -> PowerpackWidgetTimeseriesDefinitionRequestQueryApmResourceStatsQueryOutputReference:
        return typing.cast(PowerpackWidgetTimeseriesDefinitionRequestQueryApmResourceStatsQueryOutputReference, jsii.get(self, "apmResourceStatsQuery"))

    @builtins.property
    @jsii.member(jsii_name="cloudCostQuery")
    def cloud_cost_query(
        self,
    ) -> PowerpackWidgetTimeseriesDefinitionRequestQueryCloudCostQueryOutputReference:
        return typing.cast(PowerpackWidgetTimeseriesDefinitionRequestQueryCloudCostQueryOutputReference, jsii.get(self, "cloudCostQuery"))

    @builtins.property
    @jsii.member(jsii_name="eventQuery")
    def event_query(
        self,
    ) -> PowerpackWidgetTimeseriesDefinitionRequestQueryEventQueryOutputReference:
        return typing.cast(PowerpackWidgetTimeseriesDefinitionRequestQueryEventQueryOutputReference, jsii.get(self, "eventQuery"))

    @builtins.property
    @jsii.member(jsii_name="metricQuery")
    def metric_query(
        self,
    ) -> PowerpackWidgetTimeseriesDefinitionRequestQueryMetricQueryOutputReference:
        return typing.cast(PowerpackWidgetTimeseriesDefinitionRequestQueryMetricQueryOutputReference, jsii.get(self, "metricQuery"))

    @builtins.property
    @jsii.member(jsii_name="processQuery")
    def process_query(
        self,
    ) -> "PowerpackWidgetTimeseriesDefinitionRequestQueryProcessQueryOutputReference":
        return typing.cast("PowerpackWidgetTimeseriesDefinitionRequestQueryProcessQueryOutputReference", jsii.get(self, "processQuery"))

    @builtins.property
    @jsii.member(jsii_name="sloQuery")
    def slo_query(
        self,
    ) -> "PowerpackWidgetTimeseriesDefinitionRequestQuerySloQueryOutputReference":
        return typing.cast("PowerpackWidgetTimeseriesDefinitionRequestQuerySloQueryOutputReference", jsii.get(self, "sloQuery"))

    @builtins.property
    @jsii.member(jsii_name="apmDependencyStatsQueryInput")
    def apm_dependency_stats_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestQueryApmDependencyStatsQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestQueryApmDependencyStatsQuery], jsii.get(self, "apmDependencyStatsQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="apmResourceStatsQueryInput")
    def apm_resource_stats_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestQueryApmResourceStatsQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestQueryApmResourceStatsQuery], jsii.get(self, "apmResourceStatsQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="cloudCostQueryInput")
    def cloud_cost_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestQueryCloudCostQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestQueryCloudCostQuery], jsii.get(self, "cloudCostQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="eventQueryInput")
    def event_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestQueryEventQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestQueryEventQuery], jsii.get(self, "eventQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="metricQueryInput")
    def metric_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestQueryMetricQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestQueryMetricQuery], jsii.get(self, "metricQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="processQueryInput")
    def process_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestQueryProcessQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestQueryProcessQuery"], jsii.get(self, "processQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="sloQueryInput")
    def slo_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestQuerySloQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestQuerySloQuery"], jsii.get(self, "sloQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTimeseriesDefinitionRequestQuery]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTimeseriesDefinitionRequestQuery]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTimeseriesDefinitionRequestQuery]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b4287e2c8d863c37a9e155059cfe8066f331d31d06e25e14b10662cd14fc4b6e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestQueryProcessQuery",
    jsii_struct_bases=[],
    name_mapping={
        "data_source": "dataSource",
        "metric": "metric",
        "name": "name",
        "aggregator": "aggregator",
        "cross_org_uuids": "crossOrgUuids",
        "is_normalized_cpu": "isNormalizedCpu",
        "limit": "limit",
        "sort": "sort",
        "tag_filters": "tagFilters",
        "text_filter": "textFilter",
    },
)
class PowerpackWidgetTimeseriesDefinitionRequestQueryProcessQuery:
    def __init__(
        self,
        *,
        data_source: builtins.str,
        metric: builtins.str,
        name: builtins.str,
        aggregator: typing.Optional[builtins.str] = None,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        is_normalized_cpu: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        limit: typing.Optional[jsii.Number] = None,
        sort: typing.Optional[builtins.str] = None,
        tag_filters: typing.Optional[typing.Sequence[builtins.str]] = None,
        text_filter: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param data_source: The data source for process queries. Valid values are ``process``, ``container``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param metric: The process metric name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        :param name: The name of query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param aggregator: The aggregation methods available for metrics queries. Valid values are ``avg``, ``min``, ``max``, ``sum``, ``last``, ``area``, ``l2norm``, ``percentile``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregator Powerpack#aggregator}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param is_normalized_cpu: Whether to normalize the CPU percentages. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#is_normalized_cpu Powerpack#is_normalized_cpu}
        :param limit: The number of hits to return. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param sort: The direction of the sort. Valid values are ``asc``, ``desc``. Defaults to ``"desc"``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort Powerpack#sort}
        :param tag_filters: An array of tags to filter by. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#tag_filters Powerpack#tag_filters}
        :param text_filter: The text to use as a filter. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#text_filter Powerpack#text_filter}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__81e7b2f18cfca3b2b4b7099dfade01164cb24d83c07dcc031554ac0473116f03)
            check_type(argname="argument data_source", value=data_source, expected_type=type_hints["data_source"])
            check_type(argname="argument metric", value=metric, expected_type=type_hints["metric"])
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument aggregator", value=aggregator, expected_type=type_hints["aggregator"])
            check_type(argname="argument cross_org_uuids", value=cross_org_uuids, expected_type=type_hints["cross_org_uuids"])
            check_type(argname="argument is_normalized_cpu", value=is_normalized_cpu, expected_type=type_hints["is_normalized_cpu"])
            check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
            check_type(argname="argument sort", value=sort, expected_type=type_hints["sort"])
            check_type(argname="argument tag_filters", value=tag_filters, expected_type=type_hints["tag_filters"])
            check_type(argname="argument text_filter", value=text_filter, expected_type=type_hints["text_filter"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "data_source": data_source,
            "metric": metric,
            "name": name,
        }
        if aggregator is not None:
            self._values["aggregator"] = aggregator
        if cross_org_uuids is not None:
            self._values["cross_org_uuids"] = cross_org_uuids
        if is_normalized_cpu is not None:
            self._values["is_normalized_cpu"] = is_normalized_cpu
        if limit is not None:
            self._values["limit"] = limit
        if sort is not None:
            self._values["sort"] = sort
        if tag_filters is not None:
            self._values["tag_filters"] = tag_filters
        if text_filter is not None:
            self._values["text_filter"] = text_filter

    @builtins.property
    def data_source(self) -> builtins.str:
        '''The data source for process queries. Valid values are ``process``, ``container``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        '''
        result = self._values.get("data_source")
        assert result is not None, "Required property 'data_source' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def metric(self) -> builtins.str:
        '''The process metric name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        '''
        result = self._values.get("metric")
        assert result is not None, "Required property 'metric' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def name(self) -> builtins.str:
        '''The name of query for use in formulas.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        '''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def aggregator(self) -> typing.Optional[builtins.str]:
        '''The aggregation methods available for metrics queries. Valid values are ``avg``, ``min``, ``max``, ``sum``, ``last``, ``area``, ``l2norm``, ``percentile``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregator Powerpack#aggregator}
        '''
        result = self._values.get("aggregator")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def cross_org_uuids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''The source organization UUID for cross organization queries. Feature in Private Beta.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        '''
        result = self._values.get("cross_org_uuids")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def is_normalized_cpu(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        '''Whether to normalize the CPU percentages.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#is_normalized_cpu Powerpack#is_normalized_cpu}
        '''
        result = self._values.get("is_normalized_cpu")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)

    @builtins.property
    def limit(self) -> typing.Optional[jsii.Number]:
        '''The number of hits to return.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        '''
        result = self._values.get("limit")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def sort(self) -> typing.Optional[builtins.str]:
        '''The direction of the sort. Valid values are ``asc``, ``desc``. Defaults to ``"desc"``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort Powerpack#sort}
        '''
        result = self._values.get("sort")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def tag_filters(self) -> typing.Optional[typing.List[builtins.str]]:
        '''An array of tags to filter by.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#tag_filters Powerpack#tag_filters}
        '''
        result = self._values.get("tag_filters")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def text_filter(self) -> typing.Optional[builtins.str]:
        '''The text to use as a filter.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#text_filter Powerpack#text_filter}
        '''
        result = self._values.get("text_filter")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetTimeseriesDefinitionRequestQueryProcessQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetTimeseriesDefinitionRequestQueryProcessQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestQueryProcessQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c4f4855457d92e6dd26f8bb48e5cbe97ed940c1a81f7dd94a72079b548d80bb9)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetAggregator")
    def reset_aggregator(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAggregator", []))

    @jsii.member(jsii_name="resetCrossOrgUuids")
    def reset_cross_org_uuids(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCrossOrgUuids", []))

    @jsii.member(jsii_name="resetIsNormalizedCpu")
    def reset_is_normalized_cpu(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetIsNormalizedCpu", []))

    @jsii.member(jsii_name="resetLimit")
    def reset_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLimit", []))

    @jsii.member(jsii_name="resetSort")
    def reset_sort(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSort", []))

    @jsii.member(jsii_name="resetTagFilters")
    def reset_tag_filters(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTagFilters", []))

    @jsii.member(jsii_name="resetTextFilter")
    def reset_text_filter(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTextFilter", []))

    @builtins.property
    @jsii.member(jsii_name="aggregatorInput")
    def aggregator_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregatorInput"))

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuidsInput")
    def cross_org_uuids_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "crossOrgUuidsInput"))

    @builtins.property
    @jsii.member(jsii_name="dataSourceInput")
    def data_source_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "dataSourceInput"))

    @builtins.property
    @jsii.member(jsii_name="isNormalizedCpuInput")
    def is_normalized_cpu_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "isNormalizedCpuInput"))

    @builtins.property
    @jsii.member(jsii_name="limitInput")
    def limit_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "limitInput"))

    @builtins.property
    @jsii.member(jsii_name="metricInput")
    def metric_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "metricInput"))

    @builtins.property
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property
    @jsii.member(jsii_name="sortInput")
    def sort_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "sortInput"))

    @builtins.property
    @jsii.member(jsii_name="tagFiltersInput")
    def tag_filters_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "tagFiltersInput"))

    @builtins.property
    @jsii.member(jsii_name="textFilterInput")
    def text_filter_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "textFilterInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregator")
    def aggregator(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregator"))

    @aggregator.setter
    def aggregator(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6baf37ff28b6da811f748b3faecc23ddcfe4905c12cabde2d89d378c7e496f09)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregator", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuids")
    def cross_org_uuids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "crossOrgUuids"))

    @cross_org_uuids.setter
    def cross_org_uuids(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a5376d462b4bb6e5fac5707e434a0dd171c41e639a3b876e4523bd4de76bc864)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "crossOrgUuids", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="dataSource")
    def data_source(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "dataSource"))

    @data_source.setter
    def data_source(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d488d905f5c9a83fee89a43c00cb86f23371ff2a6a5011b4accaa8477290dc9b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "dataSource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="isNormalizedCpu")
    def is_normalized_cpu(
        self,
    ) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "isNormalizedCpu"))

    @is_normalized_cpu.setter
    def is_normalized_cpu(
        self,
        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fc73bc028602ba759b7a0621b38df6bb5827a6ee3aecde213b8c252c72ebc588)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "isNormalizedCpu", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="limit")
    def limit(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "limit"))

    @limit.setter
    def limit(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__590283de44f876f3d1da4a4b0900e47fcdd3ec248603aad7024149c0f6740d35)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "limit", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="metric")
    def metric(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "metric"))

    @metric.setter
    def metric(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__198094afa367739b44a8572c395edc27473995a1e9028afc961fe9d039eeb201)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "metric", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ce5e160ca5b365526362dea254ae6b2114ef913611b3c23e911095f91665b8c0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "name", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="sort")
    def sort(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "sort"))

    @sort.setter
    def sort(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d8227e7864fbf6ef1f4c5f4654624bec019aa210436af94c097ab72cb8b048b0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "sort", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="tagFilters")
    def tag_filters(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "tagFilters"))

    @tag_filters.setter
    def tag_filters(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__49e48723e34826df7d0929f61721408934a2e7b50ddf073555827cceb64f34a3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "tagFilters", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="textFilter")
    def text_filter(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "textFilter"))

    @text_filter.setter
    def text_filter(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3df9b2288a21dad8be1a1b19df892f1fb80e2ebbaa876ceae2f541fef4fb755f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "textFilter", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestQueryProcessQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestQueryProcessQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestQueryProcessQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__464ab4c096da91bc9e7a0706db51619724178c2a81a251ee61f303d0168e81e2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestQuerySloQuery",
    jsii_struct_bases=[],
    name_mapping={
        "data_source": "dataSource",
        "measure": "measure",
        "slo_id": "sloId",
        "additional_query_filters": "additionalQueryFilters",
        "cross_org_uuids": "crossOrgUuids",
        "group_mode": "groupMode",
        "name": "name",
        "slo_query_type": "sloQueryType",
    },
)
class PowerpackWidgetTimeseriesDefinitionRequestQuerySloQuery:
    def __init__(
        self,
        *,
        data_source: builtins.str,
        measure: builtins.str,
        slo_id: builtins.str,
        additional_query_filters: typing.Optional[builtins.str] = None,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        group_mode: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
        slo_query_type: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param data_source: The data source for SLO queries. Valid values are ``slo``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param measure: SLO measures queries. Valid values are ``good_events``, ``bad_events``, ``good_minutes``, ``bad_minutes``, ``slo_status``, ``error_budget_remaining``, ``burn_rate``, ``error_budget_burndown``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#measure Powerpack#measure}
        :param slo_id: ID of an SLO to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#slo_id Powerpack#slo_id}
        :param additional_query_filters: Additional filters applied to the SLO query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#additional_query_filters Powerpack#additional_query_filters}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param group_mode: Group mode to query measures. Valid values are ``overall``, ``components``. Defaults to ``"overall"``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_mode Powerpack#group_mode}
        :param name: The name of query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param slo_query_type: type of the SLO to query. Valid values are ``metric``, ``monitor``, ``time_slice``. Defaults to ``"metric"``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#slo_query_type Powerpack#slo_query_type}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0934f6ffe25b840adf939a73e2d35c72a8f05f6848a399870f95d354fcb448af)
            check_type(argname="argument data_source", value=data_source, expected_type=type_hints["data_source"])
            check_type(argname="argument measure", value=measure, expected_type=type_hints["measure"])
            check_type(argname="argument slo_id", value=slo_id, expected_type=type_hints["slo_id"])
            check_type(argname="argument additional_query_filters", value=additional_query_filters, expected_type=type_hints["additional_query_filters"])
            check_type(argname="argument cross_org_uuids", value=cross_org_uuids, expected_type=type_hints["cross_org_uuids"])
            check_type(argname="argument group_mode", value=group_mode, expected_type=type_hints["group_mode"])
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument slo_query_type", value=slo_query_type, expected_type=type_hints["slo_query_type"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "data_source": data_source,
            "measure": measure,
            "slo_id": slo_id,
        }
        if additional_query_filters is not None:
            self._values["additional_query_filters"] = additional_query_filters
        if cross_org_uuids is not None:
            self._values["cross_org_uuids"] = cross_org_uuids
        if group_mode is not None:
            self._values["group_mode"] = group_mode
        if name is not None:
            self._values["name"] = name
        if slo_query_type is not None:
            self._values["slo_query_type"] = slo_query_type

    @builtins.property
    def data_source(self) -> builtins.str:
        '''The data source for SLO queries. Valid values are ``slo``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        '''
        result = self._values.get("data_source")
        assert result is not None, "Required property 'data_source' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def measure(self) -> builtins.str:
        '''SLO measures queries. Valid values are ``good_events``, ``bad_events``, ``good_minutes``, ``bad_minutes``, ``slo_status``, ``error_budget_remaining``, ``burn_rate``, ``error_budget_burndown``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#measure Powerpack#measure}
        '''
        result = self._values.get("measure")
        assert result is not None, "Required property 'measure' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def slo_id(self) -> builtins.str:
        '''ID of an SLO to query.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#slo_id Powerpack#slo_id}
        '''
        result = self._values.get("slo_id")
        assert result is not None, "Required property 'slo_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def additional_query_filters(self) -> typing.Optional[builtins.str]:
        '''Additional filters applied to the SLO query.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#additional_query_filters Powerpack#additional_query_filters}
        '''
        result = self._values.get("additional_query_filters")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def cross_org_uuids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''The source organization UUID for cross organization queries. Feature in Private Beta.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        '''
        result = self._values.get("cross_org_uuids")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def group_mode(self) -> typing.Optional[builtins.str]:
        '''Group mode to query measures. Valid values are ``overall``, ``components``. Defaults to ``"overall"``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_mode Powerpack#group_mode}
        '''
        result = self._values.get("group_mode")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''The name of query for use in formulas.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        '''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def slo_query_type(self) -> typing.Optional[builtins.str]:
        '''type of the SLO to query. Valid values are ``metric``, ``monitor``, ``time_slice``. Defaults to ``"metric"``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#slo_query_type Powerpack#slo_query_type}
        '''
        result = self._values.get("slo_query_type")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetTimeseriesDefinitionRequestQuerySloQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetTimeseriesDefinitionRequestQuerySloQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestQuerySloQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a784df6068f129ebf344a9d77a0e249b3d032df8490ba05c852a07e07ab65f9a)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetAdditionalQueryFilters")
    def reset_additional_query_filters(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAdditionalQueryFilters", []))

    @jsii.member(jsii_name="resetCrossOrgUuids")
    def reset_cross_org_uuids(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCrossOrgUuids", []))

    @jsii.member(jsii_name="resetGroupMode")
    def reset_group_mode(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGroupMode", []))

    @jsii.member(jsii_name="resetName")
    def reset_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetName", []))

    @jsii.member(jsii_name="resetSloQueryType")
    def reset_slo_query_type(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSloQueryType", []))

    @builtins.property
    @jsii.member(jsii_name="additionalQueryFiltersInput")
    def additional_query_filters_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "additionalQueryFiltersInput"))

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuidsInput")
    def cross_org_uuids_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "crossOrgUuidsInput"))

    @builtins.property
    @jsii.member(jsii_name="dataSourceInput")
    def data_source_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "dataSourceInput"))

    @builtins.property
    @jsii.member(jsii_name="groupModeInput")
    def group_mode_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "groupModeInput"))

    @builtins.property
    @jsii.member(jsii_name="measureInput")
    def measure_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "measureInput"))

    @builtins.property
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property
    @jsii.member(jsii_name="sloIdInput")
    def slo_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "sloIdInput"))

    @builtins.property
    @jsii.member(jsii_name="sloQueryTypeInput")
    def slo_query_type_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "sloQueryTypeInput"))

    @builtins.property
    @jsii.member(jsii_name="additionalQueryFilters")
    def additional_query_filters(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "additionalQueryFilters"))

    @additional_query_filters.setter
    def additional_query_filters(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__154d8a30e659497d27752fffaf41a11221a555d8fc506b0bd96a54cc81f65c4d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "additionalQueryFilters", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuids")
    def cross_org_uuids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "crossOrgUuids"))

    @cross_org_uuids.setter
    def cross_org_uuids(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a615b3d55836c9b276d012359ab7f2df8e3f41b39b2c0125eef47e4e8de1654a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "crossOrgUuids", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="dataSource")
    def data_source(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "dataSource"))

    @data_source.setter
    def data_source(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__46707c2a54d11734e5e96900693aeb6f789f15cb184742e7bfa00db4dd13f656)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "dataSource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="groupMode")
    def group_mode(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "groupMode"))

    @group_mode.setter
    def group_mode(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__abb6ff80cce937f330f37fe17b29645037acffabfadb0b3c7027f934fe551f41)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "groupMode", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="measure")
    def measure(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "measure"))

    @measure.setter
    def measure(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d01c5f668b20b8a59d3ce827d1fd20f37ad920463047e9aa324ab0e75dca8b8a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "measure", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c5c5a0fe660bf4a950c63b3f22d0ddf5ad60dbdaf8e613484c73fe4afd14b182)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "name", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="sloId")
    def slo_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "sloId"))

    @slo_id.setter
    def slo_id(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__599f728df1408b7ec93cf1081ea1a5de896b7c0fe49b7d3c0020e51986ba72c7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "sloId", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="sloQueryType")
    def slo_query_type(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "sloQueryType"))

    @slo_query_type.setter
    def slo_query_type(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6ccee986d75fa7dbcb88bddcb0347083585990546d01e63ccc3937854f9954bb)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "sloQueryType", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestQuerySloQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestQuerySloQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestQuerySloQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__85e8d71a2ee8ce093697fed566829fae0f88836b39549a3392ea07e04fe64689)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestRumQuery",
    jsii_struct_bases=[],
    name_mapping={
        "index": "index",
        "compute_query": "computeQuery",
        "group_by": "groupBy",
        "multi_compute": "multiCompute",
        "search_query": "searchQuery",
    },
)
class PowerpackWidgetTimeseriesDefinitionRequestRumQuery:
    def __init__(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union["PowerpackWidgetTimeseriesDefinitionRequestRumQueryComputeQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetTimeseriesDefinitionRequestRumQueryGroupBy", typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetTimeseriesDefinitionRequestRumQueryMultiCompute", typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        if isinstance(compute_query, dict):
            compute_query = PowerpackWidgetTimeseriesDefinitionRequestRumQueryComputeQuery(**compute_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f1e15116a3cb82b24b14499170141e244eb31ba673f158465628e4f03e550449)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
            check_type(argname="argument compute_query", value=compute_query, expected_type=type_hints["compute_query"])
            check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
            check_type(argname="argument multi_compute", value=multi_compute, expected_type=type_hints["multi_compute"])
            check_type(argname="argument search_query", value=search_query, expected_type=type_hints["search_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "index": index,
        }
        if compute_query is not None:
            self._values["compute_query"] = compute_query
        if group_by is not None:
            self._values["group_by"] = group_by
        if multi_compute is not None:
            self._values["multi_compute"] = multi_compute
        if search_query is not None:
            self._values["search_query"] = search_query

    @builtins.property
    def index(self) -> builtins.str:
        '''The name of the index to query.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        '''
        result = self._values.get("index")
        assert result is not None, "Required property 'index' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def compute_query(
        self,
    ) -> typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestRumQueryComputeQuery"]:
        '''compute_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        '''
        result = self._values.get("compute_query")
        return typing.cast(typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestRumQueryComputeQuery"], result)

    @builtins.property
    def group_by(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetTimeseriesDefinitionRequestRumQueryGroupBy"]]]:
        '''group_by block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        '''
        result = self._values.get("group_by")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetTimeseriesDefinitionRequestRumQueryGroupBy"]]], result)

    @builtins.property
    def multi_compute(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetTimeseriesDefinitionRequestRumQueryMultiCompute"]]]:
        '''multi_compute block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        '''
        result = self._values.get("multi_compute")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetTimeseriesDefinitionRequestRumQueryMultiCompute"]]], result)

    @builtins.property
    def search_query(self) -> typing.Optional[builtins.str]:
        '''The search query to use.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        result = self._values.get("search_query")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetTimeseriesDefinitionRequestRumQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestRumQueryComputeQuery",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetTimeseriesDefinitionRequestRumQueryComputeQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5159233f31a116458e80de064da0919438f35ad97871e6165c96d765f132c3e5)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetTimeseriesDefinitionRequestRumQueryComputeQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetTimeseriesDefinitionRequestRumQueryComputeQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestRumQueryComputeQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__61fcd795ab17d36242ebfd99e16fad0893f1b4b638f84c9aee6c5f96824daac9)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__08314ffddc963804428935f950300517c80a64f3a9ab40b757c193ceb007a8a5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__451b8f5da91a7decb5f59b6c2c5702627f62461ab5c62bb6c9082317e87dc560)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6bd5fe35a71b6ae770f61ab60e754bbbfa86a9c0ba2bd76da3796a2ec3a32606)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestRumQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestRumQueryComputeQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestRumQueryComputeQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__814b4eeb49a8c455cda94697fa4eabb58315e10a512ecf324672202f2a6d990d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestRumQueryGroupBy",
    jsii_struct_bases=[],
    name_mapping={"facet": "facet", "limit": "limit", "sort_query": "sortQuery"},
)
class PowerpackWidgetTimeseriesDefinitionRequestRumQueryGroupBy:
    def __init__(
        self,
        *,
        facet: typing.Optional[builtins.str] = None,
        limit: typing.Optional[jsii.Number] = None,
        sort_query: typing.Optional[typing.Union["PowerpackWidgetTimeseriesDefinitionRequestRumQueryGroupBySortQuery", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param limit: The maximum number of items in the group. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param sort_query: sort_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        if isinstance(sort_query, dict):
            sort_query = PowerpackWidgetTimeseriesDefinitionRequestRumQueryGroupBySortQuery(**sort_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e34ff591efc20a78af4274fed2ab61291890524a62b442987c2a9cd50f92af29)
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
            check_type(argname="argument sort_query", value=sort_query, expected_type=type_hints["sort_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if facet is not None:
            self._values["facet"] = facet
        if limit is not None:
            self._values["limit"] = limit
        if sort_query is not None:
            self._values["sort_query"] = sort_query

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def limit(self) -> typing.Optional[jsii.Number]:
        '''The maximum number of items in the group.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        '''
        result = self._values.get("limit")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def sort_query(
        self,
    ) -> typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestRumQueryGroupBySortQuery"]:
        '''sort_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        result = self._values.get("sort_query")
        return typing.cast(typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestRumQueryGroupBySortQuery"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetTimeseriesDefinitionRequestRumQueryGroupBy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetTimeseriesDefinitionRequestRumQueryGroupByList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestRumQueryGroupByList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d8297ca65b53b28f7b72f786e508006dd763e9f443b71f1883cc647495d9fa98)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetTimeseriesDefinitionRequestRumQueryGroupByOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0763c93e85211ca9a3d56def2083b2d2021bce0e0e5bf652bba5c5928244e55d)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetTimeseriesDefinitionRequestRumQueryGroupByOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__470adb864a19c61da83999303a30bfb5926de8d9df581a021d8e4b9f57757270)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__12a1af8da6b169e5a323bb105130ad345625ed7e19d944116491a492db41a68c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__232c39f8b880eb448c5b909abc279f7400fa31e1efac0b0d28e5d8df22310db7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestRumQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestRumQueryGroupBy]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestRumQueryGroupBy]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8754c6930865aa8f2edcc7f79720cb635e12b5140fc8a297803bb65e39907e64)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetTimeseriesDefinitionRequestRumQueryGroupByOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestRumQueryGroupByOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2757d2b4dd81d6f5b17b11c77a8f8a4b0bc471de8c92151208854786322b9feb)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putSortQuery")
    def put_sort_query(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        value = PowerpackWidgetTimeseriesDefinitionRequestRumQueryGroupBySortQuery(
            aggregation=aggregation, order=order, facet=facet
        )

        return typing.cast(None, jsii.invoke(self, "putSortQuery", [value]))

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetLimit")
    def reset_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLimit", []))

    @jsii.member(jsii_name="resetSortQuery")
    def reset_sort_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSortQuery", []))

    @builtins.property
    @jsii.member(jsii_name="sortQuery")
    def sort_query(
        self,
    ) -> "PowerpackWidgetTimeseriesDefinitionRequestRumQueryGroupBySortQueryOutputReference":
        return typing.cast("PowerpackWidgetTimeseriesDefinitionRequestRumQueryGroupBySortQueryOutputReference", jsii.get(self, "sortQuery"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="limitInput")
    def limit_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "limitInput"))

    @builtins.property
    @jsii.member(jsii_name="sortQueryInput")
    def sort_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestRumQueryGroupBySortQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestRumQueryGroupBySortQuery"], jsii.get(self, "sortQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__18a0e6233cefd3ce60e794838f099d3edee1bdff6e271b63b1774769a0ef6fc6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="limit")
    def limit(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "limit"))

    @limit.setter
    def limit(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a3fdeb8807fef621c101eed154adbb23a3f195a8887d988220b6e6725b62d55c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "limit", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTimeseriesDefinitionRequestRumQueryGroupBy]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTimeseriesDefinitionRequestRumQueryGroupBy]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTimeseriesDefinitionRequestRumQueryGroupBy]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__078f4ab9deaf6f02d875fb7c431ea3ff8f9a7d9fb3b8c9c15dfc240a9b650244)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestRumQueryGroupBySortQuery",
    jsii_struct_bases=[],
    name_mapping={"aggregation": "aggregation", "order": "order", "facet": "facet"},
)
class PowerpackWidgetTimeseriesDefinitionRequestRumQueryGroupBySortQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6f91a3eb615adc714214abb092ceb49c8f8cfc48e389d262cf562d248e233b7c)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument order", value=order, expected_type=type_hints["order"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
            "order": order,
        }
        if facet is not None:
            self._values["facet"] = facet

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def order(self) -> builtins.str:
        '''Widget sorting methods. Valid values are ``asc``, ``desc``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        result = self._values.get("order")
        assert result is not None, "Required property 'order' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetTimeseriesDefinitionRequestRumQueryGroupBySortQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetTimeseriesDefinitionRequestRumQueryGroupBySortQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestRumQueryGroupBySortQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a7e0732765beee1fde28b3abf73203458d73c45ca0521be1c2c5f7cd9d9469e3)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="orderInput")
    def order_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "orderInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d1a342585f9eea8c7dd2dd19dce367aea66ddfc280f1a0c1cc6219cbfb1b871c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__636046dc62141e3b3156db6743282146f0b1e237b5d025be1319b258f990de50)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="order")
    def order(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "order"))

    @order.setter
    def order(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e9c1e5a65530341b720fb12b637f9e223ffb758477a5e031d473a2fe30bb927b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "order", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestRumQueryGroupBySortQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestRumQueryGroupBySortQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestRumQueryGroupBySortQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8e0c1b12d3678154a97629da35ce502a0b80b79cea3c00dd4adee2170c16f2d2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestRumQueryMultiCompute",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetTimeseriesDefinitionRequestRumQueryMultiCompute:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6840209a9a03d8e2b4bcaa837c9d2fa032b054a6a01234e2462d35aa94c3bf42)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetTimeseriesDefinitionRequestRumQueryMultiCompute(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetTimeseriesDefinitionRequestRumQueryMultiComputeList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestRumQueryMultiComputeList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3f2cc970143d6a4df15fcf2b1d86bcea6ff0757eb45149de6ffd889b4c55399e)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetTimeseriesDefinitionRequestRumQueryMultiComputeOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0cfe91c6991b0c5b101e1477836af7cb1609943f5c4393f97485ae17d4d1a32b)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetTimeseriesDefinitionRequestRumQueryMultiComputeOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ec856ec028b535160bc67396b1454acb8b2d0ce78f970bbdb7be28dfa7c71f02)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__49f628aeb54879d17bf1c84be3d1c95d8f5227ac7d984755b5d172ae800e1f9d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7184ca1f1cb83a43996ae7a95dc01817a7e7cea605fd34dd779f6c2dfc3abaf6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestRumQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestRumQueryMultiCompute]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestRumQueryMultiCompute]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f55be7707a5e844b94bb353593672627470624ff826013acee57ba6a58c6800c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetTimeseriesDefinitionRequestRumQueryMultiComputeOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestRumQueryMultiComputeOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__891cd580f195f052f9e54387c4f58c505b6284f6063f6e77f8b6a2713bfc664b)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__74b0cb3189e65d45afc49f4d85e09e551768b7750122e8e225f8e1bb5dadae68)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9de78d0628a64854de7a9d18da8d1b590680763f0f27fe154efffa8792385ac0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4a1454e90e59128456185b21bad9ad50b7e88def46299d98d881d44ec8da9602)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTimeseriesDefinitionRequestRumQueryMultiCompute]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTimeseriesDefinitionRequestRumQueryMultiCompute]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTimeseriesDefinitionRequestRumQueryMultiCompute]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3fe00ee7edc4ad94fde7ce6070b7010a0b3516a818c2e88ab1563c9eb20ebdc6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetTimeseriesDefinitionRequestRumQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestRumQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a93fe5e65f2addfb614b7ca76d03c37214f83b5cdacad776d302d129584f8205)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putComputeQuery")
    def put_compute_query(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        value = PowerpackWidgetTimeseriesDefinitionRequestRumQueryComputeQuery(
            aggregation=aggregation, facet=facet, interval=interval
        )

        return typing.cast(None, jsii.invoke(self, "putComputeQuery", [value]))

    @jsii.member(jsii_name="putGroupBy")
    def put_group_by(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestRumQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5406879d06ad6eea3ebbeacd06a5e1b7ab38fee63da89a4e6ebf4617b0e469da)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putGroupBy", [value]))

    @jsii.member(jsii_name="putMultiCompute")
    def put_multi_compute(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestRumQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__03de81b229400417bddf80614c2f073807788b9954ad81e9faea239dccc6a002)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putMultiCompute", [value]))

    @jsii.member(jsii_name="resetComputeQuery")
    def reset_compute_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetComputeQuery", []))

    @jsii.member(jsii_name="resetGroupBy")
    def reset_group_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGroupBy", []))

    @jsii.member(jsii_name="resetMultiCompute")
    def reset_multi_compute(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMultiCompute", []))

    @jsii.member(jsii_name="resetSearchQuery")
    def reset_search_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSearchQuery", []))

    @builtins.property
    @jsii.member(jsii_name="computeQuery")
    def compute_query(
        self,
    ) -> PowerpackWidgetTimeseriesDefinitionRequestRumQueryComputeQueryOutputReference:
        return typing.cast(PowerpackWidgetTimeseriesDefinitionRequestRumQueryComputeQueryOutputReference, jsii.get(self, "computeQuery"))

    @builtins.property
    @jsii.member(jsii_name="groupBy")
    def group_by(self) -> PowerpackWidgetTimeseriesDefinitionRequestRumQueryGroupByList:
        return typing.cast(PowerpackWidgetTimeseriesDefinitionRequestRumQueryGroupByList, jsii.get(self, "groupBy"))

    @builtins.property
    @jsii.member(jsii_name="multiCompute")
    def multi_compute(
        self,
    ) -> PowerpackWidgetTimeseriesDefinitionRequestRumQueryMultiComputeList:
        return typing.cast(PowerpackWidgetTimeseriesDefinitionRequestRumQueryMultiComputeList, jsii.get(self, "multiCompute"))

    @builtins.property
    @jsii.member(jsii_name="computeQueryInput")
    def compute_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestRumQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestRumQueryComputeQuery], jsii.get(self, "computeQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="groupByInput")
    def group_by_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestRumQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestRumQueryGroupBy]]], jsii.get(self, "groupByInput"))

    @builtins.property
    @jsii.member(jsii_name="indexInput")
    def index_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "indexInput"))

    @builtins.property
    @jsii.member(jsii_name="multiComputeInput")
    def multi_compute_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestRumQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestRumQueryMultiCompute]]], jsii.get(self, "multiComputeInput"))

    @builtins.property
    @jsii.member(jsii_name="searchQueryInput")
    def search_query_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "searchQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="index")
    def index(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "index"))

    @index.setter
    def index(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0884e3e2b1d55d4301f5ada8e994c31dbe2b27a87dfba29d050585e5708b7295)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "index", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="searchQuery")
    def search_query(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "searchQuery"))

    @search_query.setter
    def search_query(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__94757794c40c30e41b4fa6f4d1a12e822fb4c48bd87d5f15218e720ac10bd947)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "searchQuery", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestRumQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestRumQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestRumQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fba140d80226034b00735cff19645e2aeab0a17d5b5c2bdc0005466bf85cdad6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestSecurityQuery",
    jsii_struct_bases=[],
    name_mapping={
        "index": "index",
        "compute_query": "computeQuery",
        "group_by": "groupBy",
        "multi_compute": "multiCompute",
        "search_query": "searchQuery",
    },
)
class PowerpackWidgetTimeseriesDefinitionRequestSecurityQuery:
    def __init__(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union["PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryComputeQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryGroupBy", typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryMultiCompute", typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        if isinstance(compute_query, dict):
            compute_query = PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryComputeQuery(**compute_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__27c1430b5d8a764a2f059dcdf3e1bb6b19fda04e2e7f906882b1d20300f9d497)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
            check_type(argname="argument compute_query", value=compute_query, expected_type=type_hints["compute_query"])
            check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
            check_type(argname="argument multi_compute", value=multi_compute, expected_type=type_hints["multi_compute"])
            check_type(argname="argument search_query", value=search_query, expected_type=type_hints["search_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "index": index,
        }
        if compute_query is not None:
            self._values["compute_query"] = compute_query
        if group_by is not None:
            self._values["group_by"] = group_by
        if multi_compute is not None:
            self._values["multi_compute"] = multi_compute
        if search_query is not None:
            self._values["search_query"] = search_query

    @builtins.property
    def index(self) -> builtins.str:
        '''The name of the index to query.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        '''
        result = self._values.get("index")
        assert result is not None, "Required property 'index' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def compute_query(
        self,
    ) -> typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryComputeQuery"]:
        '''compute_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        '''
        result = self._values.get("compute_query")
        return typing.cast(typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryComputeQuery"], result)

    @builtins.property
    def group_by(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryGroupBy"]]]:
        '''group_by block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        '''
        result = self._values.get("group_by")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryGroupBy"]]], result)

    @builtins.property
    def multi_compute(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryMultiCompute"]]]:
        '''multi_compute block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        '''
        result = self._values.get("multi_compute")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryMultiCompute"]]], result)

    @builtins.property
    def search_query(self) -> typing.Optional[builtins.str]:
        '''The search query to use.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        result = self._values.get("search_query")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetTimeseriesDefinitionRequestSecurityQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryComputeQuery",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryComputeQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6a0a5ea30ca04827a40ac7e8460cd0bbc343f831ebd8b725ceb0cb17fc4caedc)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryComputeQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryComputeQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryComputeQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4b9ad0001b170eb16f4ec59c663f8e783713760e6727ab63a619eff29fd3b298)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9d2a4b45083acd25305282ffa03ce0521391006ef17114b19f597a0b021d6d51)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ef95d77a714fc549bd47a365103e4f203e5e8d9e678a54b4df813d499d4180c7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__84d57f78b0eae46c1d156ed40ec41d23a75e5cbc0ce62d2182e633c9c3d80216)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryComputeQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryComputeQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__07b204a10df552da4bcd827011771818fbaa9d561ce7a8dec7bf357ae9650a1e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryGroupBy",
    jsii_struct_bases=[],
    name_mapping={"facet": "facet", "limit": "limit", "sort_query": "sortQuery"},
)
class PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryGroupBy:
    def __init__(
        self,
        *,
        facet: typing.Optional[builtins.str] = None,
        limit: typing.Optional[jsii.Number] = None,
        sort_query: typing.Optional[typing.Union["PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryGroupBySortQuery", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param limit: The maximum number of items in the group. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param sort_query: sort_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        if isinstance(sort_query, dict):
            sort_query = PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryGroupBySortQuery(**sort_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6882877ddaee08d412066d2eb09f4bf75830e763fa5a9ef9d849b1323ae56819)
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
            check_type(argname="argument sort_query", value=sort_query, expected_type=type_hints["sort_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if facet is not None:
            self._values["facet"] = facet
        if limit is not None:
            self._values["limit"] = limit
        if sort_query is not None:
            self._values["sort_query"] = sort_query

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def limit(self) -> typing.Optional[jsii.Number]:
        '''The maximum number of items in the group.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        '''
        result = self._values.get("limit")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def sort_query(
        self,
    ) -> typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryGroupBySortQuery"]:
        '''sort_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        result = self._values.get("sort_query")
        return typing.cast(typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryGroupBySortQuery"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryGroupBy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryGroupByList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryGroupByList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__45e6eb27bbc5a02024a9a5654efe3c3adc607889e098d1fbefc87e3b318f8c8d)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryGroupByOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d3497a23ae0205302b4484db6121015e271b905db2e948178defcc5f2179d840)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryGroupByOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bcc41abc094c6db627a5229858c3c6a547c4fe5e63039b5e86b0a3a3854a474b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c70225b5f105ee7be79c182b4a21ddf2aa2233ed7c6dda5aba004a5d98733733)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0292cf5cf0834cbc2f7c2ce08c8d55de47e93e2d523310e23ca8dd4c0edc410c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryGroupBy]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryGroupBy]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8f5c950f1b7595ac62c3c871c7a187114f1af6f9a38373e5243216a08e84afa2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryGroupByOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryGroupByOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__35c88829239ebb576fb92741015dac1011d2159ae00bd5763278fe85e16882f5)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putSortQuery")
    def put_sort_query(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        value = PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryGroupBySortQuery(
            aggregation=aggregation, order=order, facet=facet
        )

        return typing.cast(None, jsii.invoke(self, "putSortQuery", [value]))

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetLimit")
    def reset_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLimit", []))

    @jsii.member(jsii_name="resetSortQuery")
    def reset_sort_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSortQuery", []))

    @builtins.property
    @jsii.member(jsii_name="sortQuery")
    def sort_query(
        self,
    ) -> "PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryGroupBySortQueryOutputReference":
        return typing.cast("PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryGroupBySortQueryOutputReference", jsii.get(self, "sortQuery"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="limitInput")
    def limit_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "limitInput"))

    @builtins.property
    @jsii.member(jsii_name="sortQueryInput")
    def sort_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryGroupBySortQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryGroupBySortQuery"], jsii.get(self, "sortQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d2a23902a2d33fbc5205d5e322ff2a57a21c9f52fb4e8c975eef75317266f536)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="limit")
    def limit(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "limit"))

    @limit.setter
    def limit(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9ab1896c423e0d8b5639890d15154db3932a976832d495c20de777c2734e74cf)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "limit", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryGroupBy]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryGroupBy]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryGroupBy]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e75bb1742b5853189ae61c7d8cf04a42653805a05e1274fd9a4daca4c3435ac6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryGroupBySortQuery",
    jsii_struct_bases=[],
    name_mapping={"aggregation": "aggregation", "order": "order", "facet": "facet"},
)
class PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryGroupBySortQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d646495971f534cfc76b6cc1c188bee0e13f8172452f90659944dffaec4963a5)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument order", value=order, expected_type=type_hints["order"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
            "order": order,
        }
        if facet is not None:
            self._values["facet"] = facet

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def order(self) -> builtins.str:
        '''Widget sorting methods. Valid values are ``asc``, ``desc``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        result = self._values.get("order")
        assert result is not None, "Required property 'order' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryGroupBySortQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryGroupBySortQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryGroupBySortQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__750105fbd729aa45404e44e7a792a86ace2588905241b18c1234030ed2d14874)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="orderInput")
    def order_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "orderInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ece3835b914dabaaa5f0a29ec51bc3c841f84dca93f76a5cb6144329c696ecaa)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__79159daf8f3bd9b5ef59f2371fb49402ee1821b0d66bad39c782720c0ab0ec03)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="order")
    def order(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "order"))

    @order.setter
    def order(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b968264dcaab00e4fea3ac9b78d6f2324024f08a0f3e8a0bb638c53ada266f82)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "order", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryGroupBySortQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryGroupBySortQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryGroupBySortQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ddbef4fd052eae4480cf4e5aa7a56157307a29bee902083f30ad759bb4f1d39f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryMultiCompute",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryMultiCompute:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__68aae0b7d6601b5ae5b0c375bc5d3966306834227744445cce4930dec90c34bb)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryMultiCompute(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryMultiComputeList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryMultiComputeList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4a5c3614ac35e0ecd2c4f061a003dcd3ec27cc3bbc9b3fee5135b1ef44ccb7db)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryMultiComputeOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7e5912908ac52126bcfcc8edac679258551c581328daceb45560c5bc4a7b0053)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryMultiComputeOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3efd7febe8e8e13e186c23d5783d2f8c941ccc6df8f13d166a6ded32b3e63915)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7b1db46610026d3775dbb9b09904169c84cd3a5a9254f155610ac36c32d4870a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__77655720cffad68c9579296b908a127aeeedcd2a2206dcddfd4442608676abb0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryMultiCompute]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryMultiCompute]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0e3297b9e12f0b5800be90b2963634b262a93b0792b25efb6f334499b6c9f811)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryMultiComputeOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryMultiComputeOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0e35bd963ebdc263c556c520dd9b6ee7c19dc94de1f006f43b4a4db67bdb7367)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3653fa0c849dea3bfe087873bf90f91ba616b57ee1fc492d2321973207cdd447)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4d4362bdc04666fa21c4bcbeb80e21815fdd203986c57be330e925f32fe07463)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9c2f2ae714913055c35ca00eff6115ee207e1b08c62d6b38878aa5eff413869d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryMultiCompute]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryMultiCompute]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryMultiCompute]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c5dc9bae12da9e1b1002b3e77d323df82c09933e3c5d8aa305f610c29433fae8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__eec395da72699341a2264076be1ee1b91970f018fad00f7c4c79c8eb9b1e013e)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putComputeQuery")
    def put_compute_query(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        value = PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryComputeQuery(
            aggregation=aggregation, facet=facet, interval=interval
        )

        return typing.cast(None, jsii.invoke(self, "putComputeQuery", [value]))

    @jsii.member(jsii_name="putGroupBy")
    def put_group_by(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__67b5d38c98af967bf1ea28faddd5803f9d72c747d7815a765fe34f7d27c5afbc)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putGroupBy", [value]))

    @jsii.member(jsii_name="putMultiCompute")
    def put_multi_compute(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c540e3ad6b2f154dbbf03855816c59931c2bda05312e7f89aba136b5361d27d3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putMultiCompute", [value]))

    @jsii.member(jsii_name="resetComputeQuery")
    def reset_compute_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetComputeQuery", []))

    @jsii.member(jsii_name="resetGroupBy")
    def reset_group_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGroupBy", []))

    @jsii.member(jsii_name="resetMultiCompute")
    def reset_multi_compute(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMultiCompute", []))

    @jsii.member(jsii_name="resetSearchQuery")
    def reset_search_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSearchQuery", []))

    @builtins.property
    @jsii.member(jsii_name="computeQuery")
    def compute_query(
        self,
    ) -> PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryComputeQueryOutputReference:
        return typing.cast(PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryComputeQueryOutputReference, jsii.get(self, "computeQuery"))

    @builtins.property
    @jsii.member(jsii_name="groupBy")
    def group_by(
        self,
    ) -> PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryGroupByList:
        return typing.cast(PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryGroupByList, jsii.get(self, "groupBy"))

    @builtins.property
    @jsii.member(jsii_name="multiCompute")
    def multi_compute(
        self,
    ) -> PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryMultiComputeList:
        return typing.cast(PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryMultiComputeList, jsii.get(self, "multiCompute"))

    @builtins.property
    @jsii.member(jsii_name="computeQueryInput")
    def compute_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryComputeQuery], jsii.get(self, "computeQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="groupByInput")
    def group_by_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryGroupBy]]], jsii.get(self, "groupByInput"))

    @builtins.property
    @jsii.member(jsii_name="indexInput")
    def index_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "indexInput"))

    @builtins.property
    @jsii.member(jsii_name="multiComputeInput")
    def multi_compute_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryMultiCompute]]], jsii.get(self, "multiComputeInput"))

    @builtins.property
    @jsii.member(jsii_name="searchQueryInput")
    def search_query_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "searchQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="index")
    def index(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "index"))

    @index.setter
    def index(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d785d31a50b5460af7f3e22251983be1afccb2993664e59899620764ae882d92)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "index", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="searchQuery")
    def search_query(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "searchQuery"))

    @search_query.setter
    def search_query(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__27cca65559cd35fe4e6c93385b0597b96d94d85f58d39d4d325ca111e5704524)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "searchQuery", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestSecurityQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestSecurityQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestSecurityQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b0e0a7e2c69d620752314158b453ac70b0fac0cc5257d9cdfcf3c95ebd88aaa9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestStyle",
    jsii_struct_bases=[],
    name_mapping={
        "line_type": "lineType",
        "line_width": "lineWidth",
        "palette": "palette",
    },
)
class PowerpackWidgetTimeseriesDefinitionRequestStyle:
    def __init__(
        self,
        *,
        line_type: typing.Optional[builtins.str] = None,
        line_width: typing.Optional[builtins.str] = None,
        palette: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param line_type: The type of lines displayed. Valid values are ``dashed``, ``dotted``, ``solid``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#line_type Powerpack#line_type}
        :param line_width: The width of line displayed. Valid values are ``normal``, ``thick``, ``thin``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#line_width Powerpack#line_width}
        :param palette: A color palette to apply to the widget. The available options are available at: https://docs.datadoghq.com/dashboards/widgets/timeseries/#appearance. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette Powerpack#palette}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6ce096ec99d6c79a15def6291f39b91a09a5b41d17b11aabc73106289cce399b)
            check_type(argname="argument line_type", value=line_type, expected_type=type_hints["line_type"])
            check_type(argname="argument line_width", value=line_width, expected_type=type_hints["line_width"])
            check_type(argname="argument palette", value=palette, expected_type=type_hints["palette"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if line_type is not None:
            self._values["line_type"] = line_type
        if line_width is not None:
            self._values["line_width"] = line_width
        if palette is not None:
            self._values["palette"] = palette

    @builtins.property
    def line_type(self) -> typing.Optional[builtins.str]:
        '''The type of lines displayed. Valid values are ``dashed``, ``dotted``, ``solid``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#line_type Powerpack#line_type}
        '''
        result = self._values.get("line_type")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def line_width(self) -> typing.Optional[builtins.str]:
        '''The width of line displayed. Valid values are ``normal``, ``thick``, ``thin``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#line_width Powerpack#line_width}
        '''
        result = self._values.get("line_width")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def palette(self) -> typing.Optional[builtins.str]:
        '''A color palette to apply to the widget. The available options are available at: https://docs.datadoghq.com/dashboards/widgets/timeseries/#appearance.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette Powerpack#palette}
        '''
        result = self._values.get("palette")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetTimeseriesDefinitionRequestStyle(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetTimeseriesDefinitionRequestStyleOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRequestStyleOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__00a4b50b327c8a2d509bc7c1dba475a38ac7ac881007f4ecd6698c64701e81d2)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetLineType")
    def reset_line_type(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLineType", []))

    @jsii.member(jsii_name="resetLineWidth")
    def reset_line_width(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLineWidth", []))

    @jsii.member(jsii_name="resetPalette")
    def reset_palette(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPalette", []))

    @builtins.property
    @jsii.member(jsii_name="lineTypeInput")
    def line_type_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "lineTypeInput"))

    @builtins.property
    @jsii.member(jsii_name="lineWidthInput")
    def line_width_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "lineWidthInput"))

    @builtins.property
    @jsii.member(jsii_name="paletteInput")
    def palette_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "paletteInput"))

    @builtins.property
    @jsii.member(jsii_name="lineType")
    def line_type(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "lineType"))

    @line_type.setter
    def line_type(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3a1960ee252b8bdef9792e8cae6962e1390ef808f5e24cf1d8cb4bd8da5056e0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "lineType", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="lineWidth")
    def line_width(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "lineWidth"))

    @line_width.setter
    def line_width(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c870c53094cb9adc45612047065cf97ef39150c866df8e96f1ed4655bb892a14)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "lineWidth", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="palette")
    def palette(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "palette"))

    @palette.setter
    def palette(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__08551710162070b3c451707524572a538b327aad2c37fbe0e2d99eda8833a447)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "palette", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestStyle]:
        return typing.cast(typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestStyle], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestStyle],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__98705214e737e69fba886310b001127556f723b9cdd2d2a21f6793735db1a7bc)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRightYaxis",
    jsii_struct_bases=[],
    name_mapping={
        "include_zero": "includeZero",
        "label": "label",
        "max": "max",
        "min": "min",
        "scale": "scale",
    },
)
class PowerpackWidgetTimeseriesDefinitionRightYaxis:
    def __init__(
        self,
        *,
        include_zero: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        label: typing.Optional[builtins.str] = None,
        max: typing.Optional[builtins.str] = None,
        min: typing.Optional[builtins.str] = None,
        scale: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param include_zero: Always include zero or fit the axis to the data range. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#include_zero Powerpack#include_zero}
        :param label: The label of the axis to display on the graph. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#label Powerpack#label}
        :param max: Specify the maximum value to show on the Y-axis. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#max Powerpack#max}
        :param min: Specify the minimum value to show on the Y-axis. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#min Powerpack#min}
        :param scale: Specify the scale type, options: ``linear``, ``log``, ``pow``, ``sqrt``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#scale Powerpack#scale}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fd96fe88c9462541ee1f7c6d967f8d845239ea12c3718a535cfded2d2f6be369)
            check_type(argname="argument include_zero", value=include_zero, expected_type=type_hints["include_zero"])
            check_type(argname="argument label", value=label, expected_type=type_hints["label"])
            check_type(argname="argument max", value=max, expected_type=type_hints["max"])
            check_type(argname="argument min", value=min, expected_type=type_hints["min"])
            check_type(argname="argument scale", value=scale, expected_type=type_hints["scale"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if include_zero is not None:
            self._values["include_zero"] = include_zero
        if label is not None:
            self._values["label"] = label
        if max is not None:
            self._values["max"] = max
        if min is not None:
            self._values["min"] = min
        if scale is not None:
            self._values["scale"] = scale

    @builtins.property
    def include_zero(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        '''Always include zero or fit the axis to the data range.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#include_zero Powerpack#include_zero}
        '''
        result = self._values.get("include_zero")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)

    @builtins.property
    def label(self) -> typing.Optional[builtins.str]:
        '''The label of the axis to display on the graph.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#label Powerpack#label}
        '''
        result = self._values.get("label")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def max(self) -> typing.Optional[builtins.str]:
        '''Specify the maximum value to show on the Y-axis.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#max Powerpack#max}
        '''
        result = self._values.get("max")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def min(self) -> typing.Optional[builtins.str]:
        '''Specify the minimum value to show on the Y-axis.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#min Powerpack#min}
        '''
        result = self._values.get("min")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def scale(self) -> typing.Optional[builtins.str]:
        '''Specify the scale type, options: ``linear``, ``log``, ``pow``, ``sqrt``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#scale Powerpack#scale}
        '''
        result = self._values.get("scale")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetTimeseriesDefinitionRightYaxis(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetTimeseriesDefinitionRightYaxisOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionRightYaxisOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2dbd24605231e1f6fd1f6dd82453ad447ed2f0654b92ec729abfc8360d925a35)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetIncludeZero")
    def reset_include_zero(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetIncludeZero", []))

    @jsii.member(jsii_name="resetLabel")
    def reset_label(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLabel", []))

    @jsii.member(jsii_name="resetMax")
    def reset_max(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMax", []))

    @jsii.member(jsii_name="resetMin")
    def reset_min(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMin", []))

    @jsii.member(jsii_name="resetScale")
    def reset_scale(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetScale", []))

    @builtins.property
    @jsii.member(jsii_name="includeZeroInput")
    def include_zero_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "includeZeroInput"))

    @builtins.property
    @jsii.member(jsii_name="labelInput")
    def label_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "labelInput"))

    @builtins.property
    @jsii.member(jsii_name="maxInput")
    def max_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "maxInput"))

    @builtins.property
    @jsii.member(jsii_name="minInput")
    def min_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "minInput"))

    @builtins.property
    @jsii.member(jsii_name="scaleInput")
    def scale_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "scaleInput"))

    @builtins.property
    @jsii.member(jsii_name="includeZero")
    def include_zero(self) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "includeZero"))

    @include_zero.setter
    def include_zero(
        self,
        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f6c8ac0cc704d444d9b6451620d21147fc4cb8da38e9343d03d7c642139b40f9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "includeZero", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="label")
    def label(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "label"))

    @label.setter
    def label(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f3a1585718fb01c43aebf0ea0cbbeb7738593d29ff78a5e2257c2d87c9dc845a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "label", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="max")
    def max(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "max"))

    @max.setter
    def max(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f2f7a123f3de4d89fdacba189955b479c386ba4c49cde4a3c39050243535ed59)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "max", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="min")
    def min(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "min"))

    @min.setter
    def min(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__52eca119ba3978722e6701b87732ed223f4b08831cacd7b54282f4e1d5a65028)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "min", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="scale")
    def scale(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "scale"))

    @scale.setter
    def scale(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1ea4f16db7a0363b6e619c3f4daeabb07c9d9e5bb316d41cc813a64d1f0409c5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "scale", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetTimeseriesDefinitionRightYaxis]:
        return typing.cast(typing.Optional[PowerpackWidgetTimeseriesDefinitionRightYaxis], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetTimeseriesDefinitionRightYaxis],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__10bae89661deecdc47bf84a52ada8a10ad17d1a262408a0390c0a50808bf403e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionYaxis",
    jsii_struct_bases=[],
    name_mapping={
        "include_zero": "includeZero",
        "label": "label",
        "max": "max",
        "min": "min",
        "scale": "scale",
    },
)
class PowerpackWidgetTimeseriesDefinitionYaxis:
    def __init__(
        self,
        *,
        include_zero: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        label: typing.Optional[builtins.str] = None,
        max: typing.Optional[builtins.str] = None,
        min: typing.Optional[builtins.str] = None,
        scale: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param include_zero: Always include zero or fit the axis to the data range. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#include_zero Powerpack#include_zero}
        :param label: The label of the axis to display on the graph. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#label Powerpack#label}
        :param max: Specify the maximum value to show on the Y-axis. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#max Powerpack#max}
        :param min: Specify the minimum value to show on the Y-axis. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#min Powerpack#min}
        :param scale: Specify the scale type, options: ``linear``, ``log``, ``pow``, ``sqrt``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#scale Powerpack#scale}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5eeb726533b557d5558a4051e3b2de7166fcf9be98c755e89a8c552a881a0469)
            check_type(argname="argument include_zero", value=include_zero, expected_type=type_hints["include_zero"])
            check_type(argname="argument label", value=label, expected_type=type_hints["label"])
            check_type(argname="argument max", value=max, expected_type=type_hints["max"])
            check_type(argname="argument min", value=min, expected_type=type_hints["min"])
            check_type(argname="argument scale", value=scale, expected_type=type_hints["scale"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if include_zero is not None:
            self._values["include_zero"] = include_zero
        if label is not None:
            self._values["label"] = label
        if max is not None:
            self._values["max"] = max
        if min is not None:
            self._values["min"] = min
        if scale is not None:
            self._values["scale"] = scale

    @builtins.property
    def include_zero(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        '''Always include zero or fit the axis to the data range.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#include_zero Powerpack#include_zero}
        '''
        result = self._values.get("include_zero")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)

    @builtins.property
    def label(self) -> typing.Optional[builtins.str]:
        '''The label of the axis to display on the graph.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#label Powerpack#label}
        '''
        result = self._values.get("label")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def max(self) -> typing.Optional[builtins.str]:
        '''Specify the maximum value to show on the Y-axis.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#max Powerpack#max}
        '''
        result = self._values.get("max")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def min(self) -> typing.Optional[builtins.str]:
        '''Specify the minimum value to show on the Y-axis.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#min Powerpack#min}
        '''
        result = self._values.get("min")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def scale(self) -> typing.Optional[builtins.str]:
        '''Specify the scale type, options: ``linear``, ``log``, ``pow``, ``sqrt``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#scale Powerpack#scale}
        '''
        result = self._values.get("scale")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetTimeseriesDefinitionYaxis(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetTimeseriesDefinitionYaxisOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTimeseriesDefinitionYaxisOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__538b97b26702cbd46c3e90bb4272ab8bd94ac773e3fba8e30ab40c5543ac22e2)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetIncludeZero")
    def reset_include_zero(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetIncludeZero", []))

    @jsii.member(jsii_name="resetLabel")
    def reset_label(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLabel", []))

    @jsii.member(jsii_name="resetMax")
    def reset_max(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMax", []))

    @jsii.member(jsii_name="resetMin")
    def reset_min(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMin", []))

    @jsii.member(jsii_name="resetScale")
    def reset_scale(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetScale", []))

    @builtins.property
    @jsii.member(jsii_name="includeZeroInput")
    def include_zero_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "includeZeroInput"))

    @builtins.property
    @jsii.member(jsii_name="labelInput")
    def label_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "labelInput"))

    @builtins.property
    @jsii.member(jsii_name="maxInput")
    def max_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "maxInput"))

    @builtins.property
    @jsii.member(jsii_name="minInput")
    def min_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "minInput"))

    @builtins.property
    @jsii.member(jsii_name="scaleInput")
    def scale_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "scaleInput"))

    @builtins.property
    @jsii.member(jsii_name="includeZero")
    def include_zero(self) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "includeZero"))

    @include_zero.setter
    def include_zero(
        self,
        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9b12fce1d2e892ec63e4aa35749c5a329d308a2128ae016ae05491b6dbc04dfc)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "includeZero", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="label")
    def label(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "label"))

    @label.setter
    def label(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__31fe5da41cadbcaf3312ef60a7a2d32337489b2897c3e94cf8acce7825709da7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "label", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="max")
    def max(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "max"))

    @max.setter
    def max(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6bbf8130570a94be8d91c9b7b5ba81e436fb5f6942199223a321227c54d35c91)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "max", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="min")
    def min(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "min"))

    @min.setter
    def min(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__76eab25b92cc7270ac7ffb5303992f972f677bab99d33399d1c7b8330e9ddf06)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "min", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="scale")
    def scale(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "scale"))

    @scale.setter
    def scale(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1e6822dc738c93de8270167a2ec99f1c7c839fd651e41d6110b87190a4529ce8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "scale", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetTimeseriesDefinitionYaxis]:
        return typing.cast(typing.Optional[PowerpackWidgetTimeseriesDefinitionYaxis], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetTimeseriesDefinitionYaxis],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__94cdb41f9ddd49634428a0e474b09515b72ab53d339b9f33f664629983d63682)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinition",
    jsii_struct_bases=[],
    name_mapping={
        "custom_link": "customLink",
        "live_span": "liveSpan",
        "request": "request",
        "style": "style",
        "title": "title",
        "title_align": "titleAlign",
        "title_size": "titleSize",
    },
)
class PowerpackWidgetToplistDefinition:
    def __init__(
        self,
        *,
        custom_link: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetToplistDefinitionCustomLink", typing.Dict[builtins.str, typing.Any]]]]] = None,
        live_span: typing.Optional[builtins.str] = None,
        request: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetToplistDefinitionRequest", typing.Dict[builtins.str, typing.Any]]]]] = None,
        style: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetToplistDefinitionStyle", typing.Dict[builtins.str, typing.Any]]]]] = None,
        title: typing.Optional[builtins.str] = None,
        title_align: typing.Optional[builtins.str] = None,
        title_size: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param custom_link: custom_link block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom_link Powerpack#custom_link}
        :param live_span: The timeframe to use when displaying the widget. Valid values are ``1m``, ``5m``, ``10m``, ``15m``, ``30m``, ``1h``, ``4h``, ``1d``, ``2d``, ``1w``, ``1mo``, ``3mo``, ``6mo``, ``week_to_date``, ``month_to_date``, ``1y``, ``alert``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#live_span Powerpack#live_span}
        :param request: request block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#request Powerpack#request}
        :param style: style block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#style Powerpack#style}
        :param title: The title of the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title Powerpack#title}
        :param title_align: The alignment of the widget's title. Valid values are ``center``, ``left``, ``right``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_align Powerpack#title_align}
        :param title_size: The size of the widget's title (defaults to 16). Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_size Powerpack#title_size}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__273bd147ea86d43b762b2a52adf9493f460c0e1a0cd4a667ed7dae08cfc0ae1e)
            check_type(argname="argument custom_link", value=custom_link, expected_type=type_hints["custom_link"])
            check_type(argname="argument live_span", value=live_span, expected_type=type_hints["live_span"])
            check_type(argname="argument request", value=request, expected_type=type_hints["request"])
            check_type(argname="argument style", value=style, expected_type=type_hints["style"])
            check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            check_type(argname="argument title_align", value=title_align, expected_type=type_hints["title_align"])
            check_type(argname="argument title_size", value=title_size, expected_type=type_hints["title_size"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if custom_link is not None:
            self._values["custom_link"] = custom_link
        if live_span is not None:
            self._values["live_span"] = live_span
        if request is not None:
            self._values["request"] = request
        if style is not None:
            self._values["style"] = style
        if title is not None:
            self._values["title"] = title
        if title_align is not None:
            self._values["title_align"] = title_align
        if title_size is not None:
            self._values["title_size"] = title_size

    @builtins.property
    def custom_link(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetToplistDefinitionCustomLink"]]]:
        '''custom_link block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom_link Powerpack#custom_link}
        '''
        result = self._values.get("custom_link")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetToplistDefinitionCustomLink"]]], result)

    @builtins.property
    def live_span(self) -> typing.Optional[builtins.str]:
        '''The timeframe to use when displaying the widget.

        Valid values are ``1m``, ``5m``, ``10m``, ``15m``, ``30m``, ``1h``, ``4h``, ``1d``, ``2d``, ``1w``, ``1mo``, ``3mo``, ``6mo``, ``week_to_date``, ``month_to_date``, ``1y``, ``alert``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#live_span Powerpack#live_span}
        '''
        result = self._values.get("live_span")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def request(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetToplistDefinitionRequest"]]]:
        '''request block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#request Powerpack#request}
        '''
        result = self._values.get("request")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetToplistDefinitionRequest"]]], result)

    @builtins.property
    def style(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetToplistDefinitionStyle"]]]:
        '''style block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#style Powerpack#style}
        '''
        result = self._values.get("style")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetToplistDefinitionStyle"]]], result)

    @builtins.property
    def title(self) -> typing.Optional[builtins.str]:
        '''The title of the widget.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title Powerpack#title}
        '''
        result = self._values.get("title")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def title_align(self) -> typing.Optional[builtins.str]:
        '''The alignment of the widget's title. Valid values are ``center``, ``left``, ``right``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_align Powerpack#title_align}
        '''
        result = self._values.get("title_align")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def title_size(self) -> typing.Optional[builtins.str]:
        '''The size of the widget's title (defaults to 16).

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_size Powerpack#title_size}
        '''
        result = self._values.get("title_size")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetToplistDefinition(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionCustomLink",
    jsii_struct_bases=[],
    name_mapping={
        "is_hidden": "isHidden",
        "label": "label",
        "link": "link",
        "override_label": "overrideLabel",
    },
)
class PowerpackWidgetToplistDefinitionCustomLink:
    def __init__(
        self,
        *,
        is_hidden: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        label: typing.Optional[builtins.str] = None,
        link: typing.Optional[builtins.str] = None,
        override_label: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param is_hidden: The flag for toggling context menu link visibility. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#is_hidden Powerpack#is_hidden}
        :param label: The label for the custom link URL. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#label Powerpack#label}
        :param link: The URL of the custom link. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#link Powerpack#link}
        :param override_label: The label ID that refers to a context menu link item. When ``override_label`` is provided, the client request omits the label field. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#override_label Powerpack#override_label}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8afbd59e21f8935007ab0e09784668693df69eadc9661d7ce6b1d8703bbabad8)
            check_type(argname="argument is_hidden", value=is_hidden, expected_type=type_hints["is_hidden"])
            check_type(argname="argument label", value=label, expected_type=type_hints["label"])
            check_type(argname="argument link", value=link, expected_type=type_hints["link"])
            check_type(argname="argument override_label", value=override_label, expected_type=type_hints["override_label"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if is_hidden is not None:
            self._values["is_hidden"] = is_hidden
        if label is not None:
            self._values["label"] = label
        if link is not None:
            self._values["link"] = link
        if override_label is not None:
            self._values["override_label"] = override_label

    @builtins.property
    def is_hidden(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        '''The flag for toggling context menu link visibility.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#is_hidden Powerpack#is_hidden}
        '''
        result = self._values.get("is_hidden")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)

    @builtins.property
    def label(self) -> typing.Optional[builtins.str]:
        '''The label for the custom link URL.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#label Powerpack#label}
        '''
        result = self._values.get("label")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def link(self) -> typing.Optional[builtins.str]:
        '''The URL of the custom link.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#link Powerpack#link}
        '''
        result = self._values.get("link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def override_label(self) -> typing.Optional[builtins.str]:
        '''The label ID that refers to a context menu link item.

        When ``override_label`` is provided, the client request omits the label field.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#override_label Powerpack#override_label}
        '''
        result = self._values.get("override_label")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetToplistDefinitionCustomLink(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetToplistDefinitionCustomLinkList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionCustomLinkList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__902d0f1937e891531ee6d297e4e22635a79a3030b0f969dfd62610a84527e5f1)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetToplistDefinitionCustomLinkOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c6cd8711b1a8e17190271907f091776c9c8407d4cbfbeebfc7e2171dd9276704)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetToplistDefinitionCustomLinkOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__704e425b2c5ec0a3eafdd9ae920c86434620d734980f7c9a61a2162981d39f7d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3cdf901a04b17cd83b2bc8d9ca2a68b74a7fe8b72eed8cf0e6967098f31f866d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c3d2f1608f54a28cd9d902de6cdd529cfb4b9a207b4767f7a0abc4ba0324f7e0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionCustomLink]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionCustomLink]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionCustomLink]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8fecf2bf20203ab2078c22b19fd0cdd0f04a385762683099f52931a36f814ec1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetToplistDefinitionCustomLinkOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionCustomLinkOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__64381967f34e6f97b3cc5f721cbc4bf54dbd90df1c91ba48e7bbf1b3b83dcfd3)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetIsHidden")
    def reset_is_hidden(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetIsHidden", []))

    @jsii.member(jsii_name="resetLabel")
    def reset_label(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLabel", []))

    @jsii.member(jsii_name="resetLink")
    def reset_link(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLink", []))

    @jsii.member(jsii_name="resetOverrideLabel")
    def reset_override_label(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetOverrideLabel", []))

    @builtins.property
    @jsii.member(jsii_name="isHiddenInput")
    def is_hidden_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "isHiddenInput"))

    @builtins.property
    @jsii.member(jsii_name="labelInput")
    def label_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "labelInput"))

    @builtins.property
    @jsii.member(jsii_name="linkInput")
    def link_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "linkInput"))

    @builtins.property
    @jsii.member(jsii_name="overrideLabelInput")
    def override_label_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "overrideLabelInput"))

    @builtins.property
    @jsii.member(jsii_name="isHidden")
    def is_hidden(self) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "isHidden"))

    @is_hidden.setter
    def is_hidden(
        self,
        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3c6748a9ecc89bc64ebdd4d138b15b44b0b91eaa7089b30a5c86a4173b215080)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "isHidden", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="label")
    def label(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "label"))

    @label.setter
    def label(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8d886ef2c2f38389cafebf222d2584739d5b13b4ef2c9dca558cbb598897307d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "label", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="link")
    def link(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "link"))

    @link.setter
    def link(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fa2b0c38d591c3c04cac53c078e98e8f564d83ab0f0b6b9b4abbd22fe468d1cd)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "link", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="overrideLabel")
    def override_label(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "overrideLabel"))

    @override_label.setter
    def override_label(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__89fdc94fe2d2382b14cbcd09ebe9c0f69cfd1788d611f185de30ea982bc7f18e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "overrideLabel", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetToplistDefinitionCustomLink]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetToplistDefinitionCustomLink]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetToplistDefinitionCustomLink]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__55c89023292d93fadb1a95892d36f0dc528f5199cd937306202540684e1d64df)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetToplistDefinitionOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__575bd7fac7028d563604a485461be9df40afd8220b2b599771f8b1c856c95f14)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putCustomLink")
    def put_custom_link(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetToplistDefinitionCustomLink, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8e34ae117cf07a86e4cc41b29cc751ce58f0d55d94bc0673b3605ded03afda21)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putCustomLink", [value]))

    @jsii.member(jsii_name="putRequest")
    def put_request(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetToplistDefinitionRequest", typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d0d36f81edfcf1011eaffb9d1ac7b1b6eb26456d8d403138bc8ba09168cab99f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putRequest", [value]))

    @jsii.member(jsii_name="putStyle")
    def put_style(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetToplistDefinitionStyle", typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__93c904858910ceb7dbd2e3b7abcf99eac98ee60ab0c3ef8a8cbd39b55b6dc159)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putStyle", [value]))

    @jsii.member(jsii_name="resetCustomLink")
    def reset_custom_link(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCustomLink", []))

    @jsii.member(jsii_name="resetLiveSpan")
    def reset_live_span(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLiveSpan", []))

    @jsii.member(jsii_name="resetRequest")
    def reset_request(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetRequest", []))

    @jsii.member(jsii_name="resetStyle")
    def reset_style(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetStyle", []))

    @jsii.member(jsii_name="resetTitle")
    def reset_title(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTitle", []))

    @jsii.member(jsii_name="resetTitleAlign")
    def reset_title_align(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTitleAlign", []))

    @jsii.member(jsii_name="resetTitleSize")
    def reset_title_size(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTitleSize", []))

    @builtins.property
    @jsii.member(jsii_name="customLink")
    def custom_link(self) -> PowerpackWidgetToplistDefinitionCustomLinkList:
        return typing.cast(PowerpackWidgetToplistDefinitionCustomLinkList, jsii.get(self, "customLink"))

    @builtins.property
    @jsii.member(jsii_name="request")
    def request(self) -> "PowerpackWidgetToplistDefinitionRequestList":
        return typing.cast("PowerpackWidgetToplistDefinitionRequestList", jsii.get(self, "request"))

    @builtins.property
    @jsii.member(jsii_name="style")
    def style(self) -> "PowerpackWidgetToplistDefinitionStyleList":
        return typing.cast("PowerpackWidgetToplistDefinitionStyleList", jsii.get(self, "style"))

    @builtins.property
    @jsii.member(jsii_name="customLinkInput")
    def custom_link_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionCustomLink]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionCustomLink]]], jsii.get(self, "customLinkInput"))

    @builtins.property
    @jsii.member(jsii_name="liveSpanInput")
    def live_span_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "liveSpanInput"))

    @builtins.property
    @jsii.member(jsii_name="requestInput")
    def request_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetToplistDefinitionRequest"]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetToplistDefinitionRequest"]]], jsii.get(self, "requestInput"))

    @builtins.property
    @jsii.member(jsii_name="styleInput")
    def style_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetToplistDefinitionStyle"]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetToplistDefinitionStyle"]]], jsii.get(self, "styleInput"))

    @builtins.property
    @jsii.member(jsii_name="titleAlignInput")
    def title_align_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "titleAlignInput"))

    @builtins.property
    @jsii.member(jsii_name="titleInput")
    def title_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "titleInput"))

    @builtins.property
    @jsii.member(jsii_name="titleSizeInput")
    def title_size_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "titleSizeInput"))

    @builtins.property
    @jsii.member(jsii_name="liveSpan")
    def live_span(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "liveSpan"))

    @live_span.setter
    def live_span(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__638288c5400a11e4e5765a2f0c0615a02e85f06981c7b03b1076777bbcbc348b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "liveSpan", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="title")
    def title(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "title"))

    @title.setter
    def title(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__674f80df69a3f6dd149836c1d690bcc7985ea104c9015b12a390978e7f0accdc)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "title", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="titleAlign")
    def title_align(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "titleAlign"))

    @title_align.setter
    def title_align(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5268e72ccefea69b48aa919fd348b975a961689ff75cbe2b449cc474fe653b67)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "titleAlign", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="titleSize")
    def title_size(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "titleSize"))

    @title_size.setter
    def title_size(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d8bc7aaad86b1f62f550d9e612c7ba63a4ac825b5438dfa8789b6aedd1c423f6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "titleSize", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[PowerpackWidgetToplistDefinition]:
        return typing.cast(typing.Optional[PowerpackWidgetToplistDefinition], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetToplistDefinition],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a9caf1036965a5a9cbe25cd5878e117f2e0d22aee7c03f22d56f8295dc293e5b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequest",
    jsii_struct_bases=[],
    name_mapping={
        "apm_query": "apmQuery",
        "audit_query": "auditQuery",
        "conditional_formats": "conditionalFormats",
        "formula": "formula",
        "log_query": "logQuery",
        "process_query": "processQuery",
        "q": "q",
        "query": "query",
        "rum_query": "rumQuery",
        "security_query": "securityQuery",
        "style": "style",
    },
)
class PowerpackWidgetToplistDefinitionRequest:
    def __init__(
        self,
        *,
        apm_query: typing.Optional[typing.Union["PowerpackWidgetToplistDefinitionRequestApmQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        audit_query: typing.Optional[typing.Union["PowerpackWidgetToplistDefinitionRequestAuditQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        conditional_formats: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetToplistDefinitionRequestConditionalFormats", typing.Dict[builtins.str, typing.Any]]]]] = None,
        formula: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetToplistDefinitionRequestFormula", typing.Dict[builtins.str, typing.Any]]]]] = None,
        log_query: typing.Optional[typing.Union["PowerpackWidgetToplistDefinitionRequestLogQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        process_query: typing.Optional[typing.Union["PowerpackWidgetToplistDefinitionRequestProcessQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        q: typing.Optional[builtins.str] = None,
        query: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetToplistDefinitionRequestQuery", typing.Dict[builtins.str, typing.Any]]]]] = None,
        rum_query: typing.Optional[typing.Union["PowerpackWidgetToplistDefinitionRequestRumQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        security_query: typing.Optional[typing.Union["PowerpackWidgetToplistDefinitionRequestSecurityQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        style: typing.Optional[typing.Union["PowerpackWidgetToplistDefinitionRequestStyle", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param apm_query: apm_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#apm_query Powerpack#apm_query}
        :param audit_query: audit_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#audit_query Powerpack#audit_query}
        :param conditional_formats: conditional_formats block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#conditional_formats Powerpack#conditional_formats}
        :param formula: formula block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#formula Powerpack#formula}
        :param log_query: log_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#log_query Powerpack#log_query}
        :param process_query: process_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#process_query Powerpack#process_query}
        :param q: The metric query to use for this widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#q Powerpack#q}
        :param query: query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        :param rum_query: rum_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#rum_query Powerpack#rum_query}
        :param security_query: security_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#security_query Powerpack#security_query}
        :param style: style block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#style Powerpack#style}
        '''
        if isinstance(apm_query, dict):
            apm_query = PowerpackWidgetToplistDefinitionRequestApmQuery(**apm_query)
        if isinstance(audit_query, dict):
            audit_query = PowerpackWidgetToplistDefinitionRequestAuditQuery(**audit_query)
        if isinstance(log_query, dict):
            log_query = PowerpackWidgetToplistDefinitionRequestLogQuery(**log_query)
        if isinstance(process_query, dict):
            process_query = PowerpackWidgetToplistDefinitionRequestProcessQuery(**process_query)
        if isinstance(rum_query, dict):
            rum_query = PowerpackWidgetToplistDefinitionRequestRumQuery(**rum_query)
        if isinstance(security_query, dict):
            security_query = PowerpackWidgetToplistDefinitionRequestSecurityQuery(**security_query)
        if isinstance(style, dict):
            style = PowerpackWidgetToplistDefinitionRequestStyle(**style)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8de4987406758dfe634f94b0e960f3ab7455949b7c625a28b436331443eb8727)
            check_type(argname="argument apm_query", value=apm_query, expected_type=type_hints["apm_query"])
            check_type(argname="argument audit_query", value=audit_query, expected_type=type_hints["audit_query"])
            check_type(argname="argument conditional_formats", value=conditional_formats, expected_type=type_hints["conditional_formats"])
            check_type(argname="argument formula", value=formula, expected_type=type_hints["formula"])
            check_type(argname="argument log_query", value=log_query, expected_type=type_hints["log_query"])
            check_type(argname="argument process_query", value=process_query, expected_type=type_hints["process_query"])
            check_type(argname="argument q", value=q, expected_type=type_hints["q"])
            check_type(argname="argument query", value=query, expected_type=type_hints["query"])
            check_type(argname="argument rum_query", value=rum_query, expected_type=type_hints["rum_query"])
            check_type(argname="argument security_query", value=security_query, expected_type=type_hints["security_query"])
            check_type(argname="argument style", value=style, expected_type=type_hints["style"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if apm_query is not None:
            self._values["apm_query"] = apm_query
        if audit_query is not None:
            self._values["audit_query"] = audit_query
        if conditional_formats is not None:
            self._values["conditional_formats"] = conditional_formats
        if formula is not None:
            self._values["formula"] = formula
        if log_query is not None:
            self._values["log_query"] = log_query
        if process_query is not None:
            self._values["process_query"] = process_query
        if q is not None:
            self._values["q"] = q
        if query is not None:
            self._values["query"] = query
        if rum_query is not None:
            self._values["rum_query"] = rum_query
        if security_query is not None:
            self._values["security_query"] = security_query
        if style is not None:
            self._values["style"] = style

    @builtins.property
    def apm_query(
        self,
    ) -> typing.Optional["PowerpackWidgetToplistDefinitionRequestApmQuery"]:
        '''apm_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#apm_query Powerpack#apm_query}
        '''
        result = self._values.get("apm_query")
        return typing.cast(typing.Optional["PowerpackWidgetToplistDefinitionRequestApmQuery"], result)

    @builtins.property
    def audit_query(
        self,
    ) -> typing.Optional["PowerpackWidgetToplistDefinitionRequestAuditQuery"]:
        '''audit_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#audit_query Powerpack#audit_query}
        '''
        result = self._values.get("audit_query")
        return typing.cast(typing.Optional["PowerpackWidgetToplistDefinitionRequestAuditQuery"], result)

    @builtins.property
    def conditional_formats(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetToplistDefinitionRequestConditionalFormats"]]]:
        '''conditional_formats block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#conditional_formats Powerpack#conditional_formats}
        '''
        result = self._values.get("conditional_formats")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetToplistDefinitionRequestConditionalFormats"]]], result)

    @builtins.property
    def formula(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetToplistDefinitionRequestFormula"]]]:
        '''formula block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#formula Powerpack#formula}
        '''
        result = self._values.get("formula")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetToplistDefinitionRequestFormula"]]], result)

    @builtins.property
    def log_query(
        self,
    ) -> typing.Optional["PowerpackWidgetToplistDefinitionRequestLogQuery"]:
        '''log_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#log_query Powerpack#log_query}
        '''
        result = self._values.get("log_query")
        return typing.cast(typing.Optional["PowerpackWidgetToplistDefinitionRequestLogQuery"], result)

    @builtins.property
    def process_query(
        self,
    ) -> typing.Optional["PowerpackWidgetToplistDefinitionRequestProcessQuery"]:
        '''process_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#process_query Powerpack#process_query}
        '''
        result = self._values.get("process_query")
        return typing.cast(typing.Optional["PowerpackWidgetToplistDefinitionRequestProcessQuery"], result)

    @builtins.property
    def q(self) -> typing.Optional[builtins.str]:
        '''The metric query to use for this widget.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#q Powerpack#q}
        '''
        result = self._values.get("q")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def query(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetToplistDefinitionRequestQuery"]]]:
        '''query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        '''
        result = self._values.get("query")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetToplistDefinitionRequestQuery"]]], result)

    @builtins.property
    def rum_query(
        self,
    ) -> typing.Optional["PowerpackWidgetToplistDefinitionRequestRumQuery"]:
        '''rum_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#rum_query Powerpack#rum_query}
        '''
        result = self._values.get("rum_query")
        return typing.cast(typing.Optional["PowerpackWidgetToplistDefinitionRequestRumQuery"], result)

    @builtins.property
    def security_query(
        self,
    ) -> typing.Optional["PowerpackWidgetToplistDefinitionRequestSecurityQuery"]:
        '''security_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#security_query Powerpack#security_query}
        '''
        result = self._values.get("security_query")
        return typing.cast(typing.Optional["PowerpackWidgetToplistDefinitionRequestSecurityQuery"], result)

    @builtins.property
    def style(self) -> typing.Optional["PowerpackWidgetToplistDefinitionRequestStyle"]:
        '''style block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#style Powerpack#style}
        '''
        result = self._values.get("style")
        return typing.cast(typing.Optional["PowerpackWidgetToplistDefinitionRequestStyle"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetToplistDefinitionRequest(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestApmQuery",
    jsii_struct_bases=[],
    name_mapping={
        "index": "index",
        "compute_query": "computeQuery",
        "group_by": "groupBy",
        "multi_compute": "multiCompute",
        "search_query": "searchQuery",
    },
)
class PowerpackWidgetToplistDefinitionRequestApmQuery:
    def __init__(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union["PowerpackWidgetToplistDefinitionRequestApmQueryComputeQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetToplistDefinitionRequestApmQueryGroupBy", typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetToplistDefinitionRequestApmQueryMultiCompute", typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        if isinstance(compute_query, dict):
            compute_query = PowerpackWidgetToplistDefinitionRequestApmQueryComputeQuery(**compute_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__abea32f6f9f5f733f4c128a916b6e5c684bc43a067c80be1cf28d17313adff48)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
            check_type(argname="argument compute_query", value=compute_query, expected_type=type_hints["compute_query"])
            check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
            check_type(argname="argument multi_compute", value=multi_compute, expected_type=type_hints["multi_compute"])
            check_type(argname="argument search_query", value=search_query, expected_type=type_hints["search_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "index": index,
        }
        if compute_query is not None:
            self._values["compute_query"] = compute_query
        if group_by is not None:
            self._values["group_by"] = group_by
        if multi_compute is not None:
            self._values["multi_compute"] = multi_compute
        if search_query is not None:
            self._values["search_query"] = search_query

    @builtins.property
    def index(self) -> builtins.str:
        '''The name of the index to query.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        '''
        result = self._values.get("index")
        assert result is not None, "Required property 'index' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def compute_query(
        self,
    ) -> typing.Optional["PowerpackWidgetToplistDefinitionRequestApmQueryComputeQuery"]:
        '''compute_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        '''
        result = self._values.get("compute_query")
        return typing.cast(typing.Optional["PowerpackWidgetToplistDefinitionRequestApmQueryComputeQuery"], result)

    @builtins.property
    def group_by(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetToplistDefinitionRequestApmQueryGroupBy"]]]:
        '''group_by block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        '''
        result = self._values.get("group_by")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetToplistDefinitionRequestApmQueryGroupBy"]]], result)

    @builtins.property
    def multi_compute(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetToplistDefinitionRequestApmQueryMultiCompute"]]]:
        '''multi_compute block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        '''
        result = self._values.get("multi_compute")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetToplistDefinitionRequestApmQueryMultiCompute"]]], result)

    @builtins.property
    def search_query(self) -> typing.Optional[builtins.str]:
        '''The search query to use.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        result = self._values.get("search_query")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetToplistDefinitionRequestApmQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestApmQueryComputeQuery",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetToplistDefinitionRequestApmQueryComputeQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3c0fe869b9b2c6d3dc7ffe17a5a15ec4a669eed7e113a9b4c9a86e15fb699d44)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetToplistDefinitionRequestApmQueryComputeQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetToplistDefinitionRequestApmQueryComputeQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestApmQueryComputeQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c39168abc00482dda8a85502c3b211301eef5b99b18f8256245621aecfcb70bb)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b676c14b04d8b30c0cb3ca77fec94ee1a7f93e3185f2095ded0b99e1237b02e4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d2a67de416b3dffa586e4255b4846bdf7e582f4d621e6f78022e32c0c8dfb81c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__664260ac0dc4b3c97e1aa048b33827b5cbbe8cc8f71e7e727bcb226cd8a70dd7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetToplistDefinitionRequestApmQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetToplistDefinitionRequestApmQueryComputeQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetToplistDefinitionRequestApmQueryComputeQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f8b921093d9bd04f9c1f641e37504ef1c01bc2484f7cd51f6994e63facf3cee3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestApmQueryGroupBy",
    jsii_struct_bases=[],
    name_mapping={"facet": "facet", "limit": "limit", "sort_query": "sortQuery"},
)
class PowerpackWidgetToplistDefinitionRequestApmQueryGroupBy:
    def __init__(
        self,
        *,
        facet: typing.Optional[builtins.str] = None,
        limit: typing.Optional[jsii.Number] = None,
        sort_query: typing.Optional[typing.Union["PowerpackWidgetToplistDefinitionRequestApmQueryGroupBySortQuery", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param limit: The maximum number of items in the group. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param sort_query: sort_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        if isinstance(sort_query, dict):
            sort_query = PowerpackWidgetToplistDefinitionRequestApmQueryGroupBySortQuery(**sort_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9538082d8cd96a1c478bfd7c3105fc3ac12f228fe694c93fef2cb65307f36735)
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
            check_type(argname="argument sort_query", value=sort_query, expected_type=type_hints["sort_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if facet is not None:
            self._values["facet"] = facet
        if limit is not None:
            self._values["limit"] = limit
        if sort_query is not None:
            self._values["sort_query"] = sort_query

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def limit(self) -> typing.Optional[jsii.Number]:
        '''The maximum number of items in the group.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        '''
        result = self._values.get("limit")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def sort_query(
        self,
    ) -> typing.Optional["PowerpackWidgetToplistDefinitionRequestApmQueryGroupBySortQuery"]:
        '''sort_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        result = self._values.get("sort_query")
        return typing.cast(typing.Optional["PowerpackWidgetToplistDefinitionRequestApmQueryGroupBySortQuery"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetToplistDefinitionRequestApmQueryGroupBy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetToplistDefinitionRequestApmQueryGroupByList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestApmQueryGroupByList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__670ad668ab9dac9a4598c8b442df87a4825c38e46155f64d158968452384ac9e)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetToplistDefinitionRequestApmQueryGroupByOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a3cedb7c734774dacaec064dcb53eb5d5098b4c140434d806402652f3bc57c34)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetToplistDefinitionRequestApmQueryGroupByOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b756b892100fabfbf1880be7220df2cf9ec1fd7c984ce1ec85fbd329f3f427f4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__44063b6dd926851d9f4eb8d89b1ec78251699ba2b943a2c9e4b7ab9c8c945d24)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__36b237107b5531dfc3adef39a5474d53f0eb3ad646decf82d42399bd3fcf4d87)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionRequestApmQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionRequestApmQueryGroupBy]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionRequestApmQueryGroupBy]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7cc3bf3e8ee3743493c5a67cd3e2136357be6d6bbe8c955932199f99e62d14a4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetToplistDefinitionRequestApmQueryGroupByOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestApmQueryGroupByOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__46e6feb7bc59c110bdbe566ac800e6da31fadff770e75dccebd03bef313fdbd0)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putSortQuery")
    def put_sort_query(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        value = PowerpackWidgetToplistDefinitionRequestApmQueryGroupBySortQuery(
            aggregation=aggregation, order=order, facet=facet
        )

        return typing.cast(None, jsii.invoke(self, "putSortQuery", [value]))

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetLimit")
    def reset_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLimit", []))

    @jsii.member(jsii_name="resetSortQuery")
    def reset_sort_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSortQuery", []))

    @builtins.property
    @jsii.member(jsii_name="sortQuery")
    def sort_query(
        self,
    ) -> "PowerpackWidgetToplistDefinitionRequestApmQueryGroupBySortQueryOutputReference":
        return typing.cast("PowerpackWidgetToplistDefinitionRequestApmQueryGroupBySortQueryOutputReference", jsii.get(self, "sortQuery"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="limitInput")
    def limit_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "limitInput"))

    @builtins.property
    @jsii.member(jsii_name="sortQueryInput")
    def sort_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetToplistDefinitionRequestApmQueryGroupBySortQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetToplistDefinitionRequestApmQueryGroupBySortQuery"], jsii.get(self, "sortQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f57c6f50419e2fc404a685b9fbf74703cfbad21b3f5782b817d50c7f9bb31f7a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="limit")
    def limit(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "limit"))

    @limit.setter
    def limit(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__de61fdbd1a2a5a7b9e06e1f84a79523209a3f317978f4935ca1f530652a6a4fa)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "limit", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetToplistDefinitionRequestApmQueryGroupBy]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetToplistDefinitionRequestApmQueryGroupBy]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetToplistDefinitionRequestApmQueryGroupBy]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4575646c49fb4e45a9c57fe406dc17c68cab0d431dc9205495adf5fe0ef10ebb)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestApmQueryGroupBySortQuery",
    jsii_struct_bases=[],
    name_mapping={"aggregation": "aggregation", "order": "order", "facet": "facet"},
)
class PowerpackWidgetToplistDefinitionRequestApmQueryGroupBySortQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__98764c99392d6a4e93160d43763b2ba2604dce7a0fc335828e31c82ebe6fe3a9)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument order", value=order, expected_type=type_hints["order"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
            "order": order,
        }
        if facet is not None:
            self._values["facet"] = facet

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def order(self) -> builtins.str:
        '''Widget sorting methods. Valid values are ``asc``, ``desc``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        result = self._values.get("order")
        assert result is not None, "Required property 'order' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetToplistDefinitionRequestApmQueryGroupBySortQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetToplistDefinitionRequestApmQueryGroupBySortQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestApmQueryGroupBySortQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__42369d2f8ac93f903310742a7fe5301922623b1b78da78f6ef92bfb07ef2d163)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="orderInput")
    def order_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "orderInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b1ce06f5a23ebc1f341c999a5198f539cc7f617551317ae6f2dafcb8e2a0efe4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__58d322b64fc1916d3f36ebdd85a6433969a044f5bb79a24031e6e428d1c6c99a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="order")
    def order(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "order"))

    @order.setter
    def order(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3a6730328e0a1d6c72b8d1c18bf086ab54510626fad20fd04bd091b2f31043b3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "order", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetToplistDefinitionRequestApmQueryGroupBySortQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetToplistDefinitionRequestApmQueryGroupBySortQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetToplistDefinitionRequestApmQueryGroupBySortQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b10fd1c874da0d3f8ac0aa4bd8e97e825068bba8402a21c01b1b9ffbfc83dcbc)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestApmQueryMultiCompute",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetToplistDefinitionRequestApmQueryMultiCompute:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__60a8f660969fe9fdeefe58a5af9d0ca813f8bede6933558190c702e3c0fb87ca)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetToplistDefinitionRequestApmQueryMultiCompute(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetToplistDefinitionRequestApmQueryMultiComputeList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestApmQueryMultiComputeList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bcad328749223d0f5ca49f63720e6bc94ebc7a9bdbd617ff4069edbe60d85c69)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetToplistDefinitionRequestApmQueryMultiComputeOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__715e09219284e501bc2b6b54de482bf6d741bca6fe6958ee36df66337008eddf)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetToplistDefinitionRequestApmQueryMultiComputeOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7b37e9a88f75057874fff3434ddff07ed934bb11e8faf7b3f3f6e01c43e91a36)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6744fabd4bd4c0da2228b7a788fa6bbbf301d95b10442e7befe4b43520aef5e4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4c92eae412dd65de740beb4ed9500b3de550c0014ce6826b1b6bb8c77dea098d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionRequestApmQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionRequestApmQueryMultiCompute]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionRequestApmQueryMultiCompute]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__86373bb339714bad13f3a1e2fd7160dd4361fe68c73764bb9bd9158f670d9cd1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetToplistDefinitionRequestApmQueryMultiComputeOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestApmQueryMultiComputeOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7c45f28ac40fde9b03de7675865cad3354dbd72e22ced44e9418ea7fe0528571)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__af499ada3e1e6857be3d2edda43ea54673eed4e1ef82dca8f2d5fbcb594a63af)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ec57da219c493fea1cd4bdcdf5899018e4a285670b6118d942a8f656a55bb0b8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__330b2b4218110108fb293553e028b1d788e44606b44f58b2a1b0377ec8c99ae3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetToplistDefinitionRequestApmQueryMultiCompute]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetToplistDefinitionRequestApmQueryMultiCompute]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetToplistDefinitionRequestApmQueryMultiCompute]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__144156fcfd06186eec35b476cfbbbcfd41505f338e86b49a1c29a108e3bdc75a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetToplistDefinitionRequestApmQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestApmQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0d59d067e020dfb39c577c7c9c24eb0d09ef91498abdba0d9e731c93b7d5b444)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putComputeQuery")
    def put_compute_query(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        value = PowerpackWidgetToplistDefinitionRequestApmQueryComputeQuery(
            aggregation=aggregation, facet=facet, interval=interval
        )

        return typing.cast(None, jsii.invoke(self, "putComputeQuery", [value]))

    @jsii.member(jsii_name="putGroupBy")
    def put_group_by(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetToplistDefinitionRequestApmQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e9cf4e2c7688e314ef63e0fbf44f1cbf8e974b899f8f6f77518e22f6e708efc6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putGroupBy", [value]))

    @jsii.member(jsii_name="putMultiCompute")
    def put_multi_compute(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetToplistDefinitionRequestApmQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__39687643aa6416d6bf19256834b7159161d2f8d42f8ef8f5a5d79656b6d9deca)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putMultiCompute", [value]))

    @jsii.member(jsii_name="resetComputeQuery")
    def reset_compute_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetComputeQuery", []))

    @jsii.member(jsii_name="resetGroupBy")
    def reset_group_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGroupBy", []))

    @jsii.member(jsii_name="resetMultiCompute")
    def reset_multi_compute(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMultiCompute", []))

    @jsii.member(jsii_name="resetSearchQuery")
    def reset_search_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSearchQuery", []))

    @builtins.property
    @jsii.member(jsii_name="computeQuery")
    def compute_query(
        self,
    ) -> PowerpackWidgetToplistDefinitionRequestApmQueryComputeQueryOutputReference:
        return typing.cast(PowerpackWidgetToplistDefinitionRequestApmQueryComputeQueryOutputReference, jsii.get(self, "computeQuery"))

    @builtins.property
    @jsii.member(jsii_name="groupBy")
    def group_by(self) -> PowerpackWidgetToplistDefinitionRequestApmQueryGroupByList:
        return typing.cast(PowerpackWidgetToplistDefinitionRequestApmQueryGroupByList, jsii.get(self, "groupBy"))

    @builtins.property
    @jsii.member(jsii_name="multiCompute")
    def multi_compute(
        self,
    ) -> PowerpackWidgetToplistDefinitionRequestApmQueryMultiComputeList:
        return typing.cast(PowerpackWidgetToplistDefinitionRequestApmQueryMultiComputeList, jsii.get(self, "multiCompute"))

    @builtins.property
    @jsii.member(jsii_name="computeQueryInput")
    def compute_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetToplistDefinitionRequestApmQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetToplistDefinitionRequestApmQueryComputeQuery], jsii.get(self, "computeQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="groupByInput")
    def group_by_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionRequestApmQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionRequestApmQueryGroupBy]]], jsii.get(self, "groupByInput"))

    @builtins.property
    @jsii.member(jsii_name="indexInput")
    def index_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "indexInput"))

    @builtins.property
    @jsii.member(jsii_name="multiComputeInput")
    def multi_compute_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionRequestApmQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionRequestApmQueryMultiCompute]]], jsii.get(self, "multiComputeInput"))

    @builtins.property
    @jsii.member(jsii_name="searchQueryInput")
    def search_query_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "searchQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="index")
    def index(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "index"))

    @index.setter
    def index(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a916bfadcbafcf891c18be5e23d200857a3ddd944d7977b31b944df1583b5a97)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "index", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="searchQuery")
    def search_query(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "searchQuery"))

    @search_query.setter
    def search_query(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__39031ad4df09d0d20d161959ea3be1822bbe893cb7ad76e8d3a3ee27da0da57e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "searchQuery", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetToplistDefinitionRequestApmQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetToplistDefinitionRequestApmQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetToplistDefinitionRequestApmQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6dd78afda10262729bfd87aef10bfdba932061c3ce1152d5829a3367e5540913)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestAuditQuery",
    jsii_struct_bases=[],
    name_mapping={
        "index": "index",
        "compute_query": "computeQuery",
        "group_by": "groupBy",
        "multi_compute": "multiCompute",
        "search_query": "searchQuery",
    },
)
class PowerpackWidgetToplistDefinitionRequestAuditQuery:
    def __init__(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union["PowerpackWidgetToplistDefinitionRequestAuditQueryComputeQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetToplistDefinitionRequestAuditQueryGroupBy", typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetToplistDefinitionRequestAuditQueryMultiCompute", typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        if isinstance(compute_query, dict):
            compute_query = PowerpackWidgetToplistDefinitionRequestAuditQueryComputeQuery(**compute_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__30051c635d73db349728be2853171402169501fda50757aab7dc09f65c16b8f1)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
            check_type(argname="argument compute_query", value=compute_query, expected_type=type_hints["compute_query"])
            check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
            check_type(argname="argument multi_compute", value=multi_compute, expected_type=type_hints["multi_compute"])
            check_type(argname="argument search_query", value=search_query, expected_type=type_hints["search_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "index": index,
        }
        if compute_query is not None:
            self._values["compute_query"] = compute_query
        if group_by is not None:
            self._values["group_by"] = group_by
        if multi_compute is not None:
            self._values["multi_compute"] = multi_compute
        if search_query is not None:
            self._values["search_query"] = search_query

    @builtins.property
    def index(self) -> builtins.str:
        '''The name of the index to query.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        '''
        result = self._values.get("index")
        assert result is not None, "Required property 'index' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def compute_query(
        self,
    ) -> typing.Optional["PowerpackWidgetToplistDefinitionRequestAuditQueryComputeQuery"]:
        '''compute_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        '''
        result = self._values.get("compute_query")
        return typing.cast(typing.Optional["PowerpackWidgetToplistDefinitionRequestAuditQueryComputeQuery"], result)

    @builtins.property
    def group_by(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetToplistDefinitionRequestAuditQueryGroupBy"]]]:
        '''group_by block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        '''
        result = self._values.get("group_by")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetToplistDefinitionRequestAuditQueryGroupBy"]]], result)

    @builtins.property
    def multi_compute(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetToplistDefinitionRequestAuditQueryMultiCompute"]]]:
        '''multi_compute block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        '''
        result = self._values.get("multi_compute")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetToplistDefinitionRequestAuditQueryMultiCompute"]]], result)

    @builtins.property
    def search_query(self) -> typing.Optional[builtins.str]:
        '''The search query to use.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        result = self._values.get("search_query")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetToplistDefinitionRequestAuditQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestAuditQueryComputeQuery",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetToplistDefinitionRequestAuditQueryComputeQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c1f666e0de0f03a2745d838a615d59974a0fc7576b6690a6c5f5ea1953d6a297)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetToplistDefinitionRequestAuditQueryComputeQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetToplistDefinitionRequestAuditQueryComputeQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestAuditQueryComputeQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__eaf09fa868b3249288b9d391ecfdaf56f694999f4409e49a9bf6543c0657bd81)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6ec40ed777a8bd8101344a22f574d06db2e9bdaba80debc6ac175ce6d7c3aa50)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c47cec5768e829745510f5b5328ebf61244183c271563ea87df7cc18c1acdf8d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1877a173d033a3584d2e8b2f85f7e9ccb5504fa72644a11f14f30da5f9a874b5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetToplistDefinitionRequestAuditQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetToplistDefinitionRequestAuditQueryComputeQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetToplistDefinitionRequestAuditQueryComputeQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__266773298add8e307ba043d6608c7b633237191c82f6228a6358a7ed9cca0a21)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestAuditQueryGroupBy",
    jsii_struct_bases=[],
    name_mapping={"facet": "facet", "limit": "limit", "sort_query": "sortQuery"},
)
class PowerpackWidgetToplistDefinitionRequestAuditQueryGroupBy:
    def __init__(
        self,
        *,
        facet: typing.Optional[builtins.str] = None,
        limit: typing.Optional[jsii.Number] = None,
        sort_query: typing.Optional[typing.Union["PowerpackWidgetToplistDefinitionRequestAuditQueryGroupBySortQuery", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param limit: The maximum number of items in the group. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param sort_query: sort_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        if isinstance(sort_query, dict):
            sort_query = PowerpackWidgetToplistDefinitionRequestAuditQueryGroupBySortQuery(**sort_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b39dadb07f190cf8259bf634bd5dcb3af3f102c29ffcd4da56f18bbe87735ad1)
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
            check_type(argname="argument sort_query", value=sort_query, expected_type=type_hints["sort_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if facet is not None:
            self._values["facet"] = facet
        if limit is not None:
            self._values["limit"] = limit
        if sort_query is not None:
            self._values["sort_query"] = sort_query

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def limit(self) -> typing.Optional[jsii.Number]:
        '''The maximum number of items in the group.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        '''
        result = self._values.get("limit")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def sort_query(
        self,
    ) -> typing.Optional["PowerpackWidgetToplistDefinitionRequestAuditQueryGroupBySortQuery"]:
        '''sort_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        result = self._values.get("sort_query")
        return typing.cast(typing.Optional["PowerpackWidgetToplistDefinitionRequestAuditQueryGroupBySortQuery"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetToplistDefinitionRequestAuditQueryGroupBy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetToplistDefinitionRequestAuditQueryGroupByList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestAuditQueryGroupByList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d2463e9472a9291c00ea66f72d4421c5b5e367c5e4dddf7949e5638b2e2caa2d)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetToplistDefinitionRequestAuditQueryGroupByOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__40dfbd32a819fcf5e72cc36b00bf595838e4b6ac0d26219ac660be157ac4dcfc)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetToplistDefinitionRequestAuditQueryGroupByOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f749c4c50f51cad0e43b30d84c06ab93b91d92e56d0a50cf6b6442f80ef16737)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__523c27a01d5d09c238adbdd011c60924d59d84f7c774e30082cceea80a763d03)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a182b4c7dad431a61dd32cc4bd1e6cc91c6785be5012fd523f5b0fff51e01f69)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionRequestAuditQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionRequestAuditQueryGroupBy]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionRequestAuditQueryGroupBy]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1fd899de6838299577e022380c3564cb6dce86e5cdf1fb4484301f290e8f4372)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetToplistDefinitionRequestAuditQueryGroupByOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestAuditQueryGroupByOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__49a655f5c48a8c1de0ea246749cb7229f3eeb9251a8eccdeb0e90a9ea598d198)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putSortQuery")
    def put_sort_query(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        value = PowerpackWidgetToplistDefinitionRequestAuditQueryGroupBySortQuery(
            aggregation=aggregation, order=order, facet=facet
        )

        return typing.cast(None, jsii.invoke(self, "putSortQuery", [value]))

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetLimit")
    def reset_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLimit", []))

    @jsii.member(jsii_name="resetSortQuery")
    def reset_sort_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSortQuery", []))

    @builtins.property
    @jsii.member(jsii_name="sortQuery")
    def sort_query(
        self,
    ) -> "PowerpackWidgetToplistDefinitionRequestAuditQueryGroupBySortQueryOutputReference":
        return typing.cast("PowerpackWidgetToplistDefinitionRequestAuditQueryGroupBySortQueryOutputReference", jsii.get(self, "sortQuery"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="limitInput")
    def limit_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "limitInput"))

    @builtins.property
    @jsii.member(jsii_name="sortQueryInput")
    def sort_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetToplistDefinitionRequestAuditQueryGroupBySortQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetToplistDefinitionRequestAuditQueryGroupBySortQuery"], jsii.get(self, "sortQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__50972ca10d24b7b144adfcf0c34be9f80b65598169859edda1b4acc433b48b15)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="limit")
    def limit(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "limit"))

    @limit.setter
    def limit(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__563e9d8a9705e5cad3d28019c49c3a1f4465af70d5bafa2f4ef3e5047c5b3325)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "limit", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetToplistDefinitionRequestAuditQueryGroupBy]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetToplistDefinitionRequestAuditQueryGroupBy]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetToplistDefinitionRequestAuditQueryGroupBy]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__46fce561927f1418b3d334eba9d0f0eee6ed4f5232124fc073688aa6bef0c2df)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestAuditQueryGroupBySortQuery",
    jsii_struct_bases=[],
    name_mapping={"aggregation": "aggregation", "order": "order", "facet": "facet"},
)
class PowerpackWidgetToplistDefinitionRequestAuditQueryGroupBySortQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__47f2e6b872935184ce861e6a374c16be1e99acea8fe2a4e369e35ee31a5df799)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument order", value=order, expected_type=type_hints["order"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
            "order": order,
        }
        if facet is not None:
            self._values["facet"] = facet

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def order(self) -> builtins.str:
        '''Widget sorting methods. Valid values are ``asc``, ``desc``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        result = self._values.get("order")
        assert result is not None, "Required property 'order' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetToplistDefinitionRequestAuditQueryGroupBySortQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetToplistDefinitionRequestAuditQueryGroupBySortQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestAuditQueryGroupBySortQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d8ff1c73ed432430608adfc06fb781ed1914fb5409103918d33253cb9d33bc9e)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="orderInput")
    def order_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "orderInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__50209e072b89b8a7268bbc5eee0a8fbae92b6f4b8703d1fb75ed8840cb743835)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2a2a60c5b3d58027252eab74cb762a4fdafbe2dccc713c9569b116ad1ba0e07c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="order")
    def order(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "order"))

    @order.setter
    def order(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bf8e5ed3408de4e0d5d519d6ef3a4d12c3ee221988bc2c4134775661645857c6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "order", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetToplistDefinitionRequestAuditQueryGroupBySortQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetToplistDefinitionRequestAuditQueryGroupBySortQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetToplistDefinitionRequestAuditQueryGroupBySortQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c2abdeb39787ec63ae966564135226546ce1e38fbd66960d033b79ff44dd12db)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestAuditQueryMultiCompute",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetToplistDefinitionRequestAuditQueryMultiCompute:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f5616b604eca7eb8f2261176de274085131ea10530e17c7455d268b9cc419a0c)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetToplistDefinitionRequestAuditQueryMultiCompute(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetToplistDefinitionRequestAuditQueryMultiComputeList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestAuditQueryMultiComputeList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b2080e3006fb03e6cc394cdace73ae56356221980f7312c27482a1a63e7210be)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetToplistDefinitionRequestAuditQueryMultiComputeOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__11cbbe6418a77de8b1a4306df04f83d07787f794cb9c6fb8b73fc24734a0a1c0)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetToplistDefinitionRequestAuditQueryMultiComputeOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d705f6e9c2455085133c21377e786dd9b876ca42f1377522bf69c9e672c679f5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4ee072321eaec90e6b1c6825904bcc8e8eb25fac2fb08f4c421cc11923180618)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a31d7171fe856d52193149fa2fb51b9ad30f085a087396be4e9c9979bc4e3dd4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionRequestAuditQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionRequestAuditQueryMultiCompute]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionRequestAuditQueryMultiCompute]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5101b1a268d6b3e676bae58f6ad8895f38c5bf1a8a500427534a5734285305f7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetToplistDefinitionRequestAuditQueryMultiComputeOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestAuditQueryMultiComputeOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0f679118d380e87263f46297d9356fcef1ebc931432f227adb44c90d0776f01f)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2b39606a028d9ea2f0046c6351b49b14b5aca6f60c3eaf3fe7f6dea10c514d55)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f33fbcc0861c3e60e9e9b5e14d48ecb66bcf66532cea48f9c6926e854f188d99)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5edec11cd7304287c3fe090cc33af576eb0c2b04a20e717726337e0d03de9ce1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetToplistDefinitionRequestAuditQueryMultiCompute]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetToplistDefinitionRequestAuditQueryMultiCompute]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetToplistDefinitionRequestAuditQueryMultiCompute]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7a6d3e2dee4b7e7961b5b7827e116fbb56c2e22ff4137b571cb6faab8e690caf)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetToplistDefinitionRequestAuditQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestAuditQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4bde00d9dcd13a310c4e21f509289cd74c633bb063d060cfa686e63bb7b506fa)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putComputeQuery")
    def put_compute_query(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        value = PowerpackWidgetToplistDefinitionRequestAuditQueryComputeQuery(
            aggregation=aggregation, facet=facet, interval=interval
        )

        return typing.cast(None, jsii.invoke(self, "putComputeQuery", [value]))

    @jsii.member(jsii_name="putGroupBy")
    def put_group_by(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetToplistDefinitionRequestAuditQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__60f97e0bc0c1209cb5735a9dee36e07d737ee5636c9dc1bf42848660e0eababb)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putGroupBy", [value]))

    @jsii.member(jsii_name="putMultiCompute")
    def put_multi_compute(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetToplistDefinitionRequestAuditQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cb0a5b4ca6a6b387be4e65628742377e883ee90d64a7dc4f3ea80c2a7d2bf1f3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putMultiCompute", [value]))

    @jsii.member(jsii_name="resetComputeQuery")
    def reset_compute_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetComputeQuery", []))

    @jsii.member(jsii_name="resetGroupBy")
    def reset_group_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGroupBy", []))

    @jsii.member(jsii_name="resetMultiCompute")
    def reset_multi_compute(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMultiCompute", []))

    @jsii.member(jsii_name="resetSearchQuery")
    def reset_search_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSearchQuery", []))

    @builtins.property
    @jsii.member(jsii_name="computeQuery")
    def compute_query(
        self,
    ) -> PowerpackWidgetToplistDefinitionRequestAuditQueryComputeQueryOutputReference:
        return typing.cast(PowerpackWidgetToplistDefinitionRequestAuditQueryComputeQueryOutputReference, jsii.get(self, "computeQuery"))

    @builtins.property
    @jsii.member(jsii_name="groupBy")
    def group_by(self) -> PowerpackWidgetToplistDefinitionRequestAuditQueryGroupByList:
        return typing.cast(PowerpackWidgetToplistDefinitionRequestAuditQueryGroupByList, jsii.get(self, "groupBy"))

    @builtins.property
    @jsii.member(jsii_name="multiCompute")
    def multi_compute(
        self,
    ) -> PowerpackWidgetToplistDefinitionRequestAuditQueryMultiComputeList:
        return typing.cast(PowerpackWidgetToplistDefinitionRequestAuditQueryMultiComputeList, jsii.get(self, "multiCompute"))

    @builtins.property
    @jsii.member(jsii_name="computeQueryInput")
    def compute_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetToplistDefinitionRequestAuditQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetToplistDefinitionRequestAuditQueryComputeQuery], jsii.get(self, "computeQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="groupByInput")
    def group_by_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionRequestAuditQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionRequestAuditQueryGroupBy]]], jsii.get(self, "groupByInput"))

    @builtins.property
    @jsii.member(jsii_name="indexInput")
    def index_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "indexInput"))

    @builtins.property
    @jsii.member(jsii_name="multiComputeInput")
    def multi_compute_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionRequestAuditQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionRequestAuditQueryMultiCompute]]], jsii.get(self, "multiComputeInput"))

    @builtins.property
    @jsii.member(jsii_name="searchQueryInput")
    def search_query_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "searchQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="index")
    def index(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "index"))

    @index.setter
    def index(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a7acdb35f3563335d37a3c949763ec433a2357217eae01d2c00d27f176a3977e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "index", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="searchQuery")
    def search_query(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "searchQuery"))

    @search_query.setter
    def search_query(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ca5d17aa3613920fe2760b42925016223567211a1a636ebf277f1ee844a00e1e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "searchQuery", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetToplistDefinitionRequestAuditQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetToplistDefinitionRequestAuditQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetToplistDefinitionRequestAuditQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__03934125455896d00a5d9f8202ef7a7a3581c45539f47dee2d21b16c70eb611f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestConditionalFormats",
    jsii_struct_bases=[],
    name_mapping={
        "comparator": "comparator",
        "palette": "palette",
        "value": "value",
        "custom_bg_color": "customBgColor",
        "custom_fg_color": "customFgColor",
        "hide_value": "hideValue",
        "image_url": "imageUrl",
        "metric": "metric",
        "timeframe": "timeframe",
    },
)
class PowerpackWidgetToplistDefinitionRequestConditionalFormats:
    def __init__(
        self,
        *,
        comparator: builtins.str,
        palette: builtins.str,
        value: jsii.Number,
        custom_bg_color: typing.Optional[builtins.str] = None,
        custom_fg_color: typing.Optional[builtins.str] = None,
        hide_value: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        image_url: typing.Optional[builtins.str] = None,
        metric: typing.Optional[builtins.str] = None,
        timeframe: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param comparator: The comparator to use. Valid values are ``=``, ``>``, ``>=``, ``<``, ``<=``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#comparator Powerpack#comparator}
        :param palette: The color palette to apply. Valid values are ``blue``, ``custom_bg``, ``custom_image``, ``custom_text``, ``gray_on_white``, ``grey``, ``green``, ``orange``, ``red``, ``red_on_white``, ``white_on_gray``, ``white_on_green``, ``green_on_white``, ``white_on_red``, ``white_on_yellow``, ``yellow_on_white``, ``black_on_light_yellow``, ``black_on_light_green``, ``black_on_light_red``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette Powerpack#palette}
        :param value: A value for the comparator. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#value Powerpack#value}
        :param custom_bg_color: The color palette to apply to the background, same values available as palette. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom_bg_color Powerpack#custom_bg_color}
        :param custom_fg_color: The color palette to apply to the foreground, same values available as palette. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom_fg_color Powerpack#custom_fg_color}
        :param hide_value: Setting this to True hides values. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#hide_value Powerpack#hide_value}
        :param image_url: Displays an image as the background. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#image_url Powerpack#image_url}
        :param metric: The metric from the request to correlate with this conditional format. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        :param timeframe: Defines the displayed timeframe. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#timeframe Powerpack#timeframe}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a00991e2237b600aab4b829f6a7b60439afc720a079950c481bd6537bb818873)
            check_type(argname="argument comparator", value=comparator, expected_type=type_hints["comparator"])
            check_type(argname="argument palette", value=palette, expected_type=type_hints["palette"])
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument custom_bg_color", value=custom_bg_color, expected_type=type_hints["custom_bg_color"])
            check_type(argname="argument custom_fg_color", value=custom_fg_color, expected_type=type_hints["custom_fg_color"])
            check_type(argname="argument hide_value", value=hide_value, expected_type=type_hints["hide_value"])
            check_type(argname="argument image_url", value=image_url, expected_type=type_hints["image_url"])
            check_type(argname="argument metric", value=metric, expected_type=type_hints["metric"])
            check_type(argname="argument timeframe", value=timeframe, expected_type=type_hints["timeframe"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "comparator": comparator,
            "palette": palette,
            "value": value,
        }
        if custom_bg_color is not None:
            self._values["custom_bg_color"] = custom_bg_color
        if custom_fg_color is not None:
            self._values["custom_fg_color"] = custom_fg_color
        if hide_value is not None:
            self._values["hide_value"] = hide_value
        if image_url is not None:
            self._values["image_url"] = image_url
        if metric is not None:
            self._values["metric"] = metric
        if timeframe is not None:
            self._values["timeframe"] = timeframe

    @builtins.property
    def comparator(self) -> builtins.str:
        '''The comparator to use. Valid values are ``=``, ``>``, ``>=``, ``<``, ``<=``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#comparator Powerpack#comparator}
        '''
        result = self._values.get("comparator")
        assert result is not None, "Required property 'comparator' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def palette(self) -> builtins.str:
        '''The color palette to apply.

        Valid values are ``blue``, ``custom_bg``, ``custom_image``, ``custom_text``, ``gray_on_white``, ``grey``, ``green``, ``orange``, ``red``, ``red_on_white``, ``white_on_gray``, ``white_on_green``, ``green_on_white``, ``white_on_red``, ``white_on_yellow``, ``yellow_on_white``, ``black_on_light_yellow``, ``black_on_light_green``, ``black_on_light_red``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette Powerpack#palette}
        '''
        result = self._values.get("palette")
        assert result is not None, "Required property 'palette' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def value(self) -> jsii.Number:
        '''A value for the comparator.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#value Powerpack#value}
        '''
        result = self._values.get("value")
        assert result is not None, "Required property 'value' is missing"
        return typing.cast(jsii.Number, result)

    @builtins.property
    def custom_bg_color(self) -> typing.Optional[builtins.str]:
        '''The color palette to apply to the background, same values available as palette.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom_bg_color Powerpack#custom_bg_color}
        '''
        result = self._values.get("custom_bg_color")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def custom_fg_color(self) -> typing.Optional[builtins.str]:
        '''The color palette to apply to the foreground, same values available as palette.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom_fg_color Powerpack#custom_fg_color}
        '''
        result = self._values.get("custom_fg_color")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def hide_value(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        '''Setting this to True hides values.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#hide_value Powerpack#hide_value}
        '''
        result = self._values.get("hide_value")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)

    @builtins.property
    def image_url(self) -> typing.Optional[builtins.str]:
        '''Displays an image as the background.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#image_url Powerpack#image_url}
        '''
        result = self._values.get("image_url")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def metric(self) -> typing.Optional[builtins.str]:
        '''The metric from the request to correlate with this conditional format.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        '''
        result = self._values.get("metric")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def timeframe(self) -> typing.Optional[builtins.str]:
        '''Defines the displayed timeframe.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#timeframe Powerpack#timeframe}
        '''
        result = self._values.get("timeframe")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetToplistDefinitionRequestConditionalFormats(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetToplistDefinitionRequestConditionalFormatsList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestConditionalFormatsList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__024d38c1518b2b5053d7606a94b97447dbfd44f1517af093cc56d943bcbcdbfc)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetToplistDefinitionRequestConditionalFormatsOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__231b9fc146ff8a3ff39b0bf7eda3a88efe146fffe65b766273b9f4d3e3993d23)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetToplistDefinitionRequestConditionalFormatsOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__77f6b2a2b7452873feecd1d36e56ac5c77f1fa2c3ebe6d694062545aaf2f8c66)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__26303747dc0b85af6e52074de4cf36435d755ced4071511498e43e46d087f35b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0954190d783996aaeef81f0885c767eafba26b5468bb045af9060ec0cf2644b3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionRequestConditionalFormats]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionRequestConditionalFormats]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionRequestConditionalFormats]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b2716c430498293cb5b96f3c3417ed4d7b55a49be7fea8652388170cc52fa0bc)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetToplistDefinitionRequestConditionalFormatsOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestConditionalFormatsOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f90f2f49c57d10bac53ef1af4407555650498e678ea6cc4db07dd83e47bd0374)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetCustomBgColor")
    def reset_custom_bg_color(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCustomBgColor", []))

    @jsii.member(jsii_name="resetCustomFgColor")
    def reset_custom_fg_color(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCustomFgColor", []))

    @jsii.member(jsii_name="resetHideValue")
    def reset_hide_value(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHideValue", []))

    @jsii.member(jsii_name="resetImageUrl")
    def reset_image_url(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetImageUrl", []))

    @jsii.member(jsii_name="resetMetric")
    def reset_metric(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMetric", []))

    @jsii.member(jsii_name="resetTimeframe")
    def reset_timeframe(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTimeframe", []))

    @builtins.property
    @jsii.member(jsii_name="comparatorInput")
    def comparator_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "comparatorInput"))

    @builtins.property
    @jsii.member(jsii_name="customBgColorInput")
    def custom_bg_color_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "customBgColorInput"))

    @builtins.property
    @jsii.member(jsii_name="customFgColorInput")
    def custom_fg_color_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "customFgColorInput"))

    @builtins.property
    @jsii.member(jsii_name="hideValueInput")
    def hide_value_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "hideValueInput"))

    @builtins.property
    @jsii.member(jsii_name="imageUrlInput")
    def image_url_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "imageUrlInput"))

    @builtins.property
    @jsii.member(jsii_name="metricInput")
    def metric_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "metricInput"))

    @builtins.property
    @jsii.member(jsii_name="paletteInput")
    def palette_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "paletteInput"))

    @builtins.property
    @jsii.member(jsii_name="timeframeInput")
    def timeframe_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "timeframeInput"))

    @builtins.property
    @jsii.member(jsii_name="valueInput")
    def value_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "valueInput"))

    @builtins.property
    @jsii.member(jsii_name="comparator")
    def comparator(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "comparator"))

    @comparator.setter
    def comparator(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cf3d1225ca986e2ee5bf83beb1eb8f619ab4ed9c21ccc407ffe4f25fb7d263ec)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "comparator", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="customBgColor")
    def custom_bg_color(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "customBgColor"))

    @custom_bg_color.setter
    def custom_bg_color(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__656c886115b81e633bfe1a9dfdd49f1c6b9fa10bc802e030433d96440d3b3361)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "customBgColor", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="customFgColor")
    def custom_fg_color(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "customFgColor"))

    @custom_fg_color.setter
    def custom_fg_color(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__717e546261fab62be9eb5d676cd51533673937f85b84e154bf7bf49b3505a6b1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "customFgColor", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="hideValue")
    def hide_value(self) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "hideValue"))

    @hide_value.setter
    def hide_value(
        self,
        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2bc6ff59e5aca329ef8b6bdb35a185401342581ba048715cca61b08593e82fa1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "hideValue", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="imageUrl")
    def image_url(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "imageUrl"))

    @image_url.setter
    def image_url(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__286372c6fd58ae1d798e4d1ddab511a2674f1966298340cebfa70a8be382e6a7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "imageUrl", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="metric")
    def metric(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "metric"))

    @metric.setter
    def metric(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5d867839b70c58c2850b0aadbfcfcfbdf7d8dedfee3684357f859ae4db68ec83)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "metric", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="palette")
    def palette(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "palette"))

    @palette.setter
    def palette(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0a48f82f612c6db144ab5854cb9aa6015cb205b9ee985d5bdc5b9b006d6d6f61)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "palette", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="timeframe")
    def timeframe(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "timeframe"))

    @timeframe.setter
    def timeframe(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__88338f555e276ff27136d3628cfff7a2e31e92293a5d5d70b5b0ea2b909788ef)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "timeframe", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="value")
    def value(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "value"))

    @value.setter
    def value(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__824a1dee6291996e0c5c7a5cea24b427e677f6c12ccd3afa522abde4793bc58a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "value", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetToplistDefinitionRequestConditionalFormats]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetToplistDefinitionRequestConditionalFormats]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetToplistDefinitionRequestConditionalFormats]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1563c24614567c2ff86c84b3b5f6c66f7bd64e1f12a042e790d2a829d83bac6c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestFormula",
    jsii_struct_bases=[],
    name_mapping={
        "formula_expression": "formulaExpression",
        "alias": "alias",
        "cell_display_mode": "cellDisplayMode",
        "conditional_formats": "conditionalFormats",
        "limit": "limit",
        "number_format": "numberFormat",
        "style": "style",
    },
)
class PowerpackWidgetToplistDefinitionRequestFormula:
    def __init__(
        self,
        *,
        formula_expression: builtins.str,
        alias: typing.Optional[builtins.str] = None,
        cell_display_mode: typing.Optional[builtins.str] = None,
        conditional_formats: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetToplistDefinitionRequestFormulaConditionalFormats", typing.Dict[builtins.str, typing.Any]]]]] = None,
        limit: typing.Optional[typing.Union["PowerpackWidgetToplistDefinitionRequestFormulaLimit", typing.Dict[builtins.str, typing.Any]]] = None,
        number_format: typing.Optional[typing.Union["PowerpackWidgetToplistDefinitionRequestFormulaNumberFormat", typing.Dict[builtins.str, typing.Any]]] = None,
        style: typing.Optional[typing.Union["PowerpackWidgetToplistDefinitionRequestFormulaStyle", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param formula_expression: A string expression built from queries, formulas, and functions. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#formula_expression Powerpack#formula_expression}
        :param alias: An expression alias. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#alias Powerpack#alias}
        :param cell_display_mode: A list of display modes for each table cell. Valid values are ``number``, ``bar``, ``trend``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cell_display_mode Powerpack#cell_display_mode}
        :param conditional_formats: conditional_formats block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#conditional_formats Powerpack#conditional_formats}
        :param limit: limit block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param number_format: number_format block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#number_format Powerpack#number_format}
        :param style: style block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#style Powerpack#style}
        '''
        if isinstance(limit, dict):
            limit = PowerpackWidgetToplistDefinitionRequestFormulaLimit(**limit)
        if isinstance(number_format, dict):
            number_format = PowerpackWidgetToplistDefinitionRequestFormulaNumberFormat(**number_format)
        if isinstance(style, dict):
            style = PowerpackWidgetToplistDefinitionRequestFormulaStyle(**style)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ab8faf831d902ff99a897170d16c0c81b7987c4e73515ea317dfece03bd081ce)
            check_type(argname="argument formula_expression", value=formula_expression, expected_type=type_hints["formula_expression"])
            check_type(argname="argument alias", value=alias, expected_type=type_hints["alias"])
            check_type(argname="argument cell_display_mode", value=cell_display_mode, expected_type=type_hints["cell_display_mode"])
            check_type(argname="argument conditional_formats", value=conditional_formats, expected_type=type_hints["conditional_formats"])
            check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
            check_type(argname="argument number_format", value=number_format, expected_type=type_hints["number_format"])
            check_type(argname="argument style", value=style, expected_type=type_hints["style"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "formula_expression": formula_expression,
        }
        if alias is not None:
            self._values["alias"] = alias
        if cell_display_mode is not None:
            self._values["cell_display_mode"] = cell_display_mode
        if conditional_formats is not None:
            self._values["conditional_formats"] = conditional_formats
        if limit is not None:
            self._values["limit"] = limit
        if number_format is not None:
            self._values["number_format"] = number_format
        if style is not None:
            self._values["style"] = style

    @builtins.property
    def formula_expression(self) -> builtins.str:
        '''A string expression built from queries, formulas, and functions.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#formula_expression Powerpack#formula_expression}
        '''
        result = self._values.get("formula_expression")
        assert result is not None, "Required property 'formula_expression' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def alias(self) -> typing.Optional[builtins.str]:
        '''An expression alias.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#alias Powerpack#alias}
        '''
        result = self._values.get("alias")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def cell_display_mode(self) -> typing.Optional[builtins.str]:
        '''A list of display modes for each table cell. Valid values are ``number``, ``bar``, ``trend``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cell_display_mode Powerpack#cell_display_mode}
        '''
        result = self._values.get("cell_display_mode")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def conditional_formats(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetToplistDefinitionRequestFormulaConditionalFormats"]]]:
        '''conditional_formats block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#conditional_formats Powerpack#conditional_formats}
        '''
        result = self._values.get("conditional_formats")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetToplistDefinitionRequestFormulaConditionalFormats"]]], result)

    @builtins.property
    def limit(
        self,
    ) -> typing.Optional["PowerpackWidgetToplistDefinitionRequestFormulaLimit"]:
        '''limit block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        '''
        result = self._values.get("limit")
        return typing.cast(typing.Optional["PowerpackWidgetToplistDefinitionRequestFormulaLimit"], result)

    @builtins.property
    def number_format(
        self,
    ) -> typing.Optional["PowerpackWidgetToplistDefinitionRequestFormulaNumberFormat"]:
        '''number_format block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#number_format Powerpack#number_format}
        '''
        result = self._values.get("number_format")
        return typing.cast(typing.Optional["PowerpackWidgetToplistDefinitionRequestFormulaNumberFormat"], result)

    @builtins.property
    def style(
        self,
    ) -> typing.Optional["PowerpackWidgetToplistDefinitionRequestFormulaStyle"]:
        '''style block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#style Powerpack#style}
        '''
        result = self._values.get("style")
        return typing.cast(typing.Optional["PowerpackWidgetToplistDefinitionRequestFormulaStyle"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetToplistDefinitionRequestFormula(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestFormulaConditionalFormats",
    jsii_struct_bases=[],
    name_mapping={
        "comparator": "comparator",
        "palette": "palette",
        "value": "value",
        "custom_bg_color": "customBgColor",
        "custom_fg_color": "customFgColor",
        "hide_value": "hideValue",
        "image_url": "imageUrl",
        "metric": "metric",
        "timeframe": "timeframe",
    },
)
class PowerpackWidgetToplistDefinitionRequestFormulaConditionalFormats:
    def __init__(
        self,
        *,
        comparator: builtins.str,
        palette: builtins.str,
        value: jsii.Number,
        custom_bg_color: typing.Optional[builtins.str] = None,
        custom_fg_color: typing.Optional[builtins.str] = None,
        hide_value: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        image_url: typing.Optional[builtins.str] = None,
        metric: typing.Optional[builtins.str] = None,
        timeframe: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param comparator: The comparator to use. Valid values are ``=``, ``>``, ``>=``, ``<``, ``<=``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#comparator Powerpack#comparator}
        :param palette: The color palette to apply. Valid values are ``blue``, ``custom_bg``, ``custom_image``, ``custom_text``, ``gray_on_white``, ``grey``, ``green``, ``orange``, ``red``, ``red_on_white``, ``white_on_gray``, ``white_on_green``, ``green_on_white``, ``white_on_red``, ``white_on_yellow``, ``yellow_on_white``, ``black_on_light_yellow``, ``black_on_light_green``, ``black_on_light_red``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette Powerpack#palette}
        :param value: A value for the comparator. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#value Powerpack#value}
        :param custom_bg_color: The color palette to apply to the background, same values available as palette. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom_bg_color Powerpack#custom_bg_color}
        :param custom_fg_color: The color palette to apply to the foreground, same values available as palette. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom_fg_color Powerpack#custom_fg_color}
        :param hide_value: Setting this to True hides values. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#hide_value Powerpack#hide_value}
        :param image_url: Displays an image as the background. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#image_url Powerpack#image_url}
        :param metric: The metric from the request to correlate with this conditional format. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        :param timeframe: Defines the displayed timeframe. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#timeframe Powerpack#timeframe}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5fb3c2a29de2e42b92d1f733a634d3b2952f618f6c67fba3c15b0394cfd82726)
            check_type(argname="argument comparator", value=comparator, expected_type=type_hints["comparator"])
            check_type(argname="argument palette", value=palette, expected_type=type_hints["palette"])
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument custom_bg_color", value=custom_bg_color, expected_type=type_hints["custom_bg_color"])
            check_type(argname="argument custom_fg_color", value=custom_fg_color, expected_type=type_hints["custom_fg_color"])
            check_type(argname="argument hide_value", value=hide_value, expected_type=type_hints["hide_value"])
            check_type(argname="argument image_url", value=image_url, expected_type=type_hints["image_url"])
            check_type(argname="argument metric", value=metric, expected_type=type_hints["metric"])
            check_type(argname="argument timeframe", value=timeframe, expected_type=type_hints["timeframe"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "comparator": comparator,
            "palette": palette,
            "value": value,
        }
        if custom_bg_color is not None:
            self._values["custom_bg_color"] = custom_bg_color
        if custom_fg_color is not None:
            self._values["custom_fg_color"] = custom_fg_color
        if hide_value is not None:
            self._values["hide_value"] = hide_value
        if image_url is not None:
            self._values["image_url"] = image_url
        if metric is not None:
            self._values["metric"] = metric
        if timeframe is not None:
            self._values["timeframe"] = timeframe

    @builtins.property
    def comparator(self) -> builtins.str:
        '''The comparator to use. Valid values are ``=``, ``>``, ``>=``, ``<``, ``<=``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#comparator Powerpack#comparator}
        '''
        result = self._values.get("comparator")
        assert result is not None, "Required property 'comparator' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def palette(self) -> builtins.str:
        '''The color palette to apply.

        Valid values are ``blue``, ``custom_bg``, ``custom_image``, ``custom_text``, ``gray_on_white``, ``grey``, ``green``, ``orange``, ``red``, ``red_on_white``, ``white_on_gray``, ``white_on_green``, ``green_on_white``, ``white_on_red``, ``white_on_yellow``, ``yellow_on_white``, ``black_on_light_yellow``, ``black_on_light_green``, ``black_on_light_red``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette Powerpack#palette}
        '''
        result = self._values.get("palette")
        assert result is not None, "Required property 'palette' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def value(self) -> jsii.Number:
        '''A value for the comparator.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#value Powerpack#value}
        '''
        result = self._values.get("value")
        assert result is not None, "Required property 'value' is missing"
        return typing.cast(jsii.Number, result)

    @builtins.property
    def custom_bg_color(self) -> typing.Optional[builtins.str]:
        '''The color palette to apply to the background, same values available as palette.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom_bg_color Powerpack#custom_bg_color}
        '''
        result = self._values.get("custom_bg_color")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def custom_fg_color(self) -> typing.Optional[builtins.str]:
        '''The color palette to apply to the foreground, same values available as palette.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom_fg_color Powerpack#custom_fg_color}
        '''
        result = self._values.get("custom_fg_color")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def hide_value(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        '''Setting this to True hides values.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#hide_value Powerpack#hide_value}
        '''
        result = self._values.get("hide_value")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)

    @builtins.property
    def image_url(self) -> typing.Optional[builtins.str]:
        '''Displays an image as the background.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#image_url Powerpack#image_url}
        '''
        result = self._values.get("image_url")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def metric(self) -> typing.Optional[builtins.str]:
        '''The metric from the request to correlate with this conditional format.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        '''
        result = self._values.get("metric")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def timeframe(self) -> typing.Optional[builtins.str]:
        '''Defines the displayed timeframe.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#timeframe Powerpack#timeframe}
        '''
        result = self._values.get("timeframe")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetToplistDefinitionRequestFormulaConditionalFormats(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetToplistDefinitionRequestFormulaConditionalFormatsList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestFormulaConditionalFormatsList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__150f1efcbf83c9824f50fc6fec2c938bedb5c4bd06b09004b9cf6a3e051738ed)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetToplistDefinitionRequestFormulaConditionalFormatsOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__62a4a5c75567fbfa31b9f91ad81e4c6ca0e4bac97318a3dd4ca452b188b28726)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetToplistDefinitionRequestFormulaConditionalFormatsOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9d24a2f43998632b399495a576234c45561b8d0491646f0ced34d5bb98428c5e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d14501fccec55696afd0be1fb26945ed0a62900db2d73d181722c46fd339c82c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4bae84282a7b6bfe2f251db6432c3e1622e1223bc750254946de160fa7305d73)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionRequestFormulaConditionalFormats]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionRequestFormulaConditionalFormats]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionRequestFormulaConditionalFormats]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__59d0523e091d8a4b41cde0e3a979216ca36d2abddd3d6489fd9ffc0c3b24d04b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetToplistDefinitionRequestFormulaConditionalFormatsOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestFormulaConditionalFormatsOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7839489accca3fbfad62e8f7b06ca06008e60e55f0b249a3cfe060fc0b861b1c)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetCustomBgColor")
    def reset_custom_bg_color(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCustomBgColor", []))

    @jsii.member(jsii_name="resetCustomFgColor")
    def reset_custom_fg_color(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCustomFgColor", []))

    @jsii.member(jsii_name="resetHideValue")
    def reset_hide_value(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHideValue", []))

    @jsii.member(jsii_name="resetImageUrl")
    def reset_image_url(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetImageUrl", []))

    @jsii.member(jsii_name="resetMetric")
    def reset_metric(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMetric", []))

    @jsii.member(jsii_name="resetTimeframe")
    def reset_timeframe(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTimeframe", []))

    @builtins.property
    @jsii.member(jsii_name="comparatorInput")
    def comparator_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "comparatorInput"))

    @builtins.property
    @jsii.member(jsii_name="customBgColorInput")
    def custom_bg_color_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "customBgColorInput"))

    @builtins.property
    @jsii.member(jsii_name="customFgColorInput")
    def custom_fg_color_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "customFgColorInput"))

    @builtins.property
    @jsii.member(jsii_name="hideValueInput")
    def hide_value_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "hideValueInput"))

    @builtins.property
    @jsii.member(jsii_name="imageUrlInput")
    def image_url_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "imageUrlInput"))

    @builtins.property
    @jsii.member(jsii_name="metricInput")
    def metric_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "metricInput"))

    @builtins.property
    @jsii.member(jsii_name="paletteInput")
    def palette_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "paletteInput"))

    @builtins.property
    @jsii.member(jsii_name="timeframeInput")
    def timeframe_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "timeframeInput"))

    @builtins.property
    @jsii.member(jsii_name="valueInput")
    def value_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "valueInput"))

    @builtins.property
    @jsii.member(jsii_name="comparator")
    def comparator(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "comparator"))

    @comparator.setter
    def comparator(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a1d1d78c7887822947541818c9990c53b1cdcd8776e65e8faf355d29b9dbab00)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "comparator", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="customBgColor")
    def custom_bg_color(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "customBgColor"))

    @custom_bg_color.setter
    def custom_bg_color(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5d8c22aac1b7cf08428890f652a1fdfb8b416ae6f462f9f336cea6a4d0b13fd1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "customBgColor", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="customFgColor")
    def custom_fg_color(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "customFgColor"))

    @custom_fg_color.setter
    def custom_fg_color(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__595198521fb0c4ea13b5bad83366bc96c138f61cae686f88f1ef75459de651d2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "customFgColor", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="hideValue")
    def hide_value(self) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "hideValue"))

    @hide_value.setter
    def hide_value(
        self,
        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__30bbb98310d7ed9680dc16a71470d687020623950af41210afb60c11defd8228)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "hideValue", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="imageUrl")
    def image_url(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "imageUrl"))

    @image_url.setter
    def image_url(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3535088cff0c164560d4bd2ee9e5b5efecd742c40606ee7f21e9d289ef43d362)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "imageUrl", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="metric")
    def metric(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "metric"))

    @metric.setter
    def metric(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c28be8da688912edf3655ab7616e861996faa597fbe550c4aad4a1e8eba37120)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "metric", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="palette")
    def palette(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "palette"))

    @palette.setter
    def palette(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__82cb4fd909e4e0b0550a8abc8b900b9bbb1eed01c9d5474893227c11a2b758a3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "palette", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="timeframe")
    def timeframe(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "timeframe"))

    @timeframe.setter
    def timeframe(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2bd783a2ad2bc70d0154f1898afb0d9d67b311fe6f40cf52e98230e6423d2480)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "timeframe", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="value")
    def value(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "value"))

    @value.setter
    def value(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__584346352ef0795dee07cba4f68e4856af6dd8ee782057035eac139e8dc994a0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "value", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetToplistDefinitionRequestFormulaConditionalFormats]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetToplistDefinitionRequestFormulaConditionalFormats]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetToplistDefinitionRequestFormulaConditionalFormats]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__36df04080af632892151dc83fdb2355abeb90ed08281b54c12a4293f0c1f9a34)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestFormulaLimit",
    jsii_struct_bases=[],
    name_mapping={"count": "count", "order": "order"},
)
class PowerpackWidgetToplistDefinitionRequestFormulaLimit:
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        order: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param count: The number of results to return. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#count Powerpack#count}
        :param order: The direction of the sort. Valid values are ``asc``, ``desc``. Defaults to ``"desc"``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ddb341cf55d7c8bc48bb4eb58428af58d4bd4f871ac967305b9989fc7a9aaa45)
            check_type(argname="argument count", value=count, expected_type=type_hints["count"])
            check_type(argname="argument order", value=order, expected_type=type_hints["order"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if count is not None:
            self._values["count"] = count
        if order is not None:
            self._values["order"] = order

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''The number of results to return.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#count Powerpack#count}
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def order(self) -> typing.Optional[builtins.str]:
        '''The direction of the sort. Valid values are ``asc``, ``desc``. Defaults to ``"desc"``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        result = self._values.get("order")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetToplistDefinitionRequestFormulaLimit(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetToplistDefinitionRequestFormulaLimitOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestFormulaLimitOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__58285ba7a1ac9070526c9c82432b34de83a65b59d12a2797bf12176ad5d8b7dc)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetCount")
    def reset_count(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCount", []))

    @jsii.member(jsii_name="resetOrder")
    def reset_order(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetOrder", []))

    @builtins.property
    @jsii.member(jsii_name="countInput")
    def count_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "countInput"))

    @builtins.property
    @jsii.member(jsii_name="orderInput")
    def order_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "orderInput"))

    @builtins.property
    @jsii.member(jsii_name="count")
    def count(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "count"))

    @count.setter
    def count(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dcc2d317b450e616b835e5b4b7fc34f69d2498194790ae735ccb772efae70e9f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "count", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="order")
    def order(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "order"))

    @order.setter
    def order(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__22a9dc888673695133bd7a7187a9e7ff061a8ab810b0027af9bbe50f70e590f1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "order", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetToplistDefinitionRequestFormulaLimit]:
        return typing.cast(typing.Optional[PowerpackWidgetToplistDefinitionRequestFormulaLimit], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetToplistDefinitionRequestFormulaLimit],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9617a29c3ca136106ab70654881bb1355f608ae6c0851003ed054d9fd184a1dc)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetToplistDefinitionRequestFormulaList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestFormulaList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__70aa8472e2e4fc5de7aa5e662f51daf7b1ebd0b59c9a90d96cdfae2132c81e9c)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetToplistDefinitionRequestFormulaOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5b569d56cd62de662ce60c6ec32dc26af5f98fbf1ca6ed94327313612a1d0024)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetToplistDefinitionRequestFormulaOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a815fbf790cbba8f4e9cbab2d724244b8fbdfd422b32a6c08376fc44b52cb8a3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0dd11a3ae98591d1300fb4c0c0c38c2ff767cda4413a1fd88178c13fd50612e5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__23d0bdfda9b8a13e50f7fb0c390b2ae4d12cb730d076f4a2900d1420ee66d89c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionRequestFormula]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionRequestFormula]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionRequestFormula]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d08c9daad145c2577d7501c92bfadce3ecaebbbee821bed0d2bba0484edebd87)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestFormulaNumberFormat",
    jsii_struct_bases=[],
    name_mapping={"unit": "unit", "unit_scale": "unitScale"},
)
class PowerpackWidgetToplistDefinitionRequestFormulaNumberFormat:
    def __init__(
        self,
        *,
        unit: typing.Union["PowerpackWidgetToplistDefinitionRequestFormulaNumberFormatUnit", typing.Dict[builtins.str, typing.Any]],
        unit_scale: typing.Optional[typing.Union["PowerpackWidgetToplistDefinitionRequestFormulaNumberFormatUnitScale", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param unit: unit block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit Powerpack#unit}
        :param unit_scale: unit_scale block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit_scale Powerpack#unit_scale}
        '''
        if isinstance(unit, dict):
            unit = PowerpackWidgetToplistDefinitionRequestFormulaNumberFormatUnit(**unit)
        if isinstance(unit_scale, dict):
            unit_scale = PowerpackWidgetToplistDefinitionRequestFormulaNumberFormatUnitScale(**unit_scale)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d49c894892511dcc2453fa13c37422e068aa3777b2d617376155ba1a39e5f0fd)
            check_type(argname="argument unit", value=unit, expected_type=type_hints["unit"])
            check_type(argname="argument unit_scale", value=unit_scale, expected_type=type_hints["unit_scale"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "unit": unit,
        }
        if unit_scale is not None:
            self._values["unit_scale"] = unit_scale

    @builtins.property
    def unit(self) -> "PowerpackWidgetToplistDefinitionRequestFormulaNumberFormatUnit":
        '''unit block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit Powerpack#unit}
        '''
        result = self._values.get("unit")
        assert result is not None, "Required property 'unit' is missing"
        return typing.cast("PowerpackWidgetToplistDefinitionRequestFormulaNumberFormatUnit", result)

    @builtins.property
    def unit_scale(
        self,
    ) -> typing.Optional["PowerpackWidgetToplistDefinitionRequestFormulaNumberFormatUnitScale"]:
        '''unit_scale block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit_scale Powerpack#unit_scale}
        '''
        result = self._values.get("unit_scale")
        return typing.cast(typing.Optional["PowerpackWidgetToplistDefinitionRequestFormulaNumberFormatUnitScale"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetToplistDefinitionRequestFormulaNumberFormat(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetToplistDefinitionRequestFormulaNumberFormatOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestFormulaNumberFormatOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0c3529b65a512410807491db5aa2183093c4305122367cce948c8f7cf06237c1)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putUnit")
    def put_unit(
        self,
        *,
        canonical: typing.Optional[typing.Union["PowerpackWidgetToplistDefinitionRequestFormulaNumberFormatUnitCanonical", typing.Dict[builtins.str, typing.Any]]] = None,
        custom: typing.Optional[typing.Union["PowerpackWidgetToplistDefinitionRequestFormulaNumberFormatUnitCustom", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param canonical: canonical block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#canonical Powerpack#canonical}
        :param custom: custom block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom Powerpack#custom}
        '''
        value = PowerpackWidgetToplistDefinitionRequestFormulaNumberFormatUnit(
            canonical=canonical, custom=custom
        )

        return typing.cast(None, jsii.invoke(self, "putUnit", [value]))

    @jsii.member(jsii_name="putUnitScale")
    def put_unit_scale(self, *, unit_name: builtins.str) -> None:
        '''
        :param unit_name: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit_name Powerpack#unit_name}.
        '''
        value = PowerpackWidgetToplistDefinitionRequestFormulaNumberFormatUnitScale(
            unit_name=unit_name
        )

        return typing.cast(None, jsii.invoke(self, "putUnitScale", [value]))

    @jsii.member(jsii_name="resetUnitScale")
    def reset_unit_scale(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetUnitScale", []))

    @builtins.property
    @jsii.member(jsii_name="unit")
    def unit(
        self,
    ) -> "PowerpackWidgetToplistDefinitionRequestFormulaNumberFormatUnitOutputReference":
        return typing.cast("PowerpackWidgetToplistDefinitionRequestFormulaNumberFormatUnitOutputReference", jsii.get(self, "unit"))

    @builtins.property
    @jsii.member(jsii_name="unitScale")
    def unit_scale(
        self,
    ) -> "PowerpackWidgetToplistDefinitionRequestFormulaNumberFormatUnitScaleOutputReference":
        return typing.cast("PowerpackWidgetToplistDefinitionRequestFormulaNumberFormatUnitScaleOutputReference", jsii.get(self, "unitScale"))

    @builtins.property
    @jsii.member(jsii_name="unitInput")
    def unit_input(
        self,
    ) -> typing.Optional["PowerpackWidgetToplistDefinitionRequestFormulaNumberFormatUnit"]:
        return typing.cast(typing.Optional["PowerpackWidgetToplistDefinitionRequestFormulaNumberFormatUnit"], jsii.get(self, "unitInput"))

    @builtins.property
    @jsii.member(jsii_name="unitScaleInput")
    def unit_scale_input(
        self,
    ) -> typing.Optional["PowerpackWidgetToplistDefinitionRequestFormulaNumberFormatUnitScale"]:
        return typing.cast(typing.Optional["PowerpackWidgetToplistDefinitionRequestFormulaNumberFormatUnitScale"], jsii.get(self, "unitScaleInput"))

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetToplistDefinitionRequestFormulaNumberFormat]:
        return typing.cast(typing.Optional[PowerpackWidgetToplistDefinitionRequestFormulaNumberFormat], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetToplistDefinitionRequestFormulaNumberFormat],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__459a48aa3034125fc28ec694522b938d4226aa0a7f6638275437836e3a7d533a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestFormulaNumberFormatUnit",
    jsii_struct_bases=[],
    name_mapping={"canonical": "canonical", "custom": "custom"},
)
class PowerpackWidgetToplistDefinitionRequestFormulaNumberFormatUnit:
    def __init__(
        self,
        *,
        canonical: typing.Optional[typing.Union["PowerpackWidgetToplistDefinitionRequestFormulaNumberFormatUnitCanonical", typing.Dict[builtins.str, typing.Any]]] = None,
        custom: typing.Optional[typing.Union["PowerpackWidgetToplistDefinitionRequestFormulaNumberFormatUnitCustom", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param canonical: canonical block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#canonical Powerpack#canonical}
        :param custom: custom block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom Powerpack#custom}
        '''
        if isinstance(canonical, dict):
            canonical = PowerpackWidgetToplistDefinitionRequestFormulaNumberFormatUnitCanonical(**canonical)
        if isinstance(custom, dict):
            custom = PowerpackWidgetToplistDefinitionRequestFormulaNumberFormatUnitCustom(**custom)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f3a56e5c7bcce903b792a02743ebc8412067c7eaf4a340904cd0fcfc0d2fda1b)
            check_type(argname="argument canonical", value=canonical, expected_type=type_hints["canonical"])
            check_type(argname="argument custom", value=custom, expected_type=type_hints["custom"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if canonical is not None:
            self._values["canonical"] = canonical
        if custom is not None:
            self._values["custom"] = custom

    @builtins.property
    def canonical(
        self,
    ) -> typing.Optional["PowerpackWidgetToplistDefinitionRequestFormulaNumberFormatUnitCanonical"]:
        '''canonical block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#canonical Powerpack#canonical}
        '''
        result = self._values.get("canonical")
        return typing.cast(typing.Optional["PowerpackWidgetToplistDefinitionRequestFormulaNumberFormatUnitCanonical"], result)

    @builtins.property
    def custom(
        self,
    ) -> typing.Optional["PowerpackWidgetToplistDefinitionRequestFormulaNumberFormatUnitCustom"]:
        '''custom block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom Powerpack#custom}
        '''
        result = self._values.get("custom")
        return typing.cast(typing.Optional["PowerpackWidgetToplistDefinitionRequestFormulaNumberFormatUnitCustom"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetToplistDefinitionRequestFormulaNumberFormatUnit(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestFormulaNumberFormatUnitCanonical",
    jsii_struct_bases=[],
    name_mapping={"unit_name": "unitName", "per_unit_name": "perUnitName"},
)
class PowerpackWidgetToplistDefinitionRequestFormulaNumberFormatUnitCanonical:
    def __init__(
        self,
        *,
        unit_name: builtins.str,
        per_unit_name: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param unit_name: Unit name. It should be in singular form ('megabyte' and not 'megabytes'). Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit_name Powerpack#unit_name}
        :param per_unit_name: per unit name. If you want to represent megabytes/s, you set 'unit_name' = 'megabyte' and 'per_unit_name = 'second'. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#per_unit_name Powerpack#per_unit_name}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c6227566ade3f941bdc839ee6426056171fb79b71c1b8e15065be125c650e9d6)
            check_type(argname="argument unit_name", value=unit_name, expected_type=type_hints["unit_name"])
            check_type(argname="argument per_unit_name", value=per_unit_name, expected_type=type_hints["per_unit_name"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "unit_name": unit_name,
        }
        if per_unit_name is not None:
            self._values["per_unit_name"] = per_unit_name

    @builtins.property
    def unit_name(self) -> builtins.str:
        '''Unit name. It should be in singular form ('megabyte' and not 'megabytes').

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit_name Powerpack#unit_name}
        '''
        result = self._values.get("unit_name")
        assert result is not None, "Required property 'unit_name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def per_unit_name(self) -> typing.Optional[builtins.str]:
        '''per unit name. If you want to represent megabytes/s, you set 'unit_name' = 'megabyte' and 'per_unit_name = 'second'.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#per_unit_name Powerpack#per_unit_name}
        '''
        result = self._values.get("per_unit_name")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetToplistDefinitionRequestFormulaNumberFormatUnitCanonical(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetToplistDefinitionRequestFormulaNumberFormatUnitCanonicalOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestFormulaNumberFormatUnitCanonicalOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e5c0240d5585d3e95994795539888fab80b18831ee9078bf6e13f7395f70e4f1)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetPerUnitName")
    def reset_per_unit_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPerUnitName", []))

    @builtins.property
    @jsii.member(jsii_name="perUnitNameInput")
    def per_unit_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "perUnitNameInput"))

    @builtins.property
    @jsii.member(jsii_name="unitNameInput")
    def unit_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "unitNameInput"))

    @builtins.property
    @jsii.member(jsii_name="perUnitName")
    def per_unit_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "perUnitName"))

    @per_unit_name.setter
    def per_unit_name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3f9c9932d3e47521b9551d4dbcc24b5adf817efde4d799c948f50e1dc34f435f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "perUnitName", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="unitName")
    def unit_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "unitName"))

    @unit_name.setter
    def unit_name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__747ef03e9ac3455b0f5841c26c902c2d7bc5325737d5287b4e1c9c136c4c56ec)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "unitName", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetToplistDefinitionRequestFormulaNumberFormatUnitCanonical]:
        return typing.cast(typing.Optional[PowerpackWidgetToplistDefinitionRequestFormulaNumberFormatUnitCanonical], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetToplistDefinitionRequestFormulaNumberFormatUnitCanonical],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8aaa53c73210a578495c15f40468b4af8b4c11f98077fe3b65262fd553d2ebd0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestFormulaNumberFormatUnitCustom",
    jsii_struct_bases=[],
    name_mapping={"label": "label"},
)
class PowerpackWidgetToplistDefinitionRequestFormulaNumberFormatUnitCustom:
    def __init__(self, *, label: builtins.str) -> None:
        '''
        :param label: Unit label. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#label Powerpack#label}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__740b91a2457176221ace6cbe0cc96db2853b136907f687b6747af65133fcfb13)
            check_type(argname="argument label", value=label, expected_type=type_hints["label"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "label": label,
        }

    @builtins.property
    def label(self) -> builtins.str:
        '''Unit label.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#label Powerpack#label}
        '''
        result = self._values.get("label")
        assert result is not None, "Required property 'label' is missing"
        return typing.cast(builtins.str, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetToplistDefinitionRequestFormulaNumberFormatUnitCustom(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetToplistDefinitionRequestFormulaNumberFormatUnitCustomOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestFormulaNumberFormatUnitCustomOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__79067191e2cf70a07da60c305e232b7d3277c64c015bf5b25329734c70b53625)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @builtins.property
    @jsii.member(jsii_name="labelInput")
    def label_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "labelInput"))

    @builtins.property
    @jsii.member(jsii_name="label")
    def label(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "label"))

    @label.setter
    def label(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__058e7e78437de06976e69269026b7ca7eb79aa3757bce99c52dc87c1d95b4232)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "label", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetToplistDefinitionRequestFormulaNumberFormatUnitCustom]:
        return typing.cast(typing.Optional[PowerpackWidgetToplistDefinitionRequestFormulaNumberFormatUnitCustom], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetToplistDefinitionRequestFormulaNumberFormatUnitCustom],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__530d2234bf654b4cd1e3dd6d3d242f678472ae31ef61d5e2f27a5ffa74514a1e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetToplistDefinitionRequestFormulaNumberFormatUnitOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestFormulaNumberFormatUnitOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__35c1ef4411e140100bcd8dce9dcf186256bb954e879c9c9554394c50ad4aa281)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putCanonical")
    def put_canonical(
        self,
        *,
        unit_name: builtins.str,
        per_unit_name: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param unit_name: Unit name. It should be in singular form ('megabyte' and not 'megabytes'). Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit_name Powerpack#unit_name}
        :param per_unit_name: per unit name. If you want to represent megabytes/s, you set 'unit_name' = 'megabyte' and 'per_unit_name = 'second'. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#per_unit_name Powerpack#per_unit_name}
        '''
        value = PowerpackWidgetToplistDefinitionRequestFormulaNumberFormatUnitCanonical(
            unit_name=unit_name, per_unit_name=per_unit_name
        )

        return typing.cast(None, jsii.invoke(self, "putCanonical", [value]))

    @jsii.member(jsii_name="putCustom")
    def put_custom(self, *, label: builtins.str) -> None:
        '''
        :param label: Unit label. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#label Powerpack#label}
        '''
        value = PowerpackWidgetToplistDefinitionRequestFormulaNumberFormatUnitCustom(
            label=label
        )

        return typing.cast(None, jsii.invoke(self, "putCustom", [value]))

    @jsii.member(jsii_name="resetCanonical")
    def reset_canonical(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCanonical", []))

    @jsii.member(jsii_name="resetCustom")
    def reset_custom(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCustom", []))

    @builtins.property
    @jsii.member(jsii_name="canonical")
    def canonical(
        self,
    ) -> PowerpackWidgetToplistDefinitionRequestFormulaNumberFormatUnitCanonicalOutputReference:
        return typing.cast(PowerpackWidgetToplistDefinitionRequestFormulaNumberFormatUnitCanonicalOutputReference, jsii.get(self, "canonical"))

    @builtins.property
    @jsii.member(jsii_name="custom")
    def custom(
        self,
    ) -> PowerpackWidgetToplistDefinitionRequestFormulaNumberFormatUnitCustomOutputReference:
        return typing.cast(PowerpackWidgetToplistDefinitionRequestFormulaNumberFormatUnitCustomOutputReference, jsii.get(self, "custom"))

    @builtins.property
    @jsii.member(jsii_name="canonicalInput")
    def canonical_input(
        self,
    ) -> typing.Optional[PowerpackWidgetToplistDefinitionRequestFormulaNumberFormatUnitCanonical]:
        return typing.cast(typing.Optional[PowerpackWidgetToplistDefinitionRequestFormulaNumberFormatUnitCanonical], jsii.get(self, "canonicalInput"))

    @builtins.property
    @jsii.member(jsii_name="customInput")
    def custom_input(
        self,
    ) -> typing.Optional[PowerpackWidgetToplistDefinitionRequestFormulaNumberFormatUnitCustom]:
        return typing.cast(typing.Optional[PowerpackWidgetToplistDefinitionRequestFormulaNumberFormatUnitCustom], jsii.get(self, "customInput"))

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetToplistDefinitionRequestFormulaNumberFormatUnit]:
        return typing.cast(typing.Optional[PowerpackWidgetToplistDefinitionRequestFormulaNumberFormatUnit], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetToplistDefinitionRequestFormulaNumberFormatUnit],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__625081123978f102cee30316cb9c022be11d262318e2e632bcf6f3d97e92b92a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestFormulaNumberFormatUnitScale",
    jsii_struct_bases=[],
    name_mapping={"unit_name": "unitName"},
)
class PowerpackWidgetToplistDefinitionRequestFormulaNumberFormatUnitScale:
    def __init__(self, *, unit_name: builtins.str) -> None:
        '''
        :param unit_name: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit_name Powerpack#unit_name}.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d2f55ccf4747797f149260ad16a2e990fdd41f4c6a96ac121f6eabba062864c7)
            check_type(argname="argument unit_name", value=unit_name, expected_type=type_hints["unit_name"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "unit_name": unit_name,
        }

    @builtins.property
    def unit_name(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit_name Powerpack#unit_name}.'''
        result = self._values.get("unit_name")
        assert result is not None, "Required property 'unit_name' is missing"
        return typing.cast(builtins.str, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetToplistDefinitionRequestFormulaNumberFormatUnitScale(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetToplistDefinitionRequestFormulaNumberFormatUnitScaleOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestFormulaNumberFormatUnitScaleOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c2d76d8b81aa345be4c355fbba151deb140005a0d76c3fcd1d5ffa56e06bf826)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @builtins.property
    @jsii.member(jsii_name="unitNameInput")
    def unit_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "unitNameInput"))

    @builtins.property
    @jsii.member(jsii_name="unitName")
    def unit_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "unitName"))

    @unit_name.setter
    def unit_name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0157a8a24b903cc3a3ed0a7bb2dfdbb21dafacf9008af5646b2acc353781501d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "unitName", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetToplistDefinitionRequestFormulaNumberFormatUnitScale]:
        return typing.cast(typing.Optional[PowerpackWidgetToplistDefinitionRequestFormulaNumberFormatUnitScale], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetToplistDefinitionRequestFormulaNumberFormatUnitScale],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c71e21c32469f784533da43342ba7977a76a9d5fa1521073da720568da62cdbb)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetToplistDefinitionRequestFormulaOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestFormulaOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9c89630624bd3d223c76357ba31c6cfd8899f322d85a8a603368ee56e327ce70)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putConditionalFormats")
    def put_conditional_formats(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetToplistDefinitionRequestFormulaConditionalFormats, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__11954d8af87091e385603da62327cb0a3d83f6d172554acd15741207d14dfed4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putConditionalFormats", [value]))

    @jsii.member(jsii_name="putLimit")
    def put_limit(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        order: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param count: The number of results to return. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#count Powerpack#count}
        :param order: The direction of the sort. Valid values are ``asc``, ``desc``. Defaults to ``"desc"``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        value = PowerpackWidgetToplistDefinitionRequestFormulaLimit(
            count=count, order=order
        )

        return typing.cast(None, jsii.invoke(self, "putLimit", [value]))

    @jsii.member(jsii_name="putNumberFormat")
    def put_number_format(
        self,
        *,
        unit: typing.Union[PowerpackWidgetToplistDefinitionRequestFormulaNumberFormatUnit, typing.Dict[builtins.str, typing.Any]],
        unit_scale: typing.Optional[typing.Union[PowerpackWidgetToplistDefinitionRequestFormulaNumberFormatUnitScale, typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param unit: unit block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit Powerpack#unit}
        :param unit_scale: unit_scale block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit_scale Powerpack#unit_scale}
        '''
        value = PowerpackWidgetToplistDefinitionRequestFormulaNumberFormat(
            unit=unit, unit_scale=unit_scale
        )

        return typing.cast(None, jsii.invoke(self, "putNumberFormat", [value]))

    @jsii.member(jsii_name="putStyle")
    def put_style(
        self,
        *,
        palette: typing.Optional[builtins.str] = None,
        palette_index: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param palette: The color palette used to display the formula. A guide to the available color palettes can be found at https://docs.datadoghq.com/dashboards/guide/widget_colors. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette Powerpack#palette}
        :param palette_index: Index specifying which color to use within the palette. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette_index Powerpack#palette_index}
        '''
        value = PowerpackWidgetToplistDefinitionRequestFormulaStyle(
            palette=palette, palette_index=palette_index
        )

        return typing.cast(None, jsii.invoke(self, "putStyle", [value]))

    @jsii.member(jsii_name="resetAlias")
    def reset_alias(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAlias", []))

    @jsii.member(jsii_name="resetCellDisplayMode")
    def reset_cell_display_mode(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCellDisplayMode", []))

    @jsii.member(jsii_name="resetConditionalFormats")
    def reset_conditional_formats(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetConditionalFormats", []))

    @jsii.member(jsii_name="resetLimit")
    def reset_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLimit", []))

    @jsii.member(jsii_name="resetNumberFormat")
    def reset_number_format(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetNumberFormat", []))

    @jsii.member(jsii_name="resetStyle")
    def reset_style(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetStyle", []))

    @builtins.property
    @jsii.member(jsii_name="conditionalFormats")
    def conditional_formats(
        self,
    ) -> PowerpackWidgetToplistDefinitionRequestFormulaConditionalFormatsList:
        return typing.cast(PowerpackWidgetToplistDefinitionRequestFormulaConditionalFormatsList, jsii.get(self, "conditionalFormats"))

    @builtins.property
    @jsii.member(jsii_name="limit")
    def limit(
        self,
    ) -> PowerpackWidgetToplistDefinitionRequestFormulaLimitOutputReference:
        return typing.cast(PowerpackWidgetToplistDefinitionRequestFormulaLimitOutputReference, jsii.get(self, "limit"))

    @builtins.property
    @jsii.member(jsii_name="numberFormat")
    def number_format(
        self,
    ) -> PowerpackWidgetToplistDefinitionRequestFormulaNumberFormatOutputReference:
        return typing.cast(PowerpackWidgetToplistDefinitionRequestFormulaNumberFormatOutputReference, jsii.get(self, "numberFormat"))

    @builtins.property
    @jsii.member(jsii_name="style")
    def style(
        self,
    ) -> "PowerpackWidgetToplistDefinitionRequestFormulaStyleOutputReference":
        return typing.cast("PowerpackWidgetToplistDefinitionRequestFormulaStyleOutputReference", jsii.get(self, "style"))

    @builtins.property
    @jsii.member(jsii_name="aliasInput")
    def alias_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aliasInput"))

    @builtins.property
    @jsii.member(jsii_name="cellDisplayModeInput")
    def cell_display_mode_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "cellDisplayModeInput"))

    @builtins.property
    @jsii.member(jsii_name="conditionalFormatsInput")
    def conditional_formats_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionRequestFormulaConditionalFormats]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionRequestFormulaConditionalFormats]]], jsii.get(self, "conditionalFormatsInput"))

    @builtins.property
    @jsii.member(jsii_name="formulaExpressionInput")
    def formula_expression_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "formulaExpressionInput"))

    @builtins.property
    @jsii.member(jsii_name="limitInput")
    def limit_input(
        self,
    ) -> typing.Optional[PowerpackWidgetToplistDefinitionRequestFormulaLimit]:
        return typing.cast(typing.Optional[PowerpackWidgetToplistDefinitionRequestFormulaLimit], jsii.get(self, "limitInput"))

    @builtins.property
    @jsii.member(jsii_name="numberFormatInput")
    def number_format_input(
        self,
    ) -> typing.Optional[PowerpackWidgetToplistDefinitionRequestFormulaNumberFormat]:
        return typing.cast(typing.Optional[PowerpackWidgetToplistDefinitionRequestFormulaNumberFormat], jsii.get(self, "numberFormatInput"))

    @builtins.property
    @jsii.member(jsii_name="styleInput")
    def style_input(
        self,
    ) -> typing.Optional["PowerpackWidgetToplistDefinitionRequestFormulaStyle"]:
        return typing.cast(typing.Optional["PowerpackWidgetToplistDefinitionRequestFormulaStyle"], jsii.get(self, "styleInput"))

    @builtins.property
    @jsii.member(jsii_name="alias")
    def alias(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "alias"))

    @alias.setter
    def alias(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7327e7ec34dfe7bade7e135cd19b0e85f7e0874863af0e70581ae4afdc2d38b6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "alias", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="cellDisplayMode")
    def cell_display_mode(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "cellDisplayMode"))

    @cell_display_mode.setter
    def cell_display_mode(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c3c4f50336c629f653884ed32161f72eba342a69a511ac1b8aa3850a10df85a4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "cellDisplayMode", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="formulaExpression")
    def formula_expression(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "formulaExpression"))

    @formula_expression.setter
    def formula_expression(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5b1b76030de5490963505900fabb624c930a0ebecfcab7facb12dec605f76a7c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "formulaExpression", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetToplistDefinitionRequestFormula]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetToplistDefinitionRequestFormula]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetToplistDefinitionRequestFormula]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__aaea3ef8fa68a5029efb01218d679d9b01dba81b1d57b0f8f02bbfcee5fd9195)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestFormulaStyle",
    jsii_struct_bases=[],
    name_mapping={"palette": "palette", "palette_index": "paletteIndex"},
)
class PowerpackWidgetToplistDefinitionRequestFormulaStyle:
    def __init__(
        self,
        *,
        palette: typing.Optional[builtins.str] = None,
        palette_index: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param palette: The color palette used to display the formula. A guide to the available color palettes can be found at https://docs.datadoghq.com/dashboards/guide/widget_colors. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette Powerpack#palette}
        :param palette_index: Index specifying which color to use within the palette. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette_index Powerpack#palette_index}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__152157c8315e4b96c35c8f1548751585d5df3806139f6e7d6c78b953de3596aa)
            check_type(argname="argument palette", value=palette, expected_type=type_hints["palette"])
            check_type(argname="argument palette_index", value=palette_index, expected_type=type_hints["palette_index"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if palette is not None:
            self._values["palette"] = palette
        if palette_index is not None:
            self._values["palette_index"] = palette_index

    @builtins.property
    def palette(self) -> typing.Optional[builtins.str]:
        '''The color palette used to display the formula.

        A guide to the available color palettes can be found at https://docs.datadoghq.com/dashboards/guide/widget_colors.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette Powerpack#palette}
        '''
        result = self._values.get("palette")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def palette_index(self) -> typing.Optional[jsii.Number]:
        '''Index specifying which color to use within the palette.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette_index Powerpack#palette_index}
        '''
        result = self._values.get("palette_index")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetToplistDefinitionRequestFormulaStyle(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetToplistDefinitionRequestFormulaStyleOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestFormulaStyleOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8543fcb66e811a27fdc40a0c048edcb8f2de4b3cefddcd25010491750482da44)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetPalette")
    def reset_palette(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPalette", []))

    @jsii.member(jsii_name="resetPaletteIndex")
    def reset_palette_index(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPaletteIndex", []))

    @builtins.property
    @jsii.member(jsii_name="paletteIndexInput")
    def palette_index_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "paletteIndexInput"))

    @builtins.property
    @jsii.member(jsii_name="paletteInput")
    def palette_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "paletteInput"))

    @builtins.property
    @jsii.member(jsii_name="palette")
    def palette(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "palette"))

    @palette.setter
    def palette(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ebf7d0af02dbda533250ff75d58145cae1e76dc1465c602627c503163ae5163d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "palette", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="paletteIndex")
    def palette_index(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "paletteIndex"))

    @palette_index.setter
    def palette_index(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__24f2dc39f4ef042076995649f0032010451e5634b5e0b0f9b6ec6a1f7c6725dd)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "paletteIndex", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetToplistDefinitionRequestFormulaStyle]:
        return typing.cast(typing.Optional[PowerpackWidgetToplistDefinitionRequestFormulaStyle], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetToplistDefinitionRequestFormulaStyle],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a8efd83386e9f362d879f549cf57c7da2047b17586fce6eac115c05bb9762d0d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetToplistDefinitionRequestList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a47ce83f6f3291309e6267ce52dfe1f53f2c16b96671c6ec03209a20ca62197d)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetToplistDefinitionRequestOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f1552b70b3d786ffb70f929a623052115ecc7c8451307fc7779ec81675e3464b)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetToplistDefinitionRequestOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__df8652ce6a5b57d5ca96bba4cc579adce310e40f513daa0186643be3cbd9673e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__419b50d941fcda8d43c105e17c4a7ac0469123ae8cc65698467ecf7654a4ba6c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0543df50dc0be94e18ab4c89ddcd33bde8e61cef6489461aa1a4380151063859)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionRequest]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionRequest]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionRequest]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__acae551226b8a1876a03e8ea90dc82d41734b6a094b3113a707f81b4ed060633)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestLogQuery",
    jsii_struct_bases=[],
    name_mapping={
        "index": "index",
        "compute_query": "computeQuery",
        "group_by": "groupBy",
        "multi_compute": "multiCompute",
        "search_query": "searchQuery",
    },
)
class PowerpackWidgetToplistDefinitionRequestLogQuery:
    def __init__(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union["PowerpackWidgetToplistDefinitionRequestLogQueryComputeQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetToplistDefinitionRequestLogQueryGroupBy", typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetToplistDefinitionRequestLogQueryMultiCompute", typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        if isinstance(compute_query, dict):
            compute_query = PowerpackWidgetToplistDefinitionRequestLogQueryComputeQuery(**compute_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7fe037ac53949ba38e8e3a962da809c1232dbfbccdbd91c931a9479f88e7935a)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
            check_type(argname="argument compute_query", value=compute_query, expected_type=type_hints["compute_query"])
            check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
            check_type(argname="argument multi_compute", value=multi_compute, expected_type=type_hints["multi_compute"])
            check_type(argname="argument search_query", value=search_query, expected_type=type_hints["search_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "index": index,
        }
        if compute_query is not None:
            self._values["compute_query"] = compute_query
        if group_by is not None:
            self._values["group_by"] = group_by
        if multi_compute is not None:
            self._values["multi_compute"] = multi_compute
        if search_query is not None:
            self._values["search_query"] = search_query

    @builtins.property
    def index(self) -> builtins.str:
        '''The name of the index to query.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        '''
        result = self._values.get("index")
        assert result is not None, "Required property 'index' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def compute_query(
        self,
    ) -> typing.Optional["PowerpackWidgetToplistDefinitionRequestLogQueryComputeQuery"]:
        '''compute_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        '''
        result = self._values.get("compute_query")
        return typing.cast(typing.Optional["PowerpackWidgetToplistDefinitionRequestLogQueryComputeQuery"], result)

    @builtins.property
    def group_by(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetToplistDefinitionRequestLogQueryGroupBy"]]]:
        '''group_by block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        '''
        result = self._values.get("group_by")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetToplistDefinitionRequestLogQueryGroupBy"]]], result)

    @builtins.property
    def multi_compute(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetToplistDefinitionRequestLogQueryMultiCompute"]]]:
        '''multi_compute block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        '''
        result = self._values.get("multi_compute")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetToplistDefinitionRequestLogQueryMultiCompute"]]], result)

    @builtins.property
    def search_query(self) -> typing.Optional[builtins.str]:
        '''The search query to use.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        result = self._values.get("search_query")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetToplistDefinitionRequestLogQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestLogQueryComputeQuery",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetToplistDefinitionRequestLogQueryComputeQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__081dfe787a08ba73e31ba72ee64663f6fd98a966b5a7315f581b1ac91d909477)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetToplistDefinitionRequestLogQueryComputeQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetToplistDefinitionRequestLogQueryComputeQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestLogQueryComputeQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4bfa57384b22a5c98f948322d75605a26b29c678c7072a89ff824dec014eb4fe)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1dab749f700a3493c2d2c712b426627a315a7496b625b50dd43363dfbdd7161d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b008850f52768898b7f4d73a80eb0d830265c3beb11af5b7a0db3b3dff9beaf1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9f00dcd9d2e7aacf031321f32c6de70e4c79d8374625e51a947069b9cf2f6161)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetToplistDefinitionRequestLogQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetToplistDefinitionRequestLogQueryComputeQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetToplistDefinitionRequestLogQueryComputeQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0fd30208f7101bc0c2e78a07657b5f6cbb927bf38a7f62f8b2a0a958fadab313)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestLogQueryGroupBy",
    jsii_struct_bases=[],
    name_mapping={"facet": "facet", "limit": "limit", "sort_query": "sortQuery"},
)
class PowerpackWidgetToplistDefinitionRequestLogQueryGroupBy:
    def __init__(
        self,
        *,
        facet: typing.Optional[builtins.str] = None,
        limit: typing.Optional[jsii.Number] = None,
        sort_query: typing.Optional[typing.Union["PowerpackWidgetToplistDefinitionRequestLogQueryGroupBySortQuery", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param limit: The maximum number of items in the group. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param sort_query: sort_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        if isinstance(sort_query, dict):
            sort_query = PowerpackWidgetToplistDefinitionRequestLogQueryGroupBySortQuery(**sort_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__781917eb26832b06b6597372c6be4397fb1a81d5ee828a21ce64885cd05f07da)
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
            check_type(argname="argument sort_query", value=sort_query, expected_type=type_hints["sort_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if facet is not None:
            self._values["facet"] = facet
        if limit is not None:
            self._values["limit"] = limit
        if sort_query is not None:
            self._values["sort_query"] = sort_query

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def limit(self) -> typing.Optional[jsii.Number]:
        '''The maximum number of items in the group.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        '''
        result = self._values.get("limit")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def sort_query(
        self,
    ) -> typing.Optional["PowerpackWidgetToplistDefinitionRequestLogQueryGroupBySortQuery"]:
        '''sort_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        result = self._values.get("sort_query")
        return typing.cast(typing.Optional["PowerpackWidgetToplistDefinitionRequestLogQueryGroupBySortQuery"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetToplistDefinitionRequestLogQueryGroupBy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetToplistDefinitionRequestLogQueryGroupByList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestLogQueryGroupByList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0bc3ee9c5a79bce6e84b6299f7886137d610f387acd5ca28cec287710d8beb7f)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetToplistDefinitionRequestLogQueryGroupByOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b33b3fc784fa5aad8a84663d703439db55ffe099e494364626f67c370108ff6c)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetToplistDefinitionRequestLogQueryGroupByOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e927a0dbf92ad2005d0597cebe4dc7b9ca1da2586195ab514d80ed0465999a5c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__37360bae6ec35176acbeb99bb7c8ac3d89f9a1eb437f4c470c3ae246992e8c0c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f3ec13f009c9394da96446610a123dafaec25661f8d01a9ea247c2935de089f0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionRequestLogQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionRequestLogQueryGroupBy]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionRequestLogQueryGroupBy]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__904ad8e8e5cb08c69af8c99ff25c88b73ec31fd5c67e873c66eb50f2521afe49)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetToplistDefinitionRequestLogQueryGroupByOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestLogQueryGroupByOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__376431c05cfbc4cadcece17025ac0cfb3e4c3ae1c518de32e6ae1b8bc2e5d708)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putSortQuery")
    def put_sort_query(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        value = PowerpackWidgetToplistDefinitionRequestLogQueryGroupBySortQuery(
            aggregation=aggregation, order=order, facet=facet
        )

        return typing.cast(None, jsii.invoke(self, "putSortQuery", [value]))

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetLimit")
    def reset_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLimit", []))

    @jsii.member(jsii_name="resetSortQuery")
    def reset_sort_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSortQuery", []))

    @builtins.property
    @jsii.member(jsii_name="sortQuery")
    def sort_query(
        self,
    ) -> "PowerpackWidgetToplistDefinitionRequestLogQueryGroupBySortQueryOutputReference":
        return typing.cast("PowerpackWidgetToplistDefinitionRequestLogQueryGroupBySortQueryOutputReference", jsii.get(self, "sortQuery"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="limitInput")
    def limit_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "limitInput"))

    @builtins.property
    @jsii.member(jsii_name="sortQueryInput")
    def sort_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetToplistDefinitionRequestLogQueryGroupBySortQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetToplistDefinitionRequestLogQueryGroupBySortQuery"], jsii.get(self, "sortQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e86d057c475e8d80f17cd2019994da65aecb2bbe3b5dc48e3a9aae2e3e20d433)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="limit")
    def limit(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "limit"))

    @limit.setter
    def limit(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__beed61b26c02f8d86607e6ada66328ec783cdfcc96ad87e2b18fd6db866c75e5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "limit", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetToplistDefinitionRequestLogQueryGroupBy]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetToplistDefinitionRequestLogQueryGroupBy]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetToplistDefinitionRequestLogQueryGroupBy]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__abd9a40eac811ac29a4cc55783aa602cf14e28fe8187309016a84f41c624bb99)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestLogQueryGroupBySortQuery",
    jsii_struct_bases=[],
    name_mapping={"aggregation": "aggregation", "order": "order", "facet": "facet"},
)
class PowerpackWidgetToplistDefinitionRequestLogQueryGroupBySortQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__03ec76be4e9b059f7107828587155b7cf7f043c94484251eccbbe04449af8133)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument order", value=order, expected_type=type_hints["order"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
            "order": order,
        }
        if facet is not None:
            self._values["facet"] = facet

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def order(self) -> builtins.str:
        '''Widget sorting methods. Valid values are ``asc``, ``desc``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        result = self._values.get("order")
        assert result is not None, "Required property 'order' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetToplistDefinitionRequestLogQueryGroupBySortQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetToplistDefinitionRequestLogQueryGroupBySortQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestLogQueryGroupBySortQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8f0437bc49623398b56fa0a17aa814bc881c2ab1a001560e8ed5af472f1e0a91)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="orderInput")
    def order_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "orderInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__deb74ec36d92235afdeffa7e8ad78dd063e29cff4a77b0e7f690c2879f7461ae)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__81c2fcb5bca98022959dc62742efd594eb7bfe6a865abcfd07096f1a1c29a2df)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="order")
    def order(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "order"))

    @order.setter
    def order(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0f01f2c958b5619b31e01e936427956a7d35df11b65f1014fad150590d93b8df)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "order", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetToplistDefinitionRequestLogQueryGroupBySortQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetToplistDefinitionRequestLogQueryGroupBySortQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetToplistDefinitionRequestLogQueryGroupBySortQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1f3918eef3c451ec0dc347858f26718d2d140a3bc0a0221cf8561fd0e81e6fce)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestLogQueryMultiCompute",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetToplistDefinitionRequestLogQueryMultiCompute:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c5405e91a7a3e1883405cefc064654b21723cc9bd41884bda8c4de997a6872e9)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetToplistDefinitionRequestLogQueryMultiCompute(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetToplistDefinitionRequestLogQueryMultiComputeList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestLogQueryMultiComputeList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8853f38300068155076a1ead21e582e47bd2c5e731d8ddb21b707c40408db9ec)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetToplistDefinitionRequestLogQueryMultiComputeOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__65f99c63f12fe51bfb58c576aa65dc93f08a657b7a76ce3f82948480c8c6670f)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetToplistDefinitionRequestLogQueryMultiComputeOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f862c3283c196f4e84496a93cca1d9b4f98ea470c403e39743d56234f05eb0d5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5d7dc86a286b71f52cc28c38270f815a901d3f5736fe5fbdd5001f7c11ea46b7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4311b1ba8ecf27a3fe8997a7759d8297365610c5ed73d8fd854c6be302c7e573)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionRequestLogQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionRequestLogQueryMultiCompute]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionRequestLogQueryMultiCompute]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a2da02486cb54247d1dadfdb5cc353b3383d59424991fcafe1f634017925291f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetToplistDefinitionRequestLogQueryMultiComputeOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestLogQueryMultiComputeOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bec3de74794c2a49d837c2b48713feb7ac126bc54b5b31ddcf6dfff9a2ce9786)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__362b52b9bcde17c68516db4f2bdbf0f5665058134b6a8e20f4b6121d584556ff)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dc9bcbf9b635ab7ce34bfe8fb4e9412b82476d411b30ae1862fb039e097c69e5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bbcf1387ba51948fef5a65c7f06334abfe04ca03b8880dd35c3c9d4e9f4dec54)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetToplistDefinitionRequestLogQueryMultiCompute]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetToplistDefinitionRequestLogQueryMultiCompute]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetToplistDefinitionRequestLogQueryMultiCompute]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__22e488b3b59133a6f57c696ec6c9dff0f183b38857ea37fc6354c82931f42023)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetToplistDefinitionRequestLogQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestLogQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cc56d549307486e7374dc6d77625068da3a2f984764dfa6311750652e22fa875)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putComputeQuery")
    def put_compute_query(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        value = PowerpackWidgetToplistDefinitionRequestLogQueryComputeQuery(
            aggregation=aggregation, facet=facet, interval=interval
        )

        return typing.cast(None, jsii.invoke(self, "putComputeQuery", [value]))

    @jsii.member(jsii_name="putGroupBy")
    def put_group_by(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetToplistDefinitionRequestLogQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9998fe9e4d7df8d5e5ff133d2caa9d59511ede74ef3f6e3cb3d3e8161a12f4b6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putGroupBy", [value]))

    @jsii.member(jsii_name="putMultiCompute")
    def put_multi_compute(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetToplistDefinitionRequestLogQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1a86e0d5e33c1dc9d51dcc3c881771946b90da525db2a2045b1240fb98450c68)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putMultiCompute", [value]))

    @jsii.member(jsii_name="resetComputeQuery")
    def reset_compute_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetComputeQuery", []))

    @jsii.member(jsii_name="resetGroupBy")
    def reset_group_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGroupBy", []))

    @jsii.member(jsii_name="resetMultiCompute")
    def reset_multi_compute(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMultiCompute", []))

    @jsii.member(jsii_name="resetSearchQuery")
    def reset_search_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSearchQuery", []))

    @builtins.property
    @jsii.member(jsii_name="computeQuery")
    def compute_query(
        self,
    ) -> PowerpackWidgetToplistDefinitionRequestLogQueryComputeQueryOutputReference:
        return typing.cast(PowerpackWidgetToplistDefinitionRequestLogQueryComputeQueryOutputReference, jsii.get(self, "computeQuery"))

    @builtins.property
    @jsii.member(jsii_name="groupBy")
    def group_by(self) -> PowerpackWidgetToplistDefinitionRequestLogQueryGroupByList:
        return typing.cast(PowerpackWidgetToplistDefinitionRequestLogQueryGroupByList, jsii.get(self, "groupBy"))

    @builtins.property
    @jsii.member(jsii_name="multiCompute")
    def multi_compute(
        self,
    ) -> PowerpackWidgetToplistDefinitionRequestLogQueryMultiComputeList:
        return typing.cast(PowerpackWidgetToplistDefinitionRequestLogQueryMultiComputeList, jsii.get(self, "multiCompute"))

    @builtins.property
    @jsii.member(jsii_name="computeQueryInput")
    def compute_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetToplistDefinitionRequestLogQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetToplistDefinitionRequestLogQueryComputeQuery], jsii.get(self, "computeQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="groupByInput")
    def group_by_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionRequestLogQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionRequestLogQueryGroupBy]]], jsii.get(self, "groupByInput"))

    @builtins.property
    @jsii.member(jsii_name="indexInput")
    def index_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "indexInput"))

    @builtins.property
    @jsii.member(jsii_name="multiComputeInput")
    def multi_compute_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionRequestLogQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionRequestLogQueryMultiCompute]]], jsii.get(self, "multiComputeInput"))

    @builtins.property
    @jsii.member(jsii_name="searchQueryInput")
    def search_query_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "searchQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="index")
    def index(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "index"))

    @index.setter
    def index(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9d32829b217133712e25cd22c1bcb45c335a7ccb9c1ce748a89cebf7f1c6d66f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "index", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="searchQuery")
    def search_query(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "searchQuery"))

    @search_query.setter
    def search_query(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7789ead85a404399ccfe8d71a510383a3a34a657565e01b54a0d87d078d31992)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "searchQuery", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetToplistDefinitionRequestLogQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetToplistDefinitionRequestLogQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetToplistDefinitionRequestLogQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3b7b0c048eee21736ff9872dce51757dd2550c7f1b3c8346482670779d860196)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetToplistDefinitionRequestOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9675cedc2bc954c10a4a4dd34a467a03b23a46f7155b1a111a7f6cb5c686d2d4)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putApmQuery")
    def put_apm_query(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union[PowerpackWidgetToplistDefinitionRequestApmQueryComputeQuery, typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetToplistDefinitionRequestApmQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetToplistDefinitionRequestApmQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        value = PowerpackWidgetToplistDefinitionRequestApmQuery(
            index=index,
            compute_query=compute_query,
            group_by=group_by,
            multi_compute=multi_compute,
            search_query=search_query,
        )

        return typing.cast(None, jsii.invoke(self, "putApmQuery", [value]))

    @jsii.member(jsii_name="putAuditQuery")
    def put_audit_query(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union[PowerpackWidgetToplistDefinitionRequestAuditQueryComputeQuery, typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetToplistDefinitionRequestAuditQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetToplistDefinitionRequestAuditQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        value = PowerpackWidgetToplistDefinitionRequestAuditQuery(
            index=index,
            compute_query=compute_query,
            group_by=group_by,
            multi_compute=multi_compute,
            search_query=search_query,
        )

        return typing.cast(None, jsii.invoke(self, "putAuditQuery", [value]))

    @jsii.member(jsii_name="putConditionalFormats")
    def put_conditional_formats(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetToplistDefinitionRequestConditionalFormats, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a949b3db9f0bae035254e066fdba715836f472458ac2c9f2a0aa4cb97e0ffc80)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putConditionalFormats", [value]))

    @jsii.member(jsii_name="putFormula")
    def put_formula(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetToplistDefinitionRequestFormula, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5a03fe749bc446d510479f1139afd06e407b4cc75a6ae933f040d21476d5b753)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putFormula", [value]))

    @jsii.member(jsii_name="putLogQuery")
    def put_log_query(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union[PowerpackWidgetToplistDefinitionRequestLogQueryComputeQuery, typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetToplistDefinitionRequestLogQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetToplistDefinitionRequestLogQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        value = PowerpackWidgetToplistDefinitionRequestLogQuery(
            index=index,
            compute_query=compute_query,
            group_by=group_by,
            multi_compute=multi_compute,
            search_query=search_query,
        )

        return typing.cast(None, jsii.invoke(self, "putLogQuery", [value]))

    @jsii.member(jsii_name="putProcessQuery")
    def put_process_query(
        self,
        *,
        metric: builtins.str,
        filter_by: typing.Optional[typing.Sequence[builtins.str]] = None,
        limit: typing.Optional[jsii.Number] = None,
        search_by: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param metric: Your chosen metric. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        :param filter_by: A list of processes. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#filter_by Powerpack#filter_by}
        :param limit: The max number of items in the filter list. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param search_by: Your chosen search term. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_by Powerpack#search_by}
        '''
        value = PowerpackWidgetToplistDefinitionRequestProcessQuery(
            metric=metric, filter_by=filter_by, limit=limit, search_by=search_by
        )

        return typing.cast(None, jsii.invoke(self, "putProcessQuery", [value]))

    @jsii.member(jsii_name="putQuery")
    def put_query(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetToplistDefinitionRequestQuery", typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3b297f39fa813164420597841d80cfbc303c18618b0ed6858c0e434b2b628915)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putQuery", [value]))

    @jsii.member(jsii_name="putRumQuery")
    def put_rum_query(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union["PowerpackWidgetToplistDefinitionRequestRumQueryComputeQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetToplistDefinitionRequestRumQueryGroupBy", typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetToplistDefinitionRequestRumQueryMultiCompute", typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        value = PowerpackWidgetToplistDefinitionRequestRumQuery(
            index=index,
            compute_query=compute_query,
            group_by=group_by,
            multi_compute=multi_compute,
            search_query=search_query,
        )

        return typing.cast(None, jsii.invoke(self, "putRumQuery", [value]))

    @jsii.member(jsii_name="putSecurityQuery")
    def put_security_query(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union["PowerpackWidgetToplistDefinitionRequestSecurityQueryComputeQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetToplistDefinitionRequestSecurityQueryGroupBy", typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetToplistDefinitionRequestSecurityQueryMultiCompute", typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        value = PowerpackWidgetToplistDefinitionRequestSecurityQuery(
            index=index,
            compute_query=compute_query,
            group_by=group_by,
            multi_compute=multi_compute,
            search_query=search_query,
        )

        return typing.cast(None, jsii.invoke(self, "putSecurityQuery", [value]))

    @jsii.member(jsii_name="putStyle")
    def put_style(self, *, palette: typing.Optional[builtins.str] = None) -> None:
        '''
        :param palette: A color palette to apply to the widget. The available options are available at: https://docs.datadoghq.com/dashboards/widgets/timeseries/#appearance. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette Powerpack#palette}
        '''
        value = PowerpackWidgetToplistDefinitionRequestStyle(palette=palette)

        return typing.cast(None, jsii.invoke(self, "putStyle", [value]))

    @jsii.member(jsii_name="resetApmQuery")
    def reset_apm_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetApmQuery", []))

    @jsii.member(jsii_name="resetAuditQuery")
    def reset_audit_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAuditQuery", []))

    @jsii.member(jsii_name="resetConditionalFormats")
    def reset_conditional_formats(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetConditionalFormats", []))

    @jsii.member(jsii_name="resetFormula")
    def reset_formula(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFormula", []))

    @jsii.member(jsii_name="resetLogQuery")
    def reset_log_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLogQuery", []))

    @jsii.member(jsii_name="resetProcessQuery")
    def reset_process_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetProcessQuery", []))

    @jsii.member(jsii_name="resetQ")
    def reset_q(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetQ", []))

    @jsii.member(jsii_name="resetQuery")
    def reset_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetQuery", []))

    @jsii.member(jsii_name="resetRumQuery")
    def reset_rum_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetRumQuery", []))

    @jsii.member(jsii_name="resetSecurityQuery")
    def reset_security_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSecurityQuery", []))

    @jsii.member(jsii_name="resetStyle")
    def reset_style(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetStyle", []))

    @builtins.property
    @jsii.member(jsii_name="apmQuery")
    def apm_query(
        self,
    ) -> PowerpackWidgetToplistDefinitionRequestApmQueryOutputReference:
        return typing.cast(PowerpackWidgetToplistDefinitionRequestApmQueryOutputReference, jsii.get(self, "apmQuery"))

    @builtins.property
    @jsii.member(jsii_name="auditQuery")
    def audit_query(
        self,
    ) -> PowerpackWidgetToplistDefinitionRequestAuditQueryOutputReference:
        return typing.cast(PowerpackWidgetToplistDefinitionRequestAuditQueryOutputReference, jsii.get(self, "auditQuery"))

    @builtins.property
    @jsii.member(jsii_name="conditionalFormats")
    def conditional_formats(
        self,
    ) -> PowerpackWidgetToplistDefinitionRequestConditionalFormatsList:
        return typing.cast(PowerpackWidgetToplistDefinitionRequestConditionalFormatsList, jsii.get(self, "conditionalFormats"))

    @builtins.property
    @jsii.member(jsii_name="formula")
    def formula(self) -> PowerpackWidgetToplistDefinitionRequestFormulaList:
        return typing.cast(PowerpackWidgetToplistDefinitionRequestFormulaList, jsii.get(self, "formula"))

    @builtins.property
    @jsii.member(jsii_name="logQuery")
    def log_query(
        self,
    ) -> PowerpackWidgetToplistDefinitionRequestLogQueryOutputReference:
        return typing.cast(PowerpackWidgetToplistDefinitionRequestLogQueryOutputReference, jsii.get(self, "logQuery"))

    @builtins.property
    @jsii.member(jsii_name="processQuery")
    def process_query(
        self,
    ) -> "PowerpackWidgetToplistDefinitionRequestProcessQueryOutputReference":
        return typing.cast("PowerpackWidgetToplistDefinitionRequestProcessQueryOutputReference", jsii.get(self, "processQuery"))

    @builtins.property
    @jsii.member(jsii_name="query")
    def query(self) -> "PowerpackWidgetToplistDefinitionRequestQueryList":
        return typing.cast("PowerpackWidgetToplistDefinitionRequestQueryList", jsii.get(self, "query"))

    @builtins.property
    @jsii.member(jsii_name="rumQuery")
    def rum_query(
        self,
    ) -> "PowerpackWidgetToplistDefinitionRequestRumQueryOutputReference":
        return typing.cast("PowerpackWidgetToplistDefinitionRequestRumQueryOutputReference", jsii.get(self, "rumQuery"))

    @builtins.property
    @jsii.member(jsii_name="securityQuery")
    def security_query(
        self,
    ) -> "PowerpackWidgetToplistDefinitionRequestSecurityQueryOutputReference":
        return typing.cast("PowerpackWidgetToplistDefinitionRequestSecurityQueryOutputReference", jsii.get(self, "securityQuery"))

    @builtins.property
    @jsii.member(jsii_name="style")
    def style(self) -> "PowerpackWidgetToplistDefinitionRequestStyleOutputReference":
        return typing.cast("PowerpackWidgetToplistDefinitionRequestStyleOutputReference", jsii.get(self, "style"))

    @builtins.property
    @jsii.member(jsii_name="apmQueryInput")
    def apm_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetToplistDefinitionRequestApmQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetToplistDefinitionRequestApmQuery], jsii.get(self, "apmQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="auditQueryInput")
    def audit_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetToplistDefinitionRequestAuditQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetToplistDefinitionRequestAuditQuery], jsii.get(self, "auditQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="conditionalFormatsInput")
    def conditional_formats_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionRequestConditionalFormats]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionRequestConditionalFormats]]], jsii.get(self, "conditionalFormatsInput"))

    @builtins.property
    @jsii.member(jsii_name="formulaInput")
    def formula_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionRequestFormula]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionRequestFormula]]], jsii.get(self, "formulaInput"))

    @builtins.property
    @jsii.member(jsii_name="logQueryInput")
    def log_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetToplistDefinitionRequestLogQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetToplistDefinitionRequestLogQuery], jsii.get(self, "logQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="processQueryInput")
    def process_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetToplistDefinitionRequestProcessQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetToplistDefinitionRequestProcessQuery"], jsii.get(self, "processQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="qInput")
    def q_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "qInput"))

    @builtins.property
    @jsii.member(jsii_name="queryInput")
    def query_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetToplistDefinitionRequestQuery"]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetToplistDefinitionRequestQuery"]]], jsii.get(self, "queryInput"))

    @builtins.property
    @jsii.member(jsii_name="rumQueryInput")
    def rum_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetToplistDefinitionRequestRumQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetToplistDefinitionRequestRumQuery"], jsii.get(self, "rumQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="securityQueryInput")
    def security_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetToplistDefinitionRequestSecurityQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetToplistDefinitionRequestSecurityQuery"], jsii.get(self, "securityQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="styleInput")
    def style_input(
        self,
    ) -> typing.Optional["PowerpackWidgetToplistDefinitionRequestStyle"]:
        return typing.cast(typing.Optional["PowerpackWidgetToplistDefinitionRequestStyle"], jsii.get(self, "styleInput"))

    @builtins.property
    @jsii.member(jsii_name="q")
    def q(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "q"))

    @q.setter
    def q(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e484219091ea288eb9c6268f33d32792f0a19f1d51899edaf7d3153a1d5cc2f7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "q", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetToplistDefinitionRequest]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetToplistDefinitionRequest]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetToplistDefinitionRequest]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ab9d53d14ba2f49cda814627e0f0b6094993516f0b7e82ac603261d40a5e1ef6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestProcessQuery",
    jsii_struct_bases=[],
    name_mapping={
        "metric": "metric",
        "filter_by": "filterBy",
        "limit": "limit",
        "search_by": "searchBy",
    },
)
class PowerpackWidgetToplistDefinitionRequestProcessQuery:
    def __init__(
        self,
        *,
        metric: builtins.str,
        filter_by: typing.Optional[typing.Sequence[builtins.str]] = None,
        limit: typing.Optional[jsii.Number] = None,
        search_by: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param metric: Your chosen metric. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        :param filter_by: A list of processes. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#filter_by Powerpack#filter_by}
        :param limit: The max number of items in the filter list. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param search_by: Your chosen search term. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_by Powerpack#search_by}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__17a05563f9f477a751ffc1590d7d7376539a0d29469da209ed0fbe7a012aca00)
            check_type(argname="argument metric", value=metric, expected_type=type_hints["metric"])
            check_type(argname="argument filter_by", value=filter_by, expected_type=type_hints["filter_by"])
            check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
            check_type(argname="argument search_by", value=search_by, expected_type=type_hints["search_by"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "metric": metric,
        }
        if filter_by is not None:
            self._values["filter_by"] = filter_by
        if limit is not None:
            self._values["limit"] = limit
        if search_by is not None:
            self._values["search_by"] = search_by

    @builtins.property
    def metric(self) -> builtins.str:
        '''Your chosen metric.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        '''
        result = self._values.get("metric")
        assert result is not None, "Required property 'metric' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def filter_by(self) -> typing.Optional[typing.List[builtins.str]]:
        '''A list of processes.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#filter_by Powerpack#filter_by}
        '''
        result = self._values.get("filter_by")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def limit(self) -> typing.Optional[jsii.Number]:
        '''The max number of items in the filter list.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        '''
        result = self._values.get("limit")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def search_by(self) -> typing.Optional[builtins.str]:
        '''Your chosen search term.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_by Powerpack#search_by}
        '''
        result = self._values.get("search_by")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetToplistDefinitionRequestProcessQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetToplistDefinitionRequestProcessQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestProcessQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__58bfe64058fc53926e62cb9f43cda4d3d45562d023a484a040dc70453df9b0c7)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFilterBy")
    def reset_filter_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFilterBy", []))

    @jsii.member(jsii_name="resetLimit")
    def reset_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLimit", []))

    @jsii.member(jsii_name="resetSearchBy")
    def reset_search_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSearchBy", []))

    @builtins.property
    @jsii.member(jsii_name="filterByInput")
    def filter_by_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "filterByInput"))

    @builtins.property
    @jsii.member(jsii_name="limitInput")
    def limit_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "limitInput"))

    @builtins.property
    @jsii.member(jsii_name="metricInput")
    def metric_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "metricInput"))

    @builtins.property
    @jsii.member(jsii_name="searchByInput")
    def search_by_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "searchByInput"))

    @builtins.property
    @jsii.member(jsii_name="filterBy")
    def filter_by(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "filterBy"))

    @filter_by.setter
    def filter_by(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__34b9426dd012610a254e1954c093f2a01a6da5eb23b7d4c7c66b5cced7b85fb3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "filterBy", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="limit")
    def limit(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "limit"))

    @limit.setter
    def limit(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1bdec8265886e8c3d1e9797ac816f12c975585433d6e6ae7ca7e650c37c85981)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "limit", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="metric")
    def metric(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "metric"))

    @metric.setter
    def metric(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9888c899095736f89582021822236a1c32d1f73311d5912937b7d776a74d1794)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "metric", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="searchBy")
    def search_by(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "searchBy"))

    @search_by.setter
    def search_by(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5593562249fbc100b7f529d01cd8c96a80244a660d5dad161c89e5dcb40b2f0a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "searchBy", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetToplistDefinitionRequestProcessQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetToplistDefinitionRequestProcessQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetToplistDefinitionRequestProcessQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__46510097989e770134e00d4e72a9526474a59e3151ed204317e5bb93b402be43)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestQuery",
    jsii_struct_bases=[],
    name_mapping={
        "apm_dependency_stats_query": "apmDependencyStatsQuery",
        "apm_resource_stats_query": "apmResourceStatsQuery",
        "cloud_cost_query": "cloudCostQuery",
        "event_query": "eventQuery",
        "metric_query": "metricQuery",
        "process_query": "processQuery",
        "slo_query": "sloQuery",
    },
)
class PowerpackWidgetToplistDefinitionRequestQuery:
    def __init__(
        self,
        *,
        apm_dependency_stats_query: typing.Optional[typing.Union["PowerpackWidgetToplistDefinitionRequestQueryApmDependencyStatsQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        apm_resource_stats_query: typing.Optional[typing.Union["PowerpackWidgetToplistDefinitionRequestQueryApmResourceStatsQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        cloud_cost_query: typing.Optional[typing.Union["PowerpackWidgetToplistDefinitionRequestQueryCloudCostQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        event_query: typing.Optional[typing.Union["PowerpackWidgetToplistDefinitionRequestQueryEventQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        metric_query: typing.Optional[typing.Union["PowerpackWidgetToplistDefinitionRequestQueryMetricQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        process_query: typing.Optional[typing.Union["PowerpackWidgetToplistDefinitionRequestQueryProcessQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        slo_query: typing.Optional[typing.Union["PowerpackWidgetToplistDefinitionRequestQuerySloQuery", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param apm_dependency_stats_query: apm_dependency_stats_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#apm_dependency_stats_query Powerpack#apm_dependency_stats_query}
        :param apm_resource_stats_query: apm_resource_stats_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#apm_resource_stats_query Powerpack#apm_resource_stats_query}
        :param cloud_cost_query: cloud_cost_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cloud_cost_query Powerpack#cloud_cost_query}
        :param event_query: event_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#event_query Powerpack#event_query}
        :param metric_query: metric_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric_query Powerpack#metric_query}
        :param process_query: process_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#process_query Powerpack#process_query}
        :param slo_query: slo_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#slo_query Powerpack#slo_query}
        '''
        if isinstance(apm_dependency_stats_query, dict):
            apm_dependency_stats_query = PowerpackWidgetToplistDefinitionRequestQueryApmDependencyStatsQuery(**apm_dependency_stats_query)
        if isinstance(apm_resource_stats_query, dict):
            apm_resource_stats_query = PowerpackWidgetToplistDefinitionRequestQueryApmResourceStatsQuery(**apm_resource_stats_query)
        if isinstance(cloud_cost_query, dict):
            cloud_cost_query = PowerpackWidgetToplistDefinitionRequestQueryCloudCostQuery(**cloud_cost_query)
        if isinstance(event_query, dict):
            event_query = PowerpackWidgetToplistDefinitionRequestQueryEventQuery(**event_query)
        if isinstance(metric_query, dict):
            metric_query = PowerpackWidgetToplistDefinitionRequestQueryMetricQuery(**metric_query)
        if isinstance(process_query, dict):
            process_query = PowerpackWidgetToplistDefinitionRequestQueryProcessQuery(**process_query)
        if isinstance(slo_query, dict):
            slo_query = PowerpackWidgetToplistDefinitionRequestQuerySloQuery(**slo_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__320cbad83e992eeb6fa3499f55527f356405a0c6cd4bc7d59ce5a9c098b7ca82)
            check_type(argname="argument apm_dependency_stats_query", value=apm_dependency_stats_query, expected_type=type_hints["apm_dependency_stats_query"])
            check_type(argname="argument apm_resource_stats_query", value=apm_resource_stats_query, expected_type=type_hints["apm_resource_stats_query"])
            check_type(argname="argument cloud_cost_query", value=cloud_cost_query, expected_type=type_hints["cloud_cost_query"])
            check_type(argname="argument event_query", value=event_query, expected_type=type_hints["event_query"])
            check_type(argname="argument metric_query", value=metric_query, expected_type=type_hints["metric_query"])
            check_type(argname="argument process_query", value=process_query, expected_type=type_hints["process_query"])
            check_type(argname="argument slo_query", value=slo_query, expected_type=type_hints["slo_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if apm_dependency_stats_query is not None:
            self._values["apm_dependency_stats_query"] = apm_dependency_stats_query
        if apm_resource_stats_query is not None:
            self._values["apm_resource_stats_query"] = apm_resource_stats_query
        if cloud_cost_query is not None:
            self._values["cloud_cost_query"] = cloud_cost_query
        if event_query is not None:
            self._values["event_query"] = event_query
        if metric_query is not None:
            self._values["metric_query"] = metric_query
        if process_query is not None:
            self._values["process_query"] = process_query
        if slo_query is not None:
            self._values["slo_query"] = slo_query

    @builtins.property
    def apm_dependency_stats_query(
        self,
    ) -> typing.Optional["PowerpackWidgetToplistDefinitionRequestQueryApmDependencyStatsQuery"]:
        '''apm_dependency_stats_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#apm_dependency_stats_query Powerpack#apm_dependency_stats_query}
        '''
        result = self._values.get("apm_dependency_stats_query")
        return typing.cast(typing.Optional["PowerpackWidgetToplistDefinitionRequestQueryApmDependencyStatsQuery"], result)

    @builtins.property
    def apm_resource_stats_query(
        self,
    ) -> typing.Optional["PowerpackWidgetToplistDefinitionRequestQueryApmResourceStatsQuery"]:
        '''apm_resource_stats_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#apm_resource_stats_query Powerpack#apm_resource_stats_query}
        '''
        result = self._values.get("apm_resource_stats_query")
        return typing.cast(typing.Optional["PowerpackWidgetToplistDefinitionRequestQueryApmResourceStatsQuery"], result)

    @builtins.property
    def cloud_cost_query(
        self,
    ) -> typing.Optional["PowerpackWidgetToplistDefinitionRequestQueryCloudCostQuery"]:
        '''cloud_cost_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cloud_cost_query Powerpack#cloud_cost_query}
        '''
        result = self._values.get("cloud_cost_query")
        return typing.cast(typing.Optional["PowerpackWidgetToplistDefinitionRequestQueryCloudCostQuery"], result)

    @builtins.property
    def event_query(
        self,
    ) -> typing.Optional["PowerpackWidgetToplistDefinitionRequestQueryEventQuery"]:
        '''event_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#event_query Powerpack#event_query}
        '''
        result = self._values.get("event_query")
        return typing.cast(typing.Optional["PowerpackWidgetToplistDefinitionRequestQueryEventQuery"], result)

    @builtins.property
    def metric_query(
        self,
    ) -> typing.Optional["PowerpackWidgetToplistDefinitionRequestQueryMetricQuery"]:
        '''metric_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric_query Powerpack#metric_query}
        '''
        result = self._values.get("metric_query")
        return typing.cast(typing.Optional["PowerpackWidgetToplistDefinitionRequestQueryMetricQuery"], result)

    @builtins.property
    def process_query(
        self,
    ) -> typing.Optional["PowerpackWidgetToplistDefinitionRequestQueryProcessQuery"]:
        '''process_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#process_query Powerpack#process_query}
        '''
        result = self._values.get("process_query")
        return typing.cast(typing.Optional["PowerpackWidgetToplistDefinitionRequestQueryProcessQuery"], result)

    @builtins.property
    def slo_query(
        self,
    ) -> typing.Optional["PowerpackWidgetToplistDefinitionRequestQuerySloQuery"]:
        '''slo_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#slo_query Powerpack#slo_query}
        '''
        result = self._values.get("slo_query")
        return typing.cast(typing.Optional["PowerpackWidgetToplistDefinitionRequestQuerySloQuery"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetToplistDefinitionRequestQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestQueryApmDependencyStatsQuery",
    jsii_struct_bases=[],
    name_mapping={
        "data_source": "dataSource",
        "env": "env",
        "name": "name",
        "operation_name": "operationName",
        "resource_name": "resourceName",
        "service": "service",
        "stat": "stat",
        "cross_org_uuids": "crossOrgUuids",
        "is_upstream": "isUpstream",
        "primary_tag_name": "primaryTagName",
        "primary_tag_value": "primaryTagValue",
    },
)
class PowerpackWidgetToplistDefinitionRequestQueryApmDependencyStatsQuery:
    def __init__(
        self,
        *,
        data_source: builtins.str,
        env: builtins.str,
        name: builtins.str,
        operation_name: builtins.str,
        resource_name: builtins.str,
        service: builtins.str,
        stat: builtins.str,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        is_upstream: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        primary_tag_name: typing.Optional[builtins.str] = None,
        primary_tag_value: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param data_source: The data source for APM Dependency Stats queries. Valid values are ``apm_dependency_stats``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param env: APM environment. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#env Powerpack#env}
        :param name: The name of query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param operation_name: Name of operation on service. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#operation_name Powerpack#operation_name}
        :param resource_name: APM resource. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#resource_name Powerpack#resource_name}
        :param service: APM service. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#service Powerpack#service}
        :param stat: APM statistic. Valid values are ``avg_duration``, ``avg_root_duration``, ``avg_spans_per_trace``, ``error_rate``, ``pct_exec_time``, ``pct_of_traces``, ``total_traces_count``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#stat Powerpack#stat}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param is_upstream: Determines whether stats for upstream or downstream dependencies should be queried. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#is_upstream Powerpack#is_upstream}
        :param primary_tag_name: The name of the second primary tag used within APM; required when ``primary_tag_value`` is specified. See https://docs.datadoghq.com/tracing/guide/setting_primary_tags_to_scope/#add-a-second-primary-tag-in-datadog. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_name Powerpack#primary_tag_name}
        :param primary_tag_value: Filter APM data by the second primary tag. ``primary_tag_name`` must also be specified. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_value Powerpack#primary_tag_value}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__414ebe1176aa3aeb3682c63081ef4b0a01d6767600483e2c4780099511249aca)
            check_type(argname="argument data_source", value=data_source, expected_type=type_hints["data_source"])
            check_type(argname="argument env", value=env, expected_type=type_hints["env"])
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument operation_name", value=operation_name, expected_type=type_hints["operation_name"])
            check_type(argname="argument resource_name", value=resource_name, expected_type=type_hints["resource_name"])
            check_type(argname="argument service", value=service, expected_type=type_hints["service"])
            check_type(argname="argument stat", value=stat, expected_type=type_hints["stat"])
            check_type(argname="argument cross_org_uuids", value=cross_org_uuids, expected_type=type_hints["cross_org_uuids"])
            check_type(argname="argument is_upstream", value=is_upstream, expected_type=type_hints["is_upstream"])
            check_type(argname="argument primary_tag_name", value=primary_tag_name, expected_type=type_hints["primary_tag_name"])
            check_type(argname="argument primary_tag_value", value=primary_tag_value, expected_type=type_hints["primary_tag_value"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "data_source": data_source,
            "env": env,
            "name": name,
            "operation_name": operation_name,
            "resource_name": resource_name,
            "service": service,
            "stat": stat,
        }
        if cross_org_uuids is not None:
            self._values["cross_org_uuids"] = cross_org_uuids
        if is_upstream is not None:
            self._values["is_upstream"] = is_upstream
        if primary_tag_name is not None:
            self._values["primary_tag_name"] = primary_tag_name
        if primary_tag_value is not None:
            self._values["primary_tag_value"] = primary_tag_value

    @builtins.property
    def data_source(self) -> builtins.str:
        '''The data source for APM Dependency Stats queries. Valid values are ``apm_dependency_stats``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        '''
        result = self._values.get("data_source")
        assert result is not None, "Required property 'data_source' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def env(self) -> builtins.str:
        '''APM environment.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#env Powerpack#env}
        '''
        result = self._values.get("env")
        assert result is not None, "Required property 'env' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def name(self) -> builtins.str:
        '''The name of query for use in formulas.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        '''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def operation_name(self) -> builtins.str:
        '''Name of operation on service.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#operation_name Powerpack#operation_name}
        '''
        result = self._values.get("operation_name")
        assert result is not None, "Required property 'operation_name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def resource_name(self) -> builtins.str:
        '''APM resource.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#resource_name Powerpack#resource_name}
        '''
        result = self._values.get("resource_name")
        assert result is not None, "Required property 'resource_name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def service(self) -> builtins.str:
        '''APM service.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#service Powerpack#service}
        '''
        result = self._values.get("service")
        assert result is not None, "Required property 'service' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def stat(self) -> builtins.str:
        '''APM statistic. Valid values are ``avg_duration``, ``avg_root_duration``, ``avg_spans_per_trace``, ``error_rate``, ``pct_exec_time``, ``pct_of_traces``, ``total_traces_count``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#stat Powerpack#stat}
        '''
        result = self._values.get("stat")
        assert result is not None, "Required property 'stat' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def cross_org_uuids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''The source organization UUID for cross organization queries. Feature in Private Beta.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        '''
        result = self._values.get("cross_org_uuids")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def is_upstream(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        '''Determines whether stats for upstream or downstream dependencies should be queried.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#is_upstream Powerpack#is_upstream}
        '''
        result = self._values.get("is_upstream")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)

    @builtins.property
    def primary_tag_name(self) -> typing.Optional[builtins.str]:
        '''The name of the second primary tag used within APM; required when ``primary_tag_value`` is specified. See https://docs.datadoghq.com/tracing/guide/setting_primary_tags_to_scope/#add-a-second-primary-tag-in-datadog.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_name Powerpack#primary_tag_name}
        '''
        result = self._values.get("primary_tag_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def primary_tag_value(self) -> typing.Optional[builtins.str]:
        '''Filter APM data by the second primary tag. ``primary_tag_name`` must also be specified.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_value Powerpack#primary_tag_value}
        '''
        result = self._values.get("primary_tag_value")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetToplistDefinitionRequestQueryApmDependencyStatsQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetToplistDefinitionRequestQueryApmDependencyStatsQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestQueryApmDependencyStatsQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8f7dee4edae558cab294af63497e46a5b20dc2ff0493864ba376beda2a126065)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetCrossOrgUuids")
    def reset_cross_org_uuids(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCrossOrgUuids", []))

    @jsii.member(jsii_name="resetIsUpstream")
    def reset_is_upstream(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetIsUpstream", []))

    @jsii.member(jsii_name="resetPrimaryTagName")
    def reset_primary_tag_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPrimaryTagName", []))

    @jsii.member(jsii_name="resetPrimaryTagValue")
    def reset_primary_tag_value(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPrimaryTagValue", []))

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuidsInput")
    def cross_org_uuids_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "crossOrgUuidsInput"))

    @builtins.property
    @jsii.member(jsii_name="dataSourceInput")
    def data_source_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "dataSourceInput"))

    @builtins.property
    @jsii.member(jsii_name="envInput")
    def env_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "envInput"))

    @builtins.property
    @jsii.member(jsii_name="isUpstreamInput")
    def is_upstream_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "isUpstreamInput"))

    @builtins.property
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property
    @jsii.member(jsii_name="operationNameInput")
    def operation_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "operationNameInput"))

    @builtins.property
    @jsii.member(jsii_name="primaryTagNameInput")
    def primary_tag_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "primaryTagNameInput"))

    @builtins.property
    @jsii.member(jsii_name="primaryTagValueInput")
    def primary_tag_value_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "primaryTagValueInput"))

    @builtins.property
    @jsii.member(jsii_name="resourceNameInput")
    def resource_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "resourceNameInput"))

    @builtins.property
    @jsii.member(jsii_name="serviceInput")
    def service_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "serviceInput"))

    @builtins.property
    @jsii.member(jsii_name="statInput")
    def stat_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "statInput"))

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuids")
    def cross_org_uuids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "crossOrgUuids"))

    @cross_org_uuids.setter
    def cross_org_uuids(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d7c974d4b86125736653a922381bdb557a41af3779321b2b28506c45326d290f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "crossOrgUuids", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="dataSource")
    def data_source(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "dataSource"))

    @data_source.setter
    def data_source(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__433bea0de90ee0bbd214646f7e91b651e60df7f39ae9f8ace599806c8cc2294f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "dataSource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="env")
    def env(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "env"))

    @env.setter
    def env(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a77dbb1f71b36e3fd549d5ba29a068172a7ab513e3ed3fdd3f9b76896975714c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "env", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="isUpstream")
    def is_upstream(self) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "isUpstream"))

    @is_upstream.setter
    def is_upstream(
        self,
        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f020db6de3ffe3d16398046e0eb2d5986c8a0f96508c942259a0091bcf54c9ac)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "isUpstream", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__93e3894da697c5310d748f44d01f7a6bcf5aea0e49abe85c1541c6ce1282c306)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "name", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="operationName")
    def operation_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "operationName"))

    @operation_name.setter
    def operation_name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dc622c95cf139181a532d37c58c82d093402a981342bcedb4c877d7789bc5ae8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "operationName", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="primaryTagName")
    def primary_tag_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "primaryTagName"))

    @primary_tag_name.setter
    def primary_tag_name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a5119a8479ae66f5584f5dae62f284d6faedb377d9a9df2d01584126f1087a7c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "primaryTagName", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="primaryTagValue")
    def primary_tag_value(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "primaryTagValue"))

    @primary_tag_value.setter
    def primary_tag_value(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__547751bfa605c29a22bc04cb9aacd649d0941c2eef683f52d0b9c2f2b91c6506)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "primaryTagValue", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="resourceName")
    def resource_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "resourceName"))

    @resource_name.setter
    def resource_name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__38d0f450462005799c74af9ab70f133dec6edcd8bb13a9c1cce0b6fbcbf75f75)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "resourceName", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="service")
    def service(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "service"))

    @service.setter
    def service(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cc86ddeccddfea6d7bb10d3ff7260589f5b652c76762cdf92fcefbe7f1d00886)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "service", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="stat")
    def stat(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "stat"))

    @stat.setter
    def stat(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5795ed0bf3083bbd61cc8ed88b6db295f611d6bf1662fe6b0366c7395aa60cd5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "stat", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetToplistDefinitionRequestQueryApmDependencyStatsQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetToplistDefinitionRequestQueryApmDependencyStatsQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetToplistDefinitionRequestQueryApmDependencyStatsQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4556ed166a1742af4eed02b3ebefb79c89b19953c55681100f8c2388c8689af4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestQueryApmResourceStatsQuery",
    jsii_struct_bases=[],
    name_mapping={
        "data_source": "dataSource",
        "env": "env",
        "name": "name",
        "service": "service",
        "stat": "stat",
        "cross_org_uuids": "crossOrgUuids",
        "group_by": "groupBy",
        "operation_name": "operationName",
        "primary_tag_name": "primaryTagName",
        "primary_tag_value": "primaryTagValue",
        "resource_name": "resourceName",
    },
)
class PowerpackWidgetToplistDefinitionRequestQueryApmResourceStatsQuery:
    def __init__(
        self,
        *,
        data_source: builtins.str,
        env: builtins.str,
        name: builtins.str,
        service: builtins.str,
        stat: builtins.str,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        group_by: typing.Optional[typing.Sequence[builtins.str]] = None,
        operation_name: typing.Optional[builtins.str] = None,
        primary_tag_name: typing.Optional[builtins.str] = None,
        primary_tag_value: typing.Optional[builtins.str] = None,
        resource_name: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param data_source: The data source for APM Resource Stats queries. Valid values are ``apm_resource_stats``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param env: APM environment. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#env Powerpack#env}
        :param name: The name of query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param service: APM service. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#service Powerpack#service}
        :param stat: APM statistic. Valid values are ``errors``, ``error_rate``, ``hits``, ``latency_avg``, ``latency_distribution``, ``latency_max``, ``latency_p50``, ``latency_p75``, ``latency_p90``, ``latency_p95``, ``latency_p99``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#stat Powerpack#stat}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param group_by: Array of fields to group results by. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param operation_name: Name of operation on service. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#operation_name Powerpack#operation_name}
        :param primary_tag_name: The name of the second primary tag used within APM; required when ``primary_tag_value`` is specified. See https://docs.datadoghq.com/tracing/guide/setting_primary_tags_to_scope/#add-a-second-primary-tag-in-datadog. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_name Powerpack#primary_tag_name}
        :param primary_tag_value: Filter APM data by the second primary tag. ``primary_tag_name`` must also be specified. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_value Powerpack#primary_tag_value}
        :param resource_name: APM resource. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#resource_name Powerpack#resource_name}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f90623029866ad94029541722ffb08ba387b23f5890d1103d31467275893b863)
            check_type(argname="argument data_source", value=data_source, expected_type=type_hints["data_source"])
            check_type(argname="argument env", value=env, expected_type=type_hints["env"])
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument service", value=service, expected_type=type_hints["service"])
            check_type(argname="argument stat", value=stat, expected_type=type_hints["stat"])
            check_type(argname="argument cross_org_uuids", value=cross_org_uuids, expected_type=type_hints["cross_org_uuids"])
            check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
            check_type(argname="argument operation_name", value=operation_name, expected_type=type_hints["operation_name"])
            check_type(argname="argument primary_tag_name", value=primary_tag_name, expected_type=type_hints["primary_tag_name"])
            check_type(argname="argument primary_tag_value", value=primary_tag_value, expected_type=type_hints["primary_tag_value"])
            check_type(argname="argument resource_name", value=resource_name, expected_type=type_hints["resource_name"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "data_source": data_source,
            "env": env,
            "name": name,
            "service": service,
            "stat": stat,
        }
        if cross_org_uuids is not None:
            self._values["cross_org_uuids"] = cross_org_uuids
        if group_by is not None:
            self._values["group_by"] = group_by
        if operation_name is not None:
            self._values["operation_name"] = operation_name
        if primary_tag_name is not None:
            self._values["primary_tag_name"] = primary_tag_name
        if primary_tag_value is not None:
            self._values["primary_tag_value"] = primary_tag_value
        if resource_name is not None:
            self._values["resource_name"] = resource_name

    @builtins.property
    def data_source(self) -> builtins.str:
        '''The data source for APM Resource Stats queries. Valid values are ``apm_resource_stats``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        '''
        result = self._values.get("data_source")
        assert result is not None, "Required property 'data_source' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def env(self) -> builtins.str:
        '''APM environment.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#env Powerpack#env}
        '''
        result = self._values.get("env")
        assert result is not None, "Required property 'env' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def name(self) -> builtins.str:
        '''The name of query for use in formulas.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        '''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def service(self) -> builtins.str:
        '''APM service.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#service Powerpack#service}
        '''
        result = self._values.get("service")
        assert result is not None, "Required property 'service' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def stat(self) -> builtins.str:
        '''APM statistic. Valid values are ``errors``, ``error_rate``, ``hits``, ``latency_avg``, ``latency_distribution``, ``latency_max``, ``latency_p50``, ``latency_p75``, ``latency_p90``, ``latency_p95``, ``latency_p99``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#stat Powerpack#stat}
        '''
        result = self._values.get("stat")
        assert result is not None, "Required property 'stat' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def cross_org_uuids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''The source organization UUID for cross organization queries. Feature in Private Beta.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        '''
        result = self._values.get("cross_org_uuids")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def group_by(self) -> typing.Optional[typing.List[builtins.str]]:
        '''Array of fields to group results by.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        '''
        result = self._values.get("group_by")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def operation_name(self) -> typing.Optional[builtins.str]:
        '''Name of operation on service.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#operation_name Powerpack#operation_name}
        '''
        result = self._values.get("operation_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def primary_tag_name(self) -> typing.Optional[builtins.str]:
        '''The name of the second primary tag used within APM; required when ``primary_tag_value`` is specified. See https://docs.datadoghq.com/tracing/guide/setting_primary_tags_to_scope/#add-a-second-primary-tag-in-datadog.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_name Powerpack#primary_tag_name}
        '''
        result = self._values.get("primary_tag_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def primary_tag_value(self) -> typing.Optional[builtins.str]:
        '''Filter APM data by the second primary tag. ``primary_tag_name`` must also be specified.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_value Powerpack#primary_tag_value}
        '''
        result = self._values.get("primary_tag_value")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def resource_name(self) -> typing.Optional[builtins.str]:
        '''APM resource.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#resource_name Powerpack#resource_name}
        '''
        result = self._values.get("resource_name")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetToplistDefinitionRequestQueryApmResourceStatsQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetToplistDefinitionRequestQueryApmResourceStatsQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestQueryApmResourceStatsQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__db532bced3dfa0b89ba8ac562640d2e9ce719f865839e8f888db1709f887e631)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetCrossOrgUuids")
    def reset_cross_org_uuids(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCrossOrgUuids", []))

    @jsii.member(jsii_name="resetGroupBy")
    def reset_group_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGroupBy", []))

    @jsii.member(jsii_name="resetOperationName")
    def reset_operation_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetOperationName", []))

    @jsii.member(jsii_name="resetPrimaryTagName")
    def reset_primary_tag_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPrimaryTagName", []))

    @jsii.member(jsii_name="resetPrimaryTagValue")
    def reset_primary_tag_value(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPrimaryTagValue", []))

    @jsii.member(jsii_name="resetResourceName")
    def reset_resource_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetResourceName", []))

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuidsInput")
    def cross_org_uuids_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "crossOrgUuidsInput"))

    @builtins.property
    @jsii.member(jsii_name="dataSourceInput")
    def data_source_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "dataSourceInput"))

    @builtins.property
    @jsii.member(jsii_name="envInput")
    def env_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "envInput"))

    @builtins.property
    @jsii.member(jsii_name="groupByInput")
    def group_by_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "groupByInput"))

    @builtins.property
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property
    @jsii.member(jsii_name="operationNameInput")
    def operation_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "operationNameInput"))

    @builtins.property
    @jsii.member(jsii_name="primaryTagNameInput")
    def primary_tag_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "primaryTagNameInput"))

    @builtins.property
    @jsii.member(jsii_name="primaryTagValueInput")
    def primary_tag_value_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "primaryTagValueInput"))

    @builtins.property
    @jsii.member(jsii_name="resourceNameInput")
    def resource_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "resourceNameInput"))

    @builtins.property
    @jsii.member(jsii_name="serviceInput")
    def service_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "serviceInput"))

    @builtins.property
    @jsii.member(jsii_name="statInput")
    def stat_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "statInput"))

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuids")
    def cross_org_uuids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "crossOrgUuids"))

    @cross_org_uuids.setter
    def cross_org_uuids(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9a1a9e222ff38209e164f10e7d5fa75f46de5ea8c5058d444808ccaaeccb394d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "crossOrgUuids", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="dataSource")
    def data_source(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "dataSource"))

    @data_source.setter
    def data_source(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6718f2851843b25841d87ed2984f891cf9c83826b1e15dc541b77d51c3da1f85)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "dataSource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="env")
    def env(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "env"))

    @env.setter
    def env(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ae60377f883dd3ffffe2ccefcd6fdb4b25ce651e980c3ed71f44fb5fcc990ccf)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "env", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="groupBy")
    def group_by(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "groupBy"))

    @group_by.setter
    def group_by(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0f8d2c4e20a17ba17413b3ae66ae0b18ba4bf4e3efa0883cd181d4cd5ad7a63a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "groupBy", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1887c13b5ac11811a2ba8bfe8dcdfc160364672b83a03b418724f2c17b2f2fda)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "name", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="operationName")
    def operation_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "operationName"))

    @operation_name.setter
    def operation_name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d040434a07885d3b53388420d2b56cbdfd32bca981a09ceba2f8a5de0d50967f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "operationName", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="primaryTagName")
    def primary_tag_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "primaryTagName"))

    @primary_tag_name.setter
    def primary_tag_name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__db0016d63063323ea3397939a3521c859d1fb2c72dd69a4ddd149737c48b3547)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "primaryTagName", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="primaryTagValue")
    def primary_tag_value(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "primaryTagValue"))

    @primary_tag_value.setter
    def primary_tag_value(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__365b8d08d2242ec5aca004befb4e6303819002113b429fce1a1a15c3cbb48634)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "primaryTagValue", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="resourceName")
    def resource_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "resourceName"))

    @resource_name.setter
    def resource_name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__22bee4af9dc01ccc25de96f5a04744cee75128f11e145668adad3c632863a4ee)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "resourceName", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="service")
    def service(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "service"))

    @service.setter
    def service(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__61e833eb2736afd88dfd44672de32d8d4e7d65dffb70abf6c29114298ac60dde)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "service", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="stat")
    def stat(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "stat"))

    @stat.setter
    def stat(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b6099d2d87fb419486ce647474eaa78de2d894b263097e97f737ac14bb396c89)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "stat", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetToplistDefinitionRequestQueryApmResourceStatsQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetToplistDefinitionRequestQueryApmResourceStatsQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetToplistDefinitionRequestQueryApmResourceStatsQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b2488bf6941b53cc551c4911b1a49e626a43f65cc79c76106ac7427973fd843e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestQueryCloudCostQuery",
    jsii_struct_bases=[],
    name_mapping={
        "data_source": "dataSource",
        "name": "name",
        "query": "query",
        "aggregator": "aggregator",
        "cross_org_uuids": "crossOrgUuids",
    },
)
class PowerpackWidgetToplistDefinitionRequestQueryCloudCostQuery:
    def __init__(
        self,
        *,
        data_source: builtins.str,
        name: builtins.str,
        query: builtins.str,
        aggregator: typing.Optional[builtins.str] = None,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
    ) -> None:
        '''
        :param data_source: The data source for cloud cost queries. Valid values are ``cloud_cost``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param name: The name of the query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param query: The cloud cost query definition. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        :param aggregator: The aggregation methods available for cloud cost queries. Valid values are ``avg``, ``last``, ``max``, ``min``, ``sum``, ``percentile``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregator Powerpack#aggregator}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7319ed1da4d2f3378934e56734a0b46f4bbf9b1f0d4d99e5689a0990d2ed193d)
            check_type(argname="argument data_source", value=data_source, expected_type=type_hints["data_source"])
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument query", value=query, expected_type=type_hints["query"])
            check_type(argname="argument aggregator", value=aggregator, expected_type=type_hints["aggregator"])
            check_type(argname="argument cross_org_uuids", value=cross_org_uuids, expected_type=type_hints["cross_org_uuids"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "data_source": data_source,
            "name": name,
            "query": query,
        }
        if aggregator is not None:
            self._values["aggregator"] = aggregator
        if cross_org_uuids is not None:
            self._values["cross_org_uuids"] = cross_org_uuids

    @builtins.property
    def data_source(self) -> builtins.str:
        '''The data source for cloud cost queries. Valid values are ``cloud_cost``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        '''
        result = self._values.get("data_source")
        assert result is not None, "Required property 'data_source' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def name(self) -> builtins.str:
        '''The name of the query for use in formulas.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        '''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def query(self) -> builtins.str:
        '''The cloud cost query definition.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        '''
        result = self._values.get("query")
        assert result is not None, "Required property 'query' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def aggregator(self) -> typing.Optional[builtins.str]:
        '''The aggregation methods available for cloud cost queries. Valid values are ``avg``, ``last``, ``max``, ``min``, ``sum``, ``percentile``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregator Powerpack#aggregator}
        '''
        result = self._values.get("aggregator")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def cross_org_uuids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''The source organization UUID for cross organization queries. Feature in Private Beta.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        '''
        result = self._values.get("cross_org_uuids")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetToplistDefinitionRequestQueryCloudCostQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetToplistDefinitionRequestQueryCloudCostQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestQueryCloudCostQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5fcb92fd717b4dfbecd3ee018ffb1f5ec63c7e67e937888df06b1b8c01a43c03)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetAggregator")
    def reset_aggregator(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAggregator", []))

    @jsii.member(jsii_name="resetCrossOrgUuids")
    def reset_cross_org_uuids(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCrossOrgUuids", []))

    @builtins.property
    @jsii.member(jsii_name="aggregatorInput")
    def aggregator_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregatorInput"))

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuidsInput")
    def cross_org_uuids_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "crossOrgUuidsInput"))

    @builtins.property
    @jsii.member(jsii_name="dataSourceInput")
    def data_source_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "dataSourceInput"))

    @builtins.property
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property
    @jsii.member(jsii_name="queryInput")
    def query_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "queryInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregator")
    def aggregator(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregator"))

    @aggregator.setter
    def aggregator(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__481adbb365332ab9df8e80da0a6779c6c2ad1a5767965fad2b9183882fa8954b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregator", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuids")
    def cross_org_uuids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "crossOrgUuids"))

    @cross_org_uuids.setter
    def cross_org_uuids(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fa990b3a21bbad540ed2c0df66015ceebc8024ef313638992e42d2cab3c47674)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "crossOrgUuids", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="dataSource")
    def data_source(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "dataSource"))

    @data_source.setter
    def data_source(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__679994cfb74fc451db36cb11b8d5228a97b323b7147483922d36bd3e6c3fc1b2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "dataSource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3328a48f37572026b0e1f638bfb8a9778c021eedb3be4ea6958e87740bddf560)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "name", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="query")
    def query(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "query"))

    @query.setter
    def query(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b31470392642d20096d15edc620fdedfa4be5325f3581787045256e7dbdd8777)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "query", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetToplistDefinitionRequestQueryCloudCostQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetToplistDefinitionRequestQueryCloudCostQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetToplistDefinitionRequestQueryCloudCostQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a73b99fc3dc982d4a19a071148d7ecac53adedc545f785566e8114c29a4c44f8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestQueryEventQuery",
    jsii_struct_bases=[],
    name_mapping={
        "compute": "compute",
        "data_source": "dataSource",
        "name": "name",
        "cross_org_uuids": "crossOrgUuids",
        "group_by": "groupBy",
        "indexes": "indexes",
        "search": "search",
        "storage": "storage",
    },
)
class PowerpackWidgetToplistDefinitionRequestQueryEventQuery:
    def __init__(
        self,
        *,
        compute: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetToplistDefinitionRequestQueryEventQueryCompute", typing.Dict[builtins.str, typing.Any]]]],
        data_source: builtins.str,
        name: builtins.str,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetToplistDefinitionRequestQueryEventQueryGroupBy", typing.Dict[builtins.str, typing.Any]]]]] = None,
        indexes: typing.Optional[typing.Sequence[builtins.str]] = None,
        search: typing.Optional[typing.Union["PowerpackWidgetToplistDefinitionRequestQueryEventQuerySearch", typing.Dict[builtins.str, typing.Any]]] = None,
        storage: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param compute: compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute Powerpack#compute}
        :param data_source: The data source for event platform-based queries. Valid values are ``logs``, ``spans``, ``network``, ``rum``, ``security_signals``, ``profiles``, ``audit``, ``events``, ``ci_tests``, ``ci_pipelines``, ``incident_analytics``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param name: The name of query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param indexes: An array of index names to query in the stream. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#indexes Powerpack#indexes}
        :param search: search block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search Powerpack#search}
        :param storage: Storage location (private beta). Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#storage Powerpack#storage}
        '''
        if isinstance(search, dict):
            search = PowerpackWidgetToplistDefinitionRequestQueryEventQuerySearch(**search)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a9d0e76f22894780aa8404228202958e8b9f5659950c2bb8af1e967a5b7f2db6)
            check_type(argname="argument compute", value=compute, expected_type=type_hints["compute"])
            check_type(argname="argument data_source", value=data_source, expected_type=type_hints["data_source"])
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument cross_org_uuids", value=cross_org_uuids, expected_type=type_hints["cross_org_uuids"])
            check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
            check_type(argname="argument indexes", value=indexes, expected_type=type_hints["indexes"])
            check_type(argname="argument search", value=search, expected_type=type_hints["search"])
            check_type(argname="argument storage", value=storage, expected_type=type_hints["storage"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "compute": compute,
            "data_source": data_source,
            "name": name,
        }
        if cross_org_uuids is not None:
            self._values["cross_org_uuids"] = cross_org_uuids
        if group_by is not None:
            self._values["group_by"] = group_by
        if indexes is not None:
            self._values["indexes"] = indexes
        if search is not None:
            self._values["search"] = search
        if storage is not None:
            self._values["storage"] = storage

    @builtins.property
    def compute(
        self,
    ) -> typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetToplistDefinitionRequestQueryEventQueryCompute"]]:
        '''compute block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute Powerpack#compute}
        '''
        result = self._values.get("compute")
        assert result is not None, "Required property 'compute' is missing"
        return typing.cast(typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetToplistDefinitionRequestQueryEventQueryCompute"]], result)

    @builtins.property
    def data_source(self) -> builtins.str:
        '''The data source for event platform-based queries.

        Valid values are ``logs``, ``spans``, ``network``, ``rum``, ``security_signals``, ``profiles``, ``audit``, ``events``, ``ci_tests``, ``ci_pipelines``, ``incident_analytics``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        '''
        result = self._values.get("data_source")
        assert result is not None, "Required property 'data_source' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def name(self) -> builtins.str:
        '''The name of query for use in formulas.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        '''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def cross_org_uuids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''The source organization UUID for cross organization queries. Feature in Private Beta.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        '''
        result = self._values.get("cross_org_uuids")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def group_by(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetToplistDefinitionRequestQueryEventQueryGroupBy"]]]:
        '''group_by block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        '''
        result = self._values.get("group_by")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetToplistDefinitionRequestQueryEventQueryGroupBy"]]], result)

    @builtins.property
    def indexes(self) -> typing.Optional[typing.List[builtins.str]]:
        '''An array of index names to query in the stream.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#indexes Powerpack#indexes}
        '''
        result = self._values.get("indexes")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def search(
        self,
    ) -> typing.Optional["PowerpackWidgetToplistDefinitionRequestQueryEventQuerySearch"]:
        '''search block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search Powerpack#search}
        '''
        result = self._values.get("search")
        return typing.cast(typing.Optional["PowerpackWidgetToplistDefinitionRequestQueryEventQuerySearch"], result)

    @builtins.property
    def storage(self) -> typing.Optional[builtins.str]:
        '''Storage location (private beta).

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#storage Powerpack#storage}
        '''
        result = self._values.get("storage")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetToplistDefinitionRequestQueryEventQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestQueryEventQueryCompute",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "interval": "interval",
        "metric": "metric",
    },
)
class PowerpackWidgetToplistDefinitionRequestQueryEventQueryCompute:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        interval: typing.Optional[jsii.Number] = None,
        metric: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation methods for event platform queries. Valid values are ``count``, ``cardinality``, ``median``, ``pc75``, ``pc90``, ``pc95``, ``pc98``, ``pc99``, ``sum``, ``min``, ``max``, ``avg``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param interval: A time interval in milliseconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        :param metric: The measurable attribute to compute. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5dbb39e91fff862274b4e163c04767925716833d6f92a929b4c7844dd9c9b139)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
            check_type(argname="argument metric", value=metric, expected_type=type_hints["metric"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if interval is not None:
            self._values["interval"] = interval
        if metric is not None:
            self._values["metric"] = metric

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation methods for event platform queries.

        Valid values are ``count``, ``cardinality``, ``median``, ``pc75``, ``pc90``, ``pc95``, ``pc98``, ``pc99``, ``sum``, ``min``, ``max``, ``avg``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''A time interval in milliseconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def metric(self) -> typing.Optional[builtins.str]:
        '''The measurable attribute to compute.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        '''
        result = self._values.get("metric")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetToplistDefinitionRequestQueryEventQueryCompute(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetToplistDefinitionRequestQueryEventQueryComputeList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestQueryEventQueryComputeList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__80945282e5b8410dd3e6668fbeb56eb716f6cd6e23c2e2a104d11d0c2f79dd35)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetToplistDefinitionRequestQueryEventQueryComputeOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8dd49959e79b7f41c48d1b5244268fca425a40add713f936b009929d6d737a83)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetToplistDefinitionRequestQueryEventQueryComputeOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6e3f6195d7b652de25f547dd4c9cc11e2fc01d9287642ec1af3b9af14da62583)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f294746a90ae41fc1b798ab602a7aa9f4d98f889379c322c7ed6c6b509f260c2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ff45cfcc02746a7d83511ecd68e81a9f63a02f9b67a14f23b0f224b58eaae03e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionRequestQueryEventQueryCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionRequestQueryEventQueryCompute]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionRequestQueryEventQueryCompute]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a63de3bc69be5d18f4fadb846b2e28d2f59f87dd79283b3d4ddfa8ef90b65884)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetToplistDefinitionRequestQueryEventQueryComputeOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestQueryEventQueryComputeOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a9d0899935aa708ae6a91df67d9a82363b1bae05b9c9d1cf7f937107ec9f6753)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @jsii.member(jsii_name="resetMetric")
    def reset_metric(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMetric", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="metricInput")
    def metric_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "metricInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3f0d945711a83ded82f0819b24a3587998bc5bdc6856c65e72ee4ebdedecdb5b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__80b4b3b001ad097c55133116c65755cb3d395e284329de1f915f34f3993b4df9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="metric")
    def metric(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "metric"))

    @metric.setter
    def metric(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bef5df77b4f3f8bec3edc8d4f5d0200735feceb115e15e278417f9f7e491a58e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "metric", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetToplistDefinitionRequestQueryEventQueryCompute]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetToplistDefinitionRequestQueryEventQueryCompute]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetToplistDefinitionRequestQueryEventQueryCompute]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2c264861cb7e58a79391e95f133cf4fc370f5bd0429ca3ffc073561f593111cd)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestQueryEventQueryGroupBy",
    jsii_struct_bases=[],
    name_mapping={"facet": "facet", "limit": "limit", "sort": "sort"},
)
class PowerpackWidgetToplistDefinitionRequestQueryEventQueryGroupBy:
    def __init__(
        self,
        *,
        facet: builtins.str,
        limit: typing.Optional[jsii.Number] = None,
        sort: typing.Optional[typing.Union["PowerpackWidgetToplistDefinitionRequestQueryEventQueryGroupBySort", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param facet: The event facet. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param limit: The number of groups to return. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param sort: sort block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort Powerpack#sort}
        '''
        if isinstance(sort, dict):
            sort = PowerpackWidgetToplistDefinitionRequestQueryEventQueryGroupBySort(**sort)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f80a0a75476ffc45b63dea358d55309e1bddba08de1fd22a549f16f0ff5bf43b)
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
            check_type(argname="argument sort", value=sort, expected_type=type_hints["sort"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "facet": facet,
        }
        if limit is not None:
            self._values["limit"] = limit
        if sort is not None:
            self._values["sort"] = sort

    @builtins.property
    def facet(self) -> builtins.str:
        '''The event facet.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        assert result is not None, "Required property 'facet' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def limit(self) -> typing.Optional[jsii.Number]:
        '''The number of groups to return.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        '''
        result = self._values.get("limit")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def sort(
        self,
    ) -> typing.Optional["PowerpackWidgetToplistDefinitionRequestQueryEventQueryGroupBySort"]:
        '''sort block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort Powerpack#sort}
        '''
        result = self._values.get("sort")
        return typing.cast(typing.Optional["PowerpackWidgetToplistDefinitionRequestQueryEventQueryGroupBySort"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetToplistDefinitionRequestQueryEventQueryGroupBy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetToplistDefinitionRequestQueryEventQueryGroupByList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestQueryEventQueryGroupByList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__72370ee2b0c1c84f8e71dff1679e2feb9b3672abd4a91f0bad8470bb1dde2cb8)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetToplistDefinitionRequestQueryEventQueryGroupByOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__252260cc86be06f79acaa7044270966332fd31f89472435700d1f2c2b44df8b7)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetToplistDefinitionRequestQueryEventQueryGroupByOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c5281d0d5cc6044a691b0cf0d7c909644b511741ad824d6024cbcc9a4f16f1a9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__14beb4fb0ad2b526c09bd40daeaa372fd72bfa48a9ca09a8a39530d2baaa6ea6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0609850b8d8a590dc3e1e6104d0e3599ae7575bb431eb539afe1946e8df36753)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionRequestQueryEventQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionRequestQueryEventQueryGroupBy]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionRequestQueryEventQueryGroupBy]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__49ef36d36813f4e03dac205ca8438d76d90ca9ea93515683ca0040508bd92aa6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetToplistDefinitionRequestQueryEventQueryGroupByOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestQueryEventQueryGroupByOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e15446165a4409c393fb7173270d046a7d5c4819a5b0d2ea0025490e710bf0cb)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putSort")
    def put_sort(
        self,
        *,
        aggregation: builtins.str,
        metric: typing.Optional[builtins.str] = None,
        order: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation methods for the event platform queries. Valid values are ``count``, ``cardinality``, ``median``, ``pc75``, ``pc90``, ``pc95``, ``pc98``, ``pc99``, ``sum``, ``min``, ``max``, ``avg``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param metric: The metric used for sorting group by results. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        :param order: Direction of sort. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        value = PowerpackWidgetToplistDefinitionRequestQueryEventQueryGroupBySort(
            aggregation=aggregation, metric=metric, order=order
        )

        return typing.cast(None, jsii.invoke(self, "putSort", [value]))

    @jsii.member(jsii_name="resetLimit")
    def reset_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLimit", []))

    @jsii.member(jsii_name="resetSort")
    def reset_sort(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSort", []))

    @builtins.property
    @jsii.member(jsii_name="sort")
    def sort(
        self,
    ) -> "PowerpackWidgetToplistDefinitionRequestQueryEventQueryGroupBySortOutputReference":
        return typing.cast("PowerpackWidgetToplistDefinitionRequestQueryEventQueryGroupBySortOutputReference", jsii.get(self, "sort"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="limitInput")
    def limit_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "limitInput"))

    @builtins.property
    @jsii.member(jsii_name="sortInput")
    def sort_input(
        self,
    ) -> typing.Optional["PowerpackWidgetToplistDefinitionRequestQueryEventQueryGroupBySort"]:
        return typing.cast(typing.Optional["PowerpackWidgetToplistDefinitionRequestQueryEventQueryGroupBySort"], jsii.get(self, "sortInput"))

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1afe192fb83076d33383529512d9b2f247c88e84b175c22a7ef41855e38beff1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="limit")
    def limit(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "limit"))

    @limit.setter
    def limit(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__52c1627fd6d5c46f3212348387b49a1f09b50e492d230a1c92451e8c48fcad51)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "limit", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetToplistDefinitionRequestQueryEventQueryGroupBy]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetToplistDefinitionRequestQueryEventQueryGroupBy]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetToplistDefinitionRequestQueryEventQueryGroupBy]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dee63a446c3b58ed84968347100907048aab290a3e680187e115f750a713d323)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestQueryEventQueryGroupBySort",
    jsii_struct_bases=[],
    name_mapping={"aggregation": "aggregation", "metric": "metric", "order": "order"},
)
class PowerpackWidgetToplistDefinitionRequestQueryEventQueryGroupBySort:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        metric: typing.Optional[builtins.str] = None,
        order: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation methods for the event platform queries. Valid values are ``count``, ``cardinality``, ``median``, ``pc75``, ``pc90``, ``pc95``, ``pc98``, ``pc99``, ``sum``, ``min``, ``max``, ``avg``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param metric: The metric used for sorting group by results. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        :param order: Direction of sort. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__44331b9c23de9e13f1fe4bb88b290971af51b901708f42447faa0cd8ab02a9f9)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument metric", value=metric, expected_type=type_hints["metric"])
            check_type(argname="argument order", value=order, expected_type=type_hints["order"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if metric is not None:
            self._values["metric"] = metric
        if order is not None:
            self._values["order"] = order

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation methods for the event platform queries.

        Valid values are ``count``, ``cardinality``, ``median``, ``pc75``, ``pc90``, ``pc95``, ``pc98``, ``pc99``, ``sum``, ``min``, ``max``, ``avg``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def metric(self) -> typing.Optional[builtins.str]:
        '''The metric used for sorting group by results.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        '''
        result = self._values.get("metric")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def order(self) -> typing.Optional[builtins.str]:
        '''Direction of sort. Valid values are ``asc``, ``desc``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        result = self._values.get("order")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetToplistDefinitionRequestQueryEventQueryGroupBySort(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetToplistDefinitionRequestQueryEventQueryGroupBySortOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestQueryEventQueryGroupBySortOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__66c81cc95a5e2b8595dd237f0d840094ab9c49abfc35f30c93bf6551cc735723)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetMetric")
    def reset_metric(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMetric", []))

    @jsii.member(jsii_name="resetOrder")
    def reset_order(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetOrder", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="metricInput")
    def metric_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "metricInput"))

    @builtins.property
    @jsii.member(jsii_name="orderInput")
    def order_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "orderInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4db8010b5d2cb7bfe9a7039214470a5405dd382c650181e9f02979bbdac52c8e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="metric")
    def metric(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "metric"))

    @metric.setter
    def metric(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__443a0f5937aa1d836a6798bb92a4a2b2ce6969f642787528a88bead00c808bd8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "metric", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="order")
    def order(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "order"))

    @order.setter
    def order(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3b77e407ed7f9c28198d0a0a646d92286d641059d4e28d06cea3a4baaa18c9ea)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "order", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetToplistDefinitionRequestQueryEventQueryGroupBySort]:
        return typing.cast(typing.Optional[PowerpackWidgetToplistDefinitionRequestQueryEventQueryGroupBySort], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetToplistDefinitionRequestQueryEventQueryGroupBySort],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7ded662da9f6df7980fc3d9e8bf1b678ae0e5f0d8ecedd0b89e5c939d5e8a2fb)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetToplistDefinitionRequestQueryEventQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestQueryEventQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c8fadb78df46fa6cdd329a5afc0c15cad2b949e0eb998a5fd624e12decec8faf)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putCompute")
    def put_compute(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetToplistDefinitionRequestQueryEventQueryCompute, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e588b1dcd21b1361449b1c9d7980dce3040782a33babd30e31ac5f29c0982fc7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putCompute", [value]))

    @jsii.member(jsii_name="putGroupBy")
    def put_group_by(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetToplistDefinitionRequestQueryEventQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__acdd8f6567e7f2d8137cbda0b0a2ac3d9d4c869ba1087883e4948fa0de245cca)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putGroupBy", [value]))

    @jsii.member(jsii_name="putSearch")
    def put_search(self, *, query: builtins.str) -> None:
        '''
        :param query: The events search string. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        '''
        value = PowerpackWidgetToplistDefinitionRequestQueryEventQuerySearch(
            query=query
        )

        return typing.cast(None, jsii.invoke(self, "putSearch", [value]))

    @jsii.member(jsii_name="resetCrossOrgUuids")
    def reset_cross_org_uuids(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCrossOrgUuids", []))

    @jsii.member(jsii_name="resetGroupBy")
    def reset_group_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGroupBy", []))

    @jsii.member(jsii_name="resetIndexes")
    def reset_indexes(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetIndexes", []))

    @jsii.member(jsii_name="resetSearch")
    def reset_search(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSearch", []))

    @jsii.member(jsii_name="resetStorage")
    def reset_storage(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetStorage", []))

    @builtins.property
    @jsii.member(jsii_name="compute")
    def compute(
        self,
    ) -> PowerpackWidgetToplistDefinitionRequestQueryEventQueryComputeList:
        return typing.cast(PowerpackWidgetToplistDefinitionRequestQueryEventQueryComputeList, jsii.get(self, "compute"))

    @builtins.property
    @jsii.member(jsii_name="groupBy")
    def group_by(
        self,
    ) -> PowerpackWidgetToplistDefinitionRequestQueryEventQueryGroupByList:
        return typing.cast(PowerpackWidgetToplistDefinitionRequestQueryEventQueryGroupByList, jsii.get(self, "groupBy"))

    @builtins.property
    @jsii.member(jsii_name="search")
    def search(
        self,
    ) -> "PowerpackWidgetToplistDefinitionRequestQueryEventQuerySearchOutputReference":
        return typing.cast("PowerpackWidgetToplistDefinitionRequestQueryEventQuerySearchOutputReference", jsii.get(self, "search"))

    @builtins.property
    @jsii.member(jsii_name="computeInput")
    def compute_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionRequestQueryEventQueryCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionRequestQueryEventQueryCompute]]], jsii.get(self, "computeInput"))

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuidsInput")
    def cross_org_uuids_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "crossOrgUuidsInput"))

    @builtins.property
    @jsii.member(jsii_name="dataSourceInput")
    def data_source_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "dataSourceInput"))

    @builtins.property
    @jsii.member(jsii_name="groupByInput")
    def group_by_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionRequestQueryEventQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionRequestQueryEventQueryGroupBy]]], jsii.get(self, "groupByInput"))

    @builtins.property
    @jsii.member(jsii_name="indexesInput")
    def indexes_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "indexesInput"))

    @builtins.property
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property
    @jsii.member(jsii_name="searchInput")
    def search_input(
        self,
    ) -> typing.Optional["PowerpackWidgetToplistDefinitionRequestQueryEventQuerySearch"]:
        return typing.cast(typing.Optional["PowerpackWidgetToplistDefinitionRequestQueryEventQuerySearch"], jsii.get(self, "searchInput"))

    @builtins.property
    @jsii.member(jsii_name="storageInput")
    def storage_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "storageInput"))

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuids")
    def cross_org_uuids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "crossOrgUuids"))

    @cross_org_uuids.setter
    def cross_org_uuids(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7e2308fcc873d5d04c3e7e06bb660f12f2cf9d56056b1a1b5b9109971599bf99)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "crossOrgUuids", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="dataSource")
    def data_source(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "dataSource"))

    @data_source.setter
    def data_source(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d65dbbe287cc4bd8af895c94dd9b0c8b2acfdb00c70d3cf9dabe7d670237b0aa)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "dataSource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="indexes")
    def indexes(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "indexes"))

    @indexes.setter
    def indexes(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a8703f43de0b5edefc9545867b55e40ffaa4ca9f0c2ca672d0a59ec1cf1e5bf1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "indexes", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f80f5ec2db597eec7a8a3a16996e8388af43457406a2b618f46aa734ca91d345)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "name", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="storage")
    def storage(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "storage"))

    @storage.setter
    def storage(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__55c940b8493633b2d0bed53d9314853d427198fc014e18a341515259ca859824)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "storage", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetToplistDefinitionRequestQueryEventQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetToplistDefinitionRequestQueryEventQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetToplistDefinitionRequestQueryEventQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__908516984920089393cbf16224c4987f017eb61ab38c1a4260ae9cb9ca7a16c1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestQueryEventQuerySearch",
    jsii_struct_bases=[],
    name_mapping={"query": "query"},
)
class PowerpackWidgetToplistDefinitionRequestQueryEventQuerySearch:
    def __init__(self, *, query: builtins.str) -> None:
        '''
        :param query: The events search string. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2d0264a7db603e59223125833e9c46206a06c387df12b70576d858d8de3bd33e)
            check_type(argname="argument query", value=query, expected_type=type_hints["query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "query": query,
        }

    @builtins.property
    def query(self) -> builtins.str:
        '''The events search string.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        '''
        result = self._values.get("query")
        assert result is not None, "Required property 'query' is missing"
        return typing.cast(builtins.str, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetToplistDefinitionRequestQueryEventQuerySearch(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetToplistDefinitionRequestQueryEventQuerySearchOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestQueryEventQuerySearchOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9cab9e4781089225b7f0fbb6ad9990e45e3468565e9d2cebc71c7d7c10e0108e)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @builtins.property
    @jsii.member(jsii_name="queryInput")
    def query_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "queryInput"))

    @builtins.property
    @jsii.member(jsii_name="query")
    def query(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "query"))

    @query.setter
    def query(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6fb08573e15e26a88bccf5a49cc6e68a3ff1d1c13d9c780fa15068411e58d7d2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "query", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetToplistDefinitionRequestQueryEventQuerySearch]:
        return typing.cast(typing.Optional[PowerpackWidgetToplistDefinitionRequestQueryEventQuerySearch], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetToplistDefinitionRequestQueryEventQuerySearch],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c39b942ad71df7775de5ac81b0bd4c12ec3e0ff71b94921a97d78016b31a4b53)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetToplistDefinitionRequestQueryList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestQueryList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6e63146e32308637f9164a17cfd1569a90c9458c6f660fca9e07d0be21d57253)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetToplistDefinitionRequestQueryOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__eb3c7b8fc995242f2a8384ca32a658cede017af4939559613095f68d0dba217a)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetToplistDefinitionRequestQueryOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1198ac6d27e179f400c479c787b62cf17236ae2fd16ec21e08c25752e0a6ad32)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__af4cd700bda9b4e6845d31394f3357d1307b088405b2914c0d1f90ded6434685)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__72a7fa0fac266affb39b3c1344f6437e99c79989debaaac32fb63306f5cb2498)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionRequestQuery]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionRequestQuery]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionRequestQuery]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__869b9ae8e04372e41709a4756910b6ed5f0178ea23b328a054189633927c5125)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestQueryMetricQuery",
    jsii_struct_bases=[],
    name_mapping={
        "name": "name",
        "query": "query",
        "aggregator": "aggregator",
        "cross_org_uuids": "crossOrgUuids",
        "data_source": "dataSource",
    },
)
class PowerpackWidgetToplistDefinitionRequestQueryMetricQuery:
    def __init__(
        self,
        *,
        name: builtins.str,
        query: builtins.str,
        aggregator: typing.Optional[builtins.str] = None,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        data_source: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param name: The name of the query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param query: The metrics query definition. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        :param aggregator: The aggregation methods available for metrics queries. Valid values are ``avg``, ``min``, ``max``, ``sum``, ``last``, ``area``, ``l2norm``, ``percentile``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregator Powerpack#aggregator}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param data_source: The data source for metrics queries. Defaults to ``"metrics"``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1d6a1c0d81be4c463bfe244cd4cc81897490ace4164434ef9dae1797cbc3b358)
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument query", value=query, expected_type=type_hints["query"])
            check_type(argname="argument aggregator", value=aggregator, expected_type=type_hints["aggregator"])
            check_type(argname="argument cross_org_uuids", value=cross_org_uuids, expected_type=type_hints["cross_org_uuids"])
            check_type(argname="argument data_source", value=data_source, expected_type=type_hints["data_source"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "name": name,
            "query": query,
        }
        if aggregator is not None:
            self._values["aggregator"] = aggregator
        if cross_org_uuids is not None:
            self._values["cross_org_uuids"] = cross_org_uuids
        if data_source is not None:
            self._values["data_source"] = data_source

    @builtins.property
    def name(self) -> builtins.str:
        '''The name of the query for use in formulas.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        '''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def query(self) -> builtins.str:
        '''The metrics query definition.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        '''
        result = self._values.get("query")
        assert result is not None, "Required property 'query' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def aggregator(self) -> typing.Optional[builtins.str]:
        '''The aggregation methods available for metrics queries. Valid values are ``avg``, ``min``, ``max``, ``sum``, ``last``, ``area``, ``l2norm``, ``percentile``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregator Powerpack#aggregator}
        '''
        result = self._values.get("aggregator")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def cross_org_uuids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''The source organization UUID for cross organization queries. Feature in Private Beta.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        '''
        result = self._values.get("cross_org_uuids")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def data_source(self) -> typing.Optional[builtins.str]:
        '''The data source for metrics queries. Defaults to ``"metrics"``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        '''
        result = self._values.get("data_source")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetToplistDefinitionRequestQueryMetricQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetToplistDefinitionRequestQueryMetricQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestQueryMetricQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9911f9cca6f044b0aa9bc6740baa6f012c5e4766cd4f5d61b1490cd040f471bb)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetAggregator")
    def reset_aggregator(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAggregator", []))

    @jsii.member(jsii_name="resetCrossOrgUuids")
    def reset_cross_org_uuids(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCrossOrgUuids", []))

    @jsii.member(jsii_name="resetDataSource")
    def reset_data_source(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDataSource", []))

    @builtins.property
    @jsii.member(jsii_name="aggregatorInput")
    def aggregator_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregatorInput"))

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuidsInput")
    def cross_org_uuids_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "crossOrgUuidsInput"))

    @builtins.property
    @jsii.member(jsii_name="dataSourceInput")
    def data_source_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "dataSourceInput"))

    @builtins.property
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property
    @jsii.member(jsii_name="queryInput")
    def query_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "queryInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregator")
    def aggregator(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregator"))

    @aggregator.setter
    def aggregator(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__136e51d5d2a48bde65351733e41c8849392d874315b9c65bced630c9623998ca)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregator", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuids")
    def cross_org_uuids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "crossOrgUuids"))

    @cross_org_uuids.setter
    def cross_org_uuids(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__53e1c60e38b104c997450ff2fa6e0cfe8767fd2c03143a361986f099a0912cbf)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "crossOrgUuids", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="dataSource")
    def data_source(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "dataSource"))

    @data_source.setter
    def data_source(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4f882c86eff6682dad67c6f23e7daec9cc182d6957045f29283efbed87ad2cc0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "dataSource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f9c0035fc0638646f44b5fb339aea624348dd9f334cdf392164360e5a1ebefee)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "name", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="query")
    def query(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "query"))

    @query.setter
    def query(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8eee8dc3e1bb20c15dc81f2293f633516dd796c7e66fd31b0970e5989d916379)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "query", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetToplistDefinitionRequestQueryMetricQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetToplistDefinitionRequestQueryMetricQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetToplistDefinitionRequestQueryMetricQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__59e58bc228c674d21bb9a46ae115dbadae62ba7e1d29d05806bceb6927a5c660)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetToplistDefinitionRequestQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__66a3aa60b4a666c11e40b21289479e32021fd48224165dc06abf6d0d07c3d7fc)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putApmDependencyStatsQuery")
    def put_apm_dependency_stats_query(
        self,
        *,
        data_source: builtins.str,
        env: builtins.str,
        name: builtins.str,
        operation_name: builtins.str,
        resource_name: builtins.str,
        service: builtins.str,
        stat: builtins.str,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        is_upstream: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        primary_tag_name: typing.Optional[builtins.str] = None,
        primary_tag_value: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param data_source: The data source for APM Dependency Stats queries. Valid values are ``apm_dependency_stats``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param env: APM environment. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#env Powerpack#env}
        :param name: The name of query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param operation_name: Name of operation on service. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#operation_name Powerpack#operation_name}
        :param resource_name: APM resource. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#resource_name Powerpack#resource_name}
        :param service: APM service. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#service Powerpack#service}
        :param stat: APM statistic. Valid values are ``avg_duration``, ``avg_root_duration``, ``avg_spans_per_trace``, ``error_rate``, ``pct_exec_time``, ``pct_of_traces``, ``total_traces_count``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#stat Powerpack#stat}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param is_upstream: Determines whether stats for upstream or downstream dependencies should be queried. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#is_upstream Powerpack#is_upstream}
        :param primary_tag_name: The name of the second primary tag used within APM; required when ``primary_tag_value`` is specified. See https://docs.datadoghq.com/tracing/guide/setting_primary_tags_to_scope/#add-a-second-primary-tag-in-datadog. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_name Powerpack#primary_tag_name}
        :param primary_tag_value: Filter APM data by the second primary tag. ``primary_tag_name`` must also be specified. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_value Powerpack#primary_tag_value}
        '''
        value = PowerpackWidgetToplistDefinitionRequestQueryApmDependencyStatsQuery(
            data_source=data_source,
            env=env,
            name=name,
            operation_name=operation_name,
            resource_name=resource_name,
            service=service,
            stat=stat,
            cross_org_uuids=cross_org_uuids,
            is_upstream=is_upstream,
            primary_tag_name=primary_tag_name,
            primary_tag_value=primary_tag_value,
        )

        return typing.cast(None, jsii.invoke(self, "putApmDependencyStatsQuery", [value]))

    @jsii.member(jsii_name="putApmResourceStatsQuery")
    def put_apm_resource_stats_query(
        self,
        *,
        data_source: builtins.str,
        env: builtins.str,
        name: builtins.str,
        service: builtins.str,
        stat: builtins.str,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        group_by: typing.Optional[typing.Sequence[builtins.str]] = None,
        operation_name: typing.Optional[builtins.str] = None,
        primary_tag_name: typing.Optional[builtins.str] = None,
        primary_tag_value: typing.Optional[builtins.str] = None,
        resource_name: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param data_source: The data source for APM Resource Stats queries. Valid values are ``apm_resource_stats``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param env: APM environment. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#env Powerpack#env}
        :param name: The name of query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param service: APM service. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#service Powerpack#service}
        :param stat: APM statistic. Valid values are ``errors``, ``error_rate``, ``hits``, ``latency_avg``, ``latency_distribution``, ``latency_max``, ``latency_p50``, ``latency_p75``, ``latency_p90``, ``latency_p95``, ``latency_p99``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#stat Powerpack#stat}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param group_by: Array of fields to group results by. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param operation_name: Name of operation on service. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#operation_name Powerpack#operation_name}
        :param primary_tag_name: The name of the second primary tag used within APM; required when ``primary_tag_value`` is specified. See https://docs.datadoghq.com/tracing/guide/setting_primary_tags_to_scope/#add-a-second-primary-tag-in-datadog. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_name Powerpack#primary_tag_name}
        :param primary_tag_value: Filter APM data by the second primary tag. ``primary_tag_name`` must also be specified. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_value Powerpack#primary_tag_value}
        :param resource_name: APM resource. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#resource_name Powerpack#resource_name}
        '''
        value = PowerpackWidgetToplistDefinitionRequestQueryApmResourceStatsQuery(
            data_source=data_source,
            env=env,
            name=name,
            service=service,
            stat=stat,
            cross_org_uuids=cross_org_uuids,
            group_by=group_by,
            operation_name=operation_name,
            primary_tag_name=primary_tag_name,
            primary_tag_value=primary_tag_value,
            resource_name=resource_name,
        )

        return typing.cast(None, jsii.invoke(self, "putApmResourceStatsQuery", [value]))

    @jsii.member(jsii_name="putCloudCostQuery")
    def put_cloud_cost_query(
        self,
        *,
        data_source: builtins.str,
        name: builtins.str,
        query: builtins.str,
        aggregator: typing.Optional[builtins.str] = None,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
    ) -> None:
        '''
        :param data_source: The data source for cloud cost queries. Valid values are ``cloud_cost``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param name: The name of the query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param query: The cloud cost query definition. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        :param aggregator: The aggregation methods available for cloud cost queries. Valid values are ``avg``, ``last``, ``max``, ``min``, ``sum``, ``percentile``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregator Powerpack#aggregator}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        '''
        value = PowerpackWidgetToplistDefinitionRequestQueryCloudCostQuery(
            data_source=data_source,
            name=name,
            query=query,
            aggregator=aggregator,
            cross_org_uuids=cross_org_uuids,
        )

        return typing.cast(None, jsii.invoke(self, "putCloudCostQuery", [value]))

    @jsii.member(jsii_name="putEventQuery")
    def put_event_query(
        self,
        *,
        compute: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetToplistDefinitionRequestQueryEventQueryCompute, typing.Dict[builtins.str, typing.Any]]]],
        data_source: builtins.str,
        name: builtins.str,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetToplistDefinitionRequestQueryEventQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
        indexes: typing.Optional[typing.Sequence[builtins.str]] = None,
        search: typing.Optional[typing.Union[PowerpackWidgetToplistDefinitionRequestQueryEventQuerySearch, typing.Dict[builtins.str, typing.Any]]] = None,
        storage: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param compute: compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute Powerpack#compute}
        :param data_source: The data source for event platform-based queries. Valid values are ``logs``, ``spans``, ``network``, ``rum``, ``security_signals``, ``profiles``, ``audit``, ``events``, ``ci_tests``, ``ci_pipelines``, ``incident_analytics``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param name: The name of query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param indexes: An array of index names to query in the stream. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#indexes Powerpack#indexes}
        :param search: search block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search Powerpack#search}
        :param storage: Storage location (private beta). Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#storage Powerpack#storage}
        '''
        value = PowerpackWidgetToplistDefinitionRequestQueryEventQuery(
            compute=compute,
            data_source=data_source,
            name=name,
            cross_org_uuids=cross_org_uuids,
            group_by=group_by,
            indexes=indexes,
            search=search,
            storage=storage,
        )

        return typing.cast(None, jsii.invoke(self, "putEventQuery", [value]))

    @jsii.member(jsii_name="putMetricQuery")
    def put_metric_query(
        self,
        *,
        name: builtins.str,
        query: builtins.str,
        aggregator: typing.Optional[builtins.str] = None,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        data_source: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param name: The name of the query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param query: The metrics query definition. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        :param aggregator: The aggregation methods available for metrics queries. Valid values are ``avg``, ``min``, ``max``, ``sum``, ``last``, ``area``, ``l2norm``, ``percentile``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregator Powerpack#aggregator}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param data_source: The data source for metrics queries. Defaults to ``"metrics"``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        '''
        value = PowerpackWidgetToplistDefinitionRequestQueryMetricQuery(
            name=name,
            query=query,
            aggregator=aggregator,
            cross_org_uuids=cross_org_uuids,
            data_source=data_source,
        )

        return typing.cast(None, jsii.invoke(self, "putMetricQuery", [value]))

    @jsii.member(jsii_name="putProcessQuery")
    def put_process_query(
        self,
        *,
        data_source: builtins.str,
        metric: builtins.str,
        name: builtins.str,
        aggregator: typing.Optional[builtins.str] = None,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        is_normalized_cpu: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        limit: typing.Optional[jsii.Number] = None,
        sort: typing.Optional[builtins.str] = None,
        tag_filters: typing.Optional[typing.Sequence[builtins.str]] = None,
        text_filter: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param data_source: The data source for process queries. Valid values are ``process``, ``container``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param metric: The process metric name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        :param name: The name of query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param aggregator: The aggregation methods available for metrics queries. Valid values are ``avg``, ``min``, ``max``, ``sum``, ``last``, ``area``, ``l2norm``, ``percentile``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregator Powerpack#aggregator}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param is_normalized_cpu: Whether to normalize the CPU percentages. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#is_normalized_cpu Powerpack#is_normalized_cpu}
        :param limit: The number of hits to return. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param sort: The direction of the sort. Valid values are ``asc``, ``desc``. Defaults to ``"desc"``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort Powerpack#sort}
        :param tag_filters: An array of tags to filter by. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#tag_filters Powerpack#tag_filters}
        :param text_filter: The text to use as a filter. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#text_filter Powerpack#text_filter}
        '''
        value = PowerpackWidgetToplistDefinitionRequestQueryProcessQuery(
            data_source=data_source,
            metric=metric,
            name=name,
            aggregator=aggregator,
            cross_org_uuids=cross_org_uuids,
            is_normalized_cpu=is_normalized_cpu,
            limit=limit,
            sort=sort,
            tag_filters=tag_filters,
            text_filter=text_filter,
        )

        return typing.cast(None, jsii.invoke(self, "putProcessQuery", [value]))

    @jsii.member(jsii_name="putSloQuery")
    def put_slo_query(
        self,
        *,
        data_source: builtins.str,
        measure: builtins.str,
        slo_id: builtins.str,
        additional_query_filters: typing.Optional[builtins.str] = None,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        group_mode: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
        slo_query_type: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param data_source: The data source for SLO queries. Valid values are ``slo``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param measure: SLO measures queries. Valid values are ``good_events``, ``bad_events``, ``good_minutes``, ``bad_minutes``, ``slo_status``, ``error_budget_remaining``, ``burn_rate``, ``error_budget_burndown``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#measure Powerpack#measure}
        :param slo_id: ID of an SLO to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#slo_id Powerpack#slo_id}
        :param additional_query_filters: Additional filters applied to the SLO query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#additional_query_filters Powerpack#additional_query_filters}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param group_mode: Group mode to query measures. Valid values are ``overall``, ``components``. Defaults to ``"overall"``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_mode Powerpack#group_mode}
        :param name: The name of query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param slo_query_type: type of the SLO to query. Valid values are ``metric``, ``monitor``, ``time_slice``. Defaults to ``"metric"``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#slo_query_type Powerpack#slo_query_type}
        '''
        value = PowerpackWidgetToplistDefinitionRequestQuerySloQuery(
            data_source=data_source,
            measure=measure,
            slo_id=slo_id,
            additional_query_filters=additional_query_filters,
            cross_org_uuids=cross_org_uuids,
            group_mode=group_mode,
            name=name,
            slo_query_type=slo_query_type,
        )

        return typing.cast(None, jsii.invoke(self, "putSloQuery", [value]))

    @jsii.member(jsii_name="resetApmDependencyStatsQuery")
    def reset_apm_dependency_stats_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetApmDependencyStatsQuery", []))

    @jsii.member(jsii_name="resetApmResourceStatsQuery")
    def reset_apm_resource_stats_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetApmResourceStatsQuery", []))

    @jsii.member(jsii_name="resetCloudCostQuery")
    def reset_cloud_cost_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCloudCostQuery", []))

    @jsii.member(jsii_name="resetEventQuery")
    def reset_event_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetEventQuery", []))

    @jsii.member(jsii_name="resetMetricQuery")
    def reset_metric_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMetricQuery", []))

    @jsii.member(jsii_name="resetProcessQuery")
    def reset_process_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetProcessQuery", []))

    @jsii.member(jsii_name="resetSloQuery")
    def reset_slo_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSloQuery", []))

    @builtins.property
    @jsii.member(jsii_name="apmDependencyStatsQuery")
    def apm_dependency_stats_query(
        self,
    ) -> PowerpackWidgetToplistDefinitionRequestQueryApmDependencyStatsQueryOutputReference:
        return typing.cast(PowerpackWidgetToplistDefinitionRequestQueryApmDependencyStatsQueryOutputReference, jsii.get(self, "apmDependencyStatsQuery"))

    @builtins.property
    @jsii.member(jsii_name="apmResourceStatsQuery")
    def apm_resource_stats_query(
        self,
    ) -> PowerpackWidgetToplistDefinitionRequestQueryApmResourceStatsQueryOutputReference:
        return typing.cast(PowerpackWidgetToplistDefinitionRequestQueryApmResourceStatsQueryOutputReference, jsii.get(self, "apmResourceStatsQuery"))

    @builtins.property
    @jsii.member(jsii_name="cloudCostQuery")
    def cloud_cost_query(
        self,
    ) -> PowerpackWidgetToplistDefinitionRequestQueryCloudCostQueryOutputReference:
        return typing.cast(PowerpackWidgetToplistDefinitionRequestQueryCloudCostQueryOutputReference, jsii.get(self, "cloudCostQuery"))

    @builtins.property
    @jsii.member(jsii_name="eventQuery")
    def event_query(
        self,
    ) -> PowerpackWidgetToplistDefinitionRequestQueryEventQueryOutputReference:
        return typing.cast(PowerpackWidgetToplistDefinitionRequestQueryEventQueryOutputReference, jsii.get(self, "eventQuery"))

    @builtins.property
    @jsii.member(jsii_name="metricQuery")
    def metric_query(
        self,
    ) -> PowerpackWidgetToplistDefinitionRequestQueryMetricQueryOutputReference:
        return typing.cast(PowerpackWidgetToplistDefinitionRequestQueryMetricQueryOutputReference, jsii.get(self, "metricQuery"))

    @builtins.property
    @jsii.member(jsii_name="processQuery")
    def process_query(
        self,
    ) -> "PowerpackWidgetToplistDefinitionRequestQueryProcessQueryOutputReference":
        return typing.cast("PowerpackWidgetToplistDefinitionRequestQueryProcessQueryOutputReference", jsii.get(self, "processQuery"))

    @builtins.property
    @jsii.member(jsii_name="sloQuery")
    def slo_query(
        self,
    ) -> "PowerpackWidgetToplistDefinitionRequestQuerySloQueryOutputReference":
        return typing.cast("PowerpackWidgetToplistDefinitionRequestQuerySloQueryOutputReference", jsii.get(self, "sloQuery"))

    @builtins.property
    @jsii.member(jsii_name="apmDependencyStatsQueryInput")
    def apm_dependency_stats_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetToplistDefinitionRequestQueryApmDependencyStatsQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetToplistDefinitionRequestQueryApmDependencyStatsQuery], jsii.get(self, "apmDependencyStatsQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="apmResourceStatsQueryInput")
    def apm_resource_stats_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetToplistDefinitionRequestQueryApmResourceStatsQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetToplistDefinitionRequestQueryApmResourceStatsQuery], jsii.get(self, "apmResourceStatsQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="cloudCostQueryInput")
    def cloud_cost_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetToplistDefinitionRequestQueryCloudCostQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetToplistDefinitionRequestQueryCloudCostQuery], jsii.get(self, "cloudCostQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="eventQueryInput")
    def event_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetToplistDefinitionRequestQueryEventQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetToplistDefinitionRequestQueryEventQuery], jsii.get(self, "eventQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="metricQueryInput")
    def metric_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetToplistDefinitionRequestQueryMetricQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetToplistDefinitionRequestQueryMetricQuery], jsii.get(self, "metricQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="processQueryInput")
    def process_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetToplistDefinitionRequestQueryProcessQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetToplistDefinitionRequestQueryProcessQuery"], jsii.get(self, "processQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="sloQueryInput")
    def slo_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetToplistDefinitionRequestQuerySloQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetToplistDefinitionRequestQuerySloQuery"], jsii.get(self, "sloQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetToplistDefinitionRequestQuery]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetToplistDefinitionRequestQuery]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetToplistDefinitionRequestQuery]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ae947c228148f0281ccf393ea84b47bc1fc549864897e1648e8942885ea8edde)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestQueryProcessQuery",
    jsii_struct_bases=[],
    name_mapping={
        "data_source": "dataSource",
        "metric": "metric",
        "name": "name",
        "aggregator": "aggregator",
        "cross_org_uuids": "crossOrgUuids",
        "is_normalized_cpu": "isNormalizedCpu",
        "limit": "limit",
        "sort": "sort",
        "tag_filters": "tagFilters",
        "text_filter": "textFilter",
    },
)
class PowerpackWidgetToplistDefinitionRequestQueryProcessQuery:
    def __init__(
        self,
        *,
        data_source: builtins.str,
        metric: builtins.str,
        name: builtins.str,
        aggregator: typing.Optional[builtins.str] = None,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        is_normalized_cpu: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        limit: typing.Optional[jsii.Number] = None,
        sort: typing.Optional[builtins.str] = None,
        tag_filters: typing.Optional[typing.Sequence[builtins.str]] = None,
        text_filter: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param data_source: The data source for process queries. Valid values are ``process``, ``container``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param metric: The process metric name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        :param name: The name of query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param aggregator: The aggregation methods available for metrics queries. Valid values are ``avg``, ``min``, ``max``, ``sum``, ``last``, ``area``, ``l2norm``, ``percentile``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregator Powerpack#aggregator}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param is_normalized_cpu: Whether to normalize the CPU percentages. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#is_normalized_cpu Powerpack#is_normalized_cpu}
        :param limit: The number of hits to return. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param sort: The direction of the sort. Valid values are ``asc``, ``desc``. Defaults to ``"desc"``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort Powerpack#sort}
        :param tag_filters: An array of tags to filter by. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#tag_filters Powerpack#tag_filters}
        :param text_filter: The text to use as a filter. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#text_filter Powerpack#text_filter}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7d5d0e8dd029f24bc0b495f1a67fae8c6129f8f253d8e58cfd0ef57a18e0859d)
            check_type(argname="argument data_source", value=data_source, expected_type=type_hints["data_source"])
            check_type(argname="argument metric", value=metric, expected_type=type_hints["metric"])
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument aggregator", value=aggregator, expected_type=type_hints["aggregator"])
            check_type(argname="argument cross_org_uuids", value=cross_org_uuids, expected_type=type_hints["cross_org_uuids"])
            check_type(argname="argument is_normalized_cpu", value=is_normalized_cpu, expected_type=type_hints["is_normalized_cpu"])
            check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
            check_type(argname="argument sort", value=sort, expected_type=type_hints["sort"])
            check_type(argname="argument tag_filters", value=tag_filters, expected_type=type_hints["tag_filters"])
            check_type(argname="argument text_filter", value=text_filter, expected_type=type_hints["text_filter"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "data_source": data_source,
            "metric": metric,
            "name": name,
        }
        if aggregator is not None:
            self._values["aggregator"] = aggregator
        if cross_org_uuids is not None:
            self._values["cross_org_uuids"] = cross_org_uuids
        if is_normalized_cpu is not None:
            self._values["is_normalized_cpu"] = is_normalized_cpu
        if limit is not None:
            self._values["limit"] = limit
        if sort is not None:
            self._values["sort"] = sort
        if tag_filters is not None:
            self._values["tag_filters"] = tag_filters
        if text_filter is not None:
            self._values["text_filter"] = text_filter

    @builtins.property
    def data_source(self) -> builtins.str:
        '''The data source for process queries. Valid values are ``process``, ``container``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        '''
        result = self._values.get("data_source")
        assert result is not None, "Required property 'data_source' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def metric(self) -> builtins.str:
        '''The process metric name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        '''
        result = self._values.get("metric")
        assert result is not None, "Required property 'metric' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def name(self) -> builtins.str:
        '''The name of query for use in formulas.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        '''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def aggregator(self) -> typing.Optional[builtins.str]:
        '''The aggregation methods available for metrics queries. Valid values are ``avg``, ``min``, ``max``, ``sum``, ``last``, ``area``, ``l2norm``, ``percentile``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregator Powerpack#aggregator}
        '''
        result = self._values.get("aggregator")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def cross_org_uuids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''The source organization UUID for cross organization queries. Feature in Private Beta.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        '''
        result = self._values.get("cross_org_uuids")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def is_normalized_cpu(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        '''Whether to normalize the CPU percentages.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#is_normalized_cpu Powerpack#is_normalized_cpu}
        '''
        result = self._values.get("is_normalized_cpu")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)

    @builtins.property
    def limit(self) -> typing.Optional[jsii.Number]:
        '''The number of hits to return.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        '''
        result = self._values.get("limit")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def sort(self) -> typing.Optional[builtins.str]:
        '''The direction of the sort. Valid values are ``asc``, ``desc``. Defaults to ``"desc"``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort Powerpack#sort}
        '''
        result = self._values.get("sort")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def tag_filters(self) -> typing.Optional[typing.List[builtins.str]]:
        '''An array of tags to filter by.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#tag_filters Powerpack#tag_filters}
        '''
        result = self._values.get("tag_filters")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def text_filter(self) -> typing.Optional[builtins.str]:
        '''The text to use as a filter.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#text_filter Powerpack#text_filter}
        '''
        result = self._values.get("text_filter")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetToplistDefinitionRequestQueryProcessQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetToplistDefinitionRequestQueryProcessQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestQueryProcessQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4c07fab5377c1f4dad94ed9a53062263bd208596e431773eb0149acbfbc400aa)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetAggregator")
    def reset_aggregator(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAggregator", []))

    @jsii.member(jsii_name="resetCrossOrgUuids")
    def reset_cross_org_uuids(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCrossOrgUuids", []))

    @jsii.member(jsii_name="resetIsNormalizedCpu")
    def reset_is_normalized_cpu(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetIsNormalizedCpu", []))

    @jsii.member(jsii_name="resetLimit")
    def reset_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLimit", []))

    @jsii.member(jsii_name="resetSort")
    def reset_sort(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSort", []))

    @jsii.member(jsii_name="resetTagFilters")
    def reset_tag_filters(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTagFilters", []))

    @jsii.member(jsii_name="resetTextFilter")
    def reset_text_filter(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTextFilter", []))

    @builtins.property
    @jsii.member(jsii_name="aggregatorInput")
    def aggregator_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregatorInput"))

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuidsInput")
    def cross_org_uuids_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "crossOrgUuidsInput"))

    @builtins.property
    @jsii.member(jsii_name="dataSourceInput")
    def data_source_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "dataSourceInput"))

    @builtins.property
    @jsii.member(jsii_name="isNormalizedCpuInput")
    def is_normalized_cpu_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "isNormalizedCpuInput"))

    @builtins.property
    @jsii.member(jsii_name="limitInput")
    def limit_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "limitInput"))

    @builtins.property
    @jsii.member(jsii_name="metricInput")
    def metric_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "metricInput"))

    @builtins.property
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property
    @jsii.member(jsii_name="sortInput")
    def sort_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "sortInput"))

    @builtins.property
    @jsii.member(jsii_name="tagFiltersInput")
    def tag_filters_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "tagFiltersInput"))

    @builtins.property
    @jsii.member(jsii_name="textFilterInput")
    def text_filter_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "textFilterInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregator")
    def aggregator(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregator"))

    @aggregator.setter
    def aggregator(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1a35bd7d9cc30f715ec6f158d6fa64f6195f479d20acc9b58ad731a2ab3f7fb6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregator", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuids")
    def cross_org_uuids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "crossOrgUuids"))

    @cross_org_uuids.setter
    def cross_org_uuids(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d18857d62b767da55ae83a3f5f15a11226a0a611f47d3387433d4d50f1c0cbbd)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "crossOrgUuids", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="dataSource")
    def data_source(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "dataSource"))

    @data_source.setter
    def data_source(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f44d36b0a2e8a0cbf2e19b7c0f7ea9511dfc10e7d2998681619217983bbeaeb6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "dataSource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="isNormalizedCpu")
    def is_normalized_cpu(
        self,
    ) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "isNormalizedCpu"))

    @is_normalized_cpu.setter
    def is_normalized_cpu(
        self,
        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b6c85e79cfed642d881d79f35755bf738521e721f520aaf7191859ac5c8c1983)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "isNormalizedCpu", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="limit")
    def limit(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "limit"))

    @limit.setter
    def limit(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__200aa63e083ecf9d50bd55031bb208e6c6273a3df933e2612ce84112698d0a53)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "limit", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="metric")
    def metric(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "metric"))

    @metric.setter
    def metric(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ebbe608fdd3fe529162211177769be066b4f26deb5d700fb9be6a47328ff5fa3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "metric", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5d34275df1f968277ce1aa86aea95cd72d73a18e6f2e8f3a02df9428fa8686bc)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "name", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="sort")
    def sort(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "sort"))

    @sort.setter
    def sort(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d1f4d8e2ac944518ffe7f4cc69e44cf10293a594732ae42469cafee7e1f7f912)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "sort", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="tagFilters")
    def tag_filters(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "tagFilters"))

    @tag_filters.setter
    def tag_filters(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ec9667f3f6772ff66aedcc202dc20ddbacdbf480bf7398e69da61d81828f324d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "tagFilters", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="textFilter")
    def text_filter(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "textFilter"))

    @text_filter.setter
    def text_filter(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7c50f98aa83789499138a122758fbdb06cee28ca439257a23fed6e792b34c21b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "textFilter", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetToplistDefinitionRequestQueryProcessQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetToplistDefinitionRequestQueryProcessQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetToplistDefinitionRequestQueryProcessQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6969d5ac75ef81d5e0e528805c73a88999eb858de365bdabd749222fac9d273c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestQuerySloQuery",
    jsii_struct_bases=[],
    name_mapping={
        "data_source": "dataSource",
        "measure": "measure",
        "slo_id": "sloId",
        "additional_query_filters": "additionalQueryFilters",
        "cross_org_uuids": "crossOrgUuids",
        "group_mode": "groupMode",
        "name": "name",
        "slo_query_type": "sloQueryType",
    },
)
class PowerpackWidgetToplistDefinitionRequestQuerySloQuery:
    def __init__(
        self,
        *,
        data_source: builtins.str,
        measure: builtins.str,
        slo_id: builtins.str,
        additional_query_filters: typing.Optional[builtins.str] = None,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        group_mode: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
        slo_query_type: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param data_source: The data source for SLO queries. Valid values are ``slo``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param measure: SLO measures queries. Valid values are ``good_events``, ``bad_events``, ``good_minutes``, ``bad_minutes``, ``slo_status``, ``error_budget_remaining``, ``burn_rate``, ``error_budget_burndown``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#measure Powerpack#measure}
        :param slo_id: ID of an SLO to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#slo_id Powerpack#slo_id}
        :param additional_query_filters: Additional filters applied to the SLO query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#additional_query_filters Powerpack#additional_query_filters}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param group_mode: Group mode to query measures. Valid values are ``overall``, ``components``. Defaults to ``"overall"``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_mode Powerpack#group_mode}
        :param name: The name of query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param slo_query_type: type of the SLO to query. Valid values are ``metric``, ``monitor``, ``time_slice``. Defaults to ``"metric"``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#slo_query_type Powerpack#slo_query_type}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5e5641d267d0d99f73a8f0a60651962de45d5953191a22235c9c6e25c116db7b)
            check_type(argname="argument data_source", value=data_source, expected_type=type_hints["data_source"])
            check_type(argname="argument measure", value=measure, expected_type=type_hints["measure"])
            check_type(argname="argument slo_id", value=slo_id, expected_type=type_hints["slo_id"])
            check_type(argname="argument additional_query_filters", value=additional_query_filters, expected_type=type_hints["additional_query_filters"])
            check_type(argname="argument cross_org_uuids", value=cross_org_uuids, expected_type=type_hints["cross_org_uuids"])
            check_type(argname="argument group_mode", value=group_mode, expected_type=type_hints["group_mode"])
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument slo_query_type", value=slo_query_type, expected_type=type_hints["slo_query_type"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "data_source": data_source,
            "measure": measure,
            "slo_id": slo_id,
        }
        if additional_query_filters is not None:
            self._values["additional_query_filters"] = additional_query_filters
        if cross_org_uuids is not None:
            self._values["cross_org_uuids"] = cross_org_uuids
        if group_mode is not None:
            self._values["group_mode"] = group_mode
        if name is not None:
            self._values["name"] = name
        if slo_query_type is not None:
            self._values["slo_query_type"] = slo_query_type

    @builtins.property
    def data_source(self) -> builtins.str:
        '''The data source for SLO queries. Valid values are ``slo``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        '''
        result = self._values.get("data_source")
        assert result is not None, "Required property 'data_source' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def measure(self) -> builtins.str:
        '''SLO measures queries. Valid values are ``good_events``, ``bad_events``, ``good_minutes``, ``bad_minutes``, ``slo_status``, ``error_budget_remaining``, ``burn_rate``, ``error_budget_burndown``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#measure Powerpack#measure}
        '''
        result = self._values.get("measure")
        assert result is not None, "Required property 'measure' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def slo_id(self) -> builtins.str:
        '''ID of an SLO to query.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#slo_id Powerpack#slo_id}
        '''
        result = self._values.get("slo_id")
        assert result is not None, "Required property 'slo_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def additional_query_filters(self) -> typing.Optional[builtins.str]:
        '''Additional filters applied to the SLO query.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#additional_query_filters Powerpack#additional_query_filters}
        '''
        result = self._values.get("additional_query_filters")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def cross_org_uuids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''The source organization UUID for cross organization queries. Feature in Private Beta.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        '''
        result = self._values.get("cross_org_uuids")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def group_mode(self) -> typing.Optional[builtins.str]:
        '''Group mode to query measures. Valid values are ``overall``, ``components``. Defaults to ``"overall"``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_mode Powerpack#group_mode}
        '''
        result = self._values.get("group_mode")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''The name of query for use in formulas.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        '''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def slo_query_type(self) -> typing.Optional[builtins.str]:
        '''type of the SLO to query. Valid values are ``metric``, ``monitor``, ``time_slice``. Defaults to ``"metric"``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#slo_query_type Powerpack#slo_query_type}
        '''
        result = self._values.get("slo_query_type")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetToplistDefinitionRequestQuerySloQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetToplistDefinitionRequestQuerySloQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestQuerySloQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3135e8b147bd24e2a098afe8232b8e7d82ba95c877e8181237caf8fd7fcd9b61)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetAdditionalQueryFilters")
    def reset_additional_query_filters(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAdditionalQueryFilters", []))

    @jsii.member(jsii_name="resetCrossOrgUuids")
    def reset_cross_org_uuids(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCrossOrgUuids", []))

    @jsii.member(jsii_name="resetGroupMode")
    def reset_group_mode(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGroupMode", []))

    @jsii.member(jsii_name="resetName")
    def reset_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetName", []))

    @jsii.member(jsii_name="resetSloQueryType")
    def reset_slo_query_type(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSloQueryType", []))

    @builtins.property
    @jsii.member(jsii_name="additionalQueryFiltersInput")
    def additional_query_filters_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "additionalQueryFiltersInput"))

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuidsInput")
    def cross_org_uuids_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "crossOrgUuidsInput"))

    @builtins.property
    @jsii.member(jsii_name="dataSourceInput")
    def data_source_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "dataSourceInput"))

    @builtins.property
    @jsii.member(jsii_name="groupModeInput")
    def group_mode_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "groupModeInput"))

    @builtins.property
    @jsii.member(jsii_name="measureInput")
    def measure_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "measureInput"))

    @builtins.property
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property
    @jsii.member(jsii_name="sloIdInput")
    def slo_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "sloIdInput"))

    @builtins.property
    @jsii.member(jsii_name="sloQueryTypeInput")
    def slo_query_type_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "sloQueryTypeInput"))

    @builtins.property
    @jsii.member(jsii_name="additionalQueryFilters")
    def additional_query_filters(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "additionalQueryFilters"))

    @additional_query_filters.setter
    def additional_query_filters(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8c533ea5d069659494332b0df2ab5967ed5a32639610c7eef75416f18e7a4e02)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "additionalQueryFilters", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuids")
    def cross_org_uuids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "crossOrgUuids"))

    @cross_org_uuids.setter
    def cross_org_uuids(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3d0b70321c1976bea6e66e76643e81bfc4c8311c250c45003313956f50909a59)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "crossOrgUuids", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="dataSource")
    def data_source(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "dataSource"))

    @data_source.setter
    def data_source(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cbd53ebaa4b8da08b5f9792c956d7113c80df29c5bedbfcf646a6e8d9fc2068e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "dataSource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="groupMode")
    def group_mode(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "groupMode"))

    @group_mode.setter
    def group_mode(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9366c8b13c7c57096529839cbd29dfebf143e8b9131293419260193ca5435851)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "groupMode", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="measure")
    def measure(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "measure"))

    @measure.setter
    def measure(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__47c6a5b31931e4aad10d5b39d47a5fb281a46c6781449f07cab6a9ce27a2c00e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "measure", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6e483e8cde6f672451b4fb1d1726be6aa80a84895e37e5e732d7938677e47013)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "name", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="sloId")
    def slo_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "sloId"))

    @slo_id.setter
    def slo_id(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1c200a7e153cd7d3df3185b99a088f5d81e1500f068db34107a0ca1e86f5a955)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "sloId", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="sloQueryType")
    def slo_query_type(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "sloQueryType"))

    @slo_query_type.setter
    def slo_query_type(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__89dac0f070591bb9ee11919f1eb18dfa689b3622f688011b449a17ab8b26f8de)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "sloQueryType", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetToplistDefinitionRequestQuerySloQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetToplistDefinitionRequestQuerySloQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetToplistDefinitionRequestQuerySloQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dd8b3562a1dc4d9348a6c5fae0ecb22d5ad4763365216b4319221e833787a7ea)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestRumQuery",
    jsii_struct_bases=[],
    name_mapping={
        "index": "index",
        "compute_query": "computeQuery",
        "group_by": "groupBy",
        "multi_compute": "multiCompute",
        "search_query": "searchQuery",
    },
)
class PowerpackWidgetToplistDefinitionRequestRumQuery:
    def __init__(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union["PowerpackWidgetToplistDefinitionRequestRumQueryComputeQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetToplistDefinitionRequestRumQueryGroupBy", typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetToplistDefinitionRequestRumQueryMultiCompute", typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        if isinstance(compute_query, dict):
            compute_query = PowerpackWidgetToplistDefinitionRequestRumQueryComputeQuery(**compute_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f07d5c62521a3bb453757ad2cfcf59f210bdd21726fbbeac39411b4e9976814b)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
            check_type(argname="argument compute_query", value=compute_query, expected_type=type_hints["compute_query"])
            check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
            check_type(argname="argument multi_compute", value=multi_compute, expected_type=type_hints["multi_compute"])
            check_type(argname="argument search_query", value=search_query, expected_type=type_hints["search_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "index": index,
        }
        if compute_query is not None:
            self._values["compute_query"] = compute_query
        if group_by is not None:
            self._values["group_by"] = group_by
        if multi_compute is not None:
            self._values["multi_compute"] = multi_compute
        if search_query is not None:
            self._values["search_query"] = search_query

    @builtins.property
    def index(self) -> builtins.str:
        '''The name of the index to query.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        '''
        result = self._values.get("index")
        assert result is not None, "Required property 'index' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def compute_query(
        self,
    ) -> typing.Optional["PowerpackWidgetToplistDefinitionRequestRumQueryComputeQuery"]:
        '''compute_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        '''
        result = self._values.get("compute_query")
        return typing.cast(typing.Optional["PowerpackWidgetToplistDefinitionRequestRumQueryComputeQuery"], result)

    @builtins.property
    def group_by(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetToplistDefinitionRequestRumQueryGroupBy"]]]:
        '''group_by block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        '''
        result = self._values.get("group_by")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetToplistDefinitionRequestRumQueryGroupBy"]]], result)

    @builtins.property
    def multi_compute(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetToplistDefinitionRequestRumQueryMultiCompute"]]]:
        '''multi_compute block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        '''
        result = self._values.get("multi_compute")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetToplistDefinitionRequestRumQueryMultiCompute"]]], result)

    @builtins.property
    def search_query(self) -> typing.Optional[builtins.str]:
        '''The search query to use.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        result = self._values.get("search_query")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetToplistDefinitionRequestRumQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestRumQueryComputeQuery",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetToplistDefinitionRequestRumQueryComputeQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b1a5d0b3cab212fe7ce2129a75ccefdd3bea3baed4dec8c1183c5df016ce88f3)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetToplistDefinitionRequestRumQueryComputeQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetToplistDefinitionRequestRumQueryComputeQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestRumQueryComputeQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__14a401f770f0f93d3bd7cb5ff7c3452ff216e65bea28f1466a02d174d7352e83)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d8b43e7fde65fedce3dd16c2834e0413631cdb8d2648df84398763d3aa6adaed)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a8a7e393120018cc59f555a244c39a1156722eeb15df2e52ca60fb6e492ddc69)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__61dd855316afdde7ef1915ef71ac86a1d4314d83c376e487b1b34b4e36c498c3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetToplistDefinitionRequestRumQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetToplistDefinitionRequestRumQueryComputeQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetToplistDefinitionRequestRumQueryComputeQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__317edbfc8a1029566870821892e18746e8ca732d990e7cbb29dad2308c84a191)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestRumQueryGroupBy",
    jsii_struct_bases=[],
    name_mapping={"facet": "facet", "limit": "limit", "sort_query": "sortQuery"},
)
class PowerpackWidgetToplistDefinitionRequestRumQueryGroupBy:
    def __init__(
        self,
        *,
        facet: typing.Optional[builtins.str] = None,
        limit: typing.Optional[jsii.Number] = None,
        sort_query: typing.Optional[typing.Union["PowerpackWidgetToplistDefinitionRequestRumQueryGroupBySortQuery", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param limit: The maximum number of items in the group. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param sort_query: sort_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        if isinstance(sort_query, dict):
            sort_query = PowerpackWidgetToplistDefinitionRequestRumQueryGroupBySortQuery(**sort_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c271d4e1aaeea3f51fee579a937d08e6db891d88b2cd9c3dcc78f88e58d966f1)
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
            check_type(argname="argument sort_query", value=sort_query, expected_type=type_hints["sort_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if facet is not None:
            self._values["facet"] = facet
        if limit is not None:
            self._values["limit"] = limit
        if sort_query is not None:
            self._values["sort_query"] = sort_query

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def limit(self) -> typing.Optional[jsii.Number]:
        '''The maximum number of items in the group.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        '''
        result = self._values.get("limit")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def sort_query(
        self,
    ) -> typing.Optional["PowerpackWidgetToplistDefinitionRequestRumQueryGroupBySortQuery"]:
        '''sort_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        result = self._values.get("sort_query")
        return typing.cast(typing.Optional["PowerpackWidgetToplistDefinitionRequestRumQueryGroupBySortQuery"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetToplistDefinitionRequestRumQueryGroupBy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetToplistDefinitionRequestRumQueryGroupByList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestRumQueryGroupByList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cd03c36d8e06d77347911c4566222f7708d285cbba3b3f9b69d4fc6c80ffd8e0)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetToplistDefinitionRequestRumQueryGroupByOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7ff68a475fad9b442a725ef809f881455aec348649f533572ddb23a88d6f4e18)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetToplistDefinitionRequestRumQueryGroupByOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__93fb4dab34363ad3b5100d4a1a37fd7b2f4d5ff12671672094adfcde4b81c963)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5568b02949b7539c7a7702f566cfaaebe7bfac0cf6854deb2beffe0fbf393ae0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__124bebd398108f97af8f5a7413225a2557b3921ad0fcf65029a67b17495274ba)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionRequestRumQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionRequestRumQueryGroupBy]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionRequestRumQueryGroupBy]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__36d9d5abe53ce1f3765031b508cd84706caa1d36a428c0232835ed40aa8052dc)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetToplistDefinitionRequestRumQueryGroupByOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestRumQueryGroupByOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6b849717cd2673c58ebec4802f8d01cd41d6d3c2450ec73254ac330dc663321a)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putSortQuery")
    def put_sort_query(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        value = PowerpackWidgetToplistDefinitionRequestRumQueryGroupBySortQuery(
            aggregation=aggregation, order=order, facet=facet
        )

        return typing.cast(None, jsii.invoke(self, "putSortQuery", [value]))

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetLimit")
    def reset_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLimit", []))

    @jsii.member(jsii_name="resetSortQuery")
    def reset_sort_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSortQuery", []))

    @builtins.property
    @jsii.member(jsii_name="sortQuery")
    def sort_query(
        self,
    ) -> "PowerpackWidgetToplistDefinitionRequestRumQueryGroupBySortQueryOutputReference":
        return typing.cast("PowerpackWidgetToplistDefinitionRequestRumQueryGroupBySortQueryOutputReference", jsii.get(self, "sortQuery"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="limitInput")
    def limit_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "limitInput"))

    @builtins.property
    @jsii.member(jsii_name="sortQueryInput")
    def sort_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetToplistDefinitionRequestRumQueryGroupBySortQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetToplistDefinitionRequestRumQueryGroupBySortQuery"], jsii.get(self, "sortQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9ee380871f466cb413256ce90dbe5dc07617e177504f8f617a745d7863038e55)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="limit")
    def limit(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "limit"))

    @limit.setter
    def limit(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__318168e01b2d30bc48994b3b4152bb958a7a8ae2953c2c74b174421afefa8cc4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "limit", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetToplistDefinitionRequestRumQueryGroupBy]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetToplistDefinitionRequestRumQueryGroupBy]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetToplistDefinitionRequestRumQueryGroupBy]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__22900ae7bc92f40f7f0967e6c74330e7cc0fb9a52645bdbb60d0fc04b8965ed8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestRumQueryGroupBySortQuery",
    jsii_struct_bases=[],
    name_mapping={"aggregation": "aggregation", "order": "order", "facet": "facet"},
)
class PowerpackWidgetToplistDefinitionRequestRumQueryGroupBySortQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e9160ae6a1a39081c2742c704c0ae30279bef5702aa7c701e811eeb53d947c36)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument order", value=order, expected_type=type_hints["order"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
            "order": order,
        }
        if facet is not None:
            self._values["facet"] = facet

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def order(self) -> builtins.str:
        '''Widget sorting methods. Valid values are ``asc``, ``desc``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        result = self._values.get("order")
        assert result is not None, "Required property 'order' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetToplistDefinitionRequestRumQueryGroupBySortQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetToplistDefinitionRequestRumQueryGroupBySortQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestRumQueryGroupBySortQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5176218588d423e475ad2665850a5d19b4edef79a6b5e7a4d941b6756584c4d9)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="orderInput")
    def order_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "orderInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5ebe20e988d2d116eae0daf617b717196702c0fb10dd80e0c8d836038c1c9555)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4f80a8ece8eaecdebcccb332ed1aa13cb024e2c86cab721be6ca5690a730a27a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="order")
    def order(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "order"))

    @order.setter
    def order(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dad6fc70b7bc27e62d964d8c3d4c2e720cc2a62dcb202315ce938dec417b92e4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "order", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetToplistDefinitionRequestRumQueryGroupBySortQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetToplistDefinitionRequestRumQueryGroupBySortQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetToplistDefinitionRequestRumQueryGroupBySortQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cd711031bdb69bb497f1b6f367a40aeb778909b8ddd02e918974ac1a714b1979)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestRumQueryMultiCompute",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetToplistDefinitionRequestRumQueryMultiCompute:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b1108a8be19e29fff379d1252d71ceb68b1a3d4601c08d7f9c118a580d68b8fd)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetToplistDefinitionRequestRumQueryMultiCompute(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetToplistDefinitionRequestRumQueryMultiComputeList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestRumQueryMultiComputeList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3c0b2eea3637b0eedb0617d8888598edcac222a212f3cb81b502086b23b8c789)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetToplistDefinitionRequestRumQueryMultiComputeOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__442b3c3cc07beb5668c153bfa4adde428c20d1c637ecdb6f5482ffcf8e3d20c9)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetToplistDefinitionRequestRumQueryMultiComputeOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__df3b003106c9a6bafa34a4c69a59f53b01728ddb7324dcc14d3b60fec271d0cc)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cf48c18956af271b5f91fd49ab8cdf17996aeb6e7277c78759be7e15d7b0e518)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__78c6bf8a20f92aa57ad3124c1c465af0d61f4a8916ef07ae6e06bdcf717c1aee)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionRequestRumQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionRequestRumQueryMultiCompute]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionRequestRumQueryMultiCompute]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c28133246a54931468d1e016f3f4c74ab32009f3e5250e699e3d3eab7af3f2cd)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetToplistDefinitionRequestRumQueryMultiComputeOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestRumQueryMultiComputeOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9823478e56e8c1d5774266e80738e6ef23c8134d0f158f0b37dc451586251324)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b8547f0f82ff872ed50b63991898752c6db3a560cff0442b2979402676015f8e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6b33b70f8d840279860fcac01993d1514734b62e23d60aca8d0b19a00c6886d7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e9bdd56d84ac1d37f47d3a13e4908c5ed3c90111433d01655914213e970aae8d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetToplistDefinitionRequestRumQueryMultiCompute]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetToplistDefinitionRequestRumQueryMultiCompute]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetToplistDefinitionRequestRumQueryMultiCompute]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9b07323c67f287941c1ccc583852c7e8ec1ffa25a9e186302309efee21061636)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetToplistDefinitionRequestRumQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestRumQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bd0526f8bf3d62c77a888976bca14293b5a4c0d572a16945571c33c9154a6225)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putComputeQuery")
    def put_compute_query(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        value = PowerpackWidgetToplistDefinitionRequestRumQueryComputeQuery(
            aggregation=aggregation, facet=facet, interval=interval
        )

        return typing.cast(None, jsii.invoke(self, "putComputeQuery", [value]))

    @jsii.member(jsii_name="putGroupBy")
    def put_group_by(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetToplistDefinitionRequestRumQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ab0854b6e7b9e0eb8b52d45e1cfa1290280b5d6cb4679a280ccaff36e763173b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putGroupBy", [value]))

    @jsii.member(jsii_name="putMultiCompute")
    def put_multi_compute(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetToplistDefinitionRequestRumQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3544325099098a366ca08d535d7247a90b4a8aa32f3da52eb62a4d82c7a040da)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putMultiCompute", [value]))

    @jsii.member(jsii_name="resetComputeQuery")
    def reset_compute_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetComputeQuery", []))

    @jsii.member(jsii_name="resetGroupBy")
    def reset_group_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGroupBy", []))

    @jsii.member(jsii_name="resetMultiCompute")
    def reset_multi_compute(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMultiCompute", []))

    @jsii.member(jsii_name="resetSearchQuery")
    def reset_search_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSearchQuery", []))

    @builtins.property
    @jsii.member(jsii_name="computeQuery")
    def compute_query(
        self,
    ) -> PowerpackWidgetToplistDefinitionRequestRumQueryComputeQueryOutputReference:
        return typing.cast(PowerpackWidgetToplistDefinitionRequestRumQueryComputeQueryOutputReference, jsii.get(self, "computeQuery"))

    @builtins.property
    @jsii.member(jsii_name="groupBy")
    def group_by(self) -> PowerpackWidgetToplistDefinitionRequestRumQueryGroupByList:
        return typing.cast(PowerpackWidgetToplistDefinitionRequestRumQueryGroupByList, jsii.get(self, "groupBy"))

    @builtins.property
    @jsii.member(jsii_name="multiCompute")
    def multi_compute(
        self,
    ) -> PowerpackWidgetToplistDefinitionRequestRumQueryMultiComputeList:
        return typing.cast(PowerpackWidgetToplistDefinitionRequestRumQueryMultiComputeList, jsii.get(self, "multiCompute"))

    @builtins.property
    @jsii.member(jsii_name="computeQueryInput")
    def compute_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetToplistDefinitionRequestRumQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetToplistDefinitionRequestRumQueryComputeQuery], jsii.get(self, "computeQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="groupByInput")
    def group_by_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionRequestRumQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionRequestRumQueryGroupBy]]], jsii.get(self, "groupByInput"))

    @builtins.property
    @jsii.member(jsii_name="indexInput")
    def index_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "indexInput"))

    @builtins.property
    @jsii.member(jsii_name="multiComputeInput")
    def multi_compute_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionRequestRumQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionRequestRumQueryMultiCompute]]], jsii.get(self, "multiComputeInput"))

    @builtins.property
    @jsii.member(jsii_name="searchQueryInput")
    def search_query_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "searchQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="index")
    def index(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "index"))

    @index.setter
    def index(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b2c73b2150dc127da2d131eca843dee4a216aeaf450db8b8183c5cf272892a8d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "index", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="searchQuery")
    def search_query(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "searchQuery"))

    @search_query.setter
    def search_query(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6d0b66a197358ad46ed7d4f5be42f6664301be38a123a227e78184a27d528ea9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "searchQuery", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetToplistDefinitionRequestRumQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetToplistDefinitionRequestRumQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetToplistDefinitionRequestRumQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7dd627760e20d0d7785cc3dc01082b366e4d07083ac609d65d8961b1b0b0407d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestSecurityQuery",
    jsii_struct_bases=[],
    name_mapping={
        "index": "index",
        "compute_query": "computeQuery",
        "group_by": "groupBy",
        "multi_compute": "multiCompute",
        "search_query": "searchQuery",
    },
)
class PowerpackWidgetToplistDefinitionRequestSecurityQuery:
    def __init__(
        self,
        *,
        index: builtins.str,
        compute_query: typing.Optional[typing.Union["PowerpackWidgetToplistDefinitionRequestSecurityQueryComputeQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetToplistDefinitionRequestSecurityQueryGroupBy", typing.Dict[builtins.str, typing.Any]]]]] = None,
        multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetToplistDefinitionRequestSecurityQueryMultiCompute", typing.Dict[builtins.str, typing.Any]]]]] = None,
        search_query: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param index: The name of the index to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        :param compute_query: compute_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param multi_compute: multi_compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        :param search_query: The search query to use. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        if isinstance(compute_query, dict):
            compute_query = PowerpackWidgetToplistDefinitionRequestSecurityQueryComputeQuery(**compute_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__08d0111e379f8b7425b28c6db6ac1a957ecd243fbdf36c8e3e3312ab619449d1)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
            check_type(argname="argument compute_query", value=compute_query, expected_type=type_hints["compute_query"])
            check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
            check_type(argname="argument multi_compute", value=multi_compute, expected_type=type_hints["multi_compute"])
            check_type(argname="argument search_query", value=search_query, expected_type=type_hints["search_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "index": index,
        }
        if compute_query is not None:
            self._values["compute_query"] = compute_query
        if group_by is not None:
            self._values["group_by"] = group_by
        if multi_compute is not None:
            self._values["multi_compute"] = multi_compute
        if search_query is not None:
            self._values["search_query"] = search_query

    @builtins.property
    def index(self) -> builtins.str:
        '''The name of the index to query.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#index Powerpack#index}
        '''
        result = self._values.get("index")
        assert result is not None, "Required property 'index' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def compute_query(
        self,
    ) -> typing.Optional["PowerpackWidgetToplistDefinitionRequestSecurityQueryComputeQuery"]:
        '''compute_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute_query Powerpack#compute_query}
        '''
        result = self._values.get("compute_query")
        return typing.cast(typing.Optional["PowerpackWidgetToplistDefinitionRequestSecurityQueryComputeQuery"], result)

    @builtins.property
    def group_by(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetToplistDefinitionRequestSecurityQueryGroupBy"]]]:
        '''group_by block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        '''
        result = self._values.get("group_by")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetToplistDefinitionRequestSecurityQueryGroupBy"]]], result)

    @builtins.property
    def multi_compute(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetToplistDefinitionRequestSecurityQueryMultiCompute"]]]:
        '''multi_compute block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#multi_compute Powerpack#multi_compute}
        '''
        result = self._values.get("multi_compute")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetToplistDefinitionRequestSecurityQueryMultiCompute"]]], result)

    @builtins.property
    def search_query(self) -> typing.Optional[builtins.str]:
        '''The search query to use.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search_query Powerpack#search_query}
        '''
        result = self._values.get("search_query")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetToplistDefinitionRequestSecurityQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestSecurityQueryComputeQuery",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetToplistDefinitionRequestSecurityQueryComputeQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a1bf775f9c5dca08f89bd33338499e93218795aa8ab09b78a0011317bacf5330)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetToplistDefinitionRequestSecurityQueryComputeQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetToplistDefinitionRequestSecurityQueryComputeQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestSecurityQueryComputeQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1697f1831f74a5abe0a3c6b7276487cb87f1ec2e862ec1e59d08c788e1834acf)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5f0699e3079fa9e024711bf71b12775f62b4869a4dd4ede9e9cf405308fe7cb2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fa00fa4fff139d68c454c3d07973c065477900ac3c3d5f2d81edc015eba598a5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__385efc2650d57c0210efce11b214593755f67fdc565be6d56fb56c771e4a381f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetToplistDefinitionRequestSecurityQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetToplistDefinitionRequestSecurityQueryComputeQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetToplistDefinitionRequestSecurityQueryComputeQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6b4709ce2ade041c075cfdbe3b116c415ea8337ff3b1d9ec3d41f3a882c02973)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestSecurityQueryGroupBy",
    jsii_struct_bases=[],
    name_mapping={"facet": "facet", "limit": "limit", "sort_query": "sortQuery"},
)
class PowerpackWidgetToplistDefinitionRequestSecurityQueryGroupBy:
    def __init__(
        self,
        *,
        facet: typing.Optional[builtins.str] = None,
        limit: typing.Optional[jsii.Number] = None,
        sort_query: typing.Optional[typing.Union["PowerpackWidgetToplistDefinitionRequestSecurityQueryGroupBySortQuery", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param limit: The maximum number of items in the group. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param sort_query: sort_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        if isinstance(sort_query, dict):
            sort_query = PowerpackWidgetToplistDefinitionRequestSecurityQueryGroupBySortQuery(**sort_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b9798c476e9c739268497453641443263569c404d9de587b34bb953da1f88175)
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
            check_type(argname="argument sort_query", value=sort_query, expected_type=type_hints["sort_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if facet is not None:
            self._values["facet"] = facet
        if limit is not None:
            self._values["limit"] = limit
        if sort_query is not None:
            self._values["sort_query"] = sort_query

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def limit(self) -> typing.Optional[jsii.Number]:
        '''The maximum number of items in the group.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        '''
        result = self._values.get("limit")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def sort_query(
        self,
    ) -> typing.Optional["PowerpackWidgetToplistDefinitionRequestSecurityQueryGroupBySortQuery"]:
        '''sort_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort_query Powerpack#sort_query}
        '''
        result = self._values.get("sort_query")
        return typing.cast(typing.Optional["PowerpackWidgetToplistDefinitionRequestSecurityQueryGroupBySortQuery"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetToplistDefinitionRequestSecurityQueryGroupBy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetToplistDefinitionRequestSecurityQueryGroupByList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestSecurityQueryGroupByList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__391d568851d2b7463a3b1015eebf495c4b0a5c1df55190e5ab61cd831092406f)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetToplistDefinitionRequestSecurityQueryGroupByOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e725df86bae523c013f56190c030c11d7042dc9d764480fba7b1b4a055454684)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetToplistDefinitionRequestSecurityQueryGroupByOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__89c3ceaa265a2659c09e7e4030ec40c5c237124a35823e23efe4cea40abad4b5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__abaf37c8df929604bcee9c9737ae236d857e619f2519508452b133001ef5645d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__be9cdae9d787ff5656cff2d0105aa5178532e6d1d098575799bcc4986f40d186)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionRequestSecurityQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionRequestSecurityQueryGroupBy]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionRequestSecurityQueryGroupBy]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ad204541e4ab4b116dc42877e8249c24117e30ce536b335291fcc2e8aee28d1a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetToplistDefinitionRequestSecurityQueryGroupByOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestSecurityQueryGroupByOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__87321135a144159e5bbc8c556c260abad7853e89a6e5794e9b90f12a9a26a3f1)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putSortQuery")
    def put_sort_query(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        value = PowerpackWidgetToplistDefinitionRequestSecurityQueryGroupBySortQuery(
            aggregation=aggregation, order=order, facet=facet
        )

        return typing.cast(None, jsii.invoke(self, "putSortQuery", [value]))

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetLimit")
    def reset_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLimit", []))

    @jsii.member(jsii_name="resetSortQuery")
    def reset_sort_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSortQuery", []))

    @builtins.property
    @jsii.member(jsii_name="sortQuery")
    def sort_query(
        self,
    ) -> "PowerpackWidgetToplistDefinitionRequestSecurityQueryGroupBySortQueryOutputReference":
        return typing.cast("PowerpackWidgetToplistDefinitionRequestSecurityQueryGroupBySortQueryOutputReference", jsii.get(self, "sortQuery"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="limitInput")
    def limit_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "limitInput"))

    @builtins.property
    @jsii.member(jsii_name="sortQueryInput")
    def sort_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetToplistDefinitionRequestSecurityQueryGroupBySortQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetToplistDefinitionRequestSecurityQueryGroupBySortQuery"], jsii.get(self, "sortQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__014ea717a3571df31d578076109c0f51748294e13c620f23a92b475925568574)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="limit")
    def limit(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "limit"))

    @limit.setter
    def limit(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e2e7c88fbd30a9bc3cac63ad0d189a4a3288e29b6d0cb9c1a6fed9e14b24b4bb)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "limit", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetToplistDefinitionRequestSecurityQueryGroupBy]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetToplistDefinitionRequestSecurityQueryGroupBy]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetToplistDefinitionRequestSecurityQueryGroupBy]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d83744ff89f15890a8531229edecb3941abeeb0493a1e95f7e3a4af64ad2e3f1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestSecurityQueryGroupBySortQuery",
    jsii_struct_bases=[],
    name_mapping={"aggregation": "aggregation", "order": "order", "facet": "facet"},
)
class PowerpackWidgetToplistDefinitionRequestSecurityQueryGroupBySortQuery:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        order: builtins.str,
        facet: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param order: Widget sorting methods. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__434d4ec5105440ce6760be7e683d0790641a179de590c81580d9f98b79ee2886)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument order", value=order, expected_type=type_hints["order"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
            "order": order,
        }
        if facet is not None:
            self._values["facet"] = facet

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def order(self) -> builtins.str:
        '''Widget sorting methods. Valid values are ``asc``, ``desc``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        result = self._values.get("order")
        assert result is not None, "Required property 'order' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetToplistDefinitionRequestSecurityQueryGroupBySortQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetToplistDefinitionRequestSecurityQueryGroupBySortQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestSecurityQueryGroupBySortQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__397744ab8231d8e819bca1b64228987c24df4160d585eeaccf35466c3d5b8895)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="orderInput")
    def order_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "orderInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8f5dd8faa893ea62a27d28d53bffdaa518f44af1ff4b327acd20efe4d3e364c5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cd47cbe4d6b0b8b0163f635e7fd83b1cd97200a18bdcce2c30fe0041e509b55f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="order")
    def order(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "order"))

    @order.setter
    def order(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d113c895a66c56a16607e52884deed0d1752064e574753ecfbaa0f5561b7fa3a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "order", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetToplistDefinitionRequestSecurityQueryGroupBySortQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetToplistDefinitionRequestSecurityQueryGroupBySortQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetToplistDefinitionRequestSecurityQueryGroupBySortQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e3b0c3ee5643bde603f7eac0ec3f26e1f156a6b40117438434febe63176ed929)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestSecurityQueryMultiCompute",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "facet": "facet",
        "interval": "interval",
    },
)
class PowerpackWidgetToplistDefinitionRequestSecurityQueryMultiCompute:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__66e42c587239b148cde16756acdf1963305aa1170a5588759500d2603ff5ddb4)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if facet is not None:
            self._values["facet"] = facet
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation method.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def facet(self) -> typing.Optional[builtins.str]:
        '''The facet name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Define the time interval in seconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetToplistDefinitionRequestSecurityQueryMultiCompute(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetToplistDefinitionRequestSecurityQueryMultiComputeList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestSecurityQueryMultiComputeList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ad92111dd1c531b4f0e7bb933dcedcfa3658d2d7202f22a352819d84e9e8a242)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetToplistDefinitionRequestSecurityQueryMultiComputeOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a7e422e0e679fd9215c3cf64cd2bae3d77721e4dc3a2434d9ad79affec7fffa8)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetToplistDefinitionRequestSecurityQueryMultiComputeOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__842b58117842eeb44c31a88cee02eaf5bd716d5a080e9ad63906fdfee2864511)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__da3d1fbf4f89100ac351f267ec00f4edc1cd3559d748850dd29f54a32e04a656)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e109b325038fcfd85391eb67afc8604a59be6a9a733ed2ee272c529041c672fd)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionRequestSecurityQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionRequestSecurityQueryMultiCompute]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionRequestSecurityQueryMultiCompute]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cb8aa3040a9a83dd5a7549ba29fe35959a89036b9ec4f5e30c06b334d8ddedd0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetToplistDefinitionRequestSecurityQueryMultiComputeOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestSecurityQueryMultiComputeOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__74830e576fe4e2d870e4eecb467666dc95fe466c9e908649a97780b113c65ceb)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetFacet")
    def reset_facet(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFacet", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b01e8328473c38b907bbabc1e1aa4887808fc68faba9cf9c57be1378466d0b1a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ffcd395ca0f8a6e5d27a29c4a54006bcc32f34af0df9867db138ed2dc6ae6a48)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__80c24defd63c23ae2b75bac4dc14bbb428b47d376bdb8e844df601f28ed5df3c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetToplistDefinitionRequestSecurityQueryMultiCompute]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetToplistDefinitionRequestSecurityQueryMultiCompute]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetToplistDefinitionRequestSecurityQueryMultiCompute]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__33682fa86bb0ce4c148d703f0a378762d356d7d53f766b39a7d0fdb33ee806e1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetToplistDefinitionRequestSecurityQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestSecurityQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ed6afecd198b344301d1b1a9a1dc4d8b0456c3dfb9f20c6a763d5efd46e77ef7)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putComputeQuery")
    def put_compute_query(
        self,
        *,
        aggregation: builtins.str,
        facet: typing.Optional[builtins.str] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation method. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param facet: The facet name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param interval: Define the time interval in seconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        value = PowerpackWidgetToplistDefinitionRequestSecurityQueryComputeQuery(
            aggregation=aggregation, facet=facet, interval=interval
        )

        return typing.cast(None, jsii.invoke(self, "putComputeQuery", [value]))

    @jsii.member(jsii_name="putGroupBy")
    def put_group_by(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetToplistDefinitionRequestSecurityQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__09345a207fa80ff27d57b6832bfe666b13039f7839eee6616fc2c24519e6d6ad)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putGroupBy", [value]))

    @jsii.member(jsii_name="putMultiCompute")
    def put_multi_compute(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetToplistDefinitionRequestSecurityQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__095865b9375cad2f7e87fefe12aef070dab72ca2d34835a68878a16f4f951404)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putMultiCompute", [value]))

    @jsii.member(jsii_name="resetComputeQuery")
    def reset_compute_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetComputeQuery", []))

    @jsii.member(jsii_name="resetGroupBy")
    def reset_group_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGroupBy", []))

    @jsii.member(jsii_name="resetMultiCompute")
    def reset_multi_compute(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMultiCompute", []))

    @jsii.member(jsii_name="resetSearchQuery")
    def reset_search_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSearchQuery", []))

    @builtins.property
    @jsii.member(jsii_name="computeQuery")
    def compute_query(
        self,
    ) -> PowerpackWidgetToplistDefinitionRequestSecurityQueryComputeQueryOutputReference:
        return typing.cast(PowerpackWidgetToplistDefinitionRequestSecurityQueryComputeQueryOutputReference, jsii.get(self, "computeQuery"))

    @builtins.property
    @jsii.member(jsii_name="groupBy")
    def group_by(
        self,
    ) -> PowerpackWidgetToplistDefinitionRequestSecurityQueryGroupByList:
        return typing.cast(PowerpackWidgetToplistDefinitionRequestSecurityQueryGroupByList, jsii.get(self, "groupBy"))

    @builtins.property
    @jsii.member(jsii_name="multiCompute")
    def multi_compute(
        self,
    ) -> PowerpackWidgetToplistDefinitionRequestSecurityQueryMultiComputeList:
        return typing.cast(PowerpackWidgetToplistDefinitionRequestSecurityQueryMultiComputeList, jsii.get(self, "multiCompute"))

    @builtins.property
    @jsii.member(jsii_name="computeQueryInput")
    def compute_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetToplistDefinitionRequestSecurityQueryComputeQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetToplistDefinitionRequestSecurityQueryComputeQuery], jsii.get(self, "computeQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="groupByInput")
    def group_by_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionRequestSecurityQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionRequestSecurityQueryGroupBy]]], jsii.get(self, "groupByInput"))

    @builtins.property
    @jsii.member(jsii_name="indexInput")
    def index_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "indexInput"))

    @builtins.property
    @jsii.member(jsii_name="multiComputeInput")
    def multi_compute_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionRequestSecurityQueryMultiCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionRequestSecurityQueryMultiCompute]]], jsii.get(self, "multiComputeInput"))

    @builtins.property
    @jsii.member(jsii_name="searchQueryInput")
    def search_query_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "searchQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="index")
    def index(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "index"))

    @index.setter
    def index(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dbde6bcaf102689602692cb70d86373c0ee75f2fdbb63845ad82ef2886ce8be3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "index", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="searchQuery")
    def search_query(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "searchQuery"))

    @search_query.setter
    def search_query(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a9bb718b17535ebbca00766533bdbeb4165196a54be0ebebfa9656752928bc40)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "searchQuery", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetToplistDefinitionRequestSecurityQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetToplistDefinitionRequestSecurityQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetToplistDefinitionRequestSecurityQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1934cef43f6a6111987fdddcf37cf8c47b63eb617284191972022943e78ed3aa)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestStyle",
    jsii_struct_bases=[],
    name_mapping={"palette": "palette"},
)
class PowerpackWidgetToplistDefinitionRequestStyle:
    def __init__(self, *, palette: typing.Optional[builtins.str] = None) -> None:
        '''
        :param palette: A color palette to apply to the widget. The available options are available at: https://docs.datadoghq.com/dashboards/widgets/timeseries/#appearance. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette Powerpack#palette}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e264778977ad83cd690e04d323532dda9b324a904019991c2f03e27e97cb3801)
            check_type(argname="argument palette", value=palette, expected_type=type_hints["palette"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if palette is not None:
            self._values["palette"] = palette

    @builtins.property
    def palette(self) -> typing.Optional[builtins.str]:
        '''A color palette to apply to the widget. The available options are available at: https://docs.datadoghq.com/dashboards/widgets/timeseries/#appearance.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette Powerpack#palette}
        '''
        result = self._values.get("palette")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetToplistDefinitionRequestStyle(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetToplistDefinitionRequestStyleOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionRequestStyleOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0881aa8ce092adb488b08dc8199afd2db7fa7931e2c470adbc8c8133c8f8bd7a)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetPalette")
    def reset_palette(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPalette", []))

    @builtins.property
    @jsii.member(jsii_name="paletteInput")
    def palette_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "paletteInput"))

    @builtins.property
    @jsii.member(jsii_name="palette")
    def palette(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "palette"))

    @palette.setter
    def palette(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__42ea96bd0790a7fcc6b293e39b35aab4fa54259327b00f806549f6bc51431a1f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "palette", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetToplistDefinitionRequestStyle]:
        return typing.cast(typing.Optional[PowerpackWidgetToplistDefinitionRequestStyle], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetToplistDefinitionRequestStyle],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f44ee46c41b47575c7433c18bc391a6def608436689a29f6c63043b2c0db707c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionStyle",
    jsii_struct_bases=[],
    name_mapping={"display": "display", "palette": "palette", "scaling": "scaling"},
)
class PowerpackWidgetToplistDefinitionStyle:
    def __init__(
        self,
        *,
        display: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetToplistDefinitionStyleDisplay", typing.Dict[builtins.str, typing.Any]]]]] = None,
        palette: typing.Optional[builtins.str] = None,
        scaling: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param display: display block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#display Powerpack#display}
        :param palette: The color palette for the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette Powerpack#palette}
        :param scaling: The scaling mode for the widget. Valid values are ``absolute``, ``relative``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#scaling Powerpack#scaling}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__29e105282ccc931d67fd981ce421173fb79c08829e63067e982d9a7769717737)
            check_type(argname="argument display", value=display, expected_type=type_hints["display"])
            check_type(argname="argument palette", value=palette, expected_type=type_hints["palette"])
            check_type(argname="argument scaling", value=scaling, expected_type=type_hints["scaling"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if display is not None:
            self._values["display"] = display
        if palette is not None:
            self._values["palette"] = palette
        if scaling is not None:
            self._values["scaling"] = scaling

    @builtins.property
    def display(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetToplistDefinitionStyleDisplay"]]]:
        '''display block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#display Powerpack#display}
        '''
        result = self._values.get("display")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetToplistDefinitionStyleDisplay"]]], result)

    @builtins.property
    def palette(self) -> typing.Optional[builtins.str]:
        '''The color palette for the widget.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette Powerpack#palette}
        '''
        result = self._values.get("palette")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def scaling(self) -> typing.Optional[builtins.str]:
        '''The scaling mode for the widget. Valid values are ``absolute``, ``relative``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#scaling Powerpack#scaling}
        '''
        result = self._values.get("scaling")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetToplistDefinitionStyle(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionStyleDisplay",
    jsii_struct_bases=[],
    name_mapping={"type": "type"},
)
class PowerpackWidgetToplistDefinitionStyleDisplay:
    def __init__(self, *, type: builtins.str) -> None:
        '''
        :param type: The display type for the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#type Powerpack#type}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__26ef2cee1a4b5451dddb0a7ab49326297d8201e97f413362ad0acdec8dd98dda)
            check_type(argname="argument type", value=type, expected_type=type_hints["type"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "type": type,
        }

    @builtins.property
    def type(self) -> builtins.str:
        '''The display type for the widget.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#type Powerpack#type}
        '''
        result = self._values.get("type")
        assert result is not None, "Required property 'type' is missing"
        return typing.cast(builtins.str, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetToplistDefinitionStyleDisplay(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetToplistDefinitionStyleDisplayList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionStyleDisplayList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c50427ddfb097fb923d347f8eb5bcbfc2f15fcf73a75256b75dd2aa2b61c350e)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetToplistDefinitionStyleDisplayOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f7629a8f255a169ffb8a499df0cd1c9ed9d0b31a483dadfbe4fe081be94dca35)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetToplistDefinitionStyleDisplayOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__675f8d1f0178c5cf0d97fa2e49e38a966e5171ced7f3ee085b619a9020970907)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b91b6f896cda8b893624e8c3cf6a5cd20efe74e9cd21d7366cbb838358b72d32)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dea07f074eb851fed2a33f506f0ff876b1507318d8f03b9ee9dcfc40de5c0514)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionStyleDisplay]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionStyleDisplay]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionStyleDisplay]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4a70b92cabc07be3e5017e008024b22ee52bf2a8c6f0f0af5bb7fd8524d85539)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetToplistDefinitionStyleDisplayOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionStyleDisplayOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f0ee9fe3b401f1fbacf9c917e2fbcf44217c240727a24aaa7767bab322516c76)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property
    @jsii.member(jsii_name="typeInput")
    def type_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "typeInput"))

    @builtins.property
    @jsii.member(jsii_name="type")
    def type(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "type"))

    @type.setter
    def type(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5831d647275e74842f5fe47285d6e47cb25e41c8aee71de419907a732d731314)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "type", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetToplistDefinitionStyleDisplay]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetToplistDefinitionStyleDisplay]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetToplistDefinitionStyleDisplay]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ab6b7fc32b1e93db047785d122f38e917fc0563c945eb0bca5881b595efa7e26)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetToplistDefinitionStyleList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionStyleList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a30cc5199bab473f84718924056c1e8ad9603219b136e014475807876c184ccb)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetToplistDefinitionStyleOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d532fb6b2d8c98d427b213efdecf09484dba595ac6d8e42fdfa34c2ff2288f9e)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetToplistDefinitionStyleOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cc8a2affbf176ca8aeabad2175e2f9033d17525ad6a2d360186e916ac116efec)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__875f17fb3614ed13b56655361f7049325dea356bdc4a6d9b1e4a67c98b50b1b6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e09117da0ccd35a7a17862804fb201ae0c2a81a017575bbe7c190890eed95084)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionStyle]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionStyle]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionStyle]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__51ecbc040e42fb5b5225a759046885061add59fd3ee4cc22911fa60b43662986)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetToplistDefinitionStyleOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetToplistDefinitionStyleOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f46fc6a9684fae9e9140e5c09d9013289da3d59f478d2f8fb60fae8f32c9ebb7)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putDisplay")
    def put_display(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetToplistDefinitionStyleDisplay, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3d58186aebb3f828bfb33ff1a370d15050fd6492222c4c7c5e0a4dc1787fb593)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putDisplay", [value]))

    @jsii.member(jsii_name="resetDisplay")
    def reset_display(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDisplay", []))

    @jsii.member(jsii_name="resetPalette")
    def reset_palette(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPalette", []))

    @jsii.member(jsii_name="resetScaling")
    def reset_scaling(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetScaling", []))

    @builtins.property
    @jsii.member(jsii_name="display")
    def display(self) -> PowerpackWidgetToplistDefinitionStyleDisplayList:
        return typing.cast(PowerpackWidgetToplistDefinitionStyleDisplayList, jsii.get(self, "display"))

    @builtins.property
    @jsii.member(jsii_name="displayInput")
    def display_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionStyleDisplay]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionStyleDisplay]]], jsii.get(self, "displayInput"))

    @builtins.property
    @jsii.member(jsii_name="paletteInput")
    def palette_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "paletteInput"))

    @builtins.property
    @jsii.member(jsii_name="scalingInput")
    def scaling_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "scalingInput"))

    @builtins.property
    @jsii.member(jsii_name="palette")
    def palette(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "palette"))

    @palette.setter
    def palette(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1584d8e4b25d58c8fe9de5113dccfac3f29bbd063d30aac2c716e1ab4594fabd)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "palette", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="scaling")
    def scaling(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "scaling"))

    @scaling.setter
    def scaling(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__44abb6ce012f2f765fcf3638581731d7eb65575cb3fb65a848b28d90b2375111)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "scaling", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetToplistDefinitionStyle]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetToplistDefinitionStyle]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetToplistDefinitionStyle]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6670674715d87d33d7c2e3bebc46f14b6523b12d1443dea8a87442934c3e019b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTopologyMapDefinition",
    jsii_struct_bases=[],
    name_mapping={
        "custom_link": "customLink",
        "request": "request",
        "title": "title",
        "title_align": "titleAlign",
        "title_size": "titleSize",
    },
)
class PowerpackWidgetTopologyMapDefinition:
    def __init__(
        self,
        *,
        custom_link: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetTopologyMapDefinitionCustomLink", typing.Dict[builtins.str, typing.Any]]]]] = None,
        request: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetTopologyMapDefinitionRequest", typing.Dict[builtins.str, typing.Any]]]]] = None,
        title: typing.Optional[builtins.str] = None,
        title_align: typing.Optional[builtins.str] = None,
        title_size: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param custom_link: custom_link block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom_link Powerpack#custom_link}
        :param request: request block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#request Powerpack#request}
        :param title: The title of the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title Powerpack#title}
        :param title_align: The alignment of the widget's title. Valid values are ``center``, ``left``, ``right``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_align Powerpack#title_align}
        :param title_size: The size of the widget's title (defaults to 16). Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_size Powerpack#title_size}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e860e5fb9de3528e02c41a6e2780e5183b953b22838d72aac38d70186bbe8ea9)
            check_type(argname="argument custom_link", value=custom_link, expected_type=type_hints["custom_link"])
            check_type(argname="argument request", value=request, expected_type=type_hints["request"])
            check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            check_type(argname="argument title_align", value=title_align, expected_type=type_hints["title_align"])
            check_type(argname="argument title_size", value=title_size, expected_type=type_hints["title_size"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if custom_link is not None:
            self._values["custom_link"] = custom_link
        if request is not None:
            self._values["request"] = request
        if title is not None:
            self._values["title"] = title
        if title_align is not None:
            self._values["title_align"] = title_align
        if title_size is not None:
            self._values["title_size"] = title_size

    @builtins.property
    def custom_link(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetTopologyMapDefinitionCustomLink"]]]:
        '''custom_link block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom_link Powerpack#custom_link}
        '''
        result = self._values.get("custom_link")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetTopologyMapDefinitionCustomLink"]]], result)

    @builtins.property
    def request(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetTopologyMapDefinitionRequest"]]]:
        '''request block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#request Powerpack#request}
        '''
        result = self._values.get("request")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetTopologyMapDefinitionRequest"]]], result)

    @builtins.property
    def title(self) -> typing.Optional[builtins.str]:
        '''The title of the widget.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title Powerpack#title}
        '''
        result = self._values.get("title")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def title_align(self) -> typing.Optional[builtins.str]:
        '''The alignment of the widget's title. Valid values are ``center``, ``left``, ``right``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_align Powerpack#title_align}
        '''
        result = self._values.get("title_align")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def title_size(self) -> typing.Optional[builtins.str]:
        '''The size of the widget's title (defaults to 16).

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_size Powerpack#title_size}
        '''
        result = self._values.get("title_size")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetTopologyMapDefinition(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTopologyMapDefinitionCustomLink",
    jsii_struct_bases=[],
    name_mapping={
        "is_hidden": "isHidden",
        "label": "label",
        "link": "link",
        "override_label": "overrideLabel",
    },
)
class PowerpackWidgetTopologyMapDefinitionCustomLink:
    def __init__(
        self,
        *,
        is_hidden: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        label: typing.Optional[builtins.str] = None,
        link: typing.Optional[builtins.str] = None,
        override_label: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param is_hidden: The flag for toggling context menu link visibility. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#is_hidden Powerpack#is_hidden}
        :param label: The label for the custom link URL. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#label Powerpack#label}
        :param link: The URL of the custom link. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#link Powerpack#link}
        :param override_label: The label ID that refers to a context menu link item. When ``override_label`` is provided, the client request omits the label field. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#override_label Powerpack#override_label}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__33c9d75c7b14743607e6415d2dab4d0ec917881a6dfc3de5d1d519eac27d34ab)
            check_type(argname="argument is_hidden", value=is_hidden, expected_type=type_hints["is_hidden"])
            check_type(argname="argument label", value=label, expected_type=type_hints["label"])
            check_type(argname="argument link", value=link, expected_type=type_hints["link"])
            check_type(argname="argument override_label", value=override_label, expected_type=type_hints["override_label"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if is_hidden is not None:
            self._values["is_hidden"] = is_hidden
        if label is not None:
            self._values["label"] = label
        if link is not None:
            self._values["link"] = link
        if override_label is not None:
            self._values["override_label"] = override_label

    @builtins.property
    def is_hidden(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        '''The flag for toggling context menu link visibility.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#is_hidden Powerpack#is_hidden}
        '''
        result = self._values.get("is_hidden")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)

    @builtins.property
    def label(self) -> typing.Optional[builtins.str]:
        '''The label for the custom link URL.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#label Powerpack#label}
        '''
        result = self._values.get("label")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def link(self) -> typing.Optional[builtins.str]:
        '''The URL of the custom link.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#link Powerpack#link}
        '''
        result = self._values.get("link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def override_label(self) -> typing.Optional[builtins.str]:
        '''The label ID that refers to a context menu link item.

        When ``override_label`` is provided, the client request omits the label field.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#override_label Powerpack#override_label}
        '''
        result = self._values.get("override_label")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetTopologyMapDefinitionCustomLink(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetTopologyMapDefinitionCustomLinkList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTopologyMapDefinitionCustomLinkList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6cb12d8686c987127c6980ca7902e79098c36f25e058692167633955e84dc25e)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetTopologyMapDefinitionCustomLinkOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__24005f5ba1d6e70c7b9f6c76ab4a04d2bdbdcae556f42a44afeb893be2168a12)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetTopologyMapDefinitionCustomLinkOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6af44975114069c2d295c255359192e51f4617113221699f27e974757af9382a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8ccf8280ae99885b7189f16143b1c98cdea13ff3bffa62118c78cb6969fc094f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7de45d34d34c93dc744d7474d30db257288ed226f3b9bd2ad36dc2923016bc03)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTopologyMapDefinitionCustomLink]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTopologyMapDefinitionCustomLink]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTopologyMapDefinitionCustomLink]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1cc2ce483ff78d26192bb2803590ba93f9c8da618e9614f39d00b56c61ee4cb4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetTopologyMapDefinitionCustomLinkOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTopologyMapDefinitionCustomLinkOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__26aa46c4f48895b8795b557d2a42f385373f11d30feeb95dac3292e762746629)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetIsHidden")
    def reset_is_hidden(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetIsHidden", []))

    @jsii.member(jsii_name="resetLabel")
    def reset_label(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLabel", []))

    @jsii.member(jsii_name="resetLink")
    def reset_link(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLink", []))

    @jsii.member(jsii_name="resetOverrideLabel")
    def reset_override_label(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetOverrideLabel", []))

    @builtins.property
    @jsii.member(jsii_name="isHiddenInput")
    def is_hidden_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "isHiddenInput"))

    @builtins.property
    @jsii.member(jsii_name="labelInput")
    def label_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "labelInput"))

    @builtins.property
    @jsii.member(jsii_name="linkInput")
    def link_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "linkInput"))

    @builtins.property
    @jsii.member(jsii_name="overrideLabelInput")
    def override_label_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "overrideLabelInput"))

    @builtins.property
    @jsii.member(jsii_name="isHidden")
    def is_hidden(self) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "isHidden"))

    @is_hidden.setter
    def is_hidden(
        self,
        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__52dbb980de1286301dc33f289ad7e3964c24d1fad28dca5b6ad7d4c4e77d3c12)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "isHidden", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="label")
    def label(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "label"))

    @label.setter
    def label(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__94853d9743e9d55546b1308aaa36e76d3c44107c10aff379cba5b9568ee8eee4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "label", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="link")
    def link(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "link"))

    @link.setter
    def link(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__df2cfb89f0a3926ae779ec90605b2ad96504d269c8d9cf95cfee5bee478906f6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "link", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="overrideLabel")
    def override_label(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "overrideLabel"))

    @override_label.setter
    def override_label(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5411970df823969f694a91e45c0135cd71230643e832f96c2c81ea1a4dba14c7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "overrideLabel", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTopologyMapDefinitionCustomLink]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTopologyMapDefinitionCustomLink]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTopologyMapDefinitionCustomLink]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b6112ed6a30384214d1cf5836bc9bf3b90f9e98255351df39e03d36d63457402)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetTopologyMapDefinitionOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTopologyMapDefinitionOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__619128ca9ee7123d9fe78e30b0d6bc7733ba237ba1784832864d68314ea5c885)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putCustomLink")
    def put_custom_link(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetTopologyMapDefinitionCustomLink, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a5d247f471002e67e81f1daccf7ee2d92f0433d2391ff140eeaf1a0690cf9064)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putCustomLink", [value]))

    @jsii.member(jsii_name="putRequest")
    def put_request(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetTopologyMapDefinitionRequest", typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__60e884585b8c958c8db62b27ef9722849244a1a87eb6b62a8c4cd21093f7b32c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putRequest", [value]))

    @jsii.member(jsii_name="resetCustomLink")
    def reset_custom_link(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCustomLink", []))

    @jsii.member(jsii_name="resetRequest")
    def reset_request(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetRequest", []))

    @jsii.member(jsii_name="resetTitle")
    def reset_title(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTitle", []))

    @jsii.member(jsii_name="resetTitleAlign")
    def reset_title_align(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTitleAlign", []))

    @jsii.member(jsii_name="resetTitleSize")
    def reset_title_size(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTitleSize", []))

    @builtins.property
    @jsii.member(jsii_name="customLink")
    def custom_link(self) -> PowerpackWidgetTopologyMapDefinitionCustomLinkList:
        return typing.cast(PowerpackWidgetTopologyMapDefinitionCustomLinkList, jsii.get(self, "customLink"))

    @builtins.property
    @jsii.member(jsii_name="request")
    def request(self) -> "PowerpackWidgetTopologyMapDefinitionRequestList":
        return typing.cast("PowerpackWidgetTopologyMapDefinitionRequestList", jsii.get(self, "request"))

    @builtins.property
    @jsii.member(jsii_name="customLinkInput")
    def custom_link_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTopologyMapDefinitionCustomLink]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTopologyMapDefinitionCustomLink]]], jsii.get(self, "customLinkInput"))

    @builtins.property
    @jsii.member(jsii_name="requestInput")
    def request_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetTopologyMapDefinitionRequest"]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetTopologyMapDefinitionRequest"]]], jsii.get(self, "requestInput"))

    @builtins.property
    @jsii.member(jsii_name="titleAlignInput")
    def title_align_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "titleAlignInput"))

    @builtins.property
    @jsii.member(jsii_name="titleInput")
    def title_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "titleInput"))

    @builtins.property
    @jsii.member(jsii_name="titleSizeInput")
    def title_size_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "titleSizeInput"))

    @builtins.property
    @jsii.member(jsii_name="title")
    def title(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "title"))

    @title.setter
    def title(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3c2cd2a05910239fd52676bee465468e391acca6ae1d032a47f11437635817c6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "title", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="titleAlign")
    def title_align(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "titleAlign"))

    @title_align.setter
    def title_align(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__69eca333c66b21d5f1878d2140d29a605174c2ad06a0a6a07ee9e0ef97348709)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "titleAlign", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="titleSize")
    def title_size(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "titleSize"))

    @title_size.setter
    def title_size(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__eebb0f43409a8511254a068efb7502ab3474c8361380f967fa111dae20483c68)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "titleSize", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[PowerpackWidgetTopologyMapDefinition]:
        return typing.cast(typing.Optional[PowerpackWidgetTopologyMapDefinition], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetTopologyMapDefinition],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__df34aea2f5d9766566f83a3645362e22f9ab0708d5bc7d90f4a6b26d702b0633)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTopologyMapDefinitionRequest",
    jsii_struct_bases=[],
    name_mapping={"query": "query", "request_type": "requestType"},
)
class PowerpackWidgetTopologyMapDefinitionRequest:
    def __init__(
        self,
        *,
        query: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetTopologyMapDefinitionRequestQuery", typing.Dict[builtins.str, typing.Any]]]],
        request_type: builtins.str,
    ) -> None:
        '''
        :param query: query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        :param request_type: The request type for the Topology request ('topology'). Valid values are ``topology``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#request_type Powerpack#request_type}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5855dee78398c4e53af30fbd0b0f85468829107bb051ecff3caa99bae9bc3ef8)
            check_type(argname="argument query", value=query, expected_type=type_hints["query"])
            check_type(argname="argument request_type", value=request_type, expected_type=type_hints["request_type"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "query": query,
            "request_type": request_type,
        }

    @builtins.property
    def query(
        self,
    ) -> typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetTopologyMapDefinitionRequestQuery"]]:
        '''query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        '''
        result = self._values.get("query")
        assert result is not None, "Required property 'query' is missing"
        return typing.cast(typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetTopologyMapDefinitionRequestQuery"]], result)

    @builtins.property
    def request_type(self) -> builtins.str:
        '''The request type for the Topology request ('topology'). Valid values are ``topology``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#request_type Powerpack#request_type}
        '''
        result = self._values.get("request_type")
        assert result is not None, "Required property 'request_type' is missing"
        return typing.cast(builtins.str, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetTopologyMapDefinitionRequest(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetTopologyMapDefinitionRequestList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTopologyMapDefinitionRequestList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5fd097ccbfbca14e8a66f197ad33527086d62962777b73e4cfc3658064879e92)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetTopologyMapDefinitionRequestOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e8aaacf2f97b57121c2b7d1a3b2e3a49f8fde78a80b3a8ce5eb38bcb9feb82d5)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetTopologyMapDefinitionRequestOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2db10eb6df9792db824b239190ca32cf130d29b71e3f2815e8648dcff28a963b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3ef4bbb388bb29d24e82dedb2af724554df97cff0216ba36134d32703239c546)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__afbf81ae306838922ef62827959eb26a2e4f85641260b06b4d95285e7217e214)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTopologyMapDefinitionRequest]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTopologyMapDefinitionRequest]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTopologyMapDefinitionRequest]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__698a5bbe9c22420e6f790b884a900ee21841f499fde0c4c9b667cd4153c8b378)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetTopologyMapDefinitionRequestOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTopologyMapDefinitionRequestOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fbd3eb1ca399d1eefb60aa4314256b73e052c30dab9fd294fe9e84590075042e)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putQuery")
    def put_query(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetTopologyMapDefinitionRequestQuery", typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__609c46f7ec007c5b155e269ce6cd565315b47348b68242e5fda2b3e05f4c9127)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putQuery", [value]))

    @builtins.property
    @jsii.member(jsii_name="query")
    def query(self) -> "PowerpackWidgetTopologyMapDefinitionRequestQueryList":
        return typing.cast("PowerpackWidgetTopologyMapDefinitionRequestQueryList", jsii.get(self, "query"))

    @builtins.property
    @jsii.member(jsii_name="queryInput")
    def query_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetTopologyMapDefinitionRequestQuery"]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetTopologyMapDefinitionRequestQuery"]]], jsii.get(self, "queryInput"))

    @builtins.property
    @jsii.member(jsii_name="requestTypeInput")
    def request_type_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "requestTypeInput"))

    @builtins.property
    @jsii.member(jsii_name="requestType")
    def request_type(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "requestType"))

    @request_type.setter
    def request_type(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d7efd0268e7669014dc75b1515cbb963bad4e0cf1a4fb762796607a1e3d93cd8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "requestType", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTopologyMapDefinitionRequest]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTopologyMapDefinitionRequest]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTopologyMapDefinitionRequest]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__52bc487a67f497caaa49bb0b7b0ef6889522dd60ca2637434cbc89f9e4f0a100)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTopologyMapDefinitionRequestQuery",
    jsii_struct_bases=[],
    name_mapping={
        "data_source": "dataSource",
        "filters": "filters",
        "service": "service",
    },
)
class PowerpackWidgetTopologyMapDefinitionRequestQuery:
    def __init__(
        self,
        *,
        data_source: builtins.str,
        filters: typing.Sequence[builtins.str],
        service: builtins.str,
    ) -> None:
        '''
        :param data_source: The data source for the Topology request ('service_map' or 'data_streams'). Valid values are ``data_streams``, ``service_map``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param filters: Your environment and primary tag (or ``*`` if enabled for your account). Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#filters Powerpack#filters}
        :param service: The ID of the service to map. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#service Powerpack#service}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f2dba32a4b96e85b95203becdce6c7c4a67020d31a576f5329d90889f12af672)
            check_type(argname="argument data_source", value=data_source, expected_type=type_hints["data_source"])
            check_type(argname="argument filters", value=filters, expected_type=type_hints["filters"])
            check_type(argname="argument service", value=service, expected_type=type_hints["service"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "data_source": data_source,
            "filters": filters,
            "service": service,
        }

    @builtins.property
    def data_source(self) -> builtins.str:
        '''The data source for the Topology request ('service_map' or 'data_streams'). Valid values are ``data_streams``, ``service_map``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        '''
        result = self._values.get("data_source")
        assert result is not None, "Required property 'data_source' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def filters(self) -> typing.List[builtins.str]:
        '''Your environment and primary tag (or ``*`` if enabled for your account).

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#filters Powerpack#filters}
        '''
        result = self._values.get("filters")
        assert result is not None, "Required property 'filters' is missing"
        return typing.cast(typing.List[builtins.str], result)

    @builtins.property
    def service(self) -> builtins.str:
        '''The ID of the service to map.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#service Powerpack#service}
        '''
        result = self._values.get("service")
        assert result is not None, "Required property 'service' is missing"
        return typing.cast(builtins.str, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetTopologyMapDefinitionRequestQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetTopologyMapDefinitionRequestQueryList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTopologyMapDefinitionRequestQueryList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__849c43a43c3c5014ba7b974ca8fcab9615cf1cd5928ede24020ef50095ee89d9)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetTopologyMapDefinitionRequestQueryOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__00889f89d95540374b4c8736c1b08d4d1a16953f48f4f1167fde56008440305b)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetTopologyMapDefinitionRequestQueryOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ef5a44698ae55b50268b9d8157912277d7b99735fc3c1bee8f1a3b811af8b338)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__354e3293031361bbd27a2afec49c8f39746c89d66b24b6a271e4e078bb04517e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f125305dded1b643d00aed2df852048d1fa3006a78d582074acf6a10052c496d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTopologyMapDefinitionRequestQuery]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTopologyMapDefinitionRequestQuery]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTopologyMapDefinitionRequestQuery]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2364ffa7fd62b532bc0f18b5fc5ff3fdc0527ee8a6d351ab05457b9d4e65c9db)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetTopologyMapDefinitionRequestQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTopologyMapDefinitionRequestQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f6c80c317c046079b2a9cd0ad239938563b9c2083435c2759c5db5cc393a1c55)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property
    @jsii.member(jsii_name="dataSourceInput")
    def data_source_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "dataSourceInput"))

    @builtins.property
    @jsii.member(jsii_name="filtersInput")
    def filters_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "filtersInput"))

    @builtins.property
    @jsii.member(jsii_name="serviceInput")
    def service_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "serviceInput"))

    @builtins.property
    @jsii.member(jsii_name="dataSource")
    def data_source(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "dataSource"))

    @data_source.setter
    def data_source(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5f08e519df10744d77198da54868e1e5d24cc9f313ccd204fa5eb24c2cdbebce)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "dataSource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="filters")
    def filters(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "filters"))

    @filters.setter
    def filters(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a36cb6dde30dec3ef63f451680d35e031cd9173f4223770c0e02f15bcb89b5b2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "filters", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="service")
    def service(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "service"))

    @service.setter
    def service(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__281ee51a26d3919786a55c466fab40e5235a9fb54cd6dbeca44a86f10ed4f735)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "service", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTopologyMapDefinitionRequestQuery]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTopologyMapDefinitionRequestQuery]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTopologyMapDefinitionRequestQuery]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f943372155bdd700324f899d034c89acc010a14a375acca42246fdea470c9ae6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTraceServiceDefinition",
    jsii_struct_bases=[],
    name_mapping={
        "env": "env",
        "service": "service",
        "span_name": "spanName",
        "display_format": "displayFormat",
        "live_span": "liveSpan",
        "show_breakdown": "showBreakdown",
        "show_distribution": "showDistribution",
        "show_errors": "showErrors",
        "show_hits": "showHits",
        "show_latency": "showLatency",
        "show_resource_list": "showResourceList",
        "size_format": "sizeFormat",
        "title": "title",
        "title_align": "titleAlign",
        "title_size": "titleSize",
    },
)
class PowerpackWidgetTraceServiceDefinition:
    def __init__(
        self,
        *,
        env: builtins.str,
        service: builtins.str,
        span_name: builtins.str,
        display_format: typing.Optional[builtins.str] = None,
        live_span: typing.Optional[builtins.str] = None,
        show_breakdown: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        show_distribution: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        show_errors: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        show_hits: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        show_latency: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        show_resource_list: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        size_format: typing.Optional[builtins.str] = None,
        title: typing.Optional[builtins.str] = None,
        title_align: typing.Optional[builtins.str] = None,
        title_size: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param env: APM environment. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#env Powerpack#env}
        :param service: APM service. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#service Powerpack#service}
        :param span_name: APM span name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#span_name Powerpack#span_name}
        :param display_format: The number of columns to display. Valid values are ``one_column``, ``two_column``, ``three_column``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#display_format Powerpack#display_format}
        :param live_span: The timeframe to use when displaying the widget. Valid values are ``1m``, ``5m``, ``10m``, ``15m``, ``30m``, ``1h``, ``4h``, ``1d``, ``2d``, ``1w``, ``1mo``, ``3mo``, ``6mo``, ``week_to_date``, ``month_to_date``, ``1y``, ``alert``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#live_span Powerpack#live_span}
        :param show_breakdown: Whether to show the latency breakdown or not. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#show_breakdown Powerpack#show_breakdown}
        :param show_distribution: Whether to show the latency distribution or not. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#show_distribution Powerpack#show_distribution}
        :param show_errors: Whether to show the error metrics or not. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#show_errors Powerpack#show_errors}
        :param show_hits: Whether to show the hits metrics or not. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#show_hits Powerpack#show_hits}
        :param show_latency: Whether to show the latency metrics or not. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#show_latency Powerpack#show_latency}
        :param show_resource_list: Whether to show the resource list or not. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#show_resource_list Powerpack#show_resource_list}
        :param size_format: The size of the widget. Valid values are ``small``, ``medium``, ``large``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#size_format Powerpack#size_format}
        :param title: The title of the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title Powerpack#title}
        :param title_align: The alignment of the widget's title. Valid values are ``center``, ``left``, ``right``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_align Powerpack#title_align}
        :param title_size: The size of the widget's title (defaults to 16). Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_size Powerpack#title_size}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cf690326f94521ae9f304ca69c75d259d831ca09c6422c2e3309e371201b7355)
            check_type(argname="argument env", value=env, expected_type=type_hints["env"])
            check_type(argname="argument service", value=service, expected_type=type_hints["service"])
            check_type(argname="argument span_name", value=span_name, expected_type=type_hints["span_name"])
            check_type(argname="argument display_format", value=display_format, expected_type=type_hints["display_format"])
            check_type(argname="argument live_span", value=live_span, expected_type=type_hints["live_span"])
            check_type(argname="argument show_breakdown", value=show_breakdown, expected_type=type_hints["show_breakdown"])
            check_type(argname="argument show_distribution", value=show_distribution, expected_type=type_hints["show_distribution"])
            check_type(argname="argument show_errors", value=show_errors, expected_type=type_hints["show_errors"])
            check_type(argname="argument show_hits", value=show_hits, expected_type=type_hints["show_hits"])
            check_type(argname="argument show_latency", value=show_latency, expected_type=type_hints["show_latency"])
            check_type(argname="argument show_resource_list", value=show_resource_list, expected_type=type_hints["show_resource_list"])
            check_type(argname="argument size_format", value=size_format, expected_type=type_hints["size_format"])
            check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            check_type(argname="argument title_align", value=title_align, expected_type=type_hints["title_align"])
            check_type(argname="argument title_size", value=title_size, expected_type=type_hints["title_size"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "env": env,
            "service": service,
            "span_name": span_name,
        }
        if display_format is not None:
            self._values["display_format"] = display_format
        if live_span is not None:
            self._values["live_span"] = live_span
        if show_breakdown is not None:
            self._values["show_breakdown"] = show_breakdown
        if show_distribution is not None:
            self._values["show_distribution"] = show_distribution
        if show_errors is not None:
            self._values["show_errors"] = show_errors
        if show_hits is not None:
            self._values["show_hits"] = show_hits
        if show_latency is not None:
            self._values["show_latency"] = show_latency
        if show_resource_list is not None:
            self._values["show_resource_list"] = show_resource_list
        if size_format is not None:
            self._values["size_format"] = size_format
        if title is not None:
            self._values["title"] = title
        if title_align is not None:
            self._values["title_align"] = title_align
        if title_size is not None:
            self._values["title_size"] = title_size

    @builtins.property
    def env(self) -> builtins.str:
        '''APM environment.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#env Powerpack#env}
        '''
        result = self._values.get("env")
        assert result is not None, "Required property 'env' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def service(self) -> builtins.str:
        '''APM service.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#service Powerpack#service}
        '''
        result = self._values.get("service")
        assert result is not None, "Required property 'service' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def span_name(self) -> builtins.str:
        '''APM span name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#span_name Powerpack#span_name}
        '''
        result = self._values.get("span_name")
        assert result is not None, "Required property 'span_name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def display_format(self) -> typing.Optional[builtins.str]:
        '''The number of columns to display. Valid values are ``one_column``, ``two_column``, ``three_column``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#display_format Powerpack#display_format}
        '''
        result = self._values.get("display_format")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def live_span(self) -> typing.Optional[builtins.str]:
        '''The timeframe to use when displaying the widget.

        Valid values are ``1m``, ``5m``, ``10m``, ``15m``, ``30m``, ``1h``, ``4h``, ``1d``, ``2d``, ``1w``, ``1mo``, ``3mo``, ``6mo``, ``week_to_date``, ``month_to_date``, ``1y``, ``alert``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#live_span Powerpack#live_span}
        '''
        result = self._values.get("live_span")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def show_breakdown(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        '''Whether to show the latency breakdown or not.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#show_breakdown Powerpack#show_breakdown}
        '''
        result = self._values.get("show_breakdown")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)

    @builtins.property
    def show_distribution(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        '''Whether to show the latency distribution or not.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#show_distribution Powerpack#show_distribution}
        '''
        result = self._values.get("show_distribution")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)

    @builtins.property
    def show_errors(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        '''Whether to show the error metrics or not.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#show_errors Powerpack#show_errors}
        '''
        result = self._values.get("show_errors")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)

    @builtins.property
    def show_hits(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        '''Whether to show the hits metrics or not.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#show_hits Powerpack#show_hits}
        '''
        result = self._values.get("show_hits")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)

    @builtins.property
    def show_latency(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        '''Whether to show the latency metrics or not.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#show_latency Powerpack#show_latency}
        '''
        result = self._values.get("show_latency")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)

    @builtins.property
    def show_resource_list(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        '''Whether to show the resource list or not.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#show_resource_list Powerpack#show_resource_list}
        '''
        result = self._values.get("show_resource_list")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)

    @builtins.property
    def size_format(self) -> typing.Optional[builtins.str]:
        '''The size of the widget. Valid values are ``small``, ``medium``, ``large``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#size_format Powerpack#size_format}
        '''
        result = self._values.get("size_format")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def title(self) -> typing.Optional[builtins.str]:
        '''The title of the widget.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title Powerpack#title}
        '''
        result = self._values.get("title")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def title_align(self) -> typing.Optional[builtins.str]:
        '''The alignment of the widget's title. Valid values are ``center``, ``left``, ``right``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_align Powerpack#title_align}
        '''
        result = self._values.get("title_align")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def title_size(self) -> typing.Optional[builtins.str]:
        '''The size of the widget's title (defaults to 16).

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title_size Powerpack#title_size}
        '''
        result = self._values.get("title_size")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetTraceServiceDefinition(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetTraceServiceDefinitionOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTraceServiceDefinitionOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__306a5dea8b3d910bf39ef2b0bd579bd8ec0fa8f8f1a5bb90b65a67341517149a)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetDisplayFormat")
    def reset_display_format(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDisplayFormat", []))

    @jsii.member(jsii_name="resetLiveSpan")
    def reset_live_span(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLiveSpan", []))

    @jsii.member(jsii_name="resetShowBreakdown")
    def reset_show_breakdown(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetShowBreakdown", []))

    @jsii.member(jsii_name="resetShowDistribution")
    def reset_show_distribution(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetShowDistribution", []))

    @jsii.member(jsii_name="resetShowErrors")
    def reset_show_errors(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetShowErrors", []))

    @jsii.member(jsii_name="resetShowHits")
    def reset_show_hits(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetShowHits", []))

    @jsii.member(jsii_name="resetShowLatency")
    def reset_show_latency(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetShowLatency", []))

    @jsii.member(jsii_name="resetShowResourceList")
    def reset_show_resource_list(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetShowResourceList", []))

    @jsii.member(jsii_name="resetSizeFormat")
    def reset_size_format(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSizeFormat", []))

    @jsii.member(jsii_name="resetTitle")
    def reset_title(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTitle", []))

    @jsii.member(jsii_name="resetTitleAlign")
    def reset_title_align(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTitleAlign", []))

    @jsii.member(jsii_name="resetTitleSize")
    def reset_title_size(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTitleSize", []))

    @builtins.property
    @jsii.member(jsii_name="displayFormatInput")
    def display_format_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "displayFormatInput"))

    @builtins.property
    @jsii.member(jsii_name="envInput")
    def env_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "envInput"))

    @builtins.property
    @jsii.member(jsii_name="liveSpanInput")
    def live_span_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "liveSpanInput"))

    @builtins.property
    @jsii.member(jsii_name="serviceInput")
    def service_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "serviceInput"))

    @builtins.property
    @jsii.member(jsii_name="showBreakdownInput")
    def show_breakdown_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "showBreakdownInput"))

    @builtins.property
    @jsii.member(jsii_name="showDistributionInput")
    def show_distribution_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "showDistributionInput"))

    @builtins.property
    @jsii.member(jsii_name="showErrorsInput")
    def show_errors_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "showErrorsInput"))

    @builtins.property
    @jsii.member(jsii_name="showHitsInput")
    def show_hits_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "showHitsInput"))

    @builtins.property
    @jsii.member(jsii_name="showLatencyInput")
    def show_latency_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "showLatencyInput"))

    @builtins.property
    @jsii.member(jsii_name="showResourceListInput")
    def show_resource_list_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "showResourceListInput"))

    @builtins.property
    @jsii.member(jsii_name="sizeFormatInput")
    def size_format_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "sizeFormatInput"))

    @builtins.property
    @jsii.member(jsii_name="spanNameInput")
    def span_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "spanNameInput"))

    @builtins.property
    @jsii.member(jsii_name="titleAlignInput")
    def title_align_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "titleAlignInput"))

    @builtins.property
    @jsii.member(jsii_name="titleInput")
    def title_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "titleInput"))

    @builtins.property
    @jsii.member(jsii_name="titleSizeInput")
    def title_size_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "titleSizeInput"))

    @builtins.property
    @jsii.member(jsii_name="displayFormat")
    def display_format(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "displayFormat"))

    @display_format.setter
    def display_format(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8a53e4a944d9f0d5b8d8b9e53452f89afc0f9ad071bfc36124f3b978cd7449bf)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "displayFormat", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="env")
    def env(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "env"))

    @env.setter
    def env(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bb7c93e1942d598a394121831c3e6d8cd6577665590cd31d46c2ec835baa45d3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "env", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="liveSpan")
    def live_span(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "liveSpan"))

    @live_span.setter
    def live_span(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c2630678513589bafa1696a478a40ca73648994b7bb1a26d8a9a440d7ddf6c19)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "liveSpan", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="service")
    def service(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "service"))

    @service.setter
    def service(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__487ea491ee5c2b124a4ab047c7e2d1057d6f4fee707ea8499eb7579920e3a9e3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "service", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="showBreakdown")
    def show_breakdown(
        self,
    ) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "showBreakdown"))

    @show_breakdown.setter
    def show_breakdown(
        self,
        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e8d64df9c44a14ac92436f869bcb9d813ccd9be721d7e02c13cfffd8a184f03c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "showBreakdown", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="showDistribution")
    def show_distribution(
        self,
    ) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "showDistribution"))

    @show_distribution.setter
    def show_distribution(
        self,
        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7ae7568b6aa4d07caf44e73ebbc4f224c73044252ad02bfdd52423145b7b26b2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "showDistribution", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="showErrors")
    def show_errors(self) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "showErrors"))

    @show_errors.setter
    def show_errors(
        self,
        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3ee6312eca96dc910b2c40f21a3d8a9ee4ba4ff85bf7e9c628c55012d96aa450)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "showErrors", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="showHits")
    def show_hits(self) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "showHits"))

    @show_hits.setter
    def show_hits(
        self,
        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f2d31c67d298bbd50feb1050aa76bca99835811fa2e58794b203b7f77ffaa7ad)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "showHits", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="showLatency")
    def show_latency(self) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "showLatency"))

    @show_latency.setter
    def show_latency(
        self,
        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f5c47fae9f537434aea13c4e5672e7f6397dd156a433d313fa43f903a650dd47)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "showLatency", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="showResourceList")
    def show_resource_list(
        self,
    ) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "showResourceList"))

    @show_resource_list.setter
    def show_resource_list(
        self,
        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b910f167802c2ce2afebfb599fa2ded06172d701b7ed9f12543ef339fe77828b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "showResourceList", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="sizeFormat")
    def size_format(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "sizeFormat"))

    @size_format.setter
    def size_format(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__de4129c18fc095df2fcb2e9598dcee52f8a10edf2fce7719b92b702014bb7f45)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "sizeFormat", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="spanName")
    def span_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "spanName"))

    @span_name.setter
    def span_name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__00b97ef4378f129e499d6db4451283977a88a2a73136b893be0afcf22513d40b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "spanName", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="title")
    def title(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "title"))

    @title.setter
    def title(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d0df21aa2a99ccedbc46be5cbafdcd6db4867a38e2d6d9d51cc4d9f03afdac33)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "title", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="titleAlign")
    def title_align(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "titleAlign"))

    @title_align.setter
    def title_align(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__aae726572056674d91a46a569e6f83dd919f3cb293b3a9efe42dd4aa7cb3cebe)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "titleAlign", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="titleSize")
    def title_size(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "titleSize"))

    @title_size.setter
    def title_size(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d57e2f10b6fa5a98fa8f3d0db925f45e2e85782c9bda994f66c98a901f93f66b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "titleSize", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[PowerpackWidgetTraceServiceDefinition]:
        return typing.cast(typing.Optional[PowerpackWidgetTraceServiceDefinition], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetTraceServiceDefinition],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e504dd3bd205f708e9e941c9bdf7b91d3d82ccaaab3a08352c3de95f19ad7328)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTreemapDefinition",
    jsii_struct_bases=[],
    name_mapping={
        "custom_links": "customLinks",
        "request": "request",
        "title": "title",
    },
)
class PowerpackWidgetTreemapDefinition:
    def __init__(
        self,
        *,
        custom_links: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetTreemapDefinitionCustomLinks", typing.Dict[builtins.str, typing.Any]]]]] = None,
        request: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetTreemapDefinitionRequest", typing.Dict[builtins.str, typing.Any]]]]] = None,
        title: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param custom_links: custom_links block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom_links Powerpack#custom_links}
        :param request: request block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#request Powerpack#request}
        :param title: The title of the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title Powerpack#title}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__33fc0431fb6d26335040f3bd538f72179f104c8f5d677e697cdf2cd084aad18d)
            check_type(argname="argument custom_links", value=custom_links, expected_type=type_hints["custom_links"])
            check_type(argname="argument request", value=request, expected_type=type_hints["request"])
            check_type(argname="argument title", value=title, expected_type=type_hints["title"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if custom_links is not None:
            self._values["custom_links"] = custom_links
        if request is not None:
            self._values["request"] = request
        if title is not None:
            self._values["title"] = title

    @builtins.property
    def custom_links(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetTreemapDefinitionCustomLinks"]]]:
        '''custom_links block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom_links Powerpack#custom_links}
        '''
        result = self._values.get("custom_links")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetTreemapDefinitionCustomLinks"]]], result)

    @builtins.property
    def request(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetTreemapDefinitionRequest"]]]:
        '''request block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#request Powerpack#request}
        '''
        result = self._values.get("request")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetTreemapDefinitionRequest"]]], result)

    @builtins.property
    def title(self) -> typing.Optional[builtins.str]:
        '''The title of the widget.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#title Powerpack#title}
        '''
        result = self._values.get("title")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetTreemapDefinition(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTreemapDefinitionCustomLinks",
    jsii_struct_bases=[],
    name_mapping={
        "is_hidden": "isHidden",
        "label": "label",
        "link": "link",
        "override_label": "overrideLabel",
    },
)
class PowerpackWidgetTreemapDefinitionCustomLinks:
    def __init__(
        self,
        *,
        is_hidden: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        label: typing.Optional[builtins.str] = None,
        link: typing.Optional[builtins.str] = None,
        override_label: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param is_hidden: The flag for toggling context menu link visibility. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#is_hidden Powerpack#is_hidden}
        :param label: The label for the custom link URL. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#label Powerpack#label}
        :param link: The URL of the custom link. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#link Powerpack#link}
        :param override_label: The label ID that refers to a context menu link item. When ``override_label`` is provided, the client request omits the label field. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#override_label Powerpack#override_label}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__264cc9c1d769c95bd453f234d033fe1e520ba0d6d6a9dd08286460e5582d4a88)
            check_type(argname="argument is_hidden", value=is_hidden, expected_type=type_hints["is_hidden"])
            check_type(argname="argument label", value=label, expected_type=type_hints["label"])
            check_type(argname="argument link", value=link, expected_type=type_hints["link"])
            check_type(argname="argument override_label", value=override_label, expected_type=type_hints["override_label"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if is_hidden is not None:
            self._values["is_hidden"] = is_hidden
        if label is not None:
            self._values["label"] = label
        if link is not None:
            self._values["link"] = link
        if override_label is not None:
            self._values["override_label"] = override_label

    @builtins.property
    def is_hidden(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        '''The flag for toggling context menu link visibility.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#is_hidden Powerpack#is_hidden}
        '''
        result = self._values.get("is_hidden")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)

    @builtins.property
    def label(self) -> typing.Optional[builtins.str]:
        '''The label for the custom link URL.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#label Powerpack#label}
        '''
        result = self._values.get("label")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def link(self) -> typing.Optional[builtins.str]:
        '''The URL of the custom link.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#link Powerpack#link}
        '''
        result = self._values.get("link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def override_label(self) -> typing.Optional[builtins.str]:
        '''The label ID that refers to a context menu link item.

        When ``override_label`` is provided, the client request omits the label field.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#override_label Powerpack#override_label}
        '''
        result = self._values.get("override_label")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetTreemapDefinitionCustomLinks(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetTreemapDefinitionCustomLinksList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTreemapDefinitionCustomLinksList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__40903b01bd1d517e8f65088c0a70be28b9b49c323b80c48c37e5e81674fbd1cc)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetTreemapDefinitionCustomLinksOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2bcda43ffa01e383cd97b264e69445ee1e1e07906b0a23c53c071c7c575290be)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetTreemapDefinitionCustomLinksOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__23292dd256b9e5e9d403fe1a68b28c20ac6197767353b223954c9080a6b2d32a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8f47b212f1c0deb76829b9347470abbedf7e67c6cc86019f730d73e7835000e1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9932265982d4ec8edfb8d6d67fb7d01ca8366568f28be4e0b268f2b6565aac33)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTreemapDefinitionCustomLinks]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTreemapDefinitionCustomLinks]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTreemapDefinitionCustomLinks]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4e2d660bf29e74919d14a17a44f1418ff7dd8add348fd04b5e33a64e55ac838e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetTreemapDefinitionCustomLinksOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTreemapDefinitionCustomLinksOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8e480cf68cee705e48fcb30ce30dbf815309d04234b043f944f12fe03c291653)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetIsHidden")
    def reset_is_hidden(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetIsHidden", []))

    @jsii.member(jsii_name="resetLabel")
    def reset_label(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLabel", []))

    @jsii.member(jsii_name="resetLink")
    def reset_link(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLink", []))

    @jsii.member(jsii_name="resetOverrideLabel")
    def reset_override_label(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetOverrideLabel", []))

    @builtins.property
    @jsii.member(jsii_name="isHiddenInput")
    def is_hidden_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "isHiddenInput"))

    @builtins.property
    @jsii.member(jsii_name="labelInput")
    def label_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "labelInput"))

    @builtins.property
    @jsii.member(jsii_name="linkInput")
    def link_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "linkInput"))

    @builtins.property
    @jsii.member(jsii_name="overrideLabelInput")
    def override_label_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "overrideLabelInput"))

    @builtins.property
    @jsii.member(jsii_name="isHidden")
    def is_hidden(self) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "isHidden"))

    @is_hidden.setter
    def is_hidden(
        self,
        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b38e2026ec94cf37327458863bca760a4e1f713fd3e1f1d2e22b2026389a5885)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "isHidden", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="label")
    def label(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "label"))

    @label.setter
    def label(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5f5bbcf7b110d8f67d5c65d7461534aa220ee22eff2311fdba86e5bf2495a12a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "label", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="link")
    def link(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "link"))

    @link.setter
    def link(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ffd7dfea0c1bb747807367c17d8b783ca4102d8a76e265ae1e1acfd8fc1a5d54)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "link", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="overrideLabel")
    def override_label(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "overrideLabel"))

    @override_label.setter
    def override_label(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a6b590af8e83dc9c280a5e507548a4bdb1462d6a185d45a7a0769357bb32f865)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "overrideLabel", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTreemapDefinitionCustomLinks]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTreemapDefinitionCustomLinks]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTreemapDefinitionCustomLinks]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c222a79e56c4b82cd9544f4c3573734de0e374a6d882a359460aa3946f9f7da0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetTreemapDefinitionOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTreemapDefinitionOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6847043c64c2b7c4cf3dd42bb7d82df39e3de8d37afceee8e782228a056891c5)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putCustomLinks")
    def put_custom_links(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetTreemapDefinitionCustomLinks, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3c36e62580fb63b0cad72930c46d13f54366b4aed609d856ee7595ac394134e9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putCustomLinks", [value]))

    @jsii.member(jsii_name="putRequest")
    def put_request(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetTreemapDefinitionRequest", typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dc6905f80ad5f075a9a3b2cc11d070f2b7def255d571a3d4978542b699b22722)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putRequest", [value]))

    @jsii.member(jsii_name="resetCustomLinks")
    def reset_custom_links(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCustomLinks", []))

    @jsii.member(jsii_name="resetRequest")
    def reset_request(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetRequest", []))

    @jsii.member(jsii_name="resetTitle")
    def reset_title(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTitle", []))

    @builtins.property
    @jsii.member(jsii_name="customLinks")
    def custom_links(self) -> PowerpackWidgetTreemapDefinitionCustomLinksList:
        return typing.cast(PowerpackWidgetTreemapDefinitionCustomLinksList, jsii.get(self, "customLinks"))

    @builtins.property
    @jsii.member(jsii_name="request")
    def request(self) -> "PowerpackWidgetTreemapDefinitionRequestList":
        return typing.cast("PowerpackWidgetTreemapDefinitionRequestList", jsii.get(self, "request"))

    @builtins.property
    @jsii.member(jsii_name="customLinksInput")
    def custom_links_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTreemapDefinitionCustomLinks]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTreemapDefinitionCustomLinks]]], jsii.get(self, "customLinksInput"))

    @builtins.property
    @jsii.member(jsii_name="requestInput")
    def request_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetTreemapDefinitionRequest"]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetTreemapDefinitionRequest"]]], jsii.get(self, "requestInput"))

    @builtins.property
    @jsii.member(jsii_name="titleInput")
    def title_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "titleInput"))

    @builtins.property
    @jsii.member(jsii_name="title")
    def title(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "title"))

    @title.setter
    def title(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b92662787ca612ab106ba4bdf14ebbd7e5113062369660096930d682e8367f77)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "title", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[PowerpackWidgetTreemapDefinition]:
        return typing.cast(typing.Optional[PowerpackWidgetTreemapDefinition], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetTreemapDefinition],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__86bcf8aa2f5a0a4338d26bde5d5f9a3bf407923c225b68d6c75680d9aa9d2d2a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTreemapDefinitionRequest",
    jsii_struct_bases=[],
    name_mapping={"formula": "formula", "query": "query"},
)
class PowerpackWidgetTreemapDefinitionRequest:
    def __init__(
        self,
        *,
        formula: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetTreemapDefinitionRequestFormula", typing.Dict[builtins.str, typing.Any]]]]] = None,
        query: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetTreemapDefinitionRequestQuery", typing.Dict[builtins.str, typing.Any]]]]] = None,
    ) -> None:
        '''
        :param formula: formula block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#formula Powerpack#formula}
        :param query: query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0bbb6dc55117f34ee5a8b209a5959b3f068988e7c8095e86ebd2fc32d5a08cf2)
            check_type(argname="argument formula", value=formula, expected_type=type_hints["formula"])
            check_type(argname="argument query", value=query, expected_type=type_hints["query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if formula is not None:
            self._values["formula"] = formula
        if query is not None:
            self._values["query"] = query

    @builtins.property
    def formula(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetTreemapDefinitionRequestFormula"]]]:
        '''formula block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#formula Powerpack#formula}
        '''
        result = self._values.get("formula")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetTreemapDefinitionRequestFormula"]]], result)

    @builtins.property
    def query(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetTreemapDefinitionRequestQuery"]]]:
        '''query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        '''
        result = self._values.get("query")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetTreemapDefinitionRequestQuery"]]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetTreemapDefinitionRequest(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTreemapDefinitionRequestFormula",
    jsii_struct_bases=[],
    name_mapping={
        "formula_expression": "formulaExpression",
        "alias": "alias",
        "cell_display_mode": "cellDisplayMode",
        "conditional_formats": "conditionalFormats",
        "limit": "limit",
        "number_format": "numberFormat",
        "style": "style",
    },
)
class PowerpackWidgetTreemapDefinitionRequestFormula:
    def __init__(
        self,
        *,
        formula_expression: builtins.str,
        alias: typing.Optional[builtins.str] = None,
        cell_display_mode: typing.Optional[builtins.str] = None,
        conditional_formats: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetTreemapDefinitionRequestFormulaConditionalFormats", typing.Dict[builtins.str, typing.Any]]]]] = None,
        limit: typing.Optional[typing.Union["PowerpackWidgetTreemapDefinitionRequestFormulaLimit", typing.Dict[builtins.str, typing.Any]]] = None,
        number_format: typing.Optional[typing.Union["PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormat", typing.Dict[builtins.str, typing.Any]]] = None,
        style: typing.Optional[typing.Union["PowerpackWidgetTreemapDefinitionRequestFormulaStyle", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param formula_expression: A string expression built from queries, formulas, and functions. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#formula_expression Powerpack#formula_expression}
        :param alias: An expression alias. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#alias Powerpack#alias}
        :param cell_display_mode: A list of display modes for each table cell. Valid values are ``number``, ``bar``, ``trend``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cell_display_mode Powerpack#cell_display_mode}
        :param conditional_formats: conditional_formats block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#conditional_formats Powerpack#conditional_formats}
        :param limit: limit block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param number_format: number_format block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#number_format Powerpack#number_format}
        :param style: style block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#style Powerpack#style}
        '''
        if isinstance(limit, dict):
            limit = PowerpackWidgetTreemapDefinitionRequestFormulaLimit(**limit)
        if isinstance(number_format, dict):
            number_format = PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormat(**number_format)
        if isinstance(style, dict):
            style = PowerpackWidgetTreemapDefinitionRequestFormulaStyle(**style)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7e46da89455f1fa58c3b3c4a65095768ddb5c4db995eba33d57b2b0cfd77c486)
            check_type(argname="argument formula_expression", value=formula_expression, expected_type=type_hints["formula_expression"])
            check_type(argname="argument alias", value=alias, expected_type=type_hints["alias"])
            check_type(argname="argument cell_display_mode", value=cell_display_mode, expected_type=type_hints["cell_display_mode"])
            check_type(argname="argument conditional_formats", value=conditional_formats, expected_type=type_hints["conditional_formats"])
            check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
            check_type(argname="argument number_format", value=number_format, expected_type=type_hints["number_format"])
            check_type(argname="argument style", value=style, expected_type=type_hints["style"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "formula_expression": formula_expression,
        }
        if alias is not None:
            self._values["alias"] = alias
        if cell_display_mode is not None:
            self._values["cell_display_mode"] = cell_display_mode
        if conditional_formats is not None:
            self._values["conditional_formats"] = conditional_formats
        if limit is not None:
            self._values["limit"] = limit
        if number_format is not None:
            self._values["number_format"] = number_format
        if style is not None:
            self._values["style"] = style

    @builtins.property
    def formula_expression(self) -> builtins.str:
        '''A string expression built from queries, formulas, and functions.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#formula_expression Powerpack#formula_expression}
        '''
        result = self._values.get("formula_expression")
        assert result is not None, "Required property 'formula_expression' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def alias(self) -> typing.Optional[builtins.str]:
        '''An expression alias.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#alias Powerpack#alias}
        '''
        result = self._values.get("alias")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def cell_display_mode(self) -> typing.Optional[builtins.str]:
        '''A list of display modes for each table cell. Valid values are ``number``, ``bar``, ``trend``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cell_display_mode Powerpack#cell_display_mode}
        '''
        result = self._values.get("cell_display_mode")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def conditional_formats(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetTreemapDefinitionRequestFormulaConditionalFormats"]]]:
        '''conditional_formats block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#conditional_formats Powerpack#conditional_formats}
        '''
        result = self._values.get("conditional_formats")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetTreemapDefinitionRequestFormulaConditionalFormats"]]], result)

    @builtins.property
    def limit(
        self,
    ) -> typing.Optional["PowerpackWidgetTreemapDefinitionRequestFormulaLimit"]:
        '''limit block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        '''
        result = self._values.get("limit")
        return typing.cast(typing.Optional["PowerpackWidgetTreemapDefinitionRequestFormulaLimit"], result)

    @builtins.property
    def number_format(
        self,
    ) -> typing.Optional["PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormat"]:
        '''number_format block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#number_format Powerpack#number_format}
        '''
        result = self._values.get("number_format")
        return typing.cast(typing.Optional["PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormat"], result)

    @builtins.property
    def style(
        self,
    ) -> typing.Optional["PowerpackWidgetTreemapDefinitionRequestFormulaStyle"]:
        '''style block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#style Powerpack#style}
        '''
        result = self._values.get("style")
        return typing.cast(typing.Optional["PowerpackWidgetTreemapDefinitionRequestFormulaStyle"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetTreemapDefinitionRequestFormula(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTreemapDefinitionRequestFormulaConditionalFormats",
    jsii_struct_bases=[],
    name_mapping={
        "comparator": "comparator",
        "palette": "palette",
        "value": "value",
        "custom_bg_color": "customBgColor",
        "custom_fg_color": "customFgColor",
        "hide_value": "hideValue",
        "image_url": "imageUrl",
        "metric": "metric",
        "timeframe": "timeframe",
    },
)
class PowerpackWidgetTreemapDefinitionRequestFormulaConditionalFormats:
    def __init__(
        self,
        *,
        comparator: builtins.str,
        palette: builtins.str,
        value: jsii.Number,
        custom_bg_color: typing.Optional[builtins.str] = None,
        custom_fg_color: typing.Optional[builtins.str] = None,
        hide_value: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        image_url: typing.Optional[builtins.str] = None,
        metric: typing.Optional[builtins.str] = None,
        timeframe: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param comparator: The comparator to use. Valid values are ``=``, ``>``, ``>=``, ``<``, ``<=``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#comparator Powerpack#comparator}
        :param palette: The color palette to apply. Valid values are ``blue``, ``custom_bg``, ``custom_image``, ``custom_text``, ``gray_on_white``, ``grey``, ``green``, ``orange``, ``red``, ``red_on_white``, ``white_on_gray``, ``white_on_green``, ``green_on_white``, ``white_on_red``, ``white_on_yellow``, ``yellow_on_white``, ``black_on_light_yellow``, ``black_on_light_green``, ``black_on_light_red``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette Powerpack#palette}
        :param value: A value for the comparator. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#value Powerpack#value}
        :param custom_bg_color: The color palette to apply to the background, same values available as palette. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom_bg_color Powerpack#custom_bg_color}
        :param custom_fg_color: The color palette to apply to the foreground, same values available as palette. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom_fg_color Powerpack#custom_fg_color}
        :param hide_value: Setting this to True hides values. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#hide_value Powerpack#hide_value}
        :param image_url: Displays an image as the background. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#image_url Powerpack#image_url}
        :param metric: The metric from the request to correlate with this conditional format. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        :param timeframe: Defines the displayed timeframe. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#timeframe Powerpack#timeframe}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d5860f711cb1fe61f91da22de27d62fbbd1de4ac1eb3ff8f4686856ff8f76e70)
            check_type(argname="argument comparator", value=comparator, expected_type=type_hints["comparator"])
            check_type(argname="argument palette", value=palette, expected_type=type_hints["palette"])
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument custom_bg_color", value=custom_bg_color, expected_type=type_hints["custom_bg_color"])
            check_type(argname="argument custom_fg_color", value=custom_fg_color, expected_type=type_hints["custom_fg_color"])
            check_type(argname="argument hide_value", value=hide_value, expected_type=type_hints["hide_value"])
            check_type(argname="argument image_url", value=image_url, expected_type=type_hints["image_url"])
            check_type(argname="argument metric", value=metric, expected_type=type_hints["metric"])
            check_type(argname="argument timeframe", value=timeframe, expected_type=type_hints["timeframe"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "comparator": comparator,
            "palette": palette,
            "value": value,
        }
        if custom_bg_color is not None:
            self._values["custom_bg_color"] = custom_bg_color
        if custom_fg_color is not None:
            self._values["custom_fg_color"] = custom_fg_color
        if hide_value is not None:
            self._values["hide_value"] = hide_value
        if image_url is not None:
            self._values["image_url"] = image_url
        if metric is not None:
            self._values["metric"] = metric
        if timeframe is not None:
            self._values["timeframe"] = timeframe

    @builtins.property
    def comparator(self) -> builtins.str:
        '''The comparator to use. Valid values are ``=``, ``>``, ``>=``, ``<``, ``<=``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#comparator Powerpack#comparator}
        '''
        result = self._values.get("comparator")
        assert result is not None, "Required property 'comparator' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def palette(self) -> builtins.str:
        '''The color palette to apply.

        Valid values are ``blue``, ``custom_bg``, ``custom_image``, ``custom_text``, ``gray_on_white``, ``grey``, ``green``, ``orange``, ``red``, ``red_on_white``, ``white_on_gray``, ``white_on_green``, ``green_on_white``, ``white_on_red``, ``white_on_yellow``, ``yellow_on_white``, ``black_on_light_yellow``, ``black_on_light_green``, ``black_on_light_red``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette Powerpack#palette}
        '''
        result = self._values.get("palette")
        assert result is not None, "Required property 'palette' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def value(self) -> jsii.Number:
        '''A value for the comparator.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#value Powerpack#value}
        '''
        result = self._values.get("value")
        assert result is not None, "Required property 'value' is missing"
        return typing.cast(jsii.Number, result)

    @builtins.property
    def custom_bg_color(self) -> typing.Optional[builtins.str]:
        '''The color palette to apply to the background, same values available as palette.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom_bg_color Powerpack#custom_bg_color}
        '''
        result = self._values.get("custom_bg_color")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def custom_fg_color(self) -> typing.Optional[builtins.str]:
        '''The color palette to apply to the foreground, same values available as palette.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom_fg_color Powerpack#custom_fg_color}
        '''
        result = self._values.get("custom_fg_color")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def hide_value(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        '''Setting this to True hides values.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#hide_value Powerpack#hide_value}
        '''
        result = self._values.get("hide_value")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)

    @builtins.property
    def image_url(self) -> typing.Optional[builtins.str]:
        '''Displays an image as the background.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#image_url Powerpack#image_url}
        '''
        result = self._values.get("image_url")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def metric(self) -> typing.Optional[builtins.str]:
        '''The metric from the request to correlate with this conditional format.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        '''
        result = self._values.get("metric")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def timeframe(self) -> typing.Optional[builtins.str]:
        '''Defines the displayed timeframe.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#timeframe Powerpack#timeframe}
        '''
        result = self._values.get("timeframe")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetTreemapDefinitionRequestFormulaConditionalFormats(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetTreemapDefinitionRequestFormulaConditionalFormatsList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTreemapDefinitionRequestFormulaConditionalFormatsList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__48d3239974c76b67f15e2b8ae945366d2bda290b845a896f7c3e69efc009670d)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetTreemapDefinitionRequestFormulaConditionalFormatsOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__05404104d4fed14a319c22eefa19a62a7764f7c3cec082cbfec96ba8b14b4f5a)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetTreemapDefinitionRequestFormulaConditionalFormatsOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__184c9787d6c62cf73ecc5412c29593fc74906cb6d56401ee2dee72a501cdfee5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b520007e1a5daece32831cd8d815d8fb465aed086bc5191f921a3ee8370fb915)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__189587c54911971e222549b6271f657984914310898f22cc3fe654c763b6574e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTreemapDefinitionRequestFormulaConditionalFormats]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTreemapDefinitionRequestFormulaConditionalFormats]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTreemapDefinitionRequestFormulaConditionalFormats]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__02d404ce5608c41c8b096bd6c56998cb1037a8f8e55216481db6da3f8c2199c4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetTreemapDefinitionRequestFormulaConditionalFormatsOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTreemapDefinitionRequestFormulaConditionalFormatsOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6279b02dcae1f6340dcdb5a1ec19a573b414ac3bb2d295bde238fe90ae29d972)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetCustomBgColor")
    def reset_custom_bg_color(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCustomBgColor", []))

    @jsii.member(jsii_name="resetCustomFgColor")
    def reset_custom_fg_color(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCustomFgColor", []))

    @jsii.member(jsii_name="resetHideValue")
    def reset_hide_value(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHideValue", []))

    @jsii.member(jsii_name="resetImageUrl")
    def reset_image_url(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetImageUrl", []))

    @jsii.member(jsii_name="resetMetric")
    def reset_metric(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMetric", []))

    @jsii.member(jsii_name="resetTimeframe")
    def reset_timeframe(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTimeframe", []))

    @builtins.property
    @jsii.member(jsii_name="comparatorInput")
    def comparator_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "comparatorInput"))

    @builtins.property
    @jsii.member(jsii_name="customBgColorInput")
    def custom_bg_color_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "customBgColorInput"))

    @builtins.property
    @jsii.member(jsii_name="customFgColorInput")
    def custom_fg_color_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "customFgColorInput"))

    @builtins.property
    @jsii.member(jsii_name="hideValueInput")
    def hide_value_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "hideValueInput"))

    @builtins.property
    @jsii.member(jsii_name="imageUrlInput")
    def image_url_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "imageUrlInput"))

    @builtins.property
    @jsii.member(jsii_name="metricInput")
    def metric_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "metricInput"))

    @builtins.property
    @jsii.member(jsii_name="paletteInput")
    def palette_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "paletteInput"))

    @builtins.property
    @jsii.member(jsii_name="timeframeInput")
    def timeframe_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "timeframeInput"))

    @builtins.property
    @jsii.member(jsii_name="valueInput")
    def value_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "valueInput"))

    @builtins.property
    @jsii.member(jsii_name="comparator")
    def comparator(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "comparator"))

    @comparator.setter
    def comparator(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c26b11e8a07279014a3b373e4294c1bc048fb41033b53be5656e6b7e8df3aca3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "comparator", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="customBgColor")
    def custom_bg_color(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "customBgColor"))

    @custom_bg_color.setter
    def custom_bg_color(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ec8f023ce4b0356ff4ce4e4400ab0cc68972613d62620522e6fabf29d4e0df8a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "customBgColor", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="customFgColor")
    def custom_fg_color(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "customFgColor"))

    @custom_fg_color.setter
    def custom_fg_color(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0df6e4d8d809651a31da97fb306fbe2dc3ff032ab0cf45c7e45c45a2ad272de5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "customFgColor", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="hideValue")
    def hide_value(self) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "hideValue"))

    @hide_value.setter
    def hide_value(
        self,
        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ecccec65f1e5ae62f87329b08f30f1970dab2003814a14d1fd7377485ab45567)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "hideValue", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="imageUrl")
    def image_url(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "imageUrl"))

    @image_url.setter
    def image_url(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2ed0ea5a7a56a476feca984e48f17c34840a1191ecf9b9541acc9a358229ed2d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "imageUrl", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="metric")
    def metric(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "metric"))

    @metric.setter
    def metric(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__aea5e7cab21f879b2917e9789c4eac0a1b1b9ee01e9fb4c21618f40a62ce2bb3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "metric", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="palette")
    def palette(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "palette"))

    @palette.setter
    def palette(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__344a3c7c88f5b258bee2cfb75dd645a9d52e34bbb5c9c4a321ca425de48edb30)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "palette", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="timeframe")
    def timeframe(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "timeframe"))

    @timeframe.setter
    def timeframe(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4e87c4dc6fc8cc463b92ed8c928a5c9b1b4a2c740554d19cd4ccfd0b022ed469)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "timeframe", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="value")
    def value(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "value"))

    @value.setter
    def value(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7e6457b929f8671b52f4513fec1ee3ebb28a5d69708fc8db6e3d41c34014da8c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "value", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTreemapDefinitionRequestFormulaConditionalFormats]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTreemapDefinitionRequestFormulaConditionalFormats]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTreemapDefinitionRequestFormulaConditionalFormats]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__68697ab7c4d3b06e0d28f1cb7f9a334198129e9d2bfc20aa03711a0d9b14f1e0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTreemapDefinitionRequestFormulaLimit",
    jsii_struct_bases=[],
    name_mapping={"count": "count", "order": "order"},
)
class PowerpackWidgetTreemapDefinitionRequestFormulaLimit:
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        order: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param count: The number of results to return. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#count Powerpack#count}
        :param order: The direction of the sort. Valid values are ``asc``, ``desc``. Defaults to ``"desc"``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b8e473c5f3e16f91671c85b4e37991a7780e9177d89ded72efecfaa7b43c45b7)
            check_type(argname="argument count", value=count, expected_type=type_hints["count"])
            check_type(argname="argument order", value=order, expected_type=type_hints["order"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if count is not None:
            self._values["count"] = count
        if order is not None:
            self._values["order"] = order

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''The number of results to return.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#count Powerpack#count}
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def order(self) -> typing.Optional[builtins.str]:
        '''The direction of the sort. Valid values are ``asc``, ``desc``. Defaults to ``"desc"``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        result = self._values.get("order")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetTreemapDefinitionRequestFormulaLimit(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetTreemapDefinitionRequestFormulaLimitOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTreemapDefinitionRequestFormulaLimitOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6bd7388365d87257c8e4c2f803a02fc3f8eb00af3519dbfcbef6bc87eefca6ca)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetCount")
    def reset_count(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCount", []))

    @jsii.member(jsii_name="resetOrder")
    def reset_order(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetOrder", []))

    @builtins.property
    @jsii.member(jsii_name="countInput")
    def count_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "countInput"))

    @builtins.property
    @jsii.member(jsii_name="orderInput")
    def order_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "orderInput"))

    @builtins.property
    @jsii.member(jsii_name="count")
    def count(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "count"))

    @count.setter
    def count(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__91f827b2841c1d3731ab5c2b1e7972f66c7a25ff62f6625e050119000539127f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "count", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="order")
    def order(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "order"))

    @order.setter
    def order(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ce5004acf31a3295fbfe8ae4327978a1b0ad8cc2254f712fcea9264da0666835)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "order", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetTreemapDefinitionRequestFormulaLimit]:
        return typing.cast(typing.Optional[PowerpackWidgetTreemapDefinitionRequestFormulaLimit], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetTreemapDefinitionRequestFormulaLimit],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b398cd73efb7e636c9ef9c28f8d50f174a89dd9f70047552a0d9b82ca970bbc7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetTreemapDefinitionRequestFormulaList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTreemapDefinitionRequestFormulaList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7bd595be88187de58c4518028978cdec44e0c67c024b9bc3bcf5a85c72448bef)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetTreemapDefinitionRequestFormulaOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__34d9cf1d34242c30af539a7deaedd75e1807f448c1bb3b330dd0b4bb3616e235)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetTreemapDefinitionRequestFormulaOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__73efd2009589d6973b49d51febaa519b7be491a740b40a000367b1364db8dd1d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f774104f6b1b3c157fc640765daa3c3777b49de57375f0d9fc70321e8959ef2c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__991e99aee5fa93cfe93a2192f97a76422acf91f51bea40fb743b8bf563e9b43b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTreemapDefinitionRequestFormula]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTreemapDefinitionRequestFormula]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTreemapDefinitionRequestFormula]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0b0bca4cd16cab19fb8596f9078d3f51b609c165b040c24661f8e61281364bab)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormat",
    jsii_struct_bases=[],
    name_mapping={"unit": "unit", "unit_scale": "unitScale"},
)
class PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormat:
    def __init__(
        self,
        *,
        unit: typing.Union["PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormatUnit", typing.Dict[builtins.str, typing.Any]],
        unit_scale: typing.Optional[typing.Union["PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormatUnitScale", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param unit: unit block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit Powerpack#unit}
        :param unit_scale: unit_scale block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit_scale Powerpack#unit_scale}
        '''
        if isinstance(unit, dict):
            unit = PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormatUnit(**unit)
        if isinstance(unit_scale, dict):
            unit_scale = PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormatUnitScale(**unit_scale)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6bb990ae66cba6dd12389e7265e2e61ed4d167a91f371e55e4f4bd5c7d3ec587)
            check_type(argname="argument unit", value=unit, expected_type=type_hints["unit"])
            check_type(argname="argument unit_scale", value=unit_scale, expected_type=type_hints["unit_scale"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "unit": unit,
        }
        if unit_scale is not None:
            self._values["unit_scale"] = unit_scale

    @builtins.property
    def unit(self) -> "PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormatUnit":
        '''unit block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit Powerpack#unit}
        '''
        result = self._values.get("unit")
        assert result is not None, "Required property 'unit' is missing"
        return typing.cast("PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormatUnit", result)

    @builtins.property
    def unit_scale(
        self,
    ) -> typing.Optional["PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormatUnitScale"]:
        '''unit_scale block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit_scale Powerpack#unit_scale}
        '''
        result = self._values.get("unit_scale")
        return typing.cast(typing.Optional["PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormatUnitScale"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormat(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormatOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormatOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__622910885e6b51ca03caf9838824d06d90e479844956022f0bd698c66babe98e)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putUnit")
    def put_unit(
        self,
        *,
        canonical: typing.Optional[typing.Union["PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormatUnitCanonical", typing.Dict[builtins.str, typing.Any]]] = None,
        custom: typing.Optional[typing.Union["PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormatUnitCustom", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param canonical: canonical block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#canonical Powerpack#canonical}
        :param custom: custom block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom Powerpack#custom}
        '''
        value = PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormatUnit(
            canonical=canonical, custom=custom
        )

        return typing.cast(None, jsii.invoke(self, "putUnit", [value]))

    @jsii.member(jsii_name="putUnitScale")
    def put_unit_scale(self, *, unit_name: builtins.str) -> None:
        '''
        :param unit_name: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit_name Powerpack#unit_name}.
        '''
        value = PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormatUnitScale(
            unit_name=unit_name
        )

        return typing.cast(None, jsii.invoke(self, "putUnitScale", [value]))

    @jsii.member(jsii_name="resetUnitScale")
    def reset_unit_scale(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetUnitScale", []))

    @builtins.property
    @jsii.member(jsii_name="unit")
    def unit(
        self,
    ) -> "PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormatUnitOutputReference":
        return typing.cast("PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormatUnitOutputReference", jsii.get(self, "unit"))

    @builtins.property
    @jsii.member(jsii_name="unitScale")
    def unit_scale(
        self,
    ) -> "PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormatUnitScaleOutputReference":
        return typing.cast("PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormatUnitScaleOutputReference", jsii.get(self, "unitScale"))

    @builtins.property
    @jsii.member(jsii_name="unitInput")
    def unit_input(
        self,
    ) -> typing.Optional["PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormatUnit"]:
        return typing.cast(typing.Optional["PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormatUnit"], jsii.get(self, "unitInput"))

    @builtins.property
    @jsii.member(jsii_name="unitScaleInput")
    def unit_scale_input(
        self,
    ) -> typing.Optional["PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormatUnitScale"]:
        return typing.cast(typing.Optional["PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormatUnitScale"], jsii.get(self, "unitScaleInput"))

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormat]:
        return typing.cast(typing.Optional[PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormat], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormat],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0b540f96215539a769bbc08e8e28320600985d70bbc02e3feb394afc47d1bc3e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormatUnit",
    jsii_struct_bases=[],
    name_mapping={"canonical": "canonical", "custom": "custom"},
)
class PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormatUnit:
    def __init__(
        self,
        *,
        canonical: typing.Optional[typing.Union["PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormatUnitCanonical", typing.Dict[builtins.str, typing.Any]]] = None,
        custom: typing.Optional[typing.Union["PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormatUnitCustom", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param canonical: canonical block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#canonical Powerpack#canonical}
        :param custom: custom block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom Powerpack#custom}
        '''
        if isinstance(canonical, dict):
            canonical = PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormatUnitCanonical(**canonical)
        if isinstance(custom, dict):
            custom = PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormatUnitCustom(**custom)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b9a43ebc9032888e21dffa5419533efbe69ca4800e70585b852b0752ba4a8080)
            check_type(argname="argument canonical", value=canonical, expected_type=type_hints["canonical"])
            check_type(argname="argument custom", value=custom, expected_type=type_hints["custom"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if canonical is not None:
            self._values["canonical"] = canonical
        if custom is not None:
            self._values["custom"] = custom

    @builtins.property
    def canonical(
        self,
    ) -> typing.Optional["PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormatUnitCanonical"]:
        '''canonical block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#canonical Powerpack#canonical}
        '''
        result = self._values.get("canonical")
        return typing.cast(typing.Optional["PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormatUnitCanonical"], result)

    @builtins.property
    def custom(
        self,
    ) -> typing.Optional["PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormatUnitCustom"]:
        '''custom block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#custom Powerpack#custom}
        '''
        result = self._values.get("custom")
        return typing.cast(typing.Optional["PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormatUnitCustom"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormatUnit(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormatUnitCanonical",
    jsii_struct_bases=[],
    name_mapping={"unit_name": "unitName", "per_unit_name": "perUnitName"},
)
class PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormatUnitCanonical:
    def __init__(
        self,
        *,
        unit_name: builtins.str,
        per_unit_name: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param unit_name: Unit name. It should be in singular form ('megabyte' and not 'megabytes'). Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit_name Powerpack#unit_name}
        :param per_unit_name: per unit name. If you want to represent megabytes/s, you set 'unit_name' = 'megabyte' and 'per_unit_name = 'second'. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#per_unit_name Powerpack#per_unit_name}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f39bb6c542373391eb0fffcf555fed7f748179eec4313bd266cc2d908b60e5d9)
            check_type(argname="argument unit_name", value=unit_name, expected_type=type_hints["unit_name"])
            check_type(argname="argument per_unit_name", value=per_unit_name, expected_type=type_hints["per_unit_name"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "unit_name": unit_name,
        }
        if per_unit_name is not None:
            self._values["per_unit_name"] = per_unit_name

    @builtins.property
    def unit_name(self) -> builtins.str:
        '''Unit name. It should be in singular form ('megabyte' and not 'megabytes').

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit_name Powerpack#unit_name}
        '''
        result = self._values.get("unit_name")
        assert result is not None, "Required property 'unit_name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def per_unit_name(self) -> typing.Optional[builtins.str]:
        '''per unit name. If you want to represent megabytes/s, you set 'unit_name' = 'megabyte' and 'per_unit_name = 'second'.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#per_unit_name Powerpack#per_unit_name}
        '''
        result = self._values.get("per_unit_name")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormatUnitCanonical(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormatUnitCanonicalOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormatUnitCanonicalOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ce0686662af65887e9d2fbb150252c943ac88c99b3fc2ef0f59910808abc8d51)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetPerUnitName")
    def reset_per_unit_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPerUnitName", []))

    @builtins.property
    @jsii.member(jsii_name="perUnitNameInput")
    def per_unit_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "perUnitNameInput"))

    @builtins.property
    @jsii.member(jsii_name="unitNameInput")
    def unit_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "unitNameInput"))

    @builtins.property
    @jsii.member(jsii_name="perUnitName")
    def per_unit_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "perUnitName"))

    @per_unit_name.setter
    def per_unit_name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fe1d0a0f8d75f4fc6bd4fd004d8f787bb00e5496604c576d7b60864e1f5bc6c1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "perUnitName", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="unitName")
    def unit_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "unitName"))

    @unit_name.setter
    def unit_name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3d4fffe36aa289ace1946caef86651f86ec7262114fe2c6952a3f37110af9052)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "unitName", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormatUnitCanonical]:
        return typing.cast(typing.Optional[PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormatUnitCanonical], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormatUnitCanonical],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__241915248ba2d49bb6ace956a74b9d9ee76e3cd307e37811943f408d54c5ae3d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormatUnitCustom",
    jsii_struct_bases=[],
    name_mapping={"label": "label"},
)
class PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormatUnitCustom:
    def __init__(self, *, label: builtins.str) -> None:
        '''
        :param label: Unit label. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#label Powerpack#label}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ce2c67dd63d4669e3b0e746127dbe922d2832b0ed0b6187a70c45522cd9f51d3)
            check_type(argname="argument label", value=label, expected_type=type_hints["label"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "label": label,
        }

    @builtins.property
    def label(self) -> builtins.str:
        '''Unit label.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#label Powerpack#label}
        '''
        result = self._values.get("label")
        assert result is not None, "Required property 'label' is missing"
        return typing.cast(builtins.str, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormatUnitCustom(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormatUnitCustomOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormatUnitCustomOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1d37883d5f919537db2c174b61803cf5b434da3413bafdd71c98787c5d2c48bc)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @builtins.property
    @jsii.member(jsii_name="labelInput")
    def label_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "labelInput"))

    @builtins.property
    @jsii.member(jsii_name="label")
    def label(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "label"))

    @label.setter
    def label(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2d417f3a86c6155333d74ba30847882a72394e187373204039d40894f4c60707)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "label", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormatUnitCustom]:
        return typing.cast(typing.Optional[PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormatUnitCustom], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormatUnitCustom],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a025863afc7396fe72deffce7ebc0258614d7fe8ee9a9bd768873cd728978a78)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormatUnitOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormatUnitOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__231ef5a4fb937792e48fe5a2a99efff591b94811759bc97ce6962dbab0bda4aa)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putCanonical")
    def put_canonical(
        self,
        *,
        unit_name: builtins.str,
        per_unit_name: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param unit_name: Unit name. It should be in singular form ('megabyte' and not 'megabytes'). Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit_name Powerpack#unit_name}
        :param per_unit_name: per unit name. If you want to represent megabytes/s, you set 'unit_name' = 'megabyte' and 'per_unit_name = 'second'. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#per_unit_name Powerpack#per_unit_name}
        '''
        value = PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormatUnitCanonical(
            unit_name=unit_name, per_unit_name=per_unit_name
        )

        return typing.cast(None, jsii.invoke(self, "putCanonical", [value]))

    @jsii.member(jsii_name="putCustom")
    def put_custom(self, *, label: builtins.str) -> None:
        '''
        :param label: Unit label. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#label Powerpack#label}
        '''
        value = PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormatUnitCustom(
            label=label
        )

        return typing.cast(None, jsii.invoke(self, "putCustom", [value]))

    @jsii.member(jsii_name="resetCanonical")
    def reset_canonical(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCanonical", []))

    @jsii.member(jsii_name="resetCustom")
    def reset_custom(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCustom", []))

    @builtins.property
    @jsii.member(jsii_name="canonical")
    def canonical(
        self,
    ) -> PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormatUnitCanonicalOutputReference:
        return typing.cast(PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormatUnitCanonicalOutputReference, jsii.get(self, "canonical"))

    @builtins.property
    @jsii.member(jsii_name="custom")
    def custom(
        self,
    ) -> PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormatUnitCustomOutputReference:
        return typing.cast(PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormatUnitCustomOutputReference, jsii.get(self, "custom"))

    @builtins.property
    @jsii.member(jsii_name="canonicalInput")
    def canonical_input(
        self,
    ) -> typing.Optional[PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormatUnitCanonical]:
        return typing.cast(typing.Optional[PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormatUnitCanonical], jsii.get(self, "canonicalInput"))

    @builtins.property
    @jsii.member(jsii_name="customInput")
    def custom_input(
        self,
    ) -> typing.Optional[PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormatUnitCustom]:
        return typing.cast(typing.Optional[PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormatUnitCustom], jsii.get(self, "customInput"))

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormatUnit]:
        return typing.cast(typing.Optional[PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormatUnit], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormatUnit],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__563c114101cb447afde53ffc8076ff9195e9b9144b4bae1138d7b1e4dad50b83)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormatUnitScale",
    jsii_struct_bases=[],
    name_mapping={"unit_name": "unitName"},
)
class PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormatUnitScale:
    def __init__(self, *, unit_name: builtins.str) -> None:
        '''
        :param unit_name: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit_name Powerpack#unit_name}.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__68191ab81134e27a8d0535b066b227bb94f41001ec7edd4e832f2827f7a89cf4)
            check_type(argname="argument unit_name", value=unit_name, expected_type=type_hints["unit_name"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "unit_name": unit_name,
        }

    @builtins.property
    def unit_name(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit_name Powerpack#unit_name}.'''
        result = self._values.get("unit_name")
        assert result is not None, "Required property 'unit_name' is missing"
        return typing.cast(builtins.str, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormatUnitScale(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormatUnitScaleOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormatUnitScaleOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__775c274bd2ae6ad7e4552058ef43f675497712cf7f4e0848d86ee54eeb1458a5)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @builtins.property
    @jsii.member(jsii_name="unitNameInput")
    def unit_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "unitNameInput"))

    @builtins.property
    @jsii.member(jsii_name="unitName")
    def unit_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "unitName"))

    @unit_name.setter
    def unit_name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__76b4366871671ac4b674dee15b8b7f14db6ee0101a3c49b4d8ed304a22b614f0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "unitName", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormatUnitScale]:
        return typing.cast(typing.Optional[PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormatUnitScale], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormatUnitScale],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f15a6a6f734806d92190e0ac886bcc724b497eb3100f8c40fe55b85500b50f95)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetTreemapDefinitionRequestFormulaOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTreemapDefinitionRequestFormulaOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3a1a53cd91cd017c2e1c09fed2df4c94f958f474546f5c17169a418e046f94e5)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putConditionalFormats")
    def put_conditional_formats(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetTreemapDefinitionRequestFormulaConditionalFormats, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__eeee701ecb5e4080f3715ca16d5c3fa2d70f7db8dc254a5baccdb7d77bef1f5e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putConditionalFormats", [value]))

    @jsii.member(jsii_name="putLimit")
    def put_limit(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        order: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param count: The number of results to return. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#count Powerpack#count}
        :param order: The direction of the sort. Valid values are ``asc``, ``desc``. Defaults to ``"desc"``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        value = PowerpackWidgetTreemapDefinitionRequestFormulaLimit(
            count=count, order=order
        )

        return typing.cast(None, jsii.invoke(self, "putLimit", [value]))

    @jsii.member(jsii_name="putNumberFormat")
    def put_number_format(
        self,
        *,
        unit: typing.Union[PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormatUnit, typing.Dict[builtins.str, typing.Any]],
        unit_scale: typing.Optional[typing.Union[PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormatUnitScale, typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param unit: unit block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit Powerpack#unit}
        :param unit_scale: unit_scale block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#unit_scale Powerpack#unit_scale}
        '''
        value = PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormat(
            unit=unit, unit_scale=unit_scale
        )

        return typing.cast(None, jsii.invoke(self, "putNumberFormat", [value]))

    @jsii.member(jsii_name="putStyle")
    def put_style(
        self,
        *,
        palette: typing.Optional[builtins.str] = None,
        palette_index: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param palette: The color palette used to display the formula. A guide to the available color palettes can be found at https://docs.datadoghq.com/dashboards/guide/widget_colors. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette Powerpack#palette}
        :param palette_index: Index specifying which color to use within the palette. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette_index Powerpack#palette_index}
        '''
        value = PowerpackWidgetTreemapDefinitionRequestFormulaStyle(
            palette=palette, palette_index=palette_index
        )

        return typing.cast(None, jsii.invoke(self, "putStyle", [value]))

    @jsii.member(jsii_name="resetAlias")
    def reset_alias(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAlias", []))

    @jsii.member(jsii_name="resetCellDisplayMode")
    def reset_cell_display_mode(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCellDisplayMode", []))

    @jsii.member(jsii_name="resetConditionalFormats")
    def reset_conditional_formats(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetConditionalFormats", []))

    @jsii.member(jsii_name="resetLimit")
    def reset_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLimit", []))

    @jsii.member(jsii_name="resetNumberFormat")
    def reset_number_format(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetNumberFormat", []))

    @jsii.member(jsii_name="resetStyle")
    def reset_style(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetStyle", []))

    @builtins.property
    @jsii.member(jsii_name="conditionalFormats")
    def conditional_formats(
        self,
    ) -> PowerpackWidgetTreemapDefinitionRequestFormulaConditionalFormatsList:
        return typing.cast(PowerpackWidgetTreemapDefinitionRequestFormulaConditionalFormatsList, jsii.get(self, "conditionalFormats"))

    @builtins.property
    @jsii.member(jsii_name="limit")
    def limit(
        self,
    ) -> PowerpackWidgetTreemapDefinitionRequestFormulaLimitOutputReference:
        return typing.cast(PowerpackWidgetTreemapDefinitionRequestFormulaLimitOutputReference, jsii.get(self, "limit"))

    @builtins.property
    @jsii.member(jsii_name="numberFormat")
    def number_format(
        self,
    ) -> PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormatOutputReference:
        return typing.cast(PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormatOutputReference, jsii.get(self, "numberFormat"))

    @builtins.property
    @jsii.member(jsii_name="style")
    def style(
        self,
    ) -> "PowerpackWidgetTreemapDefinitionRequestFormulaStyleOutputReference":
        return typing.cast("PowerpackWidgetTreemapDefinitionRequestFormulaStyleOutputReference", jsii.get(self, "style"))

    @builtins.property
    @jsii.member(jsii_name="aliasInput")
    def alias_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aliasInput"))

    @builtins.property
    @jsii.member(jsii_name="cellDisplayModeInput")
    def cell_display_mode_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "cellDisplayModeInput"))

    @builtins.property
    @jsii.member(jsii_name="conditionalFormatsInput")
    def conditional_formats_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTreemapDefinitionRequestFormulaConditionalFormats]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTreemapDefinitionRequestFormulaConditionalFormats]]], jsii.get(self, "conditionalFormatsInput"))

    @builtins.property
    @jsii.member(jsii_name="formulaExpressionInput")
    def formula_expression_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "formulaExpressionInput"))

    @builtins.property
    @jsii.member(jsii_name="limitInput")
    def limit_input(
        self,
    ) -> typing.Optional[PowerpackWidgetTreemapDefinitionRequestFormulaLimit]:
        return typing.cast(typing.Optional[PowerpackWidgetTreemapDefinitionRequestFormulaLimit], jsii.get(self, "limitInput"))

    @builtins.property
    @jsii.member(jsii_name="numberFormatInput")
    def number_format_input(
        self,
    ) -> typing.Optional[PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormat]:
        return typing.cast(typing.Optional[PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormat], jsii.get(self, "numberFormatInput"))

    @builtins.property
    @jsii.member(jsii_name="styleInput")
    def style_input(
        self,
    ) -> typing.Optional["PowerpackWidgetTreemapDefinitionRequestFormulaStyle"]:
        return typing.cast(typing.Optional["PowerpackWidgetTreemapDefinitionRequestFormulaStyle"], jsii.get(self, "styleInput"))

    @builtins.property
    @jsii.member(jsii_name="alias")
    def alias(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "alias"))

    @alias.setter
    def alias(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e2e53ab51776167d77b9d4ea4f7136c5d817663d72f683f925506c7e7fdeaca3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "alias", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="cellDisplayMode")
    def cell_display_mode(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "cellDisplayMode"))

    @cell_display_mode.setter
    def cell_display_mode(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dfee514ff07c6bdbb526fa4340f5db76ef881b1e1f47de3cbcb25b7ce67ca42d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "cellDisplayMode", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="formulaExpression")
    def formula_expression(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "formulaExpression"))

    @formula_expression.setter
    def formula_expression(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f68c163e2b1aa8e20009bc6a6ccdbc3a04b012df442c3f0caa1a31bd276acc3f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "formulaExpression", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTreemapDefinitionRequestFormula]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTreemapDefinitionRequestFormula]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTreemapDefinitionRequestFormula]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c52367da7e24ed801a1c77eaa274d56041f2c02aa3b097547bd8bd989d71df32)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTreemapDefinitionRequestFormulaStyle",
    jsii_struct_bases=[],
    name_mapping={"palette": "palette", "palette_index": "paletteIndex"},
)
class PowerpackWidgetTreemapDefinitionRequestFormulaStyle:
    def __init__(
        self,
        *,
        palette: typing.Optional[builtins.str] = None,
        palette_index: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param palette: The color palette used to display the formula. A guide to the available color palettes can be found at https://docs.datadoghq.com/dashboards/guide/widget_colors. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette Powerpack#palette}
        :param palette_index: Index specifying which color to use within the palette. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette_index Powerpack#palette_index}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b26671d570734520dbe81190028071466873e1d7496f03296b241a5418f945e3)
            check_type(argname="argument palette", value=palette, expected_type=type_hints["palette"])
            check_type(argname="argument palette_index", value=palette_index, expected_type=type_hints["palette_index"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if palette is not None:
            self._values["palette"] = palette
        if palette_index is not None:
            self._values["palette_index"] = palette_index

    @builtins.property
    def palette(self) -> typing.Optional[builtins.str]:
        '''The color palette used to display the formula.

        A guide to the available color palettes can be found at https://docs.datadoghq.com/dashboards/guide/widget_colors.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette Powerpack#palette}
        '''
        result = self._values.get("palette")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def palette_index(self) -> typing.Optional[jsii.Number]:
        '''Index specifying which color to use within the palette.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#palette_index Powerpack#palette_index}
        '''
        result = self._values.get("palette_index")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetTreemapDefinitionRequestFormulaStyle(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetTreemapDefinitionRequestFormulaStyleOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTreemapDefinitionRequestFormulaStyleOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7e1fbad6c0aca07710db8fa06db21973f6a280e419986025dcb63f81d1f79702)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetPalette")
    def reset_palette(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPalette", []))

    @jsii.member(jsii_name="resetPaletteIndex")
    def reset_palette_index(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPaletteIndex", []))

    @builtins.property
    @jsii.member(jsii_name="paletteIndexInput")
    def palette_index_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "paletteIndexInput"))

    @builtins.property
    @jsii.member(jsii_name="paletteInput")
    def palette_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "paletteInput"))

    @builtins.property
    @jsii.member(jsii_name="palette")
    def palette(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "palette"))

    @palette.setter
    def palette(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ab1225d4e7abd135b61978cb00c4917594bbef18ab6e69613c088939d2fe0a06)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "palette", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="paletteIndex")
    def palette_index(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "paletteIndex"))

    @palette_index.setter
    def palette_index(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ffcddf2353ebcd5c5edb0e40b8d2403447ddfb108a5a97bd3ad640f5e1c1e096)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "paletteIndex", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetTreemapDefinitionRequestFormulaStyle]:
        return typing.cast(typing.Optional[PowerpackWidgetTreemapDefinitionRequestFormulaStyle], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetTreemapDefinitionRequestFormulaStyle],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__28823fc4fbc0b12a2c919d803d25d8f3b8bfc403814a47f55ea917dbbc06ab4a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetTreemapDefinitionRequestList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTreemapDefinitionRequestList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c1736bbadf35d8b28041273f7c4db5f166f2cd4644df58bca42e52948779490b)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetTreemapDefinitionRequestOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__da57d94aa3683ef89e4082f79b50b9bfeb294b700a514aebac0432e6b4d6153a)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetTreemapDefinitionRequestOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__02d6858552ea75d0ec911b704870768244df1b27941b2e0e16336b6fe92422e4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__004b477147e7889bc8483f3e054d174aef279cc459fda22a5859f816867a6aeb)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bff0ded4022ef27765594884227136da993cf8a124d4b8167e9776306c978e69)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTreemapDefinitionRequest]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTreemapDefinitionRequest]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTreemapDefinitionRequest]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__04358c7f8e6019b419e396ec992316ceb12a5183a1aece9d56a4c1180ba40ffb)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetTreemapDefinitionRequestOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTreemapDefinitionRequestOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c1b702e25f3456d3b264cb08a16a897256420d623675000d6b600b768ffa992d)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putFormula")
    def put_formula(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetTreemapDefinitionRequestFormula, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b378911043395efb1ab219f3798ea09811eef90c729b6cf80897cf7b20f50ecf)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putFormula", [value]))

    @jsii.member(jsii_name="putQuery")
    def put_query(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetTreemapDefinitionRequestQuery", typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6cf01c8c117d055a87fe9e97392bb0b59677c64b461e06dfc220b33c202d9ea4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putQuery", [value]))

    @jsii.member(jsii_name="resetFormula")
    def reset_formula(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFormula", []))

    @jsii.member(jsii_name="resetQuery")
    def reset_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetQuery", []))

    @builtins.property
    @jsii.member(jsii_name="formula")
    def formula(self) -> PowerpackWidgetTreemapDefinitionRequestFormulaList:
        return typing.cast(PowerpackWidgetTreemapDefinitionRequestFormulaList, jsii.get(self, "formula"))

    @builtins.property
    @jsii.member(jsii_name="query")
    def query(self) -> "PowerpackWidgetTreemapDefinitionRequestQueryList":
        return typing.cast("PowerpackWidgetTreemapDefinitionRequestQueryList", jsii.get(self, "query"))

    @builtins.property
    @jsii.member(jsii_name="formulaInput")
    def formula_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTreemapDefinitionRequestFormula]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTreemapDefinitionRequestFormula]]], jsii.get(self, "formulaInput"))

    @builtins.property
    @jsii.member(jsii_name="queryInput")
    def query_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetTreemapDefinitionRequestQuery"]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetTreemapDefinitionRequestQuery"]]], jsii.get(self, "queryInput"))

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTreemapDefinitionRequest]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTreemapDefinitionRequest]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTreemapDefinitionRequest]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__48abfa7e8da5361ca611300f792e0300a9685a86254d8814fb48832663514bb8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTreemapDefinitionRequestQuery",
    jsii_struct_bases=[],
    name_mapping={
        "apm_dependency_stats_query": "apmDependencyStatsQuery",
        "apm_resource_stats_query": "apmResourceStatsQuery",
        "cloud_cost_query": "cloudCostQuery",
        "event_query": "eventQuery",
        "metric_query": "metricQuery",
        "process_query": "processQuery",
        "slo_query": "sloQuery",
    },
)
class PowerpackWidgetTreemapDefinitionRequestQuery:
    def __init__(
        self,
        *,
        apm_dependency_stats_query: typing.Optional[typing.Union["PowerpackWidgetTreemapDefinitionRequestQueryApmDependencyStatsQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        apm_resource_stats_query: typing.Optional[typing.Union["PowerpackWidgetTreemapDefinitionRequestQueryApmResourceStatsQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        cloud_cost_query: typing.Optional[typing.Union["PowerpackWidgetTreemapDefinitionRequestQueryCloudCostQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        event_query: typing.Optional[typing.Union["PowerpackWidgetTreemapDefinitionRequestQueryEventQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        metric_query: typing.Optional[typing.Union["PowerpackWidgetTreemapDefinitionRequestQueryMetricQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        process_query: typing.Optional[typing.Union["PowerpackWidgetTreemapDefinitionRequestQueryProcessQuery", typing.Dict[builtins.str, typing.Any]]] = None,
        slo_query: typing.Optional[typing.Union["PowerpackWidgetTreemapDefinitionRequestQuerySloQuery", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param apm_dependency_stats_query: apm_dependency_stats_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#apm_dependency_stats_query Powerpack#apm_dependency_stats_query}
        :param apm_resource_stats_query: apm_resource_stats_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#apm_resource_stats_query Powerpack#apm_resource_stats_query}
        :param cloud_cost_query: cloud_cost_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cloud_cost_query Powerpack#cloud_cost_query}
        :param event_query: event_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#event_query Powerpack#event_query}
        :param metric_query: metric_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric_query Powerpack#metric_query}
        :param process_query: process_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#process_query Powerpack#process_query}
        :param slo_query: slo_query block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#slo_query Powerpack#slo_query}
        '''
        if isinstance(apm_dependency_stats_query, dict):
            apm_dependency_stats_query = PowerpackWidgetTreemapDefinitionRequestQueryApmDependencyStatsQuery(**apm_dependency_stats_query)
        if isinstance(apm_resource_stats_query, dict):
            apm_resource_stats_query = PowerpackWidgetTreemapDefinitionRequestQueryApmResourceStatsQuery(**apm_resource_stats_query)
        if isinstance(cloud_cost_query, dict):
            cloud_cost_query = PowerpackWidgetTreemapDefinitionRequestQueryCloudCostQuery(**cloud_cost_query)
        if isinstance(event_query, dict):
            event_query = PowerpackWidgetTreemapDefinitionRequestQueryEventQuery(**event_query)
        if isinstance(metric_query, dict):
            metric_query = PowerpackWidgetTreemapDefinitionRequestQueryMetricQuery(**metric_query)
        if isinstance(process_query, dict):
            process_query = PowerpackWidgetTreemapDefinitionRequestQueryProcessQuery(**process_query)
        if isinstance(slo_query, dict):
            slo_query = PowerpackWidgetTreemapDefinitionRequestQuerySloQuery(**slo_query)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1625143f46ff499a6ea3fb6e9bbd72bfba1982aa61bd2fd66646a70de29093c0)
            check_type(argname="argument apm_dependency_stats_query", value=apm_dependency_stats_query, expected_type=type_hints["apm_dependency_stats_query"])
            check_type(argname="argument apm_resource_stats_query", value=apm_resource_stats_query, expected_type=type_hints["apm_resource_stats_query"])
            check_type(argname="argument cloud_cost_query", value=cloud_cost_query, expected_type=type_hints["cloud_cost_query"])
            check_type(argname="argument event_query", value=event_query, expected_type=type_hints["event_query"])
            check_type(argname="argument metric_query", value=metric_query, expected_type=type_hints["metric_query"])
            check_type(argname="argument process_query", value=process_query, expected_type=type_hints["process_query"])
            check_type(argname="argument slo_query", value=slo_query, expected_type=type_hints["slo_query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if apm_dependency_stats_query is not None:
            self._values["apm_dependency_stats_query"] = apm_dependency_stats_query
        if apm_resource_stats_query is not None:
            self._values["apm_resource_stats_query"] = apm_resource_stats_query
        if cloud_cost_query is not None:
            self._values["cloud_cost_query"] = cloud_cost_query
        if event_query is not None:
            self._values["event_query"] = event_query
        if metric_query is not None:
            self._values["metric_query"] = metric_query
        if process_query is not None:
            self._values["process_query"] = process_query
        if slo_query is not None:
            self._values["slo_query"] = slo_query

    @builtins.property
    def apm_dependency_stats_query(
        self,
    ) -> typing.Optional["PowerpackWidgetTreemapDefinitionRequestQueryApmDependencyStatsQuery"]:
        '''apm_dependency_stats_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#apm_dependency_stats_query Powerpack#apm_dependency_stats_query}
        '''
        result = self._values.get("apm_dependency_stats_query")
        return typing.cast(typing.Optional["PowerpackWidgetTreemapDefinitionRequestQueryApmDependencyStatsQuery"], result)

    @builtins.property
    def apm_resource_stats_query(
        self,
    ) -> typing.Optional["PowerpackWidgetTreemapDefinitionRequestQueryApmResourceStatsQuery"]:
        '''apm_resource_stats_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#apm_resource_stats_query Powerpack#apm_resource_stats_query}
        '''
        result = self._values.get("apm_resource_stats_query")
        return typing.cast(typing.Optional["PowerpackWidgetTreemapDefinitionRequestQueryApmResourceStatsQuery"], result)

    @builtins.property
    def cloud_cost_query(
        self,
    ) -> typing.Optional["PowerpackWidgetTreemapDefinitionRequestQueryCloudCostQuery"]:
        '''cloud_cost_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cloud_cost_query Powerpack#cloud_cost_query}
        '''
        result = self._values.get("cloud_cost_query")
        return typing.cast(typing.Optional["PowerpackWidgetTreemapDefinitionRequestQueryCloudCostQuery"], result)

    @builtins.property
    def event_query(
        self,
    ) -> typing.Optional["PowerpackWidgetTreemapDefinitionRequestQueryEventQuery"]:
        '''event_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#event_query Powerpack#event_query}
        '''
        result = self._values.get("event_query")
        return typing.cast(typing.Optional["PowerpackWidgetTreemapDefinitionRequestQueryEventQuery"], result)

    @builtins.property
    def metric_query(
        self,
    ) -> typing.Optional["PowerpackWidgetTreemapDefinitionRequestQueryMetricQuery"]:
        '''metric_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric_query Powerpack#metric_query}
        '''
        result = self._values.get("metric_query")
        return typing.cast(typing.Optional["PowerpackWidgetTreemapDefinitionRequestQueryMetricQuery"], result)

    @builtins.property
    def process_query(
        self,
    ) -> typing.Optional["PowerpackWidgetTreemapDefinitionRequestQueryProcessQuery"]:
        '''process_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#process_query Powerpack#process_query}
        '''
        result = self._values.get("process_query")
        return typing.cast(typing.Optional["PowerpackWidgetTreemapDefinitionRequestQueryProcessQuery"], result)

    @builtins.property
    def slo_query(
        self,
    ) -> typing.Optional["PowerpackWidgetTreemapDefinitionRequestQuerySloQuery"]:
        '''slo_query block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#slo_query Powerpack#slo_query}
        '''
        result = self._values.get("slo_query")
        return typing.cast(typing.Optional["PowerpackWidgetTreemapDefinitionRequestQuerySloQuery"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetTreemapDefinitionRequestQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTreemapDefinitionRequestQueryApmDependencyStatsQuery",
    jsii_struct_bases=[],
    name_mapping={
        "data_source": "dataSource",
        "env": "env",
        "name": "name",
        "operation_name": "operationName",
        "resource_name": "resourceName",
        "service": "service",
        "stat": "stat",
        "cross_org_uuids": "crossOrgUuids",
        "is_upstream": "isUpstream",
        "primary_tag_name": "primaryTagName",
        "primary_tag_value": "primaryTagValue",
    },
)
class PowerpackWidgetTreemapDefinitionRequestQueryApmDependencyStatsQuery:
    def __init__(
        self,
        *,
        data_source: builtins.str,
        env: builtins.str,
        name: builtins.str,
        operation_name: builtins.str,
        resource_name: builtins.str,
        service: builtins.str,
        stat: builtins.str,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        is_upstream: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        primary_tag_name: typing.Optional[builtins.str] = None,
        primary_tag_value: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param data_source: The data source for APM Dependency Stats queries. Valid values are ``apm_dependency_stats``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param env: APM environment. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#env Powerpack#env}
        :param name: The name of query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param operation_name: Name of operation on service. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#operation_name Powerpack#operation_name}
        :param resource_name: APM resource. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#resource_name Powerpack#resource_name}
        :param service: APM service. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#service Powerpack#service}
        :param stat: APM statistic. Valid values are ``avg_duration``, ``avg_root_duration``, ``avg_spans_per_trace``, ``error_rate``, ``pct_exec_time``, ``pct_of_traces``, ``total_traces_count``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#stat Powerpack#stat}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param is_upstream: Determines whether stats for upstream or downstream dependencies should be queried. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#is_upstream Powerpack#is_upstream}
        :param primary_tag_name: The name of the second primary tag used within APM; required when ``primary_tag_value`` is specified. See https://docs.datadoghq.com/tracing/guide/setting_primary_tags_to_scope/#add-a-second-primary-tag-in-datadog. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_name Powerpack#primary_tag_name}
        :param primary_tag_value: Filter APM data by the second primary tag. ``primary_tag_name`` must also be specified. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_value Powerpack#primary_tag_value}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c800cac7e30f7457ac4f5217f5dd3a7b2f27c082764aa6f7c8d8b106451922ff)
            check_type(argname="argument data_source", value=data_source, expected_type=type_hints["data_source"])
            check_type(argname="argument env", value=env, expected_type=type_hints["env"])
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument operation_name", value=operation_name, expected_type=type_hints["operation_name"])
            check_type(argname="argument resource_name", value=resource_name, expected_type=type_hints["resource_name"])
            check_type(argname="argument service", value=service, expected_type=type_hints["service"])
            check_type(argname="argument stat", value=stat, expected_type=type_hints["stat"])
            check_type(argname="argument cross_org_uuids", value=cross_org_uuids, expected_type=type_hints["cross_org_uuids"])
            check_type(argname="argument is_upstream", value=is_upstream, expected_type=type_hints["is_upstream"])
            check_type(argname="argument primary_tag_name", value=primary_tag_name, expected_type=type_hints["primary_tag_name"])
            check_type(argname="argument primary_tag_value", value=primary_tag_value, expected_type=type_hints["primary_tag_value"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "data_source": data_source,
            "env": env,
            "name": name,
            "operation_name": operation_name,
            "resource_name": resource_name,
            "service": service,
            "stat": stat,
        }
        if cross_org_uuids is not None:
            self._values["cross_org_uuids"] = cross_org_uuids
        if is_upstream is not None:
            self._values["is_upstream"] = is_upstream
        if primary_tag_name is not None:
            self._values["primary_tag_name"] = primary_tag_name
        if primary_tag_value is not None:
            self._values["primary_tag_value"] = primary_tag_value

    @builtins.property
    def data_source(self) -> builtins.str:
        '''The data source for APM Dependency Stats queries. Valid values are ``apm_dependency_stats``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        '''
        result = self._values.get("data_source")
        assert result is not None, "Required property 'data_source' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def env(self) -> builtins.str:
        '''APM environment.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#env Powerpack#env}
        '''
        result = self._values.get("env")
        assert result is not None, "Required property 'env' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def name(self) -> builtins.str:
        '''The name of query for use in formulas.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        '''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def operation_name(self) -> builtins.str:
        '''Name of operation on service.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#operation_name Powerpack#operation_name}
        '''
        result = self._values.get("operation_name")
        assert result is not None, "Required property 'operation_name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def resource_name(self) -> builtins.str:
        '''APM resource.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#resource_name Powerpack#resource_name}
        '''
        result = self._values.get("resource_name")
        assert result is not None, "Required property 'resource_name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def service(self) -> builtins.str:
        '''APM service.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#service Powerpack#service}
        '''
        result = self._values.get("service")
        assert result is not None, "Required property 'service' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def stat(self) -> builtins.str:
        '''APM statistic. Valid values are ``avg_duration``, ``avg_root_duration``, ``avg_spans_per_trace``, ``error_rate``, ``pct_exec_time``, ``pct_of_traces``, ``total_traces_count``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#stat Powerpack#stat}
        '''
        result = self._values.get("stat")
        assert result is not None, "Required property 'stat' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def cross_org_uuids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''The source organization UUID for cross organization queries. Feature in Private Beta.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        '''
        result = self._values.get("cross_org_uuids")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def is_upstream(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        '''Determines whether stats for upstream or downstream dependencies should be queried.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#is_upstream Powerpack#is_upstream}
        '''
        result = self._values.get("is_upstream")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)

    @builtins.property
    def primary_tag_name(self) -> typing.Optional[builtins.str]:
        '''The name of the second primary tag used within APM; required when ``primary_tag_value`` is specified. See https://docs.datadoghq.com/tracing/guide/setting_primary_tags_to_scope/#add-a-second-primary-tag-in-datadog.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_name Powerpack#primary_tag_name}
        '''
        result = self._values.get("primary_tag_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def primary_tag_value(self) -> typing.Optional[builtins.str]:
        '''Filter APM data by the second primary tag. ``primary_tag_name`` must also be specified.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_value Powerpack#primary_tag_value}
        '''
        result = self._values.get("primary_tag_value")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetTreemapDefinitionRequestQueryApmDependencyStatsQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetTreemapDefinitionRequestQueryApmDependencyStatsQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTreemapDefinitionRequestQueryApmDependencyStatsQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ba18897f980842aac9f2b658a057a896279c77610d72c5a817183715ff8dcf63)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetCrossOrgUuids")
    def reset_cross_org_uuids(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCrossOrgUuids", []))

    @jsii.member(jsii_name="resetIsUpstream")
    def reset_is_upstream(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetIsUpstream", []))

    @jsii.member(jsii_name="resetPrimaryTagName")
    def reset_primary_tag_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPrimaryTagName", []))

    @jsii.member(jsii_name="resetPrimaryTagValue")
    def reset_primary_tag_value(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPrimaryTagValue", []))

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuidsInput")
    def cross_org_uuids_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "crossOrgUuidsInput"))

    @builtins.property
    @jsii.member(jsii_name="dataSourceInput")
    def data_source_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "dataSourceInput"))

    @builtins.property
    @jsii.member(jsii_name="envInput")
    def env_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "envInput"))

    @builtins.property
    @jsii.member(jsii_name="isUpstreamInput")
    def is_upstream_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "isUpstreamInput"))

    @builtins.property
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property
    @jsii.member(jsii_name="operationNameInput")
    def operation_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "operationNameInput"))

    @builtins.property
    @jsii.member(jsii_name="primaryTagNameInput")
    def primary_tag_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "primaryTagNameInput"))

    @builtins.property
    @jsii.member(jsii_name="primaryTagValueInput")
    def primary_tag_value_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "primaryTagValueInput"))

    @builtins.property
    @jsii.member(jsii_name="resourceNameInput")
    def resource_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "resourceNameInput"))

    @builtins.property
    @jsii.member(jsii_name="serviceInput")
    def service_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "serviceInput"))

    @builtins.property
    @jsii.member(jsii_name="statInput")
    def stat_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "statInput"))

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuids")
    def cross_org_uuids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "crossOrgUuids"))

    @cross_org_uuids.setter
    def cross_org_uuids(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bd576faf68cc9762fe0f9093a24462469c2d6ed875e174e3cfeec5f4579942fc)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "crossOrgUuids", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="dataSource")
    def data_source(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "dataSource"))

    @data_source.setter
    def data_source(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ff80990444c52cc1203c2743507e238c58c699928f3a83b1cd5a47bd9414542c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "dataSource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="env")
    def env(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "env"))

    @env.setter
    def env(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0c90c98d2666b3663968bff4ac223a71a3350917551c8328f397afa7b1d1eadf)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "env", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="isUpstream")
    def is_upstream(self) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "isUpstream"))

    @is_upstream.setter
    def is_upstream(
        self,
        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7708376f098b2e69fd8e883970200abf4d9b840d767d397e4c853297094098c6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "isUpstream", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ef76eea7d7558113a89a60ed5fd1acfd5ec2dd3a48644d03191186ccdc10d01f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "name", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="operationName")
    def operation_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "operationName"))

    @operation_name.setter
    def operation_name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d9525126ffe2b1f9d09426e946489d3f42b5f6f9cc3a5ae18c86d7e9c700e96b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "operationName", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="primaryTagName")
    def primary_tag_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "primaryTagName"))

    @primary_tag_name.setter
    def primary_tag_name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__85370f26b8c3a53710051fa2273138c043f76001b4fc5414e94968929990d509)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "primaryTagName", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="primaryTagValue")
    def primary_tag_value(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "primaryTagValue"))

    @primary_tag_value.setter
    def primary_tag_value(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__936f469d1a1678b3d53e4f3ab92330b12dc06656059fd92b6d8e81f65ed527f0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "primaryTagValue", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="resourceName")
    def resource_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "resourceName"))

    @resource_name.setter
    def resource_name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e3ee20b0198a3a1d055c76f2666a97ca6e743284ef80932914e608bb7e339086)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "resourceName", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="service")
    def service(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "service"))

    @service.setter
    def service(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__89f917d0ff69f6885257917352835f0276a8af4d8e35cf55e823ee27421facbc)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "service", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="stat")
    def stat(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "stat"))

    @stat.setter
    def stat(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__403e04dedbbe58747a3d924397144ad43060a7e98f3684f20d9872b6526b8a6f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "stat", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetTreemapDefinitionRequestQueryApmDependencyStatsQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetTreemapDefinitionRequestQueryApmDependencyStatsQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetTreemapDefinitionRequestQueryApmDependencyStatsQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4e3e025f98ac827edcd254d561600e593cbc9fe1c5bb78f6673e1372838781cc)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTreemapDefinitionRequestQueryApmResourceStatsQuery",
    jsii_struct_bases=[],
    name_mapping={
        "data_source": "dataSource",
        "env": "env",
        "name": "name",
        "service": "service",
        "stat": "stat",
        "cross_org_uuids": "crossOrgUuids",
        "group_by": "groupBy",
        "operation_name": "operationName",
        "primary_tag_name": "primaryTagName",
        "primary_tag_value": "primaryTagValue",
        "resource_name": "resourceName",
    },
)
class PowerpackWidgetTreemapDefinitionRequestQueryApmResourceStatsQuery:
    def __init__(
        self,
        *,
        data_source: builtins.str,
        env: builtins.str,
        name: builtins.str,
        service: builtins.str,
        stat: builtins.str,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        group_by: typing.Optional[typing.Sequence[builtins.str]] = None,
        operation_name: typing.Optional[builtins.str] = None,
        primary_tag_name: typing.Optional[builtins.str] = None,
        primary_tag_value: typing.Optional[builtins.str] = None,
        resource_name: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param data_source: The data source for APM Resource Stats queries. Valid values are ``apm_resource_stats``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param env: APM environment. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#env Powerpack#env}
        :param name: The name of query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param service: APM service. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#service Powerpack#service}
        :param stat: APM statistic. Valid values are ``errors``, ``error_rate``, ``hits``, ``latency_avg``, ``latency_distribution``, ``latency_max``, ``latency_p50``, ``latency_p75``, ``latency_p90``, ``latency_p95``, ``latency_p99``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#stat Powerpack#stat}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param group_by: Array of fields to group results by. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param operation_name: Name of operation on service. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#operation_name Powerpack#operation_name}
        :param primary_tag_name: The name of the second primary tag used within APM; required when ``primary_tag_value`` is specified. See https://docs.datadoghq.com/tracing/guide/setting_primary_tags_to_scope/#add-a-second-primary-tag-in-datadog. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_name Powerpack#primary_tag_name}
        :param primary_tag_value: Filter APM data by the second primary tag. ``primary_tag_name`` must also be specified. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_value Powerpack#primary_tag_value}
        :param resource_name: APM resource. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#resource_name Powerpack#resource_name}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3015d885491c426561fbbf39de0ea1fd0f5680327f09827ddd71bef0d5f92a9e)
            check_type(argname="argument data_source", value=data_source, expected_type=type_hints["data_source"])
            check_type(argname="argument env", value=env, expected_type=type_hints["env"])
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument service", value=service, expected_type=type_hints["service"])
            check_type(argname="argument stat", value=stat, expected_type=type_hints["stat"])
            check_type(argname="argument cross_org_uuids", value=cross_org_uuids, expected_type=type_hints["cross_org_uuids"])
            check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
            check_type(argname="argument operation_name", value=operation_name, expected_type=type_hints["operation_name"])
            check_type(argname="argument primary_tag_name", value=primary_tag_name, expected_type=type_hints["primary_tag_name"])
            check_type(argname="argument primary_tag_value", value=primary_tag_value, expected_type=type_hints["primary_tag_value"])
            check_type(argname="argument resource_name", value=resource_name, expected_type=type_hints["resource_name"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "data_source": data_source,
            "env": env,
            "name": name,
            "service": service,
            "stat": stat,
        }
        if cross_org_uuids is not None:
            self._values["cross_org_uuids"] = cross_org_uuids
        if group_by is not None:
            self._values["group_by"] = group_by
        if operation_name is not None:
            self._values["operation_name"] = operation_name
        if primary_tag_name is not None:
            self._values["primary_tag_name"] = primary_tag_name
        if primary_tag_value is not None:
            self._values["primary_tag_value"] = primary_tag_value
        if resource_name is not None:
            self._values["resource_name"] = resource_name

    @builtins.property
    def data_source(self) -> builtins.str:
        '''The data source for APM Resource Stats queries. Valid values are ``apm_resource_stats``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        '''
        result = self._values.get("data_source")
        assert result is not None, "Required property 'data_source' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def env(self) -> builtins.str:
        '''APM environment.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#env Powerpack#env}
        '''
        result = self._values.get("env")
        assert result is not None, "Required property 'env' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def name(self) -> builtins.str:
        '''The name of query for use in formulas.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        '''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def service(self) -> builtins.str:
        '''APM service.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#service Powerpack#service}
        '''
        result = self._values.get("service")
        assert result is not None, "Required property 'service' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def stat(self) -> builtins.str:
        '''APM statistic. Valid values are ``errors``, ``error_rate``, ``hits``, ``latency_avg``, ``latency_distribution``, ``latency_max``, ``latency_p50``, ``latency_p75``, ``latency_p90``, ``latency_p95``, ``latency_p99``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#stat Powerpack#stat}
        '''
        result = self._values.get("stat")
        assert result is not None, "Required property 'stat' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def cross_org_uuids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''The source organization UUID for cross organization queries. Feature in Private Beta.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        '''
        result = self._values.get("cross_org_uuids")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def group_by(self) -> typing.Optional[typing.List[builtins.str]]:
        '''Array of fields to group results by.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        '''
        result = self._values.get("group_by")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def operation_name(self) -> typing.Optional[builtins.str]:
        '''Name of operation on service.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#operation_name Powerpack#operation_name}
        '''
        result = self._values.get("operation_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def primary_tag_name(self) -> typing.Optional[builtins.str]:
        '''The name of the second primary tag used within APM; required when ``primary_tag_value`` is specified. See https://docs.datadoghq.com/tracing/guide/setting_primary_tags_to_scope/#add-a-second-primary-tag-in-datadog.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_name Powerpack#primary_tag_name}
        '''
        result = self._values.get("primary_tag_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def primary_tag_value(self) -> typing.Optional[builtins.str]:
        '''Filter APM data by the second primary tag. ``primary_tag_name`` must also be specified.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_value Powerpack#primary_tag_value}
        '''
        result = self._values.get("primary_tag_value")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def resource_name(self) -> typing.Optional[builtins.str]:
        '''APM resource.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#resource_name Powerpack#resource_name}
        '''
        result = self._values.get("resource_name")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetTreemapDefinitionRequestQueryApmResourceStatsQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetTreemapDefinitionRequestQueryApmResourceStatsQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTreemapDefinitionRequestQueryApmResourceStatsQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2b56b3e0c9e9ee6e0ad295daf45d74817be230b4eb51e542d8fb5ae618c1135f)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetCrossOrgUuids")
    def reset_cross_org_uuids(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCrossOrgUuids", []))

    @jsii.member(jsii_name="resetGroupBy")
    def reset_group_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGroupBy", []))

    @jsii.member(jsii_name="resetOperationName")
    def reset_operation_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetOperationName", []))

    @jsii.member(jsii_name="resetPrimaryTagName")
    def reset_primary_tag_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPrimaryTagName", []))

    @jsii.member(jsii_name="resetPrimaryTagValue")
    def reset_primary_tag_value(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPrimaryTagValue", []))

    @jsii.member(jsii_name="resetResourceName")
    def reset_resource_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetResourceName", []))

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuidsInput")
    def cross_org_uuids_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "crossOrgUuidsInput"))

    @builtins.property
    @jsii.member(jsii_name="dataSourceInput")
    def data_source_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "dataSourceInput"))

    @builtins.property
    @jsii.member(jsii_name="envInput")
    def env_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "envInput"))

    @builtins.property
    @jsii.member(jsii_name="groupByInput")
    def group_by_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "groupByInput"))

    @builtins.property
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property
    @jsii.member(jsii_name="operationNameInput")
    def operation_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "operationNameInput"))

    @builtins.property
    @jsii.member(jsii_name="primaryTagNameInput")
    def primary_tag_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "primaryTagNameInput"))

    @builtins.property
    @jsii.member(jsii_name="primaryTagValueInput")
    def primary_tag_value_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "primaryTagValueInput"))

    @builtins.property
    @jsii.member(jsii_name="resourceNameInput")
    def resource_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "resourceNameInput"))

    @builtins.property
    @jsii.member(jsii_name="serviceInput")
    def service_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "serviceInput"))

    @builtins.property
    @jsii.member(jsii_name="statInput")
    def stat_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "statInput"))

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuids")
    def cross_org_uuids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "crossOrgUuids"))

    @cross_org_uuids.setter
    def cross_org_uuids(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8d72ded041120ab505046300414f805df860663f92d9572a60132c387a424e84)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "crossOrgUuids", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="dataSource")
    def data_source(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "dataSource"))

    @data_source.setter
    def data_source(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__082aa33327f0222155e257d8e0d941fa8aac872a6c1f40c869c86795f39361d6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "dataSource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="env")
    def env(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "env"))

    @env.setter
    def env(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5659cd32b04ff62b4c20245922f5947d89558e78462d7e76986237ca707d1bac)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "env", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="groupBy")
    def group_by(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "groupBy"))

    @group_by.setter
    def group_by(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8e96283af86058636e51c22b808b27d94ced5a57f682eeb66b815c30d7d580d7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "groupBy", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__059c028fa63d7723fc67a182c1a70e5a046bd99503f9164dd138710bafdeb931)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "name", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="operationName")
    def operation_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "operationName"))

    @operation_name.setter
    def operation_name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1962f2881145b01afc466b4753ebfaec463bc9829a907ef26a852a57a0c19ba0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "operationName", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="primaryTagName")
    def primary_tag_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "primaryTagName"))

    @primary_tag_name.setter
    def primary_tag_name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e072a037ff264be58e08144becf451fee9f97b1114d7f9c0198746a480dbd5a1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "primaryTagName", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="primaryTagValue")
    def primary_tag_value(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "primaryTagValue"))

    @primary_tag_value.setter
    def primary_tag_value(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ff4d2c72e890f012c9d3cbd0be3a2dbb08cec9365cb8adf8003da99ff7f12388)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "primaryTagValue", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="resourceName")
    def resource_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "resourceName"))

    @resource_name.setter
    def resource_name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__74cd12111211675b2f6f940e82d2dab5a6f8b330fd01e19ddf5c2a0c81553d02)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "resourceName", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="service")
    def service(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "service"))

    @service.setter
    def service(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6ee5636f0f5164cae677f4812e1c39df4915b2766dc6c080e9db73ab8114d606)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "service", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="stat")
    def stat(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "stat"))

    @stat.setter
    def stat(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7f8d2dd79a71710de8df6314cf8870edc6089e8e52630c69de5959032a61ce80)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "stat", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetTreemapDefinitionRequestQueryApmResourceStatsQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetTreemapDefinitionRequestQueryApmResourceStatsQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetTreemapDefinitionRequestQueryApmResourceStatsQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9f68b45a2b8dbbe92a63907618e1a0f09163b2924a22decf9619e600915770ed)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTreemapDefinitionRequestQueryCloudCostQuery",
    jsii_struct_bases=[],
    name_mapping={
        "data_source": "dataSource",
        "name": "name",
        "query": "query",
        "aggregator": "aggregator",
        "cross_org_uuids": "crossOrgUuids",
    },
)
class PowerpackWidgetTreemapDefinitionRequestQueryCloudCostQuery:
    def __init__(
        self,
        *,
        data_source: builtins.str,
        name: builtins.str,
        query: builtins.str,
        aggregator: typing.Optional[builtins.str] = None,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
    ) -> None:
        '''
        :param data_source: The data source for cloud cost queries. Valid values are ``cloud_cost``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param name: The name of the query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param query: The cloud cost query definition. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        :param aggregator: The aggregation methods available for cloud cost queries. Valid values are ``avg``, ``last``, ``max``, ``min``, ``sum``, ``percentile``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregator Powerpack#aggregator}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fd010fa0a15841a053b1330a22e37e1d898e80ed8ec9e5fc4bdbf3cb028d98ea)
            check_type(argname="argument data_source", value=data_source, expected_type=type_hints["data_source"])
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument query", value=query, expected_type=type_hints["query"])
            check_type(argname="argument aggregator", value=aggregator, expected_type=type_hints["aggregator"])
            check_type(argname="argument cross_org_uuids", value=cross_org_uuids, expected_type=type_hints["cross_org_uuids"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "data_source": data_source,
            "name": name,
            "query": query,
        }
        if aggregator is not None:
            self._values["aggregator"] = aggregator
        if cross_org_uuids is not None:
            self._values["cross_org_uuids"] = cross_org_uuids

    @builtins.property
    def data_source(self) -> builtins.str:
        '''The data source for cloud cost queries. Valid values are ``cloud_cost``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        '''
        result = self._values.get("data_source")
        assert result is not None, "Required property 'data_source' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def name(self) -> builtins.str:
        '''The name of the query for use in formulas.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        '''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def query(self) -> builtins.str:
        '''The cloud cost query definition.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        '''
        result = self._values.get("query")
        assert result is not None, "Required property 'query' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def aggregator(self) -> typing.Optional[builtins.str]:
        '''The aggregation methods available for cloud cost queries. Valid values are ``avg``, ``last``, ``max``, ``min``, ``sum``, ``percentile``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregator Powerpack#aggregator}
        '''
        result = self._values.get("aggregator")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def cross_org_uuids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''The source organization UUID for cross organization queries. Feature in Private Beta.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        '''
        result = self._values.get("cross_org_uuids")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetTreemapDefinitionRequestQueryCloudCostQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetTreemapDefinitionRequestQueryCloudCostQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTreemapDefinitionRequestQueryCloudCostQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d4ae44e651ccdb9a05d7dd18e66fcdc9618df42fb085b8c1e76ba5fb43523a1f)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetAggregator")
    def reset_aggregator(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAggregator", []))

    @jsii.member(jsii_name="resetCrossOrgUuids")
    def reset_cross_org_uuids(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCrossOrgUuids", []))

    @builtins.property
    @jsii.member(jsii_name="aggregatorInput")
    def aggregator_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregatorInput"))

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuidsInput")
    def cross_org_uuids_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "crossOrgUuidsInput"))

    @builtins.property
    @jsii.member(jsii_name="dataSourceInput")
    def data_source_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "dataSourceInput"))

    @builtins.property
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property
    @jsii.member(jsii_name="queryInput")
    def query_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "queryInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregator")
    def aggregator(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregator"))

    @aggregator.setter
    def aggregator(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fd4b97d351e5bd54c773d337f912630429f15f8c342f6e26c0548c5d204c38da)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregator", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuids")
    def cross_org_uuids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "crossOrgUuids"))

    @cross_org_uuids.setter
    def cross_org_uuids(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9a4e201ffd3cb4805b1859fb070ab45ea14d5aa2b02a219b5633f799e089eb2f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "crossOrgUuids", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="dataSource")
    def data_source(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "dataSource"))

    @data_source.setter
    def data_source(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ab08a65e011ac7858c42841faf81ee6283489e5e7fbc9af4d9dd05a765998018)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "dataSource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__66449f8ed2017203152bad037cb64123757476e77ea074ba19c44c6dcc0db732)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "name", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="query")
    def query(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "query"))

    @query.setter
    def query(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e485db173f6cd575f8e5cdbccc58bcdea90e562ec85533ba4c3b384722da72ce)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "query", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetTreemapDefinitionRequestQueryCloudCostQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetTreemapDefinitionRequestQueryCloudCostQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetTreemapDefinitionRequestQueryCloudCostQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__89d7188a5630799c2f60721492a679a3b237cbb8eafd75033b8f077b835d015d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTreemapDefinitionRequestQueryEventQuery",
    jsii_struct_bases=[],
    name_mapping={
        "compute": "compute",
        "data_source": "dataSource",
        "name": "name",
        "cross_org_uuids": "crossOrgUuids",
        "group_by": "groupBy",
        "indexes": "indexes",
        "search": "search",
        "storage": "storage",
    },
)
class PowerpackWidgetTreemapDefinitionRequestQueryEventQuery:
    def __init__(
        self,
        *,
        compute: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetTreemapDefinitionRequestQueryEventQueryCompute", typing.Dict[builtins.str, typing.Any]]]],
        data_source: builtins.str,
        name: builtins.str,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["PowerpackWidgetTreemapDefinitionRequestQueryEventQueryGroupBy", typing.Dict[builtins.str, typing.Any]]]]] = None,
        indexes: typing.Optional[typing.Sequence[builtins.str]] = None,
        search: typing.Optional[typing.Union["PowerpackWidgetTreemapDefinitionRequestQueryEventQuerySearch", typing.Dict[builtins.str, typing.Any]]] = None,
        storage: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param compute: compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute Powerpack#compute}
        :param data_source: The data source for event platform-based queries. Valid values are ``logs``, ``spans``, ``network``, ``rum``, ``security_signals``, ``profiles``, ``audit``, ``events``, ``ci_tests``, ``ci_pipelines``, ``incident_analytics``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param name: The name of query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param indexes: An array of index names to query in the stream. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#indexes Powerpack#indexes}
        :param search: search block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search Powerpack#search}
        :param storage: Storage location (private beta). Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#storage Powerpack#storage}
        '''
        if isinstance(search, dict):
            search = PowerpackWidgetTreemapDefinitionRequestQueryEventQuerySearch(**search)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__61a1f0a1936aef4cfbdd7562fd507e925cfdcdca6682a643adbbd0fe7716bf6d)
            check_type(argname="argument compute", value=compute, expected_type=type_hints["compute"])
            check_type(argname="argument data_source", value=data_source, expected_type=type_hints["data_source"])
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument cross_org_uuids", value=cross_org_uuids, expected_type=type_hints["cross_org_uuids"])
            check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
            check_type(argname="argument indexes", value=indexes, expected_type=type_hints["indexes"])
            check_type(argname="argument search", value=search, expected_type=type_hints["search"])
            check_type(argname="argument storage", value=storage, expected_type=type_hints["storage"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "compute": compute,
            "data_source": data_source,
            "name": name,
        }
        if cross_org_uuids is not None:
            self._values["cross_org_uuids"] = cross_org_uuids
        if group_by is not None:
            self._values["group_by"] = group_by
        if indexes is not None:
            self._values["indexes"] = indexes
        if search is not None:
            self._values["search"] = search
        if storage is not None:
            self._values["storage"] = storage

    @builtins.property
    def compute(
        self,
    ) -> typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetTreemapDefinitionRequestQueryEventQueryCompute"]]:
        '''compute block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute Powerpack#compute}
        '''
        result = self._values.get("compute")
        assert result is not None, "Required property 'compute' is missing"
        return typing.cast(typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetTreemapDefinitionRequestQueryEventQueryCompute"]], result)

    @builtins.property
    def data_source(self) -> builtins.str:
        '''The data source for event platform-based queries.

        Valid values are ``logs``, ``spans``, ``network``, ``rum``, ``security_signals``, ``profiles``, ``audit``, ``events``, ``ci_tests``, ``ci_pipelines``, ``incident_analytics``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        '''
        result = self._values.get("data_source")
        assert result is not None, "Required property 'data_source' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def name(self) -> builtins.str:
        '''The name of query for use in formulas.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        '''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def cross_org_uuids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''The source organization UUID for cross organization queries. Feature in Private Beta.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        '''
        result = self._values.get("cross_org_uuids")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def group_by(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetTreemapDefinitionRequestQueryEventQueryGroupBy"]]]:
        '''group_by block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        '''
        result = self._values.get("group_by")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["PowerpackWidgetTreemapDefinitionRequestQueryEventQueryGroupBy"]]], result)

    @builtins.property
    def indexes(self) -> typing.Optional[typing.List[builtins.str]]:
        '''An array of index names to query in the stream.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#indexes Powerpack#indexes}
        '''
        result = self._values.get("indexes")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def search(
        self,
    ) -> typing.Optional["PowerpackWidgetTreemapDefinitionRequestQueryEventQuerySearch"]:
        '''search block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search Powerpack#search}
        '''
        result = self._values.get("search")
        return typing.cast(typing.Optional["PowerpackWidgetTreemapDefinitionRequestQueryEventQuerySearch"], result)

    @builtins.property
    def storage(self) -> typing.Optional[builtins.str]:
        '''Storage location (private beta).

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#storage Powerpack#storage}
        '''
        result = self._values.get("storage")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetTreemapDefinitionRequestQueryEventQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTreemapDefinitionRequestQueryEventQueryCompute",
    jsii_struct_bases=[],
    name_mapping={
        "aggregation": "aggregation",
        "interval": "interval",
        "metric": "metric",
    },
)
class PowerpackWidgetTreemapDefinitionRequestQueryEventQueryCompute:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        interval: typing.Optional[jsii.Number] = None,
        metric: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation methods for event platform queries. Valid values are ``count``, ``cardinality``, ``median``, ``pc75``, ``pc90``, ``pc95``, ``pc98``, ``pc99``, ``sum``, ``min``, ``max``, ``avg``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param interval: A time interval in milliseconds. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        :param metric: The measurable attribute to compute. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a61b56cab240a4f1635499a14be7832194b7fffb87a86a0d6bcdfd4410c2ceb2)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
            check_type(argname="argument metric", value=metric, expected_type=type_hints["metric"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if interval is not None:
            self._values["interval"] = interval
        if metric is not None:
            self._values["metric"] = metric

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation methods for event platform queries.

        Valid values are ``count``, ``cardinality``, ``median``, ``pc75``, ``pc90``, ``pc95``, ``pc98``, ``pc99``, ``sum``, ``min``, ``max``, ``avg``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''A time interval in milliseconds.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#interval Powerpack#interval}
        '''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def metric(self) -> typing.Optional[builtins.str]:
        '''The measurable attribute to compute.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        '''
        result = self._values.get("metric")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetTreemapDefinitionRequestQueryEventQueryCompute(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetTreemapDefinitionRequestQueryEventQueryComputeList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTreemapDefinitionRequestQueryEventQueryComputeList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ed4820ff67bb6d27970f363fea12ce2e9d4531cbcc52d5127658740ed49fb2fc)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetTreemapDefinitionRequestQueryEventQueryComputeOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7911eceaded75183da59ed9a6ad9f4bf6e0f75417429dd282e3adba90241ed9f)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetTreemapDefinitionRequestQueryEventQueryComputeOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c459407725942b8261a12c546525505addbaa7ced712b8a63a4f209d02f4286b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__43953152eb62e4de8dc854378f8df8450fa2c18899991d16de8b16a7bd5d4c26)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9065cfb8f344d7ab16412bcda06af8e22c2e68040d437c2e220e8d88fd31a0a1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTreemapDefinitionRequestQueryEventQueryCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTreemapDefinitionRequestQueryEventQueryCompute]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTreemapDefinitionRequestQueryEventQueryCompute]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__40b5166dac75d43d5119cd6fb01eec88a86907181419a305a0510363d48231ff)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetTreemapDefinitionRequestQueryEventQueryComputeOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTreemapDefinitionRequestQueryEventQueryComputeOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f0ba61658f9a147b52ef7b16e8323a8f9dc25e18a847abdff5396d2b5899b678)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @jsii.member(jsii_name="resetMetric")
    def reset_metric(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMetric", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property
    @jsii.member(jsii_name="metricInput")
    def metric_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "metricInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d5ae48342939de778fbf208e032b925a00af7422143f9d3a36b863c708bc1f53)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f6b69e50d0d19689796abf279763081c3a5982aaa22331e0cad6cd4e739207a0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "interval", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="metric")
    def metric(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "metric"))

    @metric.setter
    def metric(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f539300b3f6ac557330dae7baa527d7e1599c5ee23e9c6a8304143f6531ab4ec)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "metric", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTreemapDefinitionRequestQueryEventQueryCompute]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTreemapDefinitionRequestQueryEventQueryCompute]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTreemapDefinitionRequestQueryEventQueryCompute]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9cf9ae9f6cd64b6b5da48f2b01aac496de1fafa3c6016c15289f6545ed7d8896)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTreemapDefinitionRequestQueryEventQueryGroupBy",
    jsii_struct_bases=[],
    name_mapping={"facet": "facet", "limit": "limit", "sort": "sort"},
)
class PowerpackWidgetTreemapDefinitionRequestQueryEventQueryGroupBy:
    def __init__(
        self,
        *,
        facet: builtins.str,
        limit: typing.Optional[jsii.Number] = None,
        sort: typing.Optional[typing.Union["PowerpackWidgetTreemapDefinitionRequestQueryEventQueryGroupBySort", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param facet: The event facet. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        :param limit: The number of groups to return. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param sort: sort block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort Powerpack#sort}
        '''
        if isinstance(sort, dict):
            sort = PowerpackWidgetTreemapDefinitionRequestQueryEventQueryGroupBySort(**sort)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cff69e4b4482bff65b11c9e3217db250a7fcc5d2d4faed7a83252068ec0abd89)
            check_type(argname="argument facet", value=facet, expected_type=type_hints["facet"])
            check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
            check_type(argname="argument sort", value=sort, expected_type=type_hints["sort"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "facet": facet,
        }
        if limit is not None:
            self._values["limit"] = limit
        if sort is not None:
            self._values["sort"] = sort

    @builtins.property
    def facet(self) -> builtins.str:
        '''The event facet.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#facet Powerpack#facet}
        '''
        result = self._values.get("facet")
        assert result is not None, "Required property 'facet' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def limit(self) -> typing.Optional[jsii.Number]:
        '''The number of groups to return.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        '''
        result = self._values.get("limit")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def sort(
        self,
    ) -> typing.Optional["PowerpackWidgetTreemapDefinitionRequestQueryEventQueryGroupBySort"]:
        '''sort block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort Powerpack#sort}
        '''
        result = self._values.get("sort")
        return typing.cast(typing.Optional["PowerpackWidgetTreemapDefinitionRequestQueryEventQueryGroupBySort"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetTreemapDefinitionRequestQueryEventQueryGroupBy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetTreemapDefinitionRequestQueryEventQueryGroupByList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTreemapDefinitionRequestQueryEventQueryGroupByList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6a8df3393112735d55558ea6213cb68c52daa0f7e7a72a9b114852e3f9b9719c)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetTreemapDefinitionRequestQueryEventQueryGroupByOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c0d438cc787c5b0138b0698b7b52cb1810882a56136fb0e59831c2aee448b7d2)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetTreemapDefinitionRequestQueryEventQueryGroupByOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__26641d48e8a9b12efb522d140784969ce13eb8168c203bbd59e2cfe35a42221a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__76a9085f78e36a76c78323ec8bb1ad586b5138617f65713f1eeb92fed7146369)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__36713c1a2c9e75001743bd4263dc90b4d3b630701330d062f66001f26771cf6f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTreemapDefinitionRequestQueryEventQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTreemapDefinitionRequestQueryEventQueryGroupBy]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTreemapDefinitionRequestQueryEventQueryGroupBy]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__690f407def95700c0482f8de245ecd52a52eb9d52e8f89cce1256d7154e64b80)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetTreemapDefinitionRequestQueryEventQueryGroupByOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTreemapDefinitionRequestQueryEventQueryGroupByOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5e666727ab86a6987b8fac8e5686f415aad0cdd2cd9b61a246722232fd718b32)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putSort")
    def put_sort(
        self,
        *,
        aggregation: builtins.str,
        metric: typing.Optional[builtins.str] = None,
        order: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation methods for the event platform queries. Valid values are ``count``, ``cardinality``, ``median``, ``pc75``, ``pc90``, ``pc95``, ``pc98``, ``pc99``, ``sum``, ``min``, ``max``, ``avg``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param metric: The metric used for sorting group by results. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        :param order: Direction of sort. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        value = PowerpackWidgetTreemapDefinitionRequestQueryEventQueryGroupBySort(
            aggregation=aggregation, metric=metric, order=order
        )

        return typing.cast(None, jsii.invoke(self, "putSort", [value]))

    @jsii.member(jsii_name="resetLimit")
    def reset_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLimit", []))

    @jsii.member(jsii_name="resetSort")
    def reset_sort(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSort", []))

    @builtins.property
    @jsii.member(jsii_name="sort")
    def sort(
        self,
    ) -> "PowerpackWidgetTreemapDefinitionRequestQueryEventQueryGroupBySortOutputReference":
        return typing.cast("PowerpackWidgetTreemapDefinitionRequestQueryEventQueryGroupBySortOutputReference", jsii.get(self, "sort"))

    @builtins.property
    @jsii.member(jsii_name="facetInput")
    def facet_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "facetInput"))

    @builtins.property
    @jsii.member(jsii_name="limitInput")
    def limit_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "limitInput"))

    @builtins.property
    @jsii.member(jsii_name="sortInput")
    def sort_input(
        self,
    ) -> typing.Optional["PowerpackWidgetTreemapDefinitionRequestQueryEventQueryGroupBySort"]:
        return typing.cast(typing.Optional["PowerpackWidgetTreemapDefinitionRequestQueryEventQueryGroupBySort"], jsii.get(self, "sortInput"))

    @builtins.property
    @jsii.member(jsii_name="facet")
    def facet(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "facet"))

    @facet.setter
    def facet(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9fea1e374128aadc520fc0d69dd8aec70872f16759981258e590047b5db05d91)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "facet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="limit")
    def limit(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "limit"))

    @limit.setter
    def limit(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__feb3c46c9cf18a004b95770e0757d7cd0682385e59790b358e0e1b239a174001)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "limit", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTreemapDefinitionRequestQueryEventQueryGroupBy]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTreemapDefinitionRequestQueryEventQueryGroupBy]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTreemapDefinitionRequestQueryEventQueryGroupBy]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e4f4b65d26831e281ec15d07a8d7c26b26fd7b2574bdd5edb034d7ac1f4c965a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTreemapDefinitionRequestQueryEventQueryGroupBySort",
    jsii_struct_bases=[],
    name_mapping={"aggregation": "aggregation", "metric": "metric", "order": "order"},
)
class PowerpackWidgetTreemapDefinitionRequestQueryEventQueryGroupBySort:
    def __init__(
        self,
        *,
        aggregation: builtins.str,
        metric: typing.Optional[builtins.str] = None,
        order: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param aggregation: The aggregation methods for the event platform queries. Valid values are ``count``, ``cardinality``, ``median``, ``pc75``, ``pc90``, ``pc95``, ``pc98``, ``pc99``, ``sum``, ``min``, ``max``, ``avg``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        :param metric: The metric used for sorting group by results. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        :param order: Direction of sort. Valid values are ``asc``, ``desc``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__56c6edba5fb031ffdefec8d3cf3f736afde2f0681825154aa38a845ef2745e47)
            check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
            check_type(argname="argument metric", value=metric, expected_type=type_hints["metric"])
            check_type(argname="argument order", value=order, expected_type=type_hints["order"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aggregation": aggregation,
        }
        if metric is not None:
            self._values["metric"] = metric
        if order is not None:
            self._values["order"] = order

    @builtins.property
    def aggregation(self) -> builtins.str:
        '''The aggregation methods for the event platform queries.

        Valid values are ``count``, ``cardinality``, ``median``, ``pc75``, ``pc90``, ``pc95``, ``pc98``, ``pc99``, ``sum``, ``min``, ``max``, ``avg``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregation Powerpack#aggregation}
        '''
        result = self._values.get("aggregation")
        assert result is not None, "Required property 'aggregation' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def metric(self) -> typing.Optional[builtins.str]:
        '''The metric used for sorting group by results.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        '''
        result = self._values.get("metric")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def order(self) -> typing.Optional[builtins.str]:
        '''Direction of sort. Valid values are ``asc``, ``desc``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#order Powerpack#order}
        '''
        result = self._values.get("order")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetTreemapDefinitionRequestQueryEventQueryGroupBySort(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetTreemapDefinitionRequestQueryEventQueryGroupBySortOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTreemapDefinitionRequestQueryEventQueryGroupBySortOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6046211a5cedd1c29e7266a63a490cd464b1f2c885d05301a0e392a8d2fe1df3)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetMetric")
    def reset_metric(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMetric", []))

    @jsii.member(jsii_name="resetOrder")
    def reset_order(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetOrder", []))

    @builtins.property
    @jsii.member(jsii_name="aggregationInput")
    def aggregation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregationInput"))

    @builtins.property
    @jsii.member(jsii_name="metricInput")
    def metric_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "metricInput"))

    @builtins.property
    @jsii.member(jsii_name="orderInput")
    def order_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "orderInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregation")
    def aggregation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregation"))

    @aggregation.setter
    def aggregation(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__83145e7dc2665106c8a98b4dcbfcfc01d805ae0478fc5c85e0a29f434d5fd89c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregation", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="metric")
    def metric(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "metric"))

    @metric.setter
    def metric(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__456f173ba3b45b9c488f1e2b7810e6f2510c7ddb8e92cc4edd21726ea8627bc6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "metric", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="order")
    def order(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "order"))

    @order.setter
    def order(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__50983f2fc2ced2d63880c2440aeea1995a1389a274cde55d2886793ebc1f93a4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "order", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetTreemapDefinitionRequestQueryEventQueryGroupBySort]:
        return typing.cast(typing.Optional[PowerpackWidgetTreemapDefinitionRequestQueryEventQueryGroupBySort], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetTreemapDefinitionRequestQueryEventQueryGroupBySort],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1a039fd51a9c320ce8150b0abc2cc264a37462dbab7a7a1549b65093ccb74eaa)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetTreemapDefinitionRequestQueryEventQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTreemapDefinitionRequestQueryEventQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__44ed98911ef6bb64a8d81a76d5d1143ae337c74227acd811961a0ff5fb956714)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putCompute")
    def put_compute(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetTreemapDefinitionRequestQueryEventQueryCompute, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f01c692b74e926cbc41f5916c953775b71855e72c3541a6a2b3150d0b1084dc9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putCompute", [value]))

    @jsii.member(jsii_name="putGroupBy")
    def put_group_by(
        self,
        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetTreemapDefinitionRequestQueryEventQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
    ) -> None:
        '''
        :param value: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e9506faa9d184eb0837735da72c0ea785bed7539dd042eacc807560f104b585c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "putGroupBy", [value]))

    @jsii.member(jsii_name="putSearch")
    def put_search(self, *, query: builtins.str) -> None:
        '''
        :param query: The events search string. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        '''
        value = PowerpackWidgetTreemapDefinitionRequestQueryEventQuerySearch(
            query=query
        )

        return typing.cast(None, jsii.invoke(self, "putSearch", [value]))

    @jsii.member(jsii_name="resetCrossOrgUuids")
    def reset_cross_org_uuids(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCrossOrgUuids", []))

    @jsii.member(jsii_name="resetGroupBy")
    def reset_group_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGroupBy", []))

    @jsii.member(jsii_name="resetIndexes")
    def reset_indexes(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetIndexes", []))

    @jsii.member(jsii_name="resetSearch")
    def reset_search(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSearch", []))

    @jsii.member(jsii_name="resetStorage")
    def reset_storage(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetStorage", []))

    @builtins.property
    @jsii.member(jsii_name="compute")
    def compute(
        self,
    ) -> PowerpackWidgetTreemapDefinitionRequestQueryEventQueryComputeList:
        return typing.cast(PowerpackWidgetTreemapDefinitionRequestQueryEventQueryComputeList, jsii.get(self, "compute"))

    @builtins.property
    @jsii.member(jsii_name="groupBy")
    def group_by(
        self,
    ) -> PowerpackWidgetTreemapDefinitionRequestQueryEventQueryGroupByList:
        return typing.cast(PowerpackWidgetTreemapDefinitionRequestQueryEventQueryGroupByList, jsii.get(self, "groupBy"))

    @builtins.property
    @jsii.member(jsii_name="search")
    def search(
        self,
    ) -> "PowerpackWidgetTreemapDefinitionRequestQueryEventQuerySearchOutputReference":
        return typing.cast("PowerpackWidgetTreemapDefinitionRequestQueryEventQuerySearchOutputReference", jsii.get(self, "search"))

    @builtins.property
    @jsii.member(jsii_name="computeInput")
    def compute_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTreemapDefinitionRequestQueryEventQueryCompute]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTreemapDefinitionRequestQueryEventQueryCompute]]], jsii.get(self, "computeInput"))

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuidsInput")
    def cross_org_uuids_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "crossOrgUuidsInput"))

    @builtins.property
    @jsii.member(jsii_name="dataSourceInput")
    def data_source_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "dataSourceInput"))

    @builtins.property
    @jsii.member(jsii_name="groupByInput")
    def group_by_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTreemapDefinitionRequestQueryEventQueryGroupBy]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTreemapDefinitionRequestQueryEventQueryGroupBy]]], jsii.get(self, "groupByInput"))

    @builtins.property
    @jsii.member(jsii_name="indexesInput")
    def indexes_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "indexesInput"))

    @builtins.property
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property
    @jsii.member(jsii_name="searchInput")
    def search_input(
        self,
    ) -> typing.Optional["PowerpackWidgetTreemapDefinitionRequestQueryEventQuerySearch"]:
        return typing.cast(typing.Optional["PowerpackWidgetTreemapDefinitionRequestQueryEventQuerySearch"], jsii.get(self, "searchInput"))

    @builtins.property
    @jsii.member(jsii_name="storageInput")
    def storage_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "storageInput"))

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuids")
    def cross_org_uuids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "crossOrgUuids"))

    @cross_org_uuids.setter
    def cross_org_uuids(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__aec6d7ff0ac853b271b5f22b11513f2bfc8de5d452bcc72236ea68fe4401529d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "crossOrgUuids", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="dataSource")
    def data_source(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "dataSource"))

    @data_source.setter
    def data_source(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__be3cb6987eec7653ad74455a6c1e9b6e9508aae3e90f3f5d53499e14070f0591)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "dataSource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="indexes")
    def indexes(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "indexes"))

    @indexes.setter
    def indexes(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__82d886ae6ece3e7c5b4d3b25ee20dc884d815e4f813006228ca2c1ab3c441124)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "indexes", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__16487d967aa5f762ca3fad6fb5777f0001b886778f8e75cb0526c71d2742d877)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "name", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="storage")
    def storage(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "storage"))

    @storage.setter
    def storage(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__19b9120ab19a81252b3b00f4e2121b6f7434baba1e3df6a4e11dbd27aa478505)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "storage", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetTreemapDefinitionRequestQueryEventQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetTreemapDefinitionRequestQueryEventQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetTreemapDefinitionRequestQueryEventQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fd35f15ca0c84e24012c54dd0aa3d07a5e977533495c20db1884408b2cee4a4e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTreemapDefinitionRequestQueryEventQuerySearch",
    jsii_struct_bases=[],
    name_mapping={"query": "query"},
)
class PowerpackWidgetTreemapDefinitionRequestQueryEventQuerySearch:
    def __init__(self, *, query: builtins.str) -> None:
        '''
        :param query: The events search string. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__043bd768052f329c323ebe0e40a44c8c7eed2ec3a6f27ca038939682ebc0f344)
            check_type(argname="argument query", value=query, expected_type=type_hints["query"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "query": query,
        }

    @builtins.property
    def query(self) -> builtins.str:
        '''The events search string.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        '''
        result = self._values.get("query")
        assert result is not None, "Required property 'query' is missing"
        return typing.cast(builtins.str, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetTreemapDefinitionRequestQueryEventQuerySearch(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetTreemapDefinitionRequestQueryEventQuerySearchOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTreemapDefinitionRequestQueryEventQuerySearchOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__66f1da64d0e904f944a7b8f2a4a2ce2354deb23b0c45721f5623d1b5c52b7681)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @builtins.property
    @jsii.member(jsii_name="queryInput")
    def query_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "queryInput"))

    @builtins.property
    @jsii.member(jsii_name="query")
    def query(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "query"))

    @query.setter
    def query(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b1300a239cadfbdef0240e7ca943b7161ec9591fd59c7e91b12af9237ae8b71f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "query", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetTreemapDefinitionRequestQueryEventQuerySearch]:
        return typing.cast(typing.Optional[PowerpackWidgetTreemapDefinitionRequestQueryEventQuerySearch], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetTreemapDefinitionRequestQueryEventQuerySearch],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ccb96a1f48a4544855f02a7904cd8e9901ff67763e46a82c53f46c18e712aea0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetTreemapDefinitionRequestQueryList(
    _cdktf_9a9027ec.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTreemapDefinitionRequestQueryList",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5600609ed17d65225b12f2cb88a8c93c31db2af84868963341fe70db5d29fee5)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "PowerpackWidgetTreemapDefinitionRequestQueryOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__90dfab764958aeb876fdae8d125aff118c3c48f563415ba4109fefbe17728483)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("PowerpackWidgetTreemapDefinitionRequestQueryOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bd461dad7d39f60c87d473bc687c12d778d3c56f47bcbf9d0aeef9b61e4d308b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformAttribute", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__917e108385b035e958111dd708c09a3596b3265655af5d4285de5b3071aba890)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "terraformResource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a53c74b507a028b6c5ef8431a0b25ecb80f939ffb35d9531de78d41f1e1b9060)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "wrapsSet", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTreemapDefinitionRequestQuery]]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTreemapDefinitionRequestQuery]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTreemapDefinitionRequestQuery]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e2346e265b89c561eb114e7d0b8f4a6be407123fffcab5880c17807b8349e83d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTreemapDefinitionRequestQueryMetricQuery",
    jsii_struct_bases=[],
    name_mapping={
        "name": "name",
        "query": "query",
        "aggregator": "aggregator",
        "cross_org_uuids": "crossOrgUuids",
        "data_source": "dataSource",
    },
)
class PowerpackWidgetTreemapDefinitionRequestQueryMetricQuery:
    def __init__(
        self,
        *,
        name: builtins.str,
        query: builtins.str,
        aggregator: typing.Optional[builtins.str] = None,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        data_source: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param name: The name of the query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param query: The metrics query definition. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        :param aggregator: The aggregation methods available for metrics queries. Valid values are ``avg``, ``min``, ``max``, ``sum``, ``last``, ``area``, ``l2norm``, ``percentile``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregator Powerpack#aggregator}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param data_source: The data source for metrics queries. Defaults to ``"metrics"``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b69194ca1c02dd601da36cf23d759a7dde7cf9ac076bb2d394ef10ac8de1ebe6)
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument query", value=query, expected_type=type_hints["query"])
            check_type(argname="argument aggregator", value=aggregator, expected_type=type_hints["aggregator"])
            check_type(argname="argument cross_org_uuids", value=cross_org_uuids, expected_type=type_hints["cross_org_uuids"])
            check_type(argname="argument data_source", value=data_source, expected_type=type_hints["data_source"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "name": name,
            "query": query,
        }
        if aggregator is not None:
            self._values["aggregator"] = aggregator
        if cross_org_uuids is not None:
            self._values["cross_org_uuids"] = cross_org_uuids
        if data_source is not None:
            self._values["data_source"] = data_source

    @builtins.property
    def name(self) -> builtins.str:
        '''The name of the query for use in formulas.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        '''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def query(self) -> builtins.str:
        '''The metrics query definition.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        '''
        result = self._values.get("query")
        assert result is not None, "Required property 'query' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def aggregator(self) -> typing.Optional[builtins.str]:
        '''The aggregation methods available for metrics queries. Valid values are ``avg``, ``min``, ``max``, ``sum``, ``last``, ``area``, ``l2norm``, ``percentile``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregator Powerpack#aggregator}
        '''
        result = self._values.get("aggregator")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def cross_org_uuids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''The source organization UUID for cross organization queries. Feature in Private Beta.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        '''
        result = self._values.get("cross_org_uuids")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def data_source(self) -> typing.Optional[builtins.str]:
        '''The data source for metrics queries. Defaults to ``"metrics"``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        '''
        result = self._values.get("data_source")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetTreemapDefinitionRequestQueryMetricQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetTreemapDefinitionRequestQueryMetricQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTreemapDefinitionRequestQueryMetricQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__37e354a91f8ae701b24751cdfe0faf45a4cd32121b7306692f0dc8f315803d9f)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetAggregator")
    def reset_aggregator(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAggregator", []))

    @jsii.member(jsii_name="resetCrossOrgUuids")
    def reset_cross_org_uuids(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCrossOrgUuids", []))

    @jsii.member(jsii_name="resetDataSource")
    def reset_data_source(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDataSource", []))

    @builtins.property
    @jsii.member(jsii_name="aggregatorInput")
    def aggregator_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregatorInput"))

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuidsInput")
    def cross_org_uuids_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "crossOrgUuidsInput"))

    @builtins.property
    @jsii.member(jsii_name="dataSourceInput")
    def data_source_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "dataSourceInput"))

    @builtins.property
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property
    @jsii.member(jsii_name="queryInput")
    def query_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "queryInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregator")
    def aggregator(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregator"))

    @aggregator.setter
    def aggregator(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d7bf3645fa938752d625e0ebe44a40b48716acbf8745bf0c2e833f619f56b74e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregator", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuids")
    def cross_org_uuids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "crossOrgUuids"))

    @cross_org_uuids.setter
    def cross_org_uuids(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c8440e2159cfebc4566dbf23df7900e3e1f4e058de1043821971a79c8f92e723)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "crossOrgUuids", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="dataSource")
    def data_source(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "dataSource"))

    @data_source.setter
    def data_source(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__62d15bb61c2fd8bfc113c526b14d1247bacc402711d66e0a8ee0440d93a9d6ce)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "dataSource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6327a0411706d741733605da96d742ad4663152ea8bec3e092f0a2766c00dd5d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "name", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="query")
    def query(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "query"))

    @query.setter
    def query(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cf45ae078402cc234d3aed73286b5d317244c8f13b0d3f2cc6d4616823209d2f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "query", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetTreemapDefinitionRequestQueryMetricQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetTreemapDefinitionRequestQueryMetricQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetTreemapDefinitionRequestQueryMetricQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5c9c446f5f3dfa1060f59baf805ac8d08f519effc717bba0579f74703404de93)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class PowerpackWidgetTreemapDefinitionRequestQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTreemapDefinitionRequestQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b8c486ea485ff64ba40ddfac6e8af279963653019b1563855ce9dc030cb60690)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putApmDependencyStatsQuery")
    def put_apm_dependency_stats_query(
        self,
        *,
        data_source: builtins.str,
        env: builtins.str,
        name: builtins.str,
        operation_name: builtins.str,
        resource_name: builtins.str,
        service: builtins.str,
        stat: builtins.str,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        is_upstream: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        primary_tag_name: typing.Optional[builtins.str] = None,
        primary_tag_value: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param data_source: The data source for APM Dependency Stats queries. Valid values are ``apm_dependency_stats``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param env: APM environment. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#env Powerpack#env}
        :param name: The name of query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param operation_name: Name of operation on service. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#operation_name Powerpack#operation_name}
        :param resource_name: APM resource. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#resource_name Powerpack#resource_name}
        :param service: APM service. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#service Powerpack#service}
        :param stat: APM statistic. Valid values are ``avg_duration``, ``avg_root_duration``, ``avg_spans_per_trace``, ``error_rate``, ``pct_exec_time``, ``pct_of_traces``, ``total_traces_count``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#stat Powerpack#stat}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param is_upstream: Determines whether stats for upstream or downstream dependencies should be queried. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#is_upstream Powerpack#is_upstream}
        :param primary_tag_name: The name of the second primary tag used within APM; required when ``primary_tag_value`` is specified. See https://docs.datadoghq.com/tracing/guide/setting_primary_tags_to_scope/#add-a-second-primary-tag-in-datadog. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_name Powerpack#primary_tag_name}
        :param primary_tag_value: Filter APM data by the second primary tag. ``primary_tag_name`` must also be specified. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_value Powerpack#primary_tag_value}
        '''
        value = PowerpackWidgetTreemapDefinitionRequestQueryApmDependencyStatsQuery(
            data_source=data_source,
            env=env,
            name=name,
            operation_name=operation_name,
            resource_name=resource_name,
            service=service,
            stat=stat,
            cross_org_uuids=cross_org_uuids,
            is_upstream=is_upstream,
            primary_tag_name=primary_tag_name,
            primary_tag_value=primary_tag_value,
        )

        return typing.cast(None, jsii.invoke(self, "putApmDependencyStatsQuery", [value]))

    @jsii.member(jsii_name="putApmResourceStatsQuery")
    def put_apm_resource_stats_query(
        self,
        *,
        data_source: builtins.str,
        env: builtins.str,
        name: builtins.str,
        service: builtins.str,
        stat: builtins.str,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        group_by: typing.Optional[typing.Sequence[builtins.str]] = None,
        operation_name: typing.Optional[builtins.str] = None,
        primary_tag_name: typing.Optional[builtins.str] = None,
        primary_tag_value: typing.Optional[builtins.str] = None,
        resource_name: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param data_source: The data source for APM Resource Stats queries. Valid values are ``apm_resource_stats``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param env: APM environment. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#env Powerpack#env}
        :param name: The name of query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param service: APM service. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#service Powerpack#service}
        :param stat: APM statistic. Valid values are ``errors``, ``error_rate``, ``hits``, ``latency_avg``, ``latency_distribution``, ``latency_max``, ``latency_p50``, ``latency_p75``, ``latency_p90``, ``latency_p95``, ``latency_p99``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#stat Powerpack#stat}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param group_by: Array of fields to group results by. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param operation_name: Name of operation on service. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#operation_name Powerpack#operation_name}
        :param primary_tag_name: The name of the second primary tag used within APM; required when ``primary_tag_value`` is specified. See https://docs.datadoghq.com/tracing/guide/setting_primary_tags_to_scope/#add-a-second-primary-tag-in-datadog. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_name Powerpack#primary_tag_name}
        :param primary_tag_value: Filter APM data by the second primary tag. ``primary_tag_name`` must also be specified. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#primary_tag_value Powerpack#primary_tag_value}
        :param resource_name: APM resource. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#resource_name Powerpack#resource_name}
        '''
        value = PowerpackWidgetTreemapDefinitionRequestQueryApmResourceStatsQuery(
            data_source=data_source,
            env=env,
            name=name,
            service=service,
            stat=stat,
            cross_org_uuids=cross_org_uuids,
            group_by=group_by,
            operation_name=operation_name,
            primary_tag_name=primary_tag_name,
            primary_tag_value=primary_tag_value,
            resource_name=resource_name,
        )

        return typing.cast(None, jsii.invoke(self, "putApmResourceStatsQuery", [value]))

    @jsii.member(jsii_name="putCloudCostQuery")
    def put_cloud_cost_query(
        self,
        *,
        data_source: builtins.str,
        name: builtins.str,
        query: builtins.str,
        aggregator: typing.Optional[builtins.str] = None,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
    ) -> None:
        '''
        :param data_source: The data source for cloud cost queries. Valid values are ``cloud_cost``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param name: The name of the query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param query: The cloud cost query definition. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        :param aggregator: The aggregation methods available for cloud cost queries. Valid values are ``avg``, ``last``, ``max``, ``min``, ``sum``, ``percentile``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregator Powerpack#aggregator}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        '''
        value = PowerpackWidgetTreemapDefinitionRequestQueryCloudCostQuery(
            data_source=data_source,
            name=name,
            query=query,
            aggregator=aggregator,
            cross_org_uuids=cross_org_uuids,
        )

        return typing.cast(None, jsii.invoke(self, "putCloudCostQuery", [value]))

    @jsii.member(jsii_name="putEventQuery")
    def put_event_query(
        self,
        *,
        compute: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetTreemapDefinitionRequestQueryEventQueryCompute, typing.Dict[builtins.str, typing.Any]]]],
        data_source: builtins.str,
        name: builtins.str,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetTreemapDefinitionRequestQueryEventQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
        indexes: typing.Optional[typing.Sequence[builtins.str]] = None,
        search: typing.Optional[typing.Union[PowerpackWidgetTreemapDefinitionRequestQueryEventQuerySearch, typing.Dict[builtins.str, typing.Any]]] = None,
        storage: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param compute: compute block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#compute Powerpack#compute}
        :param data_source: The data source for event platform-based queries. Valid values are ``logs``, ``spans``, ``network``, ``rum``, ``security_signals``, ``profiles``, ``audit``, ``events``, ``ci_tests``, ``ci_pipelines``, ``incident_analytics``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param name: The name of query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param group_by: group_by block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_by Powerpack#group_by}
        :param indexes: An array of index names to query in the stream. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#indexes Powerpack#indexes}
        :param search: search block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#search Powerpack#search}
        :param storage: Storage location (private beta). Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#storage Powerpack#storage}
        '''
        value = PowerpackWidgetTreemapDefinitionRequestQueryEventQuery(
            compute=compute,
            data_source=data_source,
            name=name,
            cross_org_uuids=cross_org_uuids,
            group_by=group_by,
            indexes=indexes,
            search=search,
            storage=storage,
        )

        return typing.cast(None, jsii.invoke(self, "putEventQuery", [value]))

    @jsii.member(jsii_name="putMetricQuery")
    def put_metric_query(
        self,
        *,
        name: builtins.str,
        query: builtins.str,
        aggregator: typing.Optional[builtins.str] = None,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        data_source: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param name: The name of the query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param query: The metrics query definition. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#query Powerpack#query}
        :param aggregator: The aggregation methods available for metrics queries. Valid values are ``avg``, ``min``, ``max``, ``sum``, ``last``, ``area``, ``l2norm``, ``percentile``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregator Powerpack#aggregator}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param data_source: The data source for metrics queries. Defaults to ``"metrics"``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        '''
        value = PowerpackWidgetTreemapDefinitionRequestQueryMetricQuery(
            name=name,
            query=query,
            aggregator=aggregator,
            cross_org_uuids=cross_org_uuids,
            data_source=data_source,
        )

        return typing.cast(None, jsii.invoke(self, "putMetricQuery", [value]))

    @jsii.member(jsii_name="putProcessQuery")
    def put_process_query(
        self,
        *,
        data_source: builtins.str,
        metric: builtins.str,
        name: builtins.str,
        aggregator: typing.Optional[builtins.str] = None,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        is_normalized_cpu: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        limit: typing.Optional[jsii.Number] = None,
        sort: typing.Optional[builtins.str] = None,
        tag_filters: typing.Optional[typing.Sequence[builtins.str]] = None,
        text_filter: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param data_source: The data source for process queries. Valid values are ``process``, ``container``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param metric: The process metric name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        :param name: The name of query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param aggregator: The aggregation methods available for metrics queries. Valid values are ``avg``, ``min``, ``max``, ``sum``, ``last``, ``area``, ``l2norm``, ``percentile``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregator Powerpack#aggregator}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param is_normalized_cpu: Whether to normalize the CPU percentages. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#is_normalized_cpu Powerpack#is_normalized_cpu}
        :param limit: The number of hits to return. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param sort: The direction of the sort. Valid values are ``asc``, ``desc``. Defaults to ``"desc"``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort Powerpack#sort}
        :param tag_filters: An array of tags to filter by. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#tag_filters Powerpack#tag_filters}
        :param text_filter: The text to use as a filter. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#text_filter Powerpack#text_filter}
        '''
        value = PowerpackWidgetTreemapDefinitionRequestQueryProcessQuery(
            data_source=data_source,
            metric=metric,
            name=name,
            aggregator=aggregator,
            cross_org_uuids=cross_org_uuids,
            is_normalized_cpu=is_normalized_cpu,
            limit=limit,
            sort=sort,
            tag_filters=tag_filters,
            text_filter=text_filter,
        )

        return typing.cast(None, jsii.invoke(self, "putProcessQuery", [value]))

    @jsii.member(jsii_name="putSloQuery")
    def put_slo_query(
        self,
        *,
        data_source: builtins.str,
        measure: builtins.str,
        slo_id: builtins.str,
        additional_query_filters: typing.Optional[builtins.str] = None,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        group_mode: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
        slo_query_type: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param data_source: The data source for SLO queries. Valid values are ``slo``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param measure: SLO measures queries. Valid values are ``good_events``, ``bad_events``, ``good_minutes``, ``bad_minutes``, ``slo_status``, ``error_budget_remaining``, ``burn_rate``, ``error_budget_burndown``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#measure Powerpack#measure}
        :param slo_id: ID of an SLO to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#slo_id Powerpack#slo_id}
        :param additional_query_filters: Additional filters applied to the SLO query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#additional_query_filters Powerpack#additional_query_filters}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param group_mode: Group mode to query measures. Valid values are ``overall``, ``components``. Defaults to ``"overall"``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_mode Powerpack#group_mode}
        :param name: The name of query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param slo_query_type: type of the SLO to query. Valid values are ``metric``, ``monitor``, ``time_slice``. Defaults to ``"metric"``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#slo_query_type Powerpack#slo_query_type}
        '''
        value = PowerpackWidgetTreemapDefinitionRequestQuerySloQuery(
            data_source=data_source,
            measure=measure,
            slo_id=slo_id,
            additional_query_filters=additional_query_filters,
            cross_org_uuids=cross_org_uuids,
            group_mode=group_mode,
            name=name,
            slo_query_type=slo_query_type,
        )

        return typing.cast(None, jsii.invoke(self, "putSloQuery", [value]))

    @jsii.member(jsii_name="resetApmDependencyStatsQuery")
    def reset_apm_dependency_stats_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetApmDependencyStatsQuery", []))

    @jsii.member(jsii_name="resetApmResourceStatsQuery")
    def reset_apm_resource_stats_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetApmResourceStatsQuery", []))

    @jsii.member(jsii_name="resetCloudCostQuery")
    def reset_cloud_cost_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCloudCostQuery", []))

    @jsii.member(jsii_name="resetEventQuery")
    def reset_event_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetEventQuery", []))

    @jsii.member(jsii_name="resetMetricQuery")
    def reset_metric_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMetricQuery", []))

    @jsii.member(jsii_name="resetProcessQuery")
    def reset_process_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetProcessQuery", []))

    @jsii.member(jsii_name="resetSloQuery")
    def reset_slo_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSloQuery", []))

    @builtins.property
    @jsii.member(jsii_name="apmDependencyStatsQuery")
    def apm_dependency_stats_query(
        self,
    ) -> PowerpackWidgetTreemapDefinitionRequestQueryApmDependencyStatsQueryOutputReference:
        return typing.cast(PowerpackWidgetTreemapDefinitionRequestQueryApmDependencyStatsQueryOutputReference, jsii.get(self, "apmDependencyStatsQuery"))

    @builtins.property
    @jsii.member(jsii_name="apmResourceStatsQuery")
    def apm_resource_stats_query(
        self,
    ) -> PowerpackWidgetTreemapDefinitionRequestQueryApmResourceStatsQueryOutputReference:
        return typing.cast(PowerpackWidgetTreemapDefinitionRequestQueryApmResourceStatsQueryOutputReference, jsii.get(self, "apmResourceStatsQuery"))

    @builtins.property
    @jsii.member(jsii_name="cloudCostQuery")
    def cloud_cost_query(
        self,
    ) -> PowerpackWidgetTreemapDefinitionRequestQueryCloudCostQueryOutputReference:
        return typing.cast(PowerpackWidgetTreemapDefinitionRequestQueryCloudCostQueryOutputReference, jsii.get(self, "cloudCostQuery"))

    @builtins.property
    @jsii.member(jsii_name="eventQuery")
    def event_query(
        self,
    ) -> PowerpackWidgetTreemapDefinitionRequestQueryEventQueryOutputReference:
        return typing.cast(PowerpackWidgetTreemapDefinitionRequestQueryEventQueryOutputReference, jsii.get(self, "eventQuery"))

    @builtins.property
    @jsii.member(jsii_name="metricQuery")
    def metric_query(
        self,
    ) -> PowerpackWidgetTreemapDefinitionRequestQueryMetricQueryOutputReference:
        return typing.cast(PowerpackWidgetTreemapDefinitionRequestQueryMetricQueryOutputReference, jsii.get(self, "metricQuery"))

    @builtins.property
    @jsii.member(jsii_name="processQuery")
    def process_query(
        self,
    ) -> "PowerpackWidgetTreemapDefinitionRequestQueryProcessQueryOutputReference":
        return typing.cast("PowerpackWidgetTreemapDefinitionRequestQueryProcessQueryOutputReference", jsii.get(self, "processQuery"))

    @builtins.property
    @jsii.member(jsii_name="sloQuery")
    def slo_query(
        self,
    ) -> "PowerpackWidgetTreemapDefinitionRequestQuerySloQueryOutputReference":
        return typing.cast("PowerpackWidgetTreemapDefinitionRequestQuerySloQueryOutputReference", jsii.get(self, "sloQuery"))

    @builtins.property
    @jsii.member(jsii_name="apmDependencyStatsQueryInput")
    def apm_dependency_stats_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetTreemapDefinitionRequestQueryApmDependencyStatsQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetTreemapDefinitionRequestQueryApmDependencyStatsQuery], jsii.get(self, "apmDependencyStatsQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="apmResourceStatsQueryInput")
    def apm_resource_stats_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetTreemapDefinitionRequestQueryApmResourceStatsQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetTreemapDefinitionRequestQueryApmResourceStatsQuery], jsii.get(self, "apmResourceStatsQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="cloudCostQueryInput")
    def cloud_cost_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetTreemapDefinitionRequestQueryCloudCostQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetTreemapDefinitionRequestQueryCloudCostQuery], jsii.get(self, "cloudCostQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="eventQueryInput")
    def event_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetTreemapDefinitionRequestQueryEventQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetTreemapDefinitionRequestQueryEventQuery], jsii.get(self, "eventQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="metricQueryInput")
    def metric_query_input(
        self,
    ) -> typing.Optional[PowerpackWidgetTreemapDefinitionRequestQueryMetricQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetTreemapDefinitionRequestQueryMetricQuery], jsii.get(self, "metricQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="processQueryInput")
    def process_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetTreemapDefinitionRequestQueryProcessQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetTreemapDefinitionRequestQueryProcessQuery"], jsii.get(self, "processQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="sloQueryInput")
    def slo_query_input(
        self,
    ) -> typing.Optional["PowerpackWidgetTreemapDefinitionRequestQuerySloQuery"]:
        return typing.cast(typing.Optional["PowerpackWidgetTreemapDefinitionRequestQuerySloQuery"], jsii.get(self, "sloQueryInput"))

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTreemapDefinitionRequestQuery]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTreemapDefinitionRequestQuery]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTreemapDefinitionRequestQuery]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__56b155153df00fbb6d7528a96df3525433f550eb263ca3ba1362a9562616463c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTreemapDefinitionRequestQueryProcessQuery",
    jsii_struct_bases=[],
    name_mapping={
        "data_source": "dataSource",
        "metric": "metric",
        "name": "name",
        "aggregator": "aggregator",
        "cross_org_uuids": "crossOrgUuids",
        "is_normalized_cpu": "isNormalizedCpu",
        "limit": "limit",
        "sort": "sort",
        "tag_filters": "tagFilters",
        "text_filter": "textFilter",
    },
)
class PowerpackWidgetTreemapDefinitionRequestQueryProcessQuery:
    def __init__(
        self,
        *,
        data_source: builtins.str,
        metric: builtins.str,
        name: builtins.str,
        aggregator: typing.Optional[builtins.str] = None,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        is_normalized_cpu: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        limit: typing.Optional[jsii.Number] = None,
        sort: typing.Optional[builtins.str] = None,
        tag_filters: typing.Optional[typing.Sequence[builtins.str]] = None,
        text_filter: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param data_source: The data source for process queries. Valid values are ``process``, ``container``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param metric: The process metric name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        :param name: The name of query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param aggregator: The aggregation methods available for metrics queries. Valid values are ``avg``, ``min``, ``max``, ``sum``, ``last``, ``area``, ``l2norm``, ``percentile``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregator Powerpack#aggregator}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param is_normalized_cpu: Whether to normalize the CPU percentages. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#is_normalized_cpu Powerpack#is_normalized_cpu}
        :param limit: The number of hits to return. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        :param sort: The direction of the sort. Valid values are ``asc``, ``desc``. Defaults to ``"desc"``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort Powerpack#sort}
        :param tag_filters: An array of tags to filter by. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#tag_filters Powerpack#tag_filters}
        :param text_filter: The text to use as a filter. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#text_filter Powerpack#text_filter}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ec9a12794324cddaf1e31651497f3442db51d5c951e8c6c6083c55970de53ac3)
            check_type(argname="argument data_source", value=data_source, expected_type=type_hints["data_source"])
            check_type(argname="argument metric", value=metric, expected_type=type_hints["metric"])
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument aggregator", value=aggregator, expected_type=type_hints["aggregator"])
            check_type(argname="argument cross_org_uuids", value=cross_org_uuids, expected_type=type_hints["cross_org_uuids"])
            check_type(argname="argument is_normalized_cpu", value=is_normalized_cpu, expected_type=type_hints["is_normalized_cpu"])
            check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
            check_type(argname="argument sort", value=sort, expected_type=type_hints["sort"])
            check_type(argname="argument tag_filters", value=tag_filters, expected_type=type_hints["tag_filters"])
            check_type(argname="argument text_filter", value=text_filter, expected_type=type_hints["text_filter"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "data_source": data_source,
            "metric": metric,
            "name": name,
        }
        if aggregator is not None:
            self._values["aggregator"] = aggregator
        if cross_org_uuids is not None:
            self._values["cross_org_uuids"] = cross_org_uuids
        if is_normalized_cpu is not None:
            self._values["is_normalized_cpu"] = is_normalized_cpu
        if limit is not None:
            self._values["limit"] = limit
        if sort is not None:
            self._values["sort"] = sort
        if tag_filters is not None:
            self._values["tag_filters"] = tag_filters
        if text_filter is not None:
            self._values["text_filter"] = text_filter

    @builtins.property
    def data_source(self) -> builtins.str:
        '''The data source for process queries. Valid values are ``process``, ``container``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        '''
        result = self._values.get("data_source")
        assert result is not None, "Required property 'data_source' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def metric(self) -> builtins.str:
        '''The process metric name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#metric Powerpack#metric}
        '''
        result = self._values.get("metric")
        assert result is not None, "Required property 'metric' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def name(self) -> builtins.str:
        '''The name of query for use in formulas.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        '''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def aggregator(self) -> typing.Optional[builtins.str]:
        '''The aggregation methods available for metrics queries. Valid values are ``avg``, ``min``, ``max``, ``sum``, ``last``, ``area``, ``l2norm``, ``percentile``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#aggregator Powerpack#aggregator}
        '''
        result = self._values.get("aggregator")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def cross_org_uuids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''The source organization UUID for cross organization queries. Feature in Private Beta.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        '''
        result = self._values.get("cross_org_uuids")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def is_normalized_cpu(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        '''Whether to normalize the CPU percentages.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#is_normalized_cpu Powerpack#is_normalized_cpu}
        '''
        result = self._values.get("is_normalized_cpu")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)

    @builtins.property
    def limit(self) -> typing.Optional[jsii.Number]:
        '''The number of hits to return.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#limit Powerpack#limit}
        '''
        result = self._values.get("limit")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def sort(self) -> typing.Optional[builtins.str]:
        '''The direction of the sort. Valid values are ``asc``, ``desc``. Defaults to ``"desc"``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#sort Powerpack#sort}
        '''
        result = self._values.get("sort")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def tag_filters(self) -> typing.Optional[typing.List[builtins.str]]:
        '''An array of tags to filter by.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#tag_filters Powerpack#tag_filters}
        '''
        result = self._values.get("tag_filters")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def text_filter(self) -> typing.Optional[builtins.str]:
        '''The text to use as a filter.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#text_filter Powerpack#text_filter}
        '''
        result = self._values.get("text_filter")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetTreemapDefinitionRequestQueryProcessQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetTreemapDefinitionRequestQueryProcessQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTreemapDefinitionRequestQueryProcessQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__997e9dff862a064d0df207593a68cc43d39c5999cb346e6e65d3ecf7a398e451)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetAggregator")
    def reset_aggregator(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAggregator", []))

    @jsii.member(jsii_name="resetCrossOrgUuids")
    def reset_cross_org_uuids(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCrossOrgUuids", []))

    @jsii.member(jsii_name="resetIsNormalizedCpu")
    def reset_is_normalized_cpu(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetIsNormalizedCpu", []))

    @jsii.member(jsii_name="resetLimit")
    def reset_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLimit", []))

    @jsii.member(jsii_name="resetSort")
    def reset_sort(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSort", []))

    @jsii.member(jsii_name="resetTagFilters")
    def reset_tag_filters(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTagFilters", []))

    @jsii.member(jsii_name="resetTextFilter")
    def reset_text_filter(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTextFilter", []))

    @builtins.property
    @jsii.member(jsii_name="aggregatorInput")
    def aggregator_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aggregatorInput"))

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuidsInput")
    def cross_org_uuids_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "crossOrgUuidsInput"))

    @builtins.property
    @jsii.member(jsii_name="dataSourceInput")
    def data_source_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "dataSourceInput"))

    @builtins.property
    @jsii.member(jsii_name="isNormalizedCpuInput")
    def is_normalized_cpu_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "isNormalizedCpuInput"))

    @builtins.property
    @jsii.member(jsii_name="limitInput")
    def limit_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "limitInput"))

    @builtins.property
    @jsii.member(jsii_name="metricInput")
    def metric_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "metricInput"))

    @builtins.property
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property
    @jsii.member(jsii_name="sortInput")
    def sort_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "sortInput"))

    @builtins.property
    @jsii.member(jsii_name="tagFiltersInput")
    def tag_filters_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "tagFiltersInput"))

    @builtins.property
    @jsii.member(jsii_name="textFilterInput")
    def text_filter_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "textFilterInput"))

    @builtins.property
    @jsii.member(jsii_name="aggregator")
    def aggregator(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aggregator"))

    @aggregator.setter
    def aggregator(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1c7fea2604037af8dc53509eeeb573f340ed02d3aafe26e7c5211a3d3fd04f82)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "aggregator", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuids")
    def cross_org_uuids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "crossOrgUuids"))

    @cross_org_uuids.setter
    def cross_org_uuids(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2860483dd5f2aa700abfbcd152ba5121822e3d48b09df10c7b5ce1981c07cdf4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "crossOrgUuids", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="dataSource")
    def data_source(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "dataSource"))

    @data_source.setter
    def data_source(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__26803bdd5671d42be3574f7626f8baa90115960875bc62262c4f1641b54d3084)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "dataSource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="isNormalizedCpu")
    def is_normalized_cpu(
        self,
    ) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "isNormalizedCpu"))

    @is_normalized_cpu.setter
    def is_normalized_cpu(
        self,
        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dc829c846797c98b40ca7b5e1a06712c49eb23c5b3363e41b27d32d2880bdc8f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "isNormalizedCpu", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="limit")
    def limit(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "limit"))

    @limit.setter
    def limit(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6f94929a6def34dd26a28c8c546db2850cee374a295384b3f190e54d999ea29d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "limit", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="metric")
    def metric(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "metric"))

    @metric.setter
    def metric(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2b9c86f91c1e2242652f297925d7cb76f55310b00fe7485252f802e91b586180)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "metric", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a692afaedeef3453842f22552b29d2cea8a7b14fe1a6f241deee2e917692f453)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "name", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="sort")
    def sort(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "sort"))

    @sort.setter
    def sort(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__60780648607583e464b5509df0b73dd50d40513f220cdfd48cf0520ac1d6a385)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "sort", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="tagFilters")
    def tag_filters(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "tagFilters"))

    @tag_filters.setter
    def tag_filters(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__016b5fd0520212a4832487745374ec2f06184a5ea3132bd0cfbe9b04f104a47d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "tagFilters", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="textFilter")
    def text_filter(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "textFilter"))

    @text_filter.setter
    def text_filter(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__32bb0a98caa671105fae61951e1463cb0117218e3901cb2eb6cdd6a15dd29cdb)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "textFilter", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetTreemapDefinitionRequestQueryProcessQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetTreemapDefinitionRequestQueryProcessQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetTreemapDefinitionRequestQueryProcessQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0c0d48fb1b523e1e09570834378bbe962cd86c1c8b3a8aa75ee4df9d276c9dbf)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTreemapDefinitionRequestQuerySloQuery",
    jsii_struct_bases=[],
    name_mapping={
        "data_source": "dataSource",
        "measure": "measure",
        "slo_id": "sloId",
        "additional_query_filters": "additionalQueryFilters",
        "cross_org_uuids": "crossOrgUuids",
        "group_mode": "groupMode",
        "name": "name",
        "slo_query_type": "sloQueryType",
    },
)
class PowerpackWidgetTreemapDefinitionRequestQuerySloQuery:
    def __init__(
        self,
        *,
        data_source: builtins.str,
        measure: builtins.str,
        slo_id: builtins.str,
        additional_query_filters: typing.Optional[builtins.str] = None,
        cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
        group_mode: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
        slo_query_type: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param data_source: The data source for SLO queries. Valid values are ``slo``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        :param measure: SLO measures queries. Valid values are ``good_events``, ``bad_events``, ``good_minutes``, ``bad_minutes``, ``slo_status``, ``error_budget_remaining``, ``burn_rate``, ``error_budget_burndown``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#measure Powerpack#measure}
        :param slo_id: ID of an SLO to query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#slo_id Powerpack#slo_id}
        :param additional_query_filters: Additional filters applied to the SLO query. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#additional_query_filters Powerpack#additional_query_filters}
        :param cross_org_uuids: The source organization UUID for cross organization queries. Feature in Private Beta. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        :param group_mode: Group mode to query measures. Valid values are ``overall``, ``components``. Defaults to ``"overall"``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_mode Powerpack#group_mode}
        :param name: The name of query for use in formulas. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        :param slo_query_type: type of the SLO to query. Valid values are ``metric``, ``monitor``, ``time_slice``. Defaults to ``"metric"``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#slo_query_type Powerpack#slo_query_type}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ea4308c7c3381b49675e631884220baee8a3451ac769710e6a898d5d32b5bdc8)
            check_type(argname="argument data_source", value=data_source, expected_type=type_hints["data_source"])
            check_type(argname="argument measure", value=measure, expected_type=type_hints["measure"])
            check_type(argname="argument slo_id", value=slo_id, expected_type=type_hints["slo_id"])
            check_type(argname="argument additional_query_filters", value=additional_query_filters, expected_type=type_hints["additional_query_filters"])
            check_type(argname="argument cross_org_uuids", value=cross_org_uuids, expected_type=type_hints["cross_org_uuids"])
            check_type(argname="argument group_mode", value=group_mode, expected_type=type_hints["group_mode"])
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument slo_query_type", value=slo_query_type, expected_type=type_hints["slo_query_type"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "data_source": data_source,
            "measure": measure,
            "slo_id": slo_id,
        }
        if additional_query_filters is not None:
            self._values["additional_query_filters"] = additional_query_filters
        if cross_org_uuids is not None:
            self._values["cross_org_uuids"] = cross_org_uuids
        if group_mode is not None:
            self._values["group_mode"] = group_mode
        if name is not None:
            self._values["name"] = name
        if slo_query_type is not None:
            self._values["slo_query_type"] = slo_query_type

    @builtins.property
    def data_source(self) -> builtins.str:
        '''The data source for SLO queries. Valid values are ``slo``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#data_source Powerpack#data_source}
        '''
        result = self._values.get("data_source")
        assert result is not None, "Required property 'data_source' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def measure(self) -> builtins.str:
        '''SLO measures queries. Valid values are ``good_events``, ``bad_events``, ``good_minutes``, ``bad_minutes``, ``slo_status``, ``error_budget_remaining``, ``burn_rate``, ``error_budget_burndown``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#measure Powerpack#measure}
        '''
        result = self._values.get("measure")
        assert result is not None, "Required property 'measure' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def slo_id(self) -> builtins.str:
        '''ID of an SLO to query.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#slo_id Powerpack#slo_id}
        '''
        result = self._values.get("slo_id")
        assert result is not None, "Required property 'slo_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def additional_query_filters(self) -> typing.Optional[builtins.str]:
        '''Additional filters applied to the SLO query.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#additional_query_filters Powerpack#additional_query_filters}
        '''
        result = self._values.get("additional_query_filters")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def cross_org_uuids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''The source organization UUID for cross organization queries. Feature in Private Beta.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#cross_org_uuids Powerpack#cross_org_uuids}
        '''
        result = self._values.get("cross_org_uuids")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def group_mode(self) -> typing.Optional[builtins.str]:
        '''Group mode to query measures. Valid values are ``overall``, ``components``. Defaults to ``"overall"``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#group_mode Powerpack#group_mode}
        '''
        result = self._values.get("group_mode")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''The name of query for use in formulas.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#name Powerpack#name}
        '''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def slo_query_type(self) -> typing.Optional[builtins.str]:
        '''type of the SLO to query. Valid values are ``metric``, ``monitor``, ``time_slice``. Defaults to ``"metric"``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#slo_query_type Powerpack#slo_query_type}
        '''
        result = self._values.get("slo_query_type")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetTreemapDefinitionRequestQuerySloQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetTreemapDefinitionRequestQuerySloQueryOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetTreemapDefinitionRequestQuerySloQueryOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6495b8b73fbb3b90ece65b3ce49b36f414c2a9f4c5dd6f1149ef6bfea25e267b)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetAdditionalQueryFilters")
    def reset_additional_query_filters(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAdditionalQueryFilters", []))

    @jsii.member(jsii_name="resetCrossOrgUuids")
    def reset_cross_org_uuids(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCrossOrgUuids", []))

    @jsii.member(jsii_name="resetGroupMode")
    def reset_group_mode(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGroupMode", []))

    @jsii.member(jsii_name="resetName")
    def reset_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetName", []))

    @jsii.member(jsii_name="resetSloQueryType")
    def reset_slo_query_type(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSloQueryType", []))

    @builtins.property
    @jsii.member(jsii_name="additionalQueryFiltersInput")
    def additional_query_filters_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "additionalQueryFiltersInput"))

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuidsInput")
    def cross_org_uuids_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "crossOrgUuidsInput"))

    @builtins.property
    @jsii.member(jsii_name="dataSourceInput")
    def data_source_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "dataSourceInput"))

    @builtins.property
    @jsii.member(jsii_name="groupModeInput")
    def group_mode_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "groupModeInput"))

    @builtins.property
    @jsii.member(jsii_name="measureInput")
    def measure_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "measureInput"))

    @builtins.property
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property
    @jsii.member(jsii_name="sloIdInput")
    def slo_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "sloIdInput"))

    @builtins.property
    @jsii.member(jsii_name="sloQueryTypeInput")
    def slo_query_type_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "sloQueryTypeInput"))

    @builtins.property
    @jsii.member(jsii_name="additionalQueryFilters")
    def additional_query_filters(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "additionalQueryFilters"))

    @additional_query_filters.setter
    def additional_query_filters(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6ea5d9160b698554cb6385e9c7536481c3b19335dad1a356209c02c46521e6bd)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "additionalQueryFilters", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="crossOrgUuids")
    def cross_org_uuids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "crossOrgUuids"))

    @cross_org_uuids.setter
    def cross_org_uuids(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0503a3dec02636efbb4fe69f54e35dffec976d06283a92f1ccc430578ee0e09c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "crossOrgUuids", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="dataSource")
    def data_source(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "dataSource"))

    @data_source.setter
    def data_source(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__145ab596ec16985fdb8c33376bb5217e0888a4b29b4ced1690fbf1ef9e7d4132)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "dataSource", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="groupMode")
    def group_mode(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "groupMode"))

    @group_mode.setter
    def group_mode(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a64ae871c1fe72bc0e44e5d17f16d2cad77b34c1fa44cced9a32cd8e6e332873)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "groupMode", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="measure")
    def measure(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "measure"))

    @measure.setter
    def measure(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f14c962f2eed1d1ae67278d8adc7745e822de62c9d266548f72b2ac29607efa4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "measure", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3dd05ad089d67ae3bab3dd2a7a8608b972af0a7e3c34a5d0a718661b01ac5e15)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "name", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="sloId")
    def slo_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "sloId"))

    @slo_id.setter
    def slo_id(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__648074aa77bbb573a41e2f35b5645f9167ab9a7399681f159a805e6ea987b1f8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "sloId", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="sloQueryType")
    def slo_query_type(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "sloQueryType"))

    @slo_query_type.setter
    def slo_query_type(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e8540f53f4b7ca955392de749c16a56ac9192180d4cd6c0f6090a12f2747cab1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "sloQueryType", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[PowerpackWidgetTreemapDefinitionRequestQuerySloQuery]:
        return typing.cast(typing.Optional[PowerpackWidgetTreemapDefinitionRequestQuerySloQuery], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetTreemapDefinitionRequestQuerySloQuery],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6148359312b547a685b5be260ed463469f28e5d2b3df4d8eba7fbc320d41c360)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetWidgetLayout",
    jsii_struct_bases=[],
    name_mapping={
        "height": "height",
        "width": "width",
        "x": "x",
        "y": "y",
        "is_column_break": "isColumnBreak",
    },
)
class PowerpackWidgetWidgetLayout:
    def __init__(
        self,
        *,
        height: jsii.Number,
        width: jsii.Number,
        x: jsii.Number,
        y: jsii.Number,
        is_column_break: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
    ) -> None:
        '''
        :param height: The height of the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#height Powerpack#height}
        :param width: The width of the widget. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#width Powerpack#width}
        :param x: The position of the widget on the x (horizontal) axis. Must be greater than or equal to 0. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#x Powerpack#x}
        :param y: The position of the widget on the y (vertical) axis. Must be greater than or equal to 0. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#y Powerpack#y}
        :param is_column_break: Whether the widget should be the first one on the second column in high density or not. Only one widget in the dashboard should have this property set to ``true``. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#is_column_break Powerpack#is_column_break}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ec5a54099ae59cb92b8568d6a8efc175973a02f46c1a075bb5940caff2fa83f1)
            check_type(argname="argument height", value=height, expected_type=type_hints["height"])
            check_type(argname="argument width", value=width, expected_type=type_hints["width"])
            check_type(argname="argument x", value=x, expected_type=type_hints["x"])
            check_type(argname="argument y", value=y, expected_type=type_hints["y"])
            check_type(argname="argument is_column_break", value=is_column_break, expected_type=type_hints["is_column_break"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "height": height,
            "width": width,
            "x": x,
            "y": y,
        }
        if is_column_break is not None:
            self._values["is_column_break"] = is_column_break

    @builtins.property
    def height(self) -> jsii.Number:
        '''The height of the widget.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#height Powerpack#height}
        '''
        result = self._values.get("height")
        assert result is not None, "Required property 'height' is missing"
        return typing.cast(jsii.Number, result)

    @builtins.property
    def width(self) -> jsii.Number:
        '''The width of the widget.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#width Powerpack#width}
        '''
        result = self._values.get("width")
        assert result is not None, "Required property 'width' is missing"
        return typing.cast(jsii.Number, result)

    @builtins.property
    def x(self) -> jsii.Number:
        '''The position of the widget on the x (horizontal) axis. Must be greater than or equal to 0.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#x Powerpack#x}
        '''
        result = self._values.get("x")
        assert result is not None, "Required property 'x' is missing"
        return typing.cast(jsii.Number, result)

    @builtins.property
    def y(self) -> jsii.Number:
        '''The position of the widget on the y (vertical) axis. Must be greater than or equal to 0.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#y Powerpack#y}
        '''
        result = self._values.get("y")
        assert result is not None, "Required property 'y' is missing"
        return typing.cast(jsii.Number, result)

    @builtins.property
    def is_column_break(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        '''Whether the widget should be the first one on the second column in high density or not.

        Only one widget in the dashboard should have this property set to ``true``.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/powerpack#is_column_break Powerpack#is_column_break}
        '''
        result = self._values.get("is_column_break")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PowerpackWidgetWidgetLayout(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PowerpackWidgetWidgetLayoutOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-datadog.powerpack.PowerpackWidgetWidgetLayoutOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d87bbbf3d7d5eebd1c031a6dbabf58b35e0ec70b091c9b05c8cf51a0f8d4bf96)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetIsColumnBreak")
    def reset_is_column_break(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetIsColumnBreak", []))

    @builtins.property
    @jsii.member(jsii_name="heightInput")
    def height_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "heightInput"))

    @builtins.property
    @jsii.member(jsii_name="isColumnBreakInput")
    def is_column_break_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "isColumnBreakInput"))

    @builtins.property
    @jsii.member(jsii_name="widthInput")
    def width_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "widthInput"))

    @builtins.property
    @jsii.member(jsii_name="xInput")
    def x_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "xInput"))

    @builtins.property
    @jsii.member(jsii_name="yInput")
    def y_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "yInput"))

    @builtins.property
    @jsii.member(jsii_name="height")
    def height(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "height"))

    @height.setter
    def height(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__06537abd922b9bf902114684d647455e1572a0ef1a611a7642bfbc1e60ffe354)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "height", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="isColumnBreak")
    def is_column_break(
        self,
    ) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "isColumnBreak"))

    @is_column_break.setter
    def is_column_break(
        self,
        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__037bb97e6726d8ab1144693ccb84d8d99b0b5c4572d3121381b8e6671ec73ea0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "isColumnBreak", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="width")
    def width(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "width"))

    @width.setter
    def width(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dc467eece6d9f9c7c270563c5a30eceebed2197563203439d999ef9602cd0126)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "width", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="x")
    def x(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "x"))

    @x.setter
    def x(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1c49fed4b0dfdad0999f4324e2714e0226d56c1c73f022d5e45cfb44eb06cd3a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "x", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="y")
    def y(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "y"))

    @y.setter
    def y(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d576cec1ab1734cbd58809b901adc984855a804e0701545c3b7e213260905e04)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "y", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[PowerpackWidgetWidgetLayout]:
        return typing.cast(typing.Optional[PowerpackWidgetWidgetLayout], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[PowerpackWidgetWidgetLayout],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b404a1c3944998cde43c69085b82e3224a43fda522e42a59928e1dc858da3113)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


__all__ = [
    "Powerpack",
    "PowerpackConfig",
    "PowerpackLayout",
    "PowerpackLayoutOutputReference",
    "PowerpackTemplateVariables",
    "PowerpackTemplateVariablesList",
    "PowerpackTemplateVariablesOutputReference",
    "PowerpackWidget",
    "PowerpackWidgetAlertGraphDefinition",
    "PowerpackWidgetAlertGraphDefinitionOutputReference",
    "PowerpackWidgetAlertValueDefinition",
    "PowerpackWidgetAlertValueDefinitionOutputReference",
    "PowerpackWidgetChangeDefinition",
    "PowerpackWidgetChangeDefinitionCustomLink",
    "PowerpackWidgetChangeDefinitionCustomLinkList",
    "PowerpackWidgetChangeDefinitionCustomLinkOutputReference",
    "PowerpackWidgetChangeDefinitionOutputReference",
    "PowerpackWidgetChangeDefinitionRequest",
    "PowerpackWidgetChangeDefinitionRequestApmQuery",
    "PowerpackWidgetChangeDefinitionRequestApmQueryComputeQuery",
    "PowerpackWidgetChangeDefinitionRequestApmQueryComputeQueryOutputReference",
    "PowerpackWidgetChangeDefinitionRequestApmQueryGroupBy",
    "PowerpackWidgetChangeDefinitionRequestApmQueryGroupByList",
    "PowerpackWidgetChangeDefinitionRequestApmQueryGroupByOutputReference",
    "PowerpackWidgetChangeDefinitionRequestApmQueryGroupBySortQuery",
    "PowerpackWidgetChangeDefinitionRequestApmQueryGroupBySortQueryOutputReference",
    "PowerpackWidgetChangeDefinitionRequestApmQueryMultiCompute",
    "PowerpackWidgetChangeDefinitionRequestApmQueryMultiComputeList",
    "PowerpackWidgetChangeDefinitionRequestApmQueryMultiComputeOutputReference",
    "PowerpackWidgetChangeDefinitionRequestApmQueryOutputReference",
    "PowerpackWidgetChangeDefinitionRequestFormula",
    "PowerpackWidgetChangeDefinitionRequestFormulaConditionalFormats",
    "PowerpackWidgetChangeDefinitionRequestFormulaConditionalFormatsList",
    "PowerpackWidgetChangeDefinitionRequestFormulaConditionalFormatsOutputReference",
    "PowerpackWidgetChangeDefinitionRequestFormulaLimit",
    "PowerpackWidgetChangeDefinitionRequestFormulaLimitOutputReference",
    "PowerpackWidgetChangeDefinitionRequestFormulaList",
    "PowerpackWidgetChangeDefinitionRequestFormulaNumberFormat",
    "PowerpackWidgetChangeDefinitionRequestFormulaNumberFormatOutputReference",
    "PowerpackWidgetChangeDefinitionRequestFormulaNumberFormatUnit",
    "PowerpackWidgetChangeDefinitionRequestFormulaNumberFormatUnitCanonical",
    "PowerpackWidgetChangeDefinitionRequestFormulaNumberFormatUnitCanonicalOutputReference",
    "PowerpackWidgetChangeDefinitionRequestFormulaNumberFormatUnitCustom",
    "PowerpackWidgetChangeDefinitionRequestFormulaNumberFormatUnitCustomOutputReference",
    "PowerpackWidgetChangeDefinitionRequestFormulaNumberFormatUnitOutputReference",
    "PowerpackWidgetChangeDefinitionRequestFormulaNumberFormatUnitScale",
    "PowerpackWidgetChangeDefinitionRequestFormulaNumberFormatUnitScaleOutputReference",
    "PowerpackWidgetChangeDefinitionRequestFormulaOutputReference",
    "PowerpackWidgetChangeDefinitionRequestFormulaStyle",
    "PowerpackWidgetChangeDefinitionRequestFormulaStyleOutputReference",
    "PowerpackWidgetChangeDefinitionRequestList",
    "PowerpackWidgetChangeDefinitionRequestLogQuery",
    "PowerpackWidgetChangeDefinitionRequestLogQueryComputeQuery",
    "PowerpackWidgetChangeDefinitionRequestLogQueryComputeQueryOutputReference",
    "PowerpackWidgetChangeDefinitionRequestLogQueryGroupBy",
    "PowerpackWidgetChangeDefinitionRequestLogQueryGroupByList",
    "PowerpackWidgetChangeDefinitionRequestLogQueryGroupByOutputReference",
    "PowerpackWidgetChangeDefinitionRequestLogQueryGroupBySortQuery",
    "PowerpackWidgetChangeDefinitionRequestLogQueryGroupBySortQueryOutputReference",
    "PowerpackWidgetChangeDefinitionRequestLogQueryMultiCompute",
    "PowerpackWidgetChangeDefinitionRequestLogQueryMultiComputeList",
    "PowerpackWidgetChangeDefinitionRequestLogQueryMultiComputeOutputReference",
    "PowerpackWidgetChangeDefinitionRequestLogQueryOutputReference",
    "PowerpackWidgetChangeDefinitionRequestOutputReference",
    "PowerpackWidgetChangeDefinitionRequestProcessQuery",
    "PowerpackWidgetChangeDefinitionRequestProcessQueryOutputReference",
    "PowerpackWidgetChangeDefinitionRequestQuery",
    "PowerpackWidgetChangeDefinitionRequestQueryApmDependencyStatsQuery",
    "PowerpackWidgetChangeDefinitionRequestQueryApmDependencyStatsQueryOutputReference",
    "PowerpackWidgetChangeDefinitionRequestQueryApmResourceStatsQuery",
    "PowerpackWidgetChangeDefinitionRequestQueryApmResourceStatsQueryOutputReference",
    "PowerpackWidgetChangeDefinitionRequestQueryCloudCostQuery",
    "PowerpackWidgetChangeDefinitionRequestQueryCloudCostQueryOutputReference",
    "PowerpackWidgetChangeDefinitionRequestQueryEventQuery",
    "PowerpackWidgetChangeDefinitionRequestQueryEventQueryCompute",
    "PowerpackWidgetChangeDefinitionRequestQueryEventQueryComputeList",
    "PowerpackWidgetChangeDefinitionRequestQueryEventQueryComputeOutputReference",
    "PowerpackWidgetChangeDefinitionRequestQueryEventQueryGroupBy",
    "PowerpackWidgetChangeDefinitionRequestQueryEventQueryGroupByList",
    "PowerpackWidgetChangeDefinitionRequestQueryEventQueryGroupByOutputReference",
    "PowerpackWidgetChangeDefinitionRequestQueryEventQueryGroupBySort",
    "PowerpackWidgetChangeDefinitionRequestQueryEventQueryGroupBySortOutputReference",
    "PowerpackWidgetChangeDefinitionRequestQueryEventQueryOutputReference",
    "PowerpackWidgetChangeDefinitionRequestQueryEventQuerySearch",
    "PowerpackWidgetChangeDefinitionRequestQueryEventQuerySearchOutputReference",
    "PowerpackWidgetChangeDefinitionRequestQueryList",
    "PowerpackWidgetChangeDefinitionRequestQueryMetricQuery",
    "PowerpackWidgetChangeDefinitionRequestQueryMetricQueryOutputReference",
    "PowerpackWidgetChangeDefinitionRequestQueryOutputReference",
    "PowerpackWidgetChangeDefinitionRequestQueryProcessQuery",
    "PowerpackWidgetChangeDefinitionRequestQueryProcessQueryOutputReference",
    "PowerpackWidgetChangeDefinitionRequestQuerySloQuery",
    "PowerpackWidgetChangeDefinitionRequestQuerySloQueryOutputReference",
    "PowerpackWidgetChangeDefinitionRequestRumQuery",
    "PowerpackWidgetChangeDefinitionRequestRumQueryComputeQuery",
    "PowerpackWidgetChangeDefinitionRequestRumQueryComputeQueryOutputReference",
    "PowerpackWidgetChangeDefinitionRequestRumQueryGroupBy",
    "PowerpackWidgetChangeDefinitionRequestRumQueryGroupByList",
    "PowerpackWidgetChangeDefinitionRequestRumQueryGroupByOutputReference",
    "PowerpackWidgetChangeDefinitionRequestRumQueryGroupBySortQuery",
    "PowerpackWidgetChangeDefinitionRequestRumQueryGroupBySortQueryOutputReference",
    "PowerpackWidgetChangeDefinitionRequestRumQueryMultiCompute",
    "PowerpackWidgetChangeDefinitionRequestRumQueryMultiComputeList",
    "PowerpackWidgetChangeDefinitionRequestRumQueryMultiComputeOutputReference",
    "PowerpackWidgetChangeDefinitionRequestRumQueryOutputReference",
    "PowerpackWidgetChangeDefinitionRequestSecurityQuery",
    "PowerpackWidgetChangeDefinitionRequestSecurityQueryComputeQuery",
    "PowerpackWidgetChangeDefinitionRequestSecurityQueryComputeQueryOutputReference",
    "PowerpackWidgetChangeDefinitionRequestSecurityQueryGroupBy",
    "PowerpackWidgetChangeDefinitionRequestSecurityQueryGroupByList",
    "PowerpackWidgetChangeDefinitionRequestSecurityQueryGroupByOutputReference",
    "PowerpackWidgetChangeDefinitionRequestSecurityQueryGroupBySortQuery",
    "PowerpackWidgetChangeDefinitionRequestSecurityQueryGroupBySortQueryOutputReference",
    "PowerpackWidgetChangeDefinitionRequestSecurityQueryMultiCompute",
    "PowerpackWidgetChangeDefinitionRequestSecurityQueryMultiComputeList",
    "PowerpackWidgetChangeDefinitionRequestSecurityQueryMultiComputeOutputReference",
    "PowerpackWidgetChangeDefinitionRequestSecurityQueryOutputReference",
    "PowerpackWidgetCheckStatusDefinition",
    "PowerpackWidgetCheckStatusDefinitionOutputReference",
    "PowerpackWidgetDistributionDefinition",
    "PowerpackWidgetDistributionDefinitionOutputReference",
    "PowerpackWidgetDistributionDefinitionRequest",
    "PowerpackWidgetDistributionDefinitionRequestApmQuery",
    "PowerpackWidgetDistributionDefinitionRequestApmQueryComputeQuery",
    "PowerpackWidgetDistributionDefinitionRequestApmQueryComputeQueryOutputReference",
    "PowerpackWidgetDistributionDefinitionRequestApmQueryGroupBy",
    "PowerpackWidgetDistributionDefinitionRequestApmQueryGroupByList",
    "PowerpackWidgetDistributionDefinitionRequestApmQueryGroupByOutputReference",
    "PowerpackWidgetDistributionDefinitionRequestApmQueryGroupBySortQuery",
    "PowerpackWidgetDistributionDefinitionRequestApmQueryGroupBySortQueryOutputReference",
    "PowerpackWidgetDistributionDefinitionRequestApmQueryMultiCompute",
    "PowerpackWidgetDistributionDefinitionRequestApmQueryMultiComputeList",
    "PowerpackWidgetDistributionDefinitionRequestApmQueryMultiComputeOutputReference",
    "PowerpackWidgetDistributionDefinitionRequestApmQueryOutputReference",
    "PowerpackWidgetDistributionDefinitionRequestApmStatsQuery",
    "PowerpackWidgetDistributionDefinitionRequestApmStatsQueryColumns",
    "PowerpackWidgetDistributionDefinitionRequestApmStatsQueryColumnsList",
    "PowerpackWidgetDistributionDefinitionRequestApmStatsQueryColumnsOutputReference",
    "PowerpackWidgetDistributionDefinitionRequestApmStatsQueryOutputReference",
    "PowerpackWidgetDistributionDefinitionRequestList",
    "PowerpackWidgetDistributionDefinitionRequestLogQuery",
    "PowerpackWidgetDistributionDefinitionRequestLogQueryComputeQuery",
    "PowerpackWidgetDistributionDefinitionRequestLogQueryComputeQueryOutputReference",
    "PowerpackWidgetDistributionDefinitionRequestLogQueryGroupBy",
    "PowerpackWidgetDistributionDefinitionRequestLogQueryGroupByList",
    "PowerpackWidgetDistributionDefinitionRequestLogQueryGroupByOutputReference",
    "PowerpackWidgetDistributionDefinitionRequestLogQueryGroupBySortQuery",
    "PowerpackWidgetDistributionDefinitionRequestLogQueryGroupBySortQueryOutputReference",
    "PowerpackWidgetDistributionDefinitionRequestLogQueryMultiCompute",
    "PowerpackWidgetDistributionDefinitionRequestLogQueryMultiComputeList",
    "PowerpackWidgetDistributionDefinitionRequestLogQueryMultiComputeOutputReference",
    "PowerpackWidgetDistributionDefinitionRequestLogQueryOutputReference",
    "PowerpackWidgetDistributionDefinitionRequestOutputReference",
    "PowerpackWidgetDistributionDefinitionRequestProcessQuery",
    "PowerpackWidgetDistributionDefinitionRequestProcessQueryOutputReference",
    "PowerpackWidgetDistributionDefinitionRequestRumQuery",
    "PowerpackWidgetDistributionDefinitionRequestRumQueryComputeQuery",
    "PowerpackWidgetDistributionDefinitionRequestRumQueryComputeQueryOutputReference",
    "PowerpackWidgetDistributionDefinitionRequestRumQueryGroupBy",
    "PowerpackWidgetDistributionDefinitionRequestRumQueryGroupByList",
    "PowerpackWidgetDistributionDefinitionRequestRumQueryGroupByOutputReference",
    "PowerpackWidgetDistributionDefinitionRequestRumQueryGroupBySortQuery",
    "PowerpackWidgetDistributionDefinitionRequestRumQueryGroupBySortQueryOutputReference",
    "PowerpackWidgetDistributionDefinitionRequestRumQueryMultiCompute",
    "PowerpackWidgetDistributionDefinitionRequestRumQueryMultiComputeList",
    "PowerpackWidgetDistributionDefinitionRequestRumQueryMultiComputeOutputReference",
    "PowerpackWidgetDistributionDefinitionRequestRumQueryOutputReference",
    "PowerpackWidgetDistributionDefinitionRequestSecurityQuery",
    "PowerpackWidgetDistributionDefinitionRequestSecurityQueryComputeQuery",
    "PowerpackWidgetDistributionDefinitionRequestSecurityQueryComputeQueryOutputReference",
    "PowerpackWidgetDistributionDefinitionRequestSecurityQueryGroupBy",
    "PowerpackWidgetDistributionDefinitionRequestSecurityQueryGroupByList",
    "PowerpackWidgetDistributionDefinitionRequestSecurityQueryGroupByOutputReference",
    "PowerpackWidgetDistributionDefinitionRequestSecurityQueryGroupBySortQuery",
    "PowerpackWidgetDistributionDefinitionRequestSecurityQueryGroupBySortQueryOutputReference",
    "PowerpackWidgetDistributionDefinitionRequestSecurityQueryMultiCompute",
    "PowerpackWidgetDistributionDefinitionRequestSecurityQueryMultiComputeList",
    "PowerpackWidgetDistributionDefinitionRequestSecurityQueryMultiComputeOutputReference",
    "PowerpackWidgetDistributionDefinitionRequestSecurityQueryOutputReference",
    "PowerpackWidgetDistributionDefinitionRequestStyle",
    "PowerpackWidgetDistributionDefinitionRequestStyleOutputReference",
    "PowerpackWidgetDistributionDefinitionXaxis",
    "PowerpackWidgetDistributionDefinitionXaxisOutputReference",
    "PowerpackWidgetDistributionDefinitionYaxis",
    "PowerpackWidgetDistributionDefinitionYaxisOutputReference",
    "PowerpackWidgetEventStreamDefinition",
    "PowerpackWidgetEventStreamDefinitionOutputReference",
    "PowerpackWidgetEventTimelineDefinition",
    "PowerpackWidgetEventTimelineDefinitionOutputReference",
    "PowerpackWidgetFreeTextDefinition",
    "PowerpackWidgetFreeTextDefinitionOutputReference",
    "PowerpackWidgetGeomapDefinition",
    "PowerpackWidgetGeomapDefinitionCustomLink",
    "PowerpackWidgetGeomapDefinitionCustomLinkList",
    "PowerpackWidgetGeomapDefinitionCustomLinkOutputReference",
    "PowerpackWidgetGeomapDefinitionOutputReference",
    "PowerpackWidgetGeomapDefinitionRequest",
    "PowerpackWidgetGeomapDefinitionRequestFormula",
    "PowerpackWidgetGeomapDefinitionRequestFormulaConditionalFormats",
    "PowerpackWidgetGeomapDefinitionRequestFormulaConditionalFormatsList",
    "PowerpackWidgetGeomapDefinitionRequestFormulaConditionalFormatsOutputReference",
    "PowerpackWidgetGeomapDefinitionRequestFormulaLimit",
    "PowerpackWidgetGeomapDefinitionRequestFormulaLimitOutputReference",
    "PowerpackWidgetGeomapDefinitionRequestFormulaList",
    "PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormat",
    "PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormatOutputReference",
    "PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormatUnit",
    "PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormatUnitCanonical",
    "PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormatUnitCanonicalOutputReference",
    "PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormatUnitCustom",
    "PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormatUnitCustomOutputReference",
    "PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormatUnitOutputReference",
    "PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormatUnitScale",
    "PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormatUnitScaleOutputReference",
    "PowerpackWidgetGeomapDefinitionRequestFormulaOutputReference",
    "PowerpackWidgetGeomapDefinitionRequestFormulaStyle",
    "PowerpackWidgetGeomapDefinitionRequestFormulaStyleOutputReference",
    "PowerpackWidgetGeomapDefinitionRequestList",
    "PowerpackWidgetGeomapDefinitionRequestLogQuery",
    "PowerpackWidgetGeomapDefinitionRequestLogQueryComputeQuery",
    "PowerpackWidgetGeomapDefinitionRequestLogQueryComputeQueryOutputReference",
    "PowerpackWidgetGeomapDefinitionRequestLogQueryGroupBy",
    "PowerpackWidgetGeomapDefinitionRequestLogQueryGroupByList",
    "PowerpackWidgetGeomapDefinitionRequestLogQueryGroupByOutputReference",
    "PowerpackWidgetGeomapDefinitionRequestLogQueryGroupBySortQuery",
    "PowerpackWidgetGeomapDefinitionRequestLogQueryGroupBySortQueryOutputReference",
    "PowerpackWidgetGeomapDefinitionRequestLogQueryMultiCompute",
    "PowerpackWidgetGeomapDefinitionRequestLogQueryMultiComputeList",
    "PowerpackWidgetGeomapDefinitionRequestLogQueryMultiComputeOutputReference",
    "PowerpackWidgetGeomapDefinitionRequestLogQueryOutputReference",
    "PowerpackWidgetGeomapDefinitionRequestOutputReference",
    "PowerpackWidgetGeomapDefinitionRequestQuery",
    "PowerpackWidgetGeomapDefinitionRequestQueryApmDependencyStatsQuery",
    "PowerpackWidgetGeomapDefinitionRequestQueryApmDependencyStatsQueryOutputReference",
    "PowerpackWidgetGeomapDefinitionRequestQueryApmResourceStatsQuery",
    "PowerpackWidgetGeomapDefinitionRequestQueryApmResourceStatsQueryOutputReference",
    "PowerpackWidgetGeomapDefinitionRequestQueryCloudCostQuery",
    "PowerpackWidgetGeomapDefinitionRequestQueryCloudCostQueryOutputReference",
    "PowerpackWidgetGeomapDefinitionRequestQueryEventQuery",
    "PowerpackWidgetGeomapDefinitionRequestQueryEventQueryCompute",
    "PowerpackWidgetGeomapDefinitionRequestQueryEventQueryComputeList",
    "PowerpackWidgetGeomapDefinitionRequestQueryEventQueryComputeOutputReference",
    "PowerpackWidgetGeomapDefinitionRequestQueryEventQueryGroupBy",
    "PowerpackWidgetGeomapDefinitionRequestQueryEventQueryGroupByList",
    "PowerpackWidgetGeomapDefinitionRequestQueryEventQueryGroupByOutputReference",
    "PowerpackWidgetGeomapDefinitionRequestQueryEventQueryGroupBySort",
    "PowerpackWidgetGeomapDefinitionRequestQueryEventQueryGroupBySortOutputReference",
    "PowerpackWidgetGeomapDefinitionRequestQueryEventQueryOutputReference",
    "PowerpackWidgetGeomapDefinitionRequestQueryEventQuerySearch",
    "PowerpackWidgetGeomapDefinitionRequestQueryEventQuerySearchOutputReference",
    "PowerpackWidgetGeomapDefinitionRequestQueryList",
    "PowerpackWidgetGeomapDefinitionRequestQueryMetricQuery",
    "PowerpackWidgetGeomapDefinitionRequestQueryMetricQueryOutputReference",
    "PowerpackWidgetGeomapDefinitionRequestQueryOutputReference",
    "PowerpackWidgetGeomapDefinitionRequestQueryProcessQuery",
    "PowerpackWidgetGeomapDefinitionRequestQueryProcessQueryOutputReference",
    "PowerpackWidgetGeomapDefinitionRequestQuerySloQuery",
    "PowerpackWidgetGeomapDefinitionRequestQuerySloQueryOutputReference",
    "PowerpackWidgetGeomapDefinitionRequestRumQuery",
    "PowerpackWidgetGeomapDefinitionRequestRumQueryComputeQuery",
    "PowerpackWidgetGeomapDefinitionRequestRumQueryComputeQueryOutputReference",
    "PowerpackWidgetGeomapDefinitionRequestRumQueryGroupBy",
    "PowerpackWidgetGeomapDefinitionRequestRumQueryGroupByList",
    "PowerpackWidgetGeomapDefinitionRequestRumQueryGroupByOutputReference",
    "PowerpackWidgetGeomapDefinitionRequestRumQueryGroupBySortQuery",
    "PowerpackWidgetGeomapDefinitionRequestRumQueryGroupBySortQueryOutputReference",
    "PowerpackWidgetGeomapDefinitionRequestRumQueryMultiCompute",
    "PowerpackWidgetGeomapDefinitionRequestRumQueryMultiComputeList",
    "PowerpackWidgetGeomapDefinitionRequestRumQueryMultiComputeOutputReference",
    "PowerpackWidgetGeomapDefinitionRequestRumQueryOutputReference",
    "PowerpackWidgetGeomapDefinitionStyle",
    "PowerpackWidgetGeomapDefinitionStyleOutputReference",
    "PowerpackWidgetGeomapDefinitionView",
    "PowerpackWidgetGeomapDefinitionViewOutputReference",
    "PowerpackWidgetHeatmapDefinition",
    "PowerpackWidgetHeatmapDefinitionCustomLink",
    "PowerpackWidgetHeatmapDefinitionCustomLinkList",
    "PowerpackWidgetHeatmapDefinitionCustomLinkOutputReference",
    "PowerpackWidgetHeatmapDefinitionEvent",
    "PowerpackWidgetHeatmapDefinitionEventList",
    "PowerpackWidgetHeatmapDefinitionEventOutputReference",
    "PowerpackWidgetHeatmapDefinitionOutputReference",
    "PowerpackWidgetHeatmapDefinitionRequest",
    "PowerpackWidgetHeatmapDefinitionRequestApmQuery",
    "PowerpackWidgetHeatmapDefinitionRequestApmQueryComputeQuery",
    "PowerpackWidgetHeatmapDefinitionRequestApmQueryComputeQueryOutputReference",
    "PowerpackWidgetHeatmapDefinitionRequestApmQueryGroupBy",
    "PowerpackWidgetHeatmapDefinitionRequestApmQueryGroupByList",
    "PowerpackWidgetHeatmapDefinitionRequestApmQueryGroupByOutputReference",
    "PowerpackWidgetHeatmapDefinitionRequestApmQueryGroupBySortQuery",
    "PowerpackWidgetHeatmapDefinitionRequestApmQueryGroupBySortQueryOutputReference",
    "PowerpackWidgetHeatmapDefinitionRequestApmQueryMultiCompute",
    "PowerpackWidgetHeatmapDefinitionRequestApmQueryMultiComputeList",
    "PowerpackWidgetHeatmapDefinitionRequestApmQueryMultiComputeOutputReference",
    "PowerpackWidgetHeatmapDefinitionRequestApmQueryOutputReference",
    "PowerpackWidgetHeatmapDefinitionRequestFormula",
    "PowerpackWidgetHeatmapDefinitionRequestFormulaConditionalFormats",
    "PowerpackWidgetHeatmapDefinitionRequestFormulaConditionalFormatsList",
    "PowerpackWidgetHeatmapDefinitionRequestFormulaConditionalFormatsOutputReference",
    "PowerpackWidgetHeatmapDefinitionRequestFormulaLimit",
    "PowerpackWidgetHeatmapDefinitionRequestFormulaLimitOutputReference",
    "PowerpackWidgetHeatmapDefinitionRequestFormulaList",
    "PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormat",
    "PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormatOutputReference",
    "PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormatUnit",
    "PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormatUnitCanonical",
    "PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormatUnitCanonicalOutputReference",
    "PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormatUnitCustom",
    "PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormatUnitCustomOutputReference",
    "PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormatUnitOutputReference",
    "PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormatUnitScale",
    "PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormatUnitScaleOutputReference",
    "PowerpackWidgetHeatmapDefinitionRequestFormulaOutputReference",
    "PowerpackWidgetHeatmapDefinitionRequestFormulaStyle",
    "PowerpackWidgetHeatmapDefinitionRequestFormulaStyleOutputReference",
    "PowerpackWidgetHeatmapDefinitionRequestList",
    "PowerpackWidgetHeatmapDefinitionRequestLogQuery",
    "PowerpackWidgetHeatmapDefinitionRequestLogQueryComputeQuery",
    "PowerpackWidgetHeatmapDefinitionRequestLogQueryComputeQueryOutputReference",
    "PowerpackWidgetHeatmapDefinitionRequestLogQueryGroupBy",
    "PowerpackWidgetHeatmapDefinitionRequestLogQueryGroupByList",
    "PowerpackWidgetHeatmapDefinitionRequestLogQueryGroupByOutputReference",
    "PowerpackWidgetHeatmapDefinitionRequestLogQueryGroupBySortQuery",
    "PowerpackWidgetHeatmapDefinitionRequestLogQueryGroupBySortQueryOutputReference",
    "PowerpackWidgetHeatmapDefinitionRequestLogQueryMultiCompute",
    "PowerpackWidgetHeatmapDefinitionRequestLogQueryMultiComputeList",
    "PowerpackWidgetHeatmapDefinitionRequestLogQueryMultiComputeOutputReference",
    "PowerpackWidgetHeatmapDefinitionRequestLogQueryOutputReference",
    "PowerpackWidgetHeatmapDefinitionRequestOutputReference",
    "PowerpackWidgetHeatmapDefinitionRequestProcessQuery",
    "PowerpackWidgetHeatmapDefinitionRequestProcessQueryOutputReference",
    "PowerpackWidgetHeatmapDefinitionRequestQuery",
    "PowerpackWidgetHeatmapDefinitionRequestQueryApmDependencyStatsQuery",
    "PowerpackWidgetHeatmapDefinitionRequestQueryApmDependencyStatsQueryOutputReference",
    "PowerpackWidgetHeatmapDefinitionRequestQueryApmResourceStatsQuery",
    "PowerpackWidgetHeatmapDefinitionRequestQueryApmResourceStatsQueryOutputReference",
    "PowerpackWidgetHeatmapDefinitionRequestQueryCloudCostQuery",
    "PowerpackWidgetHeatmapDefinitionRequestQueryCloudCostQueryOutputReference",
    "PowerpackWidgetHeatmapDefinitionRequestQueryEventQuery",
    "PowerpackWidgetHeatmapDefinitionRequestQueryEventQueryCompute",
    "PowerpackWidgetHeatmapDefinitionRequestQueryEventQueryComputeList",
    "PowerpackWidgetHeatmapDefinitionRequestQueryEventQueryComputeOutputReference",
    "PowerpackWidgetHeatmapDefinitionRequestQueryEventQueryGroupBy",
    "PowerpackWidgetHeatmapDefinitionRequestQueryEventQueryGroupByList",
    "PowerpackWidgetHeatmapDefinitionRequestQueryEventQueryGroupByOutputReference",
    "PowerpackWidgetHeatmapDefinitionRequestQueryEventQueryGroupBySort",
    "PowerpackWidgetHeatmapDefinitionRequestQueryEventQueryGroupBySortOutputReference",
    "PowerpackWidgetHeatmapDefinitionRequestQueryEventQueryOutputReference",
    "PowerpackWidgetHeatmapDefinitionRequestQueryEventQuerySearch",
    "PowerpackWidgetHeatmapDefinitionRequestQueryEventQuerySearchOutputReference",
    "PowerpackWidgetHeatmapDefinitionRequestQueryList",
    "PowerpackWidgetHeatmapDefinitionRequestQueryMetricQuery",
    "PowerpackWidgetHeatmapDefinitionRequestQueryMetricQueryOutputReference",
    "PowerpackWidgetHeatmapDefinitionRequestQueryOutputReference",
    "PowerpackWidgetHeatmapDefinitionRequestQueryProcessQuery",
    "PowerpackWidgetHeatmapDefinitionRequestQueryProcessQueryOutputReference",
    "PowerpackWidgetHeatmapDefinitionRequestQuerySloQuery",
    "PowerpackWidgetHeatmapDefinitionRequestQuerySloQueryOutputReference",
    "PowerpackWidgetHeatmapDefinitionRequestRumQuery",
    "PowerpackWidgetHeatmapDefinitionRequestRumQueryComputeQuery",
    "PowerpackWidgetHeatmapDefinitionRequestRumQueryComputeQueryOutputReference",
    "PowerpackWidgetHeatmapDefinitionRequestRumQueryGroupBy",
    "PowerpackWidgetHeatmapDefinitionRequestRumQueryGroupByList",
    "PowerpackWidgetHeatmapDefinitionRequestRumQueryGroupByOutputReference",
    "PowerpackWidgetHeatmapDefinitionRequestRumQueryGroupBySortQuery",
    "PowerpackWidgetHeatmapDefinitionRequestRumQueryGroupBySortQueryOutputReference",
    "PowerpackWidgetHeatmapDefinitionRequestRumQueryMultiCompute",
    "PowerpackWidgetHeatmapDefinitionRequestRumQueryMultiComputeList",
    "PowerpackWidgetHeatmapDefinitionRequestRumQueryMultiComputeOutputReference",
    "PowerpackWidgetHeatmapDefinitionRequestRumQueryOutputReference",
    "PowerpackWidgetHeatmapDefinitionRequestSecurityQuery",
    "PowerpackWidgetHeatmapDefinitionRequestSecurityQueryComputeQuery",
    "PowerpackWidgetHeatmapDefinitionRequestSecurityQueryComputeQueryOutputReference",
    "PowerpackWidgetHeatmapDefinitionRequestSecurityQueryGroupBy",
    "PowerpackWidgetHeatmapDefinitionRequestSecurityQueryGroupByList",
    "PowerpackWidgetHeatmapDefinitionRequestSecurityQueryGroupByOutputReference",
    "PowerpackWidgetHeatmapDefinitionRequestSecurityQueryGroupBySortQuery",
    "PowerpackWidgetHeatmapDefinitionRequestSecurityQueryGroupBySortQueryOutputReference",
    "PowerpackWidgetHeatmapDefinitionRequestSecurityQueryMultiCompute",
    "PowerpackWidgetHeatmapDefinitionRequestSecurityQueryMultiComputeList",
    "PowerpackWidgetHeatmapDefinitionRequestSecurityQueryMultiComputeOutputReference",
    "PowerpackWidgetHeatmapDefinitionRequestSecurityQueryOutputReference",
    "PowerpackWidgetHeatmapDefinitionRequestStyle",
    "PowerpackWidgetHeatmapDefinitionRequestStyleOutputReference",
    "PowerpackWidgetHeatmapDefinitionYaxis",
    "PowerpackWidgetHeatmapDefinitionYaxisOutputReference",
    "PowerpackWidgetHostmapDefinition",
    "PowerpackWidgetHostmapDefinitionCustomLink",
    "PowerpackWidgetHostmapDefinitionCustomLinkList",
    "PowerpackWidgetHostmapDefinitionCustomLinkOutputReference",
    "PowerpackWidgetHostmapDefinitionOutputReference",
    "PowerpackWidgetHostmapDefinitionRequest",
    "PowerpackWidgetHostmapDefinitionRequestFill",
    "PowerpackWidgetHostmapDefinitionRequestFillApmQuery",
    "PowerpackWidgetHostmapDefinitionRequestFillApmQueryComputeQuery",
    "PowerpackWidgetHostmapDefinitionRequestFillApmQueryComputeQueryOutputReference",
    "PowerpackWidgetHostmapDefinitionRequestFillApmQueryGroupBy",
    "PowerpackWidgetHostmapDefinitionRequestFillApmQueryGroupByList",
    "PowerpackWidgetHostmapDefinitionRequestFillApmQueryGroupByOutputReference",
    "PowerpackWidgetHostmapDefinitionRequestFillApmQueryGroupBySortQuery",
    "PowerpackWidgetHostmapDefinitionRequestFillApmQueryGroupBySortQueryOutputReference",
    "PowerpackWidgetHostmapDefinitionRequestFillApmQueryMultiCompute",
    "PowerpackWidgetHostmapDefinitionRequestFillApmQueryMultiComputeList",
    "PowerpackWidgetHostmapDefinitionRequestFillApmQueryMultiComputeOutputReference",
    "PowerpackWidgetHostmapDefinitionRequestFillApmQueryOutputReference",
    "PowerpackWidgetHostmapDefinitionRequestFillList",
    "PowerpackWidgetHostmapDefinitionRequestFillLogQuery",
    "PowerpackWidgetHostmapDefinitionRequestFillLogQueryComputeQuery",
    "PowerpackWidgetHostmapDefinitionRequestFillLogQueryComputeQueryOutputReference",
    "PowerpackWidgetHostmapDefinitionRequestFillLogQueryGroupBy",
    "PowerpackWidgetHostmapDefinitionRequestFillLogQueryGroupByList",
    "PowerpackWidgetHostmapDefinitionRequestFillLogQueryGroupByOutputReference",
    "PowerpackWidgetHostmapDefinitionRequestFillLogQueryGroupBySortQuery",
    "PowerpackWidgetHostmapDefinitionRequestFillLogQueryGroupBySortQueryOutputReference",
    "PowerpackWidgetHostmapDefinitionRequestFillLogQueryMultiCompute",
    "PowerpackWidgetHostmapDefinitionRequestFillLogQueryMultiComputeList",
    "PowerpackWidgetHostmapDefinitionRequestFillLogQueryMultiComputeOutputReference",
    "PowerpackWidgetHostmapDefinitionRequestFillLogQueryOutputReference",
    "PowerpackWidgetHostmapDefinitionRequestFillOutputReference",
    "PowerpackWidgetHostmapDefinitionRequestFillProcessQuery",
    "PowerpackWidgetHostmapDefinitionRequestFillProcessQueryOutputReference",
    "PowerpackWidgetHostmapDefinitionRequestFillRumQuery",
    "PowerpackWidgetHostmapDefinitionRequestFillRumQueryComputeQuery",
    "PowerpackWidgetHostmapDefinitionRequestFillRumQueryComputeQueryOutputReference",
    "PowerpackWidgetHostmapDefinitionRequestFillRumQueryGroupBy",
    "PowerpackWidgetHostmapDefinitionRequestFillRumQueryGroupByList",
    "PowerpackWidgetHostmapDefinitionRequestFillRumQueryGroupByOutputReference",
    "PowerpackWidgetHostmapDefinitionRequestFillRumQueryGroupBySortQuery",
    "PowerpackWidgetHostmapDefinitionRequestFillRumQueryGroupBySortQueryOutputReference",
    "PowerpackWidgetHostmapDefinitionRequestFillRumQueryMultiCompute",
    "PowerpackWidgetHostmapDefinitionRequestFillRumQueryMultiComputeList",
    "PowerpackWidgetHostmapDefinitionRequestFillRumQueryMultiComputeOutputReference",
    "PowerpackWidgetHostmapDefinitionRequestFillRumQueryOutputReference",
    "PowerpackWidgetHostmapDefinitionRequestFillSecurityQuery",
    "PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryComputeQuery",
    "PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryComputeQueryOutputReference",
    "PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryGroupBy",
    "PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryGroupByList",
    "PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryGroupByOutputReference",
    "PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryGroupBySortQuery",
    "PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryGroupBySortQueryOutputReference",
    "PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryMultiCompute",
    "PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryMultiComputeList",
    "PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryMultiComputeOutputReference",
    "PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryOutputReference",
    "PowerpackWidgetHostmapDefinitionRequestOutputReference",
    "PowerpackWidgetHostmapDefinitionRequestSize",
    "PowerpackWidgetHostmapDefinitionRequestSizeApmQuery",
    "PowerpackWidgetHostmapDefinitionRequestSizeApmQueryComputeQuery",
    "PowerpackWidgetHostmapDefinitionRequestSizeApmQueryComputeQueryOutputReference",
    "PowerpackWidgetHostmapDefinitionRequestSizeApmQueryGroupBy",
    "PowerpackWidgetHostmapDefinitionRequestSizeApmQueryGroupByList",
    "PowerpackWidgetHostmapDefinitionRequestSizeApmQueryGroupByOutputReference",
    "PowerpackWidgetHostmapDefinitionRequestSizeApmQueryGroupBySortQuery",
    "PowerpackWidgetHostmapDefinitionRequestSizeApmQueryGroupBySortQueryOutputReference",
    "PowerpackWidgetHostmapDefinitionRequestSizeApmQueryMultiCompute",
    "PowerpackWidgetHostmapDefinitionRequestSizeApmQueryMultiComputeList",
    "PowerpackWidgetHostmapDefinitionRequestSizeApmQueryMultiComputeOutputReference",
    "PowerpackWidgetHostmapDefinitionRequestSizeApmQueryOutputReference",
    "PowerpackWidgetHostmapDefinitionRequestSizeList",
    "PowerpackWidgetHostmapDefinitionRequestSizeLogQuery",
    "PowerpackWidgetHostmapDefinitionRequestSizeLogQueryComputeQuery",
    "PowerpackWidgetHostmapDefinitionRequestSizeLogQueryComputeQueryOutputReference",
    "PowerpackWidgetHostmapDefinitionRequestSizeLogQueryGroupBy",
    "PowerpackWidgetHostmapDefinitionRequestSizeLogQueryGroupByList",
    "PowerpackWidgetHostmapDefinitionRequestSizeLogQueryGroupByOutputReference",
    "PowerpackWidgetHostmapDefinitionRequestSizeLogQueryGroupBySortQuery",
    "PowerpackWidgetHostmapDefinitionRequestSizeLogQueryGroupBySortQueryOutputReference",
    "PowerpackWidgetHostmapDefinitionRequestSizeLogQueryMultiCompute",
    "PowerpackWidgetHostmapDefinitionRequestSizeLogQueryMultiComputeList",
    "PowerpackWidgetHostmapDefinitionRequestSizeLogQueryMultiComputeOutputReference",
    "PowerpackWidgetHostmapDefinitionRequestSizeLogQueryOutputReference",
    "PowerpackWidgetHostmapDefinitionRequestSizeOutputReference",
    "PowerpackWidgetHostmapDefinitionRequestSizeProcessQuery",
    "PowerpackWidgetHostmapDefinitionRequestSizeProcessQueryOutputReference",
    "PowerpackWidgetHostmapDefinitionRequestSizeRumQuery",
    "PowerpackWidgetHostmapDefinitionRequestSizeRumQueryComputeQuery",
    "PowerpackWidgetHostmapDefinitionRequestSizeRumQueryComputeQueryOutputReference",
    "PowerpackWidgetHostmapDefinitionRequestSizeRumQueryGroupBy",
    "PowerpackWidgetHostmapDefinitionRequestSizeRumQueryGroupByList",
    "PowerpackWidgetHostmapDefinitionRequestSizeRumQueryGroupByOutputReference",
    "PowerpackWidgetHostmapDefinitionRequestSizeRumQueryGroupBySortQuery",
    "PowerpackWidgetHostmapDefinitionRequestSizeRumQueryGroupBySortQueryOutputReference",
    "PowerpackWidgetHostmapDefinitionRequestSizeRumQueryMultiCompute",
    "PowerpackWidgetHostmapDefinitionRequestSizeRumQueryMultiComputeList",
    "PowerpackWidgetHostmapDefinitionRequestSizeRumQueryMultiComputeOutputReference",
    "PowerpackWidgetHostmapDefinitionRequestSizeRumQueryOutputReference",
    "PowerpackWidgetHostmapDefinitionRequestSizeSecurityQuery",
    "PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryComputeQuery",
    "PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryComputeQueryOutputReference",
    "PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryGroupBy",
    "PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryGroupByList",
    "PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryGroupByOutputReference",
    "PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryGroupBySortQuery",
    "PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryGroupBySortQueryOutputReference",
    "PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryMultiCompute",
    "PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryMultiComputeList",
    "PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryMultiComputeOutputReference",
    "PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryOutputReference",
    "PowerpackWidgetHostmapDefinitionStyle",
    "PowerpackWidgetHostmapDefinitionStyleOutputReference",
    "PowerpackWidgetIframeDefinition",
    "PowerpackWidgetIframeDefinitionOutputReference",
    "PowerpackWidgetImageDefinition",
    "PowerpackWidgetImageDefinitionOutputReference",
    "PowerpackWidgetList",
    "PowerpackWidgetListStreamDefinition",
    "PowerpackWidgetListStreamDefinitionOutputReference",
    "PowerpackWidgetListStreamDefinitionRequest",
    "PowerpackWidgetListStreamDefinitionRequestColumns",
    "PowerpackWidgetListStreamDefinitionRequestColumnsList",
    "PowerpackWidgetListStreamDefinitionRequestColumnsOutputReference",
    "PowerpackWidgetListStreamDefinitionRequestList",
    "PowerpackWidgetListStreamDefinitionRequestOutputReference",
    "PowerpackWidgetListStreamDefinitionRequestQuery",
    "PowerpackWidgetListStreamDefinitionRequestQueryGroupBy",
    "PowerpackWidgetListStreamDefinitionRequestQueryGroupByList",
    "PowerpackWidgetListStreamDefinitionRequestQueryGroupByOutputReference",
    "PowerpackWidgetListStreamDefinitionRequestQueryOutputReference",
    "PowerpackWidgetListStreamDefinitionRequestQuerySort",
    "PowerpackWidgetListStreamDefinitionRequestQuerySortOutputReference",
    "PowerpackWidgetLogStreamDefinition",
    "PowerpackWidgetLogStreamDefinitionOutputReference",
    "PowerpackWidgetLogStreamDefinitionSort",
    "PowerpackWidgetLogStreamDefinitionSortOutputReference",
    "PowerpackWidgetManageStatusDefinition",
    "PowerpackWidgetManageStatusDefinitionOutputReference",
    "PowerpackWidgetNoteDefinition",
    "PowerpackWidgetNoteDefinitionOutputReference",
    "PowerpackWidgetOutputReference",
    "PowerpackWidgetQueryTableDefinition",
    "PowerpackWidgetQueryTableDefinitionCustomLink",
    "PowerpackWidgetQueryTableDefinitionCustomLinkList",
    "PowerpackWidgetQueryTableDefinitionCustomLinkOutputReference",
    "PowerpackWidgetQueryTableDefinitionOutputReference",
    "PowerpackWidgetQueryTableDefinitionRequest",
    "PowerpackWidgetQueryTableDefinitionRequestApmQuery",
    "PowerpackWidgetQueryTableDefinitionRequestApmQueryComputeQuery",
    "PowerpackWidgetQueryTableDefinitionRequestApmQueryComputeQueryOutputReference",
    "PowerpackWidgetQueryTableDefinitionRequestApmQueryGroupBy",
    "PowerpackWidgetQueryTableDefinitionRequestApmQueryGroupByList",
    "PowerpackWidgetQueryTableDefinitionRequestApmQueryGroupByOutputReference",
    "PowerpackWidgetQueryTableDefinitionRequestApmQueryGroupBySortQuery",
    "PowerpackWidgetQueryTableDefinitionRequestApmQueryGroupBySortQueryOutputReference",
    "PowerpackWidgetQueryTableDefinitionRequestApmQueryMultiCompute",
    "PowerpackWidgetQueryTableDefinitionRequestApmQueryMultiComputeList",
    "PowerpackWidgetQueryTableDefinitionRequestApmQueryMultiComputeOutputReference",
    "PowerpackWidgetQueryTableDefinitionRequestApmQueryOutputReference",
    "PowerpackWidgetQueryTableDefinitionRequestApmStatsQuery",
    "PowerpackWidgetQueryTableDefinitionRequestApmStatsQueryColumns",
    "PowerpackWidgetQueryTableDefinitionRequestApmStatsQueryColumnsList",
    "PowerpackWidgetQueryTableDefinitionRequestApmStatsQueryColumnsOutputReference",
    "PowerpackWidgetQueryTableDefinitionRequestApmStatsQueryOutputReference",
    "PowerpackWidgetQueryTableDefinitionRequestConditionalFormats",
    "PowerpackWidgetQueryTableDefinitionRequestConditionalFormatsList",
    "PowerpackWidgetQueryTableDefinitionRequestConditionalFormatsOutputReference",
    "PowerpackWidgetQueryTableDefinitionRequestFormula",
    "PowerpackWidgetQueryTableDefinitionRequestFormulaCellDisplayModeOptions",
    "PowerpackWidgetQueryTableDefinitionRequestFormulaCellDisplayModeOptionsOutputReference",
    "PowerpackWidgetQueryTableDefinitionRequestFormulaConditionalFormats",
    "PowerpackWidgetQueryTableDefinitionRequestFormulaConditionalFormatsList",
    "PowerpackWidgetQueryTableDefinitionRequestFormulaConditionalFormatsOutputReference",
    "PowerpackWidgetQueryTableDefinitionRequestFormulaLimit",
    "PowerpackWidgetQueryTableDefinitionRequestFormulaLimitOutputReference",
    "PowerpackWidgetQueryTableDefinitionRequestFormulaList",
    "PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormat",
    "PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormatOutputReference",
    "PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormatUnit",
    "PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormatUnitCanonical",
    "PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormatUnitCanonicalOutputReference",
    "PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormatUnitCustom",
    "PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormatUnitCustomOutputReference",
    "PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormatUnitOutputReference",
    "PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormatUnitScale",
    "PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormatUnitScaleOutputReference",
    "PowerpackWidgetQueryTableDefinitionRequestFormulaOutputReference",
    "PowerpackWidgetQueryTableDefinitionRequestFormulaStyle",
    "PowerpackWidgetQueryTableDefinitionRequestFormulaStyleOutputReference",
    "PowerpackWidgetQueryTableDefinitionRequestList",
    "PowerpackWidgetQueryTableDefinitionRequestLogQuery",
    "PowerpackWidgetQueryTableDefinitionRequestLogQueryComputeQuery",
    "PowerpackWidgetQueryTableDefinitionRequestLogQueryComputeQueryOutputReference",
    "PowerpackWidgetQueryTableDefinitionRequestLogQueryGroupBy",
    "PowerpackWidgetQueryTableDefinitionRequestLogQueryGroupByList",
    "PowerpackWidgetQueryTableDefinitionRequestLogQueryGroupByOutputReference",
    "PowerpackWidgetQueryTableDefinitionRequestLogQueryGroupBySortQuery",
    "PowerpackWidgetQueryTableDefinitionRequestLogQueryGroupBySortQueryOutputReference",
    "PowerpackWidgetQueryTableDefinitionRequestLogQueryMultiCompute",
    "PowerpackWidgetQueryTableDefinitionRequestLogQueryMultiComputeList",
    "PowerpackWidgetQueryTableDefinitionRequestLogQueryMultiComputeOutputReference",
    "PowerpackWidgetQueryTableDefinitionRequestLogQueryOutputReference",
    "PowerpackWidgetQueryTableDefinitionRequestOutputReference",
    "PowerpackWidgetQueryTableDefinitionRequestProcessQuery",
    "PowerpackWidgetQueryTableDefinitionRequestProcessQueryOutputReference",
    "PowerpackWidgetQueryTableDefinitionRequestQuery",
    "PowerpackWidgetQueryTableDefinitionRequestQueryApmDependencyStatsQuery",
    "PowerpackWidgetQueryTableDefinitionRequestQueryApmDependencyStatsQueryOutputReference",
    "PowerpackWidgetQueryTableDefinitionRequestQueryApmResourceStatsQuery",
    "PowerpackWidgetQueryTableDefinitionRequestQueryApmResourceStatsQueryOutputReference",
    "PowerpackWidgetQueryTableDefinitionRequestQueryCloudCostQuery",
    "PowerpackWidgetQueryTableDefinitionRequestQueryCloudCostQueryOutputReference",
    "PowerpackWidgetQueryTableDefinitionRequestQueryEventQuery",
    "PowerpackWidgetQueryTableDefinitionRequestQueryEventQueryCompute",
    "PowerpackWidgetQueryTableDefinitionRequestQueryEventQueryComputeList",
    "PowerpackWidgetQueryTableDefinitionRequestQueryEventQueryComputeOutputReference",
    "PowerpackWidgetQueryTableDefinitionRequestQueryEventQueryGroupBy",
    "PowerpackWidgetQueryTableDefinitionRequestQueryEventQueryGroupByList",
    "PowerpackWidgetQueryTableDefinitionRequestQueryEventQueryGroupByOutputReference",
    "PowerpackWidgetQueryTableDefinitionRequestQueryEventQueryGroupBySort",
    "PowerpackWidgetQueryTableDefinitionRequestQueryEventQueryGroupBySortOutputReference",
    "PowerpackWidgetQueryTableDefinitionRequestQueryEventQueryOutputReference",
    "PowerpackWidgetQueryTableDefinitionRequestQueryEventQuerySearch",
    "PowerpackWidgetQueryTableDefinitionRequestQueryEventQuerySearchOutputReference",
    "PowerpackWidgetQueryTableDefinitionRequestQueryList",
    "PowerpackWidgetQueryTableDefinitionRequestQueryMetricQuery",
    "PowerpackWidgetQueryTableDefinitionRequestQueryMetricQueryOutputReference",
    "PowerpackWidgetQueryTableDefinitionRequestQueryOutputReference",
    "PowerpackWidgetQueryTableDefinitionRequestQueryProcessQuery",
    "PowerpackWidgetQueryTableDefinitionRequestQueryProcessQueryOutputReference",
    "PowerpackWidgetQueryTableDefinitionRequestQuerySloQuery",
    "PowerpackWidgetQueryTableDefinitionRequestQuerySloQueryOutputReference",
    "PowerpackWidgetQueryTableDefinitionRequestRumQuery",
    "PowerpackWidgetQueryTableDefinitionRequestRumQueryComputeQuery",
    "PowerpackWidgetQueryTableDefinitionRequestRumQueryComputeQueryOutputReference",
    "PowerpackWidgetQueryTableDefinitionRequestRumQueryGroupBy",
    "PowerpackWidgetQueryTableDefinitionRequestRumQueryGroupByList",
    "PowerpackWidgetQueryTableDefinitionRequestRumQueryGroupByOutputReference",
    "PowerpackWidgetQueryTableDefinitionRequestRumQueryGroupBySortQuery",
    "PowerpackWidgetQueryTableDefinitionRequestRumQueryGroupBySortQueryOutputReference",
    "PowerpackWidgetQueryTableDefinitionRequestRumQueryMultiCompute",
    "PowerpackWidgetQueryTableDefinitionRequestRumQueryMultiComputeList",
    "PowerpackWidgetQueryTableDefinitionRequestRumQueryMultiComputeOutputReference",
    "PowerpackWidgetQueryTableDefinitionRequestRumQueryOutputReference",
    "PowerpackWidgetQueryTableDefinitionRequestSecurityQuery",
    "PowerpackWidgetQueryTableDefinitionRequestSecurityQueryComputeQuery",
    "PowerpackWidgetQueryTableDefinitionRequestSecurityQueryComputeQueryOutputReference",
    "PowerpackWidgetQueryTableDefinitionRequestSecurityQueryGroupBy",
    "PowerpackWidgetQueryTableDefinitionRequestSecurityQueryGroupByList",
    "PowerpackWidgetQueryTableDefinitionRequestSecurityQueryGroupByOutputReference",
    "PowerpackWidgetQueryTableDefinitionRequestSecurityQueryGroupBySortQuery",
    "PowerpackWidgetQueryTableDefinitionRequestSecurityQueryGroupBySortQueryOutputReference",
    "PowerpackWidgetQueryTableDefinitionRequestSecurityQueryMultiCompute",
    "PowerpackWidgetQueryTableDefinitionRequestSecurityQueryMultiComputeList",
    "PowerpackWidgetQueryTableDefinitionRequestSecurityQueryMultiComputeOutputReference",
    "PowerpackWidgetQueryTableDefinitionRequestSecurityQueryOutputReference",
    "PowerpackWidgetQueryTableDefinitionRequestTextFormats",
    "PowerpackWidgetQueryTableDefinitionRequestTextFormatsList",
    "PowerpackWidgetQueryTableDefinitionRequestTextFormatsOutputReference",
    "PowerpackWidgetQueryTableDefinitionRequestTextFormatsTextFormat",
    "PowerpackWidgetQueryTableDefinitionRequestTextFormatsTextFormatList",
    "PowerpackWidgetQueryTableDefinitionRequestTextFormatsTextFormatMatch",
    "PowerpackWidgetQueryTableDefinitionRequestTextFormatsTextFormatMatchOutputReference",
    "PowerpackWidgetQueryTableDefinitionRequestTextFormatsTextFormatOutputReference",
    "PowerpackWidgetQueryTableDefinitionRequestTextFormatsTextFormatReplace",
    "PowerpackWidgetQueryTableDefinitionRequestTextFormatsTextFormatReplaceOutputReference",
    "PowerpackWidgetQueryValueDefinition",
    "PowerpackWidgetQueryValueDefinitionCustomLink",
    "PowerpackWidgetQueryValueDefinitionCustomLinkList",
    "PowerpackWidgetQueryValueDefinitionCustomLinkOutputReference",
    "PowerpackWidgetQueryValueDefinitionOutputReference",
    "PowerpackWidgetQueryValueDefinitionRequest",
    "PowerpackWidgetQueryValueDefinitionRequestApmQuery",
    "PowerpackWidgetQueryValueDefinitionRequestApmQueryComputeQuery",
    "PowerpackWidgetQueryValueDefinitionRequestApmQueryComputeQueryOutputReference",
    "PowerpackWidgetQueryValueDefinitionRequestApmQueryGroupBy",
    "PowerpackWidgetQueryValueDefinitionRequestApmQueryGroupByList",
    "PowerpackWidgetQueryValueDefinitionRequestApmQueryGroupByOutputReference",
    "PowerpackWidgetQueryValueDefinitionRequestApmQueryGroupBySortQuery",
    "PowerpackWidgetQueryValueDefinitionRequestApmQueryGroupBySortQueryOutputReference",
    "PowerpackWidgetQueryValueDefinitionRequestApmQueryMultiCompute",
    "PowerpackWidgetQueryValueDefinitionRequestApmQueryMultiComputeList",
    "PowerpackWidgetQueryValueDefinitionRequestApmQueryMultiComputeOutputReference",
    "PowerpackWidgetQueryValueDefinitionRequestApmQueryOutputReference",
    "PowerpackWidgetQueryValueDefinitionRequestAuditQuery",
    "PowerpackWidgetQueryValueDefinitionRequestAuditQueryComputeQuery",
    "PowerpackWidgetQueryValueDefinitionRequestAuditQueryComputeQueryOutputReference",
    "PowerpackWidgetQueryValueDefinitionRequestAuditQueryGroupBy",
    "PowerpackWidgetQueryValueDefinitionRequestAuditQueryGroupByList",
    "PowerpackWidgetQueryValueDefinitionRequestAuditQueryGroupByOutputReference",
    "PowerpackWidgetQueryValueDefinitionRequestAuditQueryGroupBySortQuery",
    "PowerpackWidgetQueryValueDefinitionRequestAuditQueryGroupBySortQueryOutputReference",
    "PowerpackWidgetQueryValueDefinitionRequestAuditQueryMultiCompute",
    "PowerpackWidgetQueryValueDefinitionRequestAuditQueryMultiComputeList",
    "PowerpackWidgetQueryValueDefinitionRequestAuditQueryMultiComputeOutputReference",
    "PowerpackWidgetQueryValueDefinitionRequestAuditQueryOutputReference",
    "PowerpackWidgetQueryValueDefinitionRequestConditionalFormats",
    "PowerpackWidgetQueryValueDefinitionRequestConditionalFormatsList",
    "PowerpackWidgetQueryValueDefinitionRequestConditionalFormatsOutputReference",
    "PowerpackWidgetQueryValueDefinitionRequestFormula",
    "PowerpackWidgetQueryValueDefinitionRequestFormulaConditionalFormats",
    "PowerpackWidgetQueryValueDefinitionRequestFormulaConditionalFormatsList",
    "PowerpackWidgetQueryValueDefinitionRequestFormulaConditionalFormatsOutputReference",
    "PowerpackWidgetQueryValueDefinitionRequestFormulaLimit",
    "PowerpackWidgetQueryValueDefinitionRequestFormulaLimitOutputReference",
    "PowerpackWidgetQueryValueDefinitionRequestFormulaList",
    "PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormat",
    "PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormatOutputReference",
    "PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormatUnit",
    "PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormatUnitCanonical",
    "PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormatUnitCanonicalOutputReference",
    "PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormatUnitCustom",
    "PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormatUnitCustomOutputReference",
    "PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormatUnitOutputReference",
    "PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormatUnitScale",
    "PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormatUnitScaleOutputReference",
    "PowerpackWidgetQueryValueDefinitionRequestFormulaOutputReference",
    "PowerpackWidgetQueryValueDefinitionRequestFormulaStyle",
    "PowerpackWidgetQueryValueDefinitionRequestFormulaStyleOutputReference",
    "PowerpackWidgetQueryValueDefinitionRequestList",
    "PowerpackWidgetQueryValueDefinitionRequestLogQuery",
    "PowerpackWidgetQueryValueDefinitionRequestLogQueryComputeQuery",
    "PowerpackWidgetQueryValueDefinitionRequestLogQueryComputeQueryOutputReference",
    "PowerpackWidgetQueryValueDefinitionRequestLogQueryGroupBy",
    "PowerpackWidgetQueryValueDefinitionRequestLogQueryGroupByList",
    "PowerpackWidgetQueryValueDefinitionRequestLogQueryGroupByOutputReference",
    "PowerpackWidgetQueryValueDefinitionRequestLogQueryGroupBySortQuery",
    "PowerpackWidgetQueryValueDefinitionRequestLogQueryGroupBySortQueryOutputReference",
    "PowerpackWidgetQueryValueDefinitionRequestLogQueryMultiCompute",
    "PowerpackWidgetQueryValueDefinitionRequestLogQueryMultiComputeList",
    "PowerpackWidgetQueryValueDefinitionRequestLogQueryMultiComputeOutputReference",
    "PowerpackWidgetQueryValueDefinitionRequestLogQueryOutputReference",
    "PowerpackWidgetQueryValueDefinitionRequestOutputReference",
    "PowerpackWidgetQueryValueDefinitionRequestProcessQuery",
    "PowerpackWidgetQueryValueDefinitionRequestProcessQueryOutputReference",
    "PowerpackWidgetQueryValueDefinitionRequestQuery",
    "PowerpackWidgetQueryValueDefinitionRequestQueryApmDependencyStatsQuery",
    "PowerpackWidgetQueryValueDefinitionRequestQueryApmDependencyStatsQueryOutputReference",
    "PowerpackWidgetQueryValueDefinitionRequestQueryApmResourceStatsQuery",
    "PowerpackWidgetQueryValueDefinitionRequestQueryApmResourceStatsQueryOutputReference",
    "PowerpackWidgetQueryValueDefinitionRequestQueryCloudCostQuery",
    "PowerpackWidgetQueryValueDefinitionRequestQueryCloudCostQueryOutputReference",
    "PowerpackWidgetQueryValueDefinitionRequestQueryEventQuery",
    "PowerpackWidgetQueryValueDefinitionRequestQueryEventQueryCompute",
    "PowerpackWidgetQueryValueDefinitionRequestQueryEventQueryComputeList",
    "PowerpackWidgetQueryValueDefinitionRequestQueryEventQueryComputeOutputReference",
    "PowerpackWidgetQueryValueDefinitionRequestQueryEventQueryGroupBy",
    "PowerpackWidgetQueryValueDefinitionRequestQueryEventQueryGroupByList",
    "PowerpackWidgetQueryValueDefinitionRequestQueryEventQueryGroupByOutputReference",
    "PowerpackWidgetQueryValueDefinitionRequestQueryEventQueryGroupBySort",
    "PowerpackWidgetQueryValueDefinitionRequestQueryEventQueryGroupBySortOutputReference",
    "PowerpackWidgetQueryValueDefinitionRequestQueryEventQueryOutputReference",
    "PowerpackWidgetQueryValueDefinitionRequestQueryEventQuerySearch",
    "PowerpackWidgetQueryValueDefinitionRequestQueryEventQuerySearchOutputReference",
    "PowerpackWidgetQueryValueDefinitionRequestQueryList",
    "PowerpackWidgetQueryValueDefinitionRequestQueryMetricQuery",
    "PowerpackWidgetQueryValueDefinitionRequestQueryMetricQueryOutputReference",
    "PowerpackWidgetQueryValueDefinitionRequestQueryOutputReference",
    "PowerpackWidgetQueryValueDefinitionRequestQueryProcessQuery",
    "PowerpackWidgetQueryValueDefinitionRequestQueryProcessQueryOutputReference",
    "PowerpackWidgetQueryValueDefinitionRequestQuerySloQuery",
    "PowerpackWidgetQueryValueDefinitionRequestQuerySloQueryOutputReference",
    "PowerpackWidgetQueryValueDefinitionRequestRumQuery",
    "PowerpackWidgetQueryValueDefinitionRequestRumQueryComputeQuery",
    "PowerpackWidgetQueryValueDefinitionRequestRumQueryComputeQueryOutputReference",
    "PowerpackWidgetQueryValueDefinitionRequestRumQueryGroupBy",
    "PowerpackWidgetQueryValueDefinitionRequestRumQueryGroupByList",
    "PowerpackWidgetQueryValueDefinitionRequestRumQueryGroupByOutputReference",
    "PowerpackWidgetQueryValueDefinitionRequestRumQueryGroupBySortQuery",
    "PowerpackWidgetQueryValueDefinitionRequestRumQueryGroupBySortQueryOutputReference",
    "PowerpackWidgetQueryValueDefinitionRequestRumQueryMultiCompute",
    "PowerpackWidgetQueryValueDefinitionRequestRumQueryMultiComputeList",
    "PowerpackWidgetQueryValueDefinitionRequestRumQueryMultiComputeOutputReference",
    "PowerpackWidgetQueryValueDefinitionRequestRumQueryOutputReference",
    "PowerpackWidgetQueryValueDefinitionRequestSecurityQuery",
    "PowerpackWidgetQueryValueDefinitionRequestSecurityQueryComputeQuery",
    "PowerpackWidgetQueryValueDefinitionRequestSecurityQueryComputeQueryOutputReference",
    "PowerpackWidgetQueryValueDefinitionRequestSecurityQueryGroupBy",
    "PowerpackWidgetQueryValueDefinitionRequestSecurityQueryGroupByList",
    "PowerpackWidgetQueryValueDefinitionRequestSecurityQueryGroupByOutputReference",
    "PowerpackWidgetQueryValueDefinitionRequestSecurityQueryGroupBySortQuery",
    "PowerpackWidgetQueryValueDefinitionRequestSecurityQueryGroupBySortQueryOutputReference",
    "PowerpackWidgetQueryValueDefinitionRequestSecurityQueryMultiCompute",
    "PowerpackWidgetQueryValueDefinitionRequestSecurityQueryMultiComputeList",
    "PowerpackWidgetQueryValueDefinitionRequestSecurityQueryMultiComputeOutputReference",
    "PowerpackWidgetQueryValueDefinitionRequestSecurityQueryOutputReference",
    "PowerpackWidgetQueryValueDefinitionTimeseriesBackground",
    "PowerpackWidgetQueryValueDefinitionTimeseriesBackgroundOutputReference",
    "PowerpackWidgetQueryValueDefinitionTimeseriesBackgroundYaxis",
    "PowerpackWidgetQueryValueDefinitionTimeseriesBackgroundYaxisOutputReference",
    "PowerpackWidgetRunWorkflowDefinition",
    "PowerpackWidgetRunWorkflowDefinitionCustomLink",
    "PowerpackWidgetRunWorkflowDefinitionCustomLinkList",
    "PowerpackWidgetRunWorkflowDefinitionCustomLinkOutputReference",
    "PowerpackWidgetRunWorkflowDefinitionInput",
    "PowerpackWidgetRunWorkflowDefinitionInputList",
    "PowerpackWidgetRunWorkflowDefinitionInputOutputReference",
    "PowerpackWidgetRunWorkflowDefinitionOutputReference",
    "PowerpackWidgetScatterplotDefinition",
    "PowerpackWidgetScatterplotDefinitionCustomLink",
    "PowerpackWidgetScatterplotDefinitionCustomLinkList",
    "PowerpackWidgetScatterplotDefinitionCustomLinkOutputReference",
    "PowerpackWidgetScatterplotDefinitionOutputReference",
    "PowerpackWidgetScatterplotDefinitionRequest",
    "PowerpackWidgetScatterplotDefinitionRequestOutputReference",
    "PowerpackWidgetScatterplotDefinitionRequestScatterplotTable",
    "PowerpackWidgetScatterplotDefinitionRequestScatterplotTableFormula",
    "PowerpackWidgetScatterplotDefinitionRequestScatterplotTableFormulaList",
    "PowerpackWidgetScatterplotDefinitionRequestScatterplotTableFormulaOutputReference",
    "PowerpackWidgetScatterplotDefinitionRequestScatterplotTableList",
    "PowerpackWidgetScatterplotDefinitionRequestScatterplotTableOutputReference",
    "PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQuery",
    "PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryApmDependencyStatsQuery",
    "PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryApmDependencyStatsQueryOutputReference",
    "PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryApmResourceStatsQuery",
    "PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryApmResourceStatsQueryOutputReference",
    "PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryCloudCostQuery",
    "PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryCloudCostQueryOutputReference",
    "PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQuery",
    "PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQueryCompute",
    "PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQueryComputeList",
    "PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQueryComputeOutputReference",
    "PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQueryGroupBy",
    "PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQueryGroupByList",
    "PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQueryGroupByOutputReference",
    "PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQueryGroupBySort",
    "PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQueryGroupBySortOutputReference",
    "PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQueryOutputReference",
    "PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQuerySearch",
    "PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQuerySearchOutputReference",
    "PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryList",
    "PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryMetricQuery",
    "PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryMetricQueryOutputReference",
    "PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryOutputReference",
    "PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryProcessQuery",
    "PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryProcessQueryOutputReference",
    "PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQuerySloQuery",
    "PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQuerySloQueryOutputReference",
    "PowerpackWidgetScatterplotDefinitionRequestX",
    "PowerpackWidgetScatterplotDefinitionRequestXApmQuery",
    "PowerpackWidgetScatterplotDefinitionRequestXApmQueryComputeQuery",
    "PowerpackWidgetScatterplotDefinitionRequestXApmQueryComputeQueryOutputReference",
    "PowerpackWidgetScatterplotDefinitionRequestXApmQueryGroupBy",
    "PowerpackWidgetScatterplotDefinitionRequestXApmQueryGroupByList",
    "PowerpackWidgetScatterplotDefinitionRequestXApmQueryGroupByOutputReference",
    "PowerpackWidgetScatterplotDefinitionRequestXApmQueryGroupBySortQuery",
    "PowerpackWidgetScatterplotDefinitionRequestXApmQueryGroupBySortQueryOutputReference",
    "PowerpackWidgetScatterplotDefinitionRequestXApmQueryMultiCompute",
    "PowerpackWidgetScatterplotDefinitionRequestXApmQueryMultiComputeList",
    "PowerpackWidgetScatterplotDefinitionRequestXApmQueryMultiComputeOutputReference",
    "PowerpackWidgetScatterplotDefinitionRequestXApmQueryOutputReference",
    "PowerpackWidgetScatterplotDefinitionRequestXList",
    "PowerpackWidgetScatterplotDefinitionRequestXLogQuery",
    "PowerpackWidgetScatterplotDefinitionRequestXLogQueryComputeQuery",
    "PowerpackWidgetScatterplotDefinitionRequestXLogQueryComputeQueryOutputReference",
    "PowerpackWidgetScatterplotDefinitionRequestXLogQueryGroupBy",
    "PowerpackWidgetScatterplotDefinitionRequestXLogQueryGroupByList",
    "PowerpackWidgetScatterplotDefinitionRequestXLogQueryGroupByOutputReference",
    "PowerpackWidgetScatterplotDefinitionRequestXLogQueryGroupBySortQuery",
    "PowerpackWidgetScatterplotDefinitionRequestXLogQueryGroupBySortQueryOutputReference",
    "PowerpackWidgetScatterplotDefinitionRequestXLogQueryMultiCompute",
    "PowerpackWidgetScatterplotDefinitionRequestXLogQueryMultiComputeList",
    "PowerpackWidgetScatterplotDefinitionRequestXLogQueryMultiComputeOutputReference",
    "PowerpackWidgetScatterplotDefinitionRequestXLogQueryOutputReference",
    "PowerpackWidgetScatterplotDefinitionRequestXOutputReference",
    "PowerpackWidgetScatterplotDefinitionRequestXProcessQuery",
    "PowerpackWidgetScatterplotDefinitionRequestXProcessQueryOutputReference",
    "PowerpackWidgetScatterplotDefinitionRequestXRumQuery",
    "PowerpackWidgetScatterplotDefinitionRequestXRumQueryComputeQuery",
    "PowerpackWidgetScatterplotDefinitionRequestXRumQueryComputeQueryOutputReference",
    "PowerpackWidgetScatterplotDefinitionRequestXRumQueryGroupBy",
    "PowerpackWidgetScatterplotDefinitionRequestXRumQueryGroupByList",
    "PowerpackWidgetScatterplotDefinitionRequestXRumQueryGroupByOutputReference",
    "PowerpackWidgetScatterplotDefinitionRequestXRumQueryGroupBySortQuery",
    "PowerpackWidgetScatterplotDefinitionRequestXRumQueryGroupBySortQueryOutputReference",
    "PowerpackWidgetScatterplotDefinitionRequestXRumQueryMultiCompute",
    "PowerpackWidgetScatterplotDefinitionRequestXRumQueryMultiComputeList",
    "PowerpackWidgetScatterplotDefinitionRequestXRumQueryMultiComputeOutputReference",
    "PowerpackWidgetScatterplotDefinitionRequestXRumQueryOutputReference",
    "PowerpackWidgetScatterplotDefinitionRequestXSecurityQuery",
    "PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryComputeQuery",
    "PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryComputeQueryOutputReference",
    "PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryGroupBy",
    "PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryGroupByList",
    "PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryGroupByOutputReference",
    "PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryGroupBySortQuery",
    "PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryGroupBySortQueryOutputReference",
    "PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryMultiCompute",
    "PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryMultiComputeList",
    "PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryMultiComputeOutputReference",
    "PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryOutputReference",
    "PowerpackWidgetScatterplotDefinitionRequestY",
    "PowerpackWidgetScatterplotDefinitionRequestYApmQuery",
    "PowerpackWidgetScatterplotDefinitionRequestYApmQueryComputeQuery",
    "PowerpackWidgetScatterplotDefinitionRequestYApmQueryComputeQueryOutputReference",
    "PowerpackWidgetScatterplotDefinitionRequestYApmQueryGroupBy",
    "PowerpackWidgetScatterplotDefinitionRequestYApmQueryGroupByList",
    "PowerpackWidgetScatterplotDefinitionRequestYApmQueryGroupByOutputReference",
    "PowerpackWidgetScatterplotDefinitionRequestYApmQueryGroupBySortQuery",
    "PowerpackWidgetScatterplotDefinitionRequestYApmQueryGroupBySortQueryOutputReference",
    "PowerpackWidgetScatterplotDefinitionRequestYApmQueryMultiCompute",
    "PowerpackWidgetScatterplotDefinitionRequestYApmQueryMultiComputeList",
    "PowerpackWidgetScatterplotDefinitionRequestYApmQueryMultiComputeOutputReference",
    "PowerpackWidgetScatterplotDefinitionRequestYApmQueryOutputReference",
    "PowerpackWidgetScatterplotDefinitionRequestYList",
    "PowerpackWidgetScatterplotDefinitionRequestYLogQuery",
    "PowerpackWidgetScatterplotDefinitionRequestYLogQueryComputeQuery",
    "PowerpackWidgetScatterplotDefinitionRequestYLogQueryComputeQueryOutputReference",
    "PowerpackWidgetScatterplotDefinitionRequestYLogQueryGroupBy",
    "PowerpackWidgetScatterplotDefinitionRequestYLogQueryGroupByList",
    "PowerpackWidgetScatterplotDefinitionRequestYLogQueryGroupByOutputReference",
    "PowerpackWidgetScatterplotDefinitionRequestYLogQueryGroupBySortQuery",
    "PowerpackWidgetScatterplotDefinitionRequestYLogQueryGroupBySortQueryOutputReference",
    "PowerpackWidgetScatterplotDefinitionRequestYLogQueryMultiCompute",
    "PowerpackWidgetScatterplotDefinitionRequestYLogQueryMultiComputeList",
    "PowerpackWidgetScatterplotDefinitionRequestYLogQueryMultiComputeOutputReference",
    "PowerpackWidgetScatterplotDefinitionRequestYLogQueryOutputReference",
    "PowerpackWidgetScatterplotDefinitionRequestYOutputReference",
    "PowerpackWidgetScatterplotDefinitionRequestYProcessQuery",
    "PowerpackWidgetScatterplotDefinitionRequestYProcessQueryOutputReference",
    "PowerpackWidgetScatterplotDefinitionRequestYRumQuery",
    "PowerpackWidgetScatterplotDefinitionRequestYRumQueryComputeQuery",
    "PowerpackWidgetScatterplotDefinitionRequestYRumQueryComputeQueryOutputReference",
    "PowerpackWidgetScatterplotDefinitionRequestYRumQueryGroupBy",
    "PowerpackWidgetScatterplotDefinitionRequestYRumQueryGroupByList",
    "PowerpackWidgetScatterplotDefinitionRequestYRumQueryGroupByOutputReference",
    "PowerpackWidgetScatterplotDefinitionRequestYRumQueryGroupBySortQuery",
    "PowerpackWidgetScatterplotDefinitionRequestYRumQueryGroupBySortQueryOutputReference",
    "PowerpackWidgetScatterplotDefinitionRequestYRumQueryMultiCompute",
    "PowerpackWidgetScatterplotDefinitionRequestYRumQueryMultiComputeList",
    "PowerpackWidgetScatterplotDefinitionRequestYRumQueryMultiComputeOutputReference",
    "PowerpackWidgetScatterplotDefinitionRequestYRumQueryOutputReference",
    "PowerpackWidgetScatterplotDefinitionRequestYSecurityQuery",
    "PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryComputeQuery",
    "PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryComputeQueryOutputReference",
    "PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryGroupBy",
    "PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryGroupByList",
    "PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryGroupByOutputReference",
    "PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryGroupBySortQuery",
    "PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryGroupBySortQueryOutputReference",
    "PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryMultiCompute",
    "PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryMultiComputeList",
    "PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryMultiComputeOutputReference",
    "PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryOutputReference",
    "PowerpackWidgetScatterplotDefinitionXaxis",
    "PowerpackWidgetScatterplotDefinitionXaxisOutputReference",
    "PowerpackWidgetScatterplotDefinitionYaxis",
    "PowerpackWidgetScatterplotDefinitionYaxisOutputReference",
    "PowerpackWidgetServiceLevelObjectiveDefinition",
    "PowerpackWidgetServiceLevelObjectiveDefinitionOutputReference",
    "PowerpackWidgetServicemapDefinition",
    "PowerpackWidgetServicemapDefinitionCustomLink",
    "PowerpackWidgetServicemapDefinitionCustomLinkList",
    "PowerpackWidgetServicemapDefinitionCustomLinkOutputReference",
    "PowerpackWidgetServicemapDefinitionOutputReference",
    "PowerpackWidgetSloListDefinition",
    "PowerpackWidgetSloListDefinitionOutputReference",
    "PowerpackWidgetSloListDefinitionRequest",
    "PowerpackWidgetSloListDefinitionRequestOutputReference",
    "PowerpackWidgetSloListDefinitionRequestQuery",
    "PowerpackWidgetSloListDefinitionRequestQueryOutputReference",
    "PowerpackWidgetSloListDefinitionRequestQuerySort",
    "PowerpackWidgetSloListDefinitionRequestQuerySortOutputReference",
    "PowerpackWidgetSunburstDefinition",
    "PowerpackWidgetSunburstDefinitionCustomLink",
    "PowerpackWidgetSunburstDefinitionCustomLinkList",
    "PowerpackWidgetSunburstDefinitionCustomLinkOutputReference",
    "PowerpackWidgetSunburstDefinitionLegendInline",
    "PowerpackWidgetSunburstDefinitionLegendInlineOutputReference",
    "PowerpackWidgetSunburstDefinitionLegendTable",
    "PowerpackWidgetSunburstDefinitionLegendTableOutputReference",
    "PowerpackWidgetSunburstDefinitionOutputReference",
    "PowerpackWidgetSunburstDefinitionRequest",
    "PowerpackWidgetSunburstDefinitionRequestApmQuery",
    "PowerpackWidgetSunburstDefinitionRequestApmQueryComputeQuery",
    "PowerpackWidgetSunburstDefinitionRequestApmQueryComputeQueryOutputReference",
    "PowerpackWidgetSunburstDefinitionRequestApmQueryGroupBy",
    "PowerpackWidgetSunburstDefinitionRequestApmQueryGroupByList",
    "PowerpackWidgetSunburstDefinitionRequestApmQueryGroupByOutputReference",
    "PowerpackWidgetSunburstDefinitionRequestApmQueryGroupBySortQuery",
    "PowerpackWidgetSunburstDefinitionRequestApmQueryGroupBySortQueryOutputReference",
    "PowerpackWidgetSunburstDefinitionRequestApmQueryMultiCompute",
    "PowerpackWidgetSunburstDefinitionRequestApmQueryMultiComputeList",
    "PowerpackWidgetSunburstDefinitionRequestApmQueryMultiComputeOutputReference",
    "PowerpackWidgetSunburstDefinitionRequestApmQueryOutputReference",
    "PowerpackWidgetSunburstDefinitionRequestAuditQuery",
    "PowerpackWidgetSunburstDefinitionRequestAuditQueryComputeQuery",
    "PowerpackWidgetSunburstDefinitionRequestAuditQueryComputeQueryOutputReference",
    "PowerpackWidgetSunburstDefinitionRequestAuditQueryGroupBy",
    "PowerpackWidgetSunburstDefinitionRequestAuditQueryGroupByList",
    "PowerpackWidgetSunburstDefinitionRequestAuditQueryGroupByOutputReference",
    "PowerpackWidgetSunburstDefinitionRequestAuditQueryGroupBySortQuery",
    "PowerpackWidgetSunburstDefinitionRequestAuditQueryGroupBySortQueryOutputReference",
    "PowerpackWidgetSunburstDefinitionRequestAuditQueryMultiCompute",
    "PowerpackWidgetSunburstDefinitionRequestAuditQueryMultiComputeList",
    "PowerpackWidgetSunburstDefinitionRequestAuditQueryMultiComputeOutputReference",
    "PowerpackWidgetSunburstDefinitionRequestAuditQueryOutputReference",
    "PowerpackWidgetSunburstDefinitionRequestFormula",
    "PowerpackWidgetSunburstDefinitionRequestFormulaConditionalFormats",
    "PowerpackWidgetSunburstDefinitionRequestFormulaConditionalFormatsList",
    "PowerpackWidgetSunburstDefinitionRequestFormulaConditionalFormatsOutputReference",
    "PowerpackWidgetSunburstDefinitionRequestFormulaLimit",
    "PowerpackWidgetSunburstDefinitionRequestFormulaLimitOutputReference",
    "PowerpackWidgetSunburstDefinitionRequestFormulaList",
    "PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormat",
    "PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormatOutputReference",
    "PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormatUnit",
    "PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormatUnitCanonical",
    "PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormatUnitCanonicalOutputReference",
    "PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormatUnitCustom",
    "PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormatUnitCustomOutputReference",
    "PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormatUnitOutputReference",
    "PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormatUnitScale",
    "PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormatUnitScaleOutputReference",
    "PowerpackWidgetSunburstDefinitionRequestFormulaOutputReference",
    "PowerpackWidgetSunburstDefinitionRequestFormulaStyle",
    "PowerpackWidgetSunburstDefinitionRequestFormulaStyleOutputReference",
    "PowerpackWidgetSunburstDefinitionRequestList",
    "PowerpackWidgetSunburstDefinitionRequestLogQuery",
    "PowerpackWidgetSunburstDefinitionRequestLogQueryComputeQuery",
    "PowerpackWidgetSunburstDefinitionRequestLogQueryComputeQueryOutputReference",
    "PowerpackWidgetSunburstDefinitionRequestLogQueryGroupBy",
    "PowerpackWidgetSunburstDefinitionRequestLogQueryGroupByList",
    "PowerpackWidgetSunburstDefinitionRequestLogQueryGroupByOutputReference",
    "PowerpackWidgetSunburstDefinitionRequestLogQueryGroupBySortQuery",
    "PowerpackWidgetSunburstDefinitionRequestLogQueryGroupBySortQueryOutputReference",
    "PowerpackWidgetSunburstDefinitionRequestLogQueryMultiCompute",
    "PowerpackWidgetSunburstDefinitionRequestLogQueryMultiComputeList",
    "PowerpackWidgetSunburstDefinitionRequestLogQueryMultiComputeOutputReference",
    "PowerpackWidgetSunburstDefinitionRequestLogQueryOutputReference",
    "PowerpackWidgetSunburstDefinitionRequestNetworkQuery",
    "PowerpackWidgetSunburstDefinitionRequestNetworkQueryComputeQuery",
    "PowerpackWidgetSunburstDefinitionRequestNetworkQueryComputeQueryOutputReference",
    "PowerpackWidgetSunburstDefinitionRequestNetworkQueryGroupBy",
    "PowerpackWidgetSunburstDefinitionRequestNetworkQueryGroupByList",
    "PowerpackWidgetSunburstDefinitionRequestNetworkQueryGroupByOutputReference",
    "PowerpackWidgetSunburstDefinitionRequestNetworkQueryGroupBySortQuery",
    "PowerpackWidgetSunburstDefinitionRequestNetworkQueryGroupBySortQueryOutputReference",
    "PowerpackWidgetSunburstDefinitionRequestNetworkQueryMultiCompute",
    "PowerpackWidgetSunburstDefinitionRequestNetworkQueryMultiComputeList",
    "PowerpackWidgetSunburstDefinitionRequestNetworkQueryMultiComputeOutputReference",
    "PowerpackWidgetSunburstDefinitionRequestNetworkQueryOutputReference",
    "PowerpackWidgetSunburstDefinitionRequestOutputReference",
    "PowerpackWidgetSunburstDefinitionRequestProcessQuery",
    "PowerpackWidgetSunburstDefinitionRequestProcessQueryOutputReference",
    "PowerpackWidgetSunburstDefinitionRequestQuery",
    "PowerpackWidgetSunburstDefinitionRequestQueryApmDependencyStatsQuery",
    "PowerpackWidgetSunburstDefinitionRequestQueryApmDependencyStatsQueryOutputReference",
    "PowerpackWidgetSunburstDefinitionRequestQueryApmResourceStatsQuery",
    "PowerpackWidgetSunburstDefinitionRequestQueryApmResourceStatsQueryOutputReference",
    "PowerpackWidgetSunburstDefinitionRequestQueryCloudCostQuery",
    "PowerpackWidgetSunburstDefinitionRequestQueryCloudCostQueryOutputReference",
    "PowerpackWidgetSunburstDefinitionRequestQueryEventQuery",
    "PowerpackWidgetSunburstDefinitionRequestQueryEventQueryCompute",
    "PowerpackWidgetSunburstDefinitionRequestQueryEventQueryComputeList",
    "PowerpackWidgetSunburstDefinitionRequestQueryEventQueryComputeOutputReference",
    "PowerpackWidgetSunburstDefinitionRequestQueryEventQueryGroupBy",
    "PowerpackWidgetSunburstDefinitionRequestQueryEventQueryGroupByList",
    "PowerpackWidgetSunburstDefinitionRequestQueryEventQueryGroupByOutputReference",
    "PowerpackWidgetSunburstDefinitionRequestQueryEventQueryGroupBySort",
    "PowerpackWidgetSunburstDefinitionRequestQueryEventQueryGroupBySortOutputReference",
    "PowerpackWidgetSunburstDefinitionRequestQueryEventQueryOutputReference",
    "PowerpackWidgetSunburstDefinitionRequestQueryEventQuerySearch",
    "PowerpackWidgetSunburstDefinitionRequestQueryEventQuerySearchOutputReference",
    "PowerpackWidgetSunburstDefinitionRequestQueryList",
    "PowerpackWidgetSunburstDefinitionRequestQueryMetricQuery",
    "PowerpackWidgetSunburstDefinitionRequestQueryMetricQueryOutputReference",
    "PowerpackWidgetSunburstDefinitionRequestQueryOutputReference",
    "PowerpackWidgetSunburstDefinitionRequestQueryProcessQuery",
    "PowerpackWidgetSunburstDefinitionRequestQueryProcessQueryOutputReference",
    "PowerpackWidgetSunburstDefinitionRequestQuerySloQuery",
    "PowerpackWidgetSunburstDefinitionRequestQuerySloQueryOutputReference",
    "PowerpackWidgetSunburstDefinitionRequestRumQuery",
    "PowerpackWidgetSunburstDefinitionRequestRumQueryComputeQuery",
    "PowerpackWidgetSunburstDefinitionRequestRumQueryComputeQueryOutputReference",
    "PowerpackWidgetSunburstDefinitionRequestRumQueryGroupBy",
    "PowerpackWidgetSunburstDefinitionRequestRumQueryGroupByList",
    "PowerpackWidgetSunburstDefinitionRequestRumQueryGroupByOutputReference",
    "PowerpackWidgetSunburstDefinitionRequestRumQueryGroupBySortQuery",
    "PowerpackWidgetSunburstDefinitionRequestRumQueryGroupBySortQueryOutputReference",
    "PowerpackWidgetSunburstDefinitionRequestRumQueryMultiCompute",
    "PowerpackWidgetSunburstDefinitionRequestRumQueryMultiComputeList",
    "PowerpackWidgetSunburstDefinitionRequestRumQueryMultiComputeOutputReference",
    "PowerpackWidgetSunburstDefinitionRequestRumQueryOutputReference",
    "PowerpackWidgetSunburstDefinitionRequestSecurityQuery",
    "PowerpackWidgetSunburstDefinitionRequestSecurityQueryComputeQuery",
    "PowerpackWidgetSunburstDefinitionRequestSecurityQueryComputeQueryOutputReference",
    "PowerpackWidgetSunburstDefinitionRequestSecurityQueryGroupBy",
    "PowerpackWidgetSunburstDefinitionRequestSecurityQueryGroupByList",
    "PowerpackWidgetSunburstDefinitionRequestSecurityQueryGroupByOutputReference",
    "PowerpackWidgetSunburstDefinitionRequestSecurityQueryGroupBySortQuery",
    "PowerpackWidgetSunburstDefinitionRequestSecurityQueryGroupBySortQueryOutputReference",
    "PowerpackWidgetSunburstDefinitionRequestSecurityQueryMultiCompute",
    "PowerpackWidgetSunburstDefinitionRequestSecurityQueryMultiComputeList",
    "PowerpackWidgetSunburstDefinitionRequestSecurityQueryMultiComputeOutputReference",
    "PowerpackWidgetSunburstDefinitionRequestSecurityQueryOutputReference",
    "PowerpackWidgetSunburstDefinitionRequestStyle",
    "PowerpackWidgetSunburstDefinitionRequestStyleOutputReference",
    "PowerpackWidgetTimeseriesDefinition",
    "PowerpackWidgetTimeseriesDefinitionCustomLink",
    "PowerpackWidgetTimeseriesDefinitionCustomLinkList",
    "PowerpackWidgetTimeseriesDefinitionCustomLinkOutputReference",
    "PowerpackWidgetTimeseriesDefinitionEvent",
    "PowerpackWidgetTimeseriesDefinitionEventList",
    "PowerpackWidgetTimeseriesDefinitionEventOutputReference",
    "PowerpackWidgetTimeseriesDefinitionMarker",
    "PowerpackWidgetTimeseriesDefinitionMarkerList",
    "PowerpackWidgetTimeseriesDefinitionMarkerOutputReference",
    "PowerpackWidgetTimeseriesDefinitionOutputReference",
    "PowerpackWidgetTimeseriesDefinitionRequest",
    "PowerpackWidgetTimeseriesDefinitionRequestApmQuery",
    "PowerpackWidgetTimeseriesDefinitionRequestApmQueryComputeQuery",
    "PowerpackWidgetTimeseriesDefinitionRequestApmQueryComputeQueryOutputReference",
    "PowerpackWidgetTimeseriesDefinitionRequestApmQueryGroupBy",
    "PowerpackWidgetTimeseriesDefinitionRequestApmQueryGroupByList",
    "PowerpackWidgetTimeseriesDefinitionRequestApmQueryGroupByOutputReference",
    "PowerpackWidgetTimeseriesDefinitionRequestApmQueryGroupBySortQuery",
    "PowerpackWidgetTimeseriesDefinitionRequestApmQueryGroupBySortQueryOutputReference",
    "PowerpackWidgetTimeseriesDefinitionRequestApmQueryMultiCompute",
    "PowerpackWidgetTimeseriesDefinitionRequestApmQueryMultiComputeList",
    "PowerpackWidgetTimeseriesDefinitionRequestApmQueryMultiComputeOutputReference",
    "PowerpackWidgetTimeseriesDefinitionRequestApmQueryOutputReference",
    "PowerpackWidgetTimeseriesDefinitionRequestAuditQuery",
    "PowerpackWidgetTimeseriesDefinitionRequestAuditQueryComputeQuery",
    "PowerpackWidgetTimeseriesDefinitionRequestAuditQueryComputeQueryOutputReference",
    "PowerpackWidgetTimeseriesDefinitionRequestAuditQueryGroupBy",
    "PowerpackWidgetTimeseriesDefinitionRequestAuditQueryGroupByList",
    "PowerpackWidgetTimeseriesDefinitionRequestAuditQueryGroupByOutputReference",
    "PowerpackWidgetTimeseriesDefinitionRequestAuditQueryGroupBySortQuery",
    "PowerpackWidgetTimeseriesDefinitionRequestAuditQueryGroupBySortQueryOutputReference",
    "PowerpackWidgetTimeseriesDefinitionRequestAuditQueryMultiCompute",
    "PowerpackWidgetTimeseriesDefinitionRequestAuditQueryMultiComputeList",
    "PowerpackWidgetTimeseriesDefinitionRequestAuditQueryMultiComputeOutputReference",
    "PowerpackWidgetTimeseriesDefinitionRequestAuditQueryOutputReference",
    "PowerpackWidgetTimeseriesDefinitionRequestFormula",
    "PowerpackWidgetTimeseriesDefinitionRequestFormulaConditionalFormats",
    "PowerpackWidgetTimeseriesDefinitionRequestFormulaConditionalFormatsList",
    "PowerpackWidgetTimeseriesDefinitionRequestFormulaConditionalFormatsOutputReference",
    "PowerpackWidgetTimeseriesDefinitionRequestFormulaLimit",
    "PowerpackWidgetTimeseriesDefinitionRequestFormulaLimitOutputReference",
    "PowerpackWidgetTimeseriesDefinitionRequestFormulaList",
    "PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormat",
    "PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormatOutputReference",
    "PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormatUnit",
    "PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormatUnitCanonical",
    "PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormatUnitCanonicalOutputReference",
    "PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormatUnitCustom",
    "PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormatUnitCustomOutputReference",
    "PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormatUnitOutputReference",
    "PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormatUnitScale",
    "PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormatUnitScaleOutputReference",
    "PowerpackWidgetTimeseriesDefinitionRequestFormulaOutputReference",
    "PowerpackWidgetTimeseriesDefinitionRequestFormulaStyle",
    "PowerpackWidgetTimeseriesDefinitionRequestFormulaStyleOutputReference",
    "PowerpackWidgetTimeseriesDefinitionRequestList",
    "PowerpackWidgetTimeseriesDefinitionRequestLogQuery",
    "PowerpackWidgetTimeseriesDefinitionRequestLogQueryComputeQuery",
    "PowerpackWidgetTimeseriesDefinitionRequestLogQueryComputeQueryOutputReference",
    "PowerpackWidgetTimeseriesDefinitionRequestLogQueryGroupBy",
    "PowerpackWidgetTimeseriesDefinitionRequestLogQueryGroupByList",
    "PowerpackWidgetTimeseriesDefinitionRequestLogQueryGroupByOutputReference",
    "PowerpackWidgetTimeseriesDefinitionRequestLogQueryGroupBySortQuery",
    "PowerpackWidgetTimeseriesDefinitionRequestLogQueryGroupBySortQueryOutputReference",
    "PowerpackWidgetTimeseriesDefinitionRequestLogQueryMultiCompute",
    "PowerpackWidgetTimeseriesDefinitionRequestLogQueryMultiComputeList",
    "PowerpackWidgetTimeseriesDefinitionRequestLogQueryMultiComputeOutputReference",
    "PowerpackWidgetTimeseriesDefinitionRequestLogQueryOutputReference",
    "PowerpackWidgetTimeseriesDefinitionRequestMetadata",
    "PowerpackWidgetTimeseriesDefinitionRequestMetadataList",
    "PowerpackWidgetTimeseriesDefinitionRequestMetadataOutputReference",
    "PowerpackWidgetTimeseriesDefinitionRequestNetworkQuery",
    "PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryComputeQuery",
    "PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryComputeQueryOutputReference",
    "PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryGroupBy",
    "PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryGroupByList",
    "PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryGroupByOutputReference",
    "PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryGroupBySortQuery",
    "PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryGroupBySortQueryOutputReference",
    "PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryMultiCompute",
    "PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryMultiComputeList",
    "PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryMultiComputeOutputReference",
    "PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryOutputReference",
    "PowerpackWidgetTimeseriesDefinitionRequestOutputReference",
    "PowerpackWidgetTimeseriesDefinitionRequestProcessQuery",
    "PowerpackWidgetTimeseriesDefinitionRequestProcessQueryOutputReference",
    "PowerpackWidgetTimeseriesDefinitionRequestQuery",
    "PowerpackWidgetTimeseriesDefinitionRequestQueryApmDependencyStatsQuery",
    "PowerpackWidgetTimeseriesDefinitionRequestQueryApmDependencyStatsQueryOutputReference",
    "PowerpackWidgetTimeseriesDefinitionRequestQueryApmResourceStatsQuery",
    "PowerpackWidgetTimeseriesDefinitionRequestQueryApmResourceStatsQueryOutputReference",
    "PowerpackWidgetTimeseriesDefinitionRequestQueryCloudCostQuery",
    "PowerpackWidgetTimeseriesDefinitionRequestQueryCloudCostQueryOutputReference",
    "PowerpackWidgetTimeseriesDefinitionRequestQueryEventQuery",
    "PowerpackWidgetTimeseriesDefinitionRequestQueryEventQueryCompute",
    "PowerpackWidgetTimeseriesDefinitionRequestQueryEventQueryComputeList",
    "PowerpackWidgetTimeseriesDefinitionRequestQueryEventQueryComputeOutputReference",
    "PowerpackWidgetTimeseriesDefinitionRequestQueryEventQueryGroupBy",
    "PowerpackWidgetTimeseriesDefinitionRequestQueryEventQueryGroupByList",
    "PowerpackWidgetTimeseriesDefinitionRequestQueryEventQueryGroupByOutputReference",
    "PowerpackWidgetTimeseriesDefinitionRequestQueryEventQueryGroupBySort",
    "PowerpackWidgetTimeseriesDefinitionRequestQueryEventQueryGroupBySortOutputReference",
    "PowerpackWidgetTimeseriesDefinitionRequestQueryEventQueryOutputReference",
    "PowerpackWidgetTimeseriesDefinitionRequestQueryEventQuerySearch",
    "PowerpackWidgetTimeseriesDefinitionRequestQueryEventQuerySearchOutputReference",
    "PowerpackWidgetTimeseriesDefinitionRequestQueryList",
    "PowerpackWidgetTimeseriesDefinitionRequestQueryMetricQuery",
    "PowerpackWidgetTimeseriesDefinitionRequestQueryMetricQueryOutputReference",
    "PowerpackWidgetTimeseriesDefinitionRequestQueryOutputReference",
    "PowerpackWidgetTimeseriesDefinitionRequestQueryProcessQuery",
    "PowerpackWidgetTimeseriesDefinitionRequestQueryProcessQueryOutputReference",
    "PowerpackWidgetTimeseriesDefinitionRequestQuerySloQuery",
    "PowerpackWidgetTimeseriesDefinitionRequestQuerySloQueryOutputReference",
    "PowerpackWidgetTimeseriesDefinitionRequestRumQuery",
    "PowerpackWidgetTimeseriesDefinitionRequestRumQueryComputeQuery",
    "PowerpackWidgetTimeseriesDefinitionRequestRumQueryComputeQueryOutputReference",
    "PowerpackWidgetTimeseriesDefinitionRequestRumQueryGroupBy",
    "PowerpackWidgetTimeseriesDefinitionRequestRumQueryGroupByList",
    "PowerpackWidgetTimeseriesDefinitionRequestRumQueryGroupByOutputReference",
    "PowerpackWidgetTimeseriesDefinitionRequestRumQueryGroupBySortQuery",
    "PowerpackWidgetTimeseriesDefinitionRequestRumQueryGroupBySortQueryOutputReference",
    "PowerpackWidgetTimeseriesDefinitionRequestRumQueryMultiCompute",
    "PowerpackWidgetTimeseriesDefinitionRequestRumQueryMultiComputeList",
    "PowerpackWidgetTimeseriesDefinitionRequestRumQueryMultiComputeOutputReference",
    "PowerpackWidgetTimeseriesDefinitionRequestRumQueryOutputReference",
    "PowerpackWidgetTimeseriesDefinitionRequestSecurityQuery",
    "PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryComputeQuery",
    "PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryComputeQueryOutputReference",
    "PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryGroupBy",
    "PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryGroupByList",
    "PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryGroupByOutputReference",
    "PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryGroupBySortQuery",
    "PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryGroupBySortQueryOutputReference",
    "PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryMultiCompute",
    "PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryMultiComputeList",
    "PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryMultiComputeOutputReference",
    "PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryOutputReference",
    "PowerpackWidgetTimeseriesDefinitionRequestStyle",
    "PowerpackWidgetTimeseriesDefinitionRequestStyleOutputReference",
    "PowerpackWidgetTimeseriesDefinitionRightYaxis",
    "PowerpackWidgetTimeseriesDefinitionRightYaxisOutputReference",
    "PowerpackWidgetTimeseriesDefinitionYaxis",
    "PowerpackWidgetTimeseriesDefinitionYaxisOutputReference",
    "PowerpackWidgetToplistDefinition",
    "PowerpackWidgetToplistDefinitionCustomLink",
    "PowerpackWidgetToplistDefinitionCustomLinkList",
    "PowerpackWidgetToplistDefinitionCustomLinkOutputReference",
    "PowerpackWidgetToplistDefinitionOutputReference",
    "PowerpackWidgetToplistDefinitionRequest",
    "PowerpackWidgetToplistDefinitionRequestApmQuery",
    "PowerpackWidgetToplistDefinitionRequestApmQueryComputeQuery",
    "PowerpackWidgetToplistDefinitionRequestApmQueryComputeQueryOutputReference",
    "PowerpackWidgetToplistDefinitionRequestApmQueryGroupBy",
    "PowerpackWidgetToplistDefinitionRequestApmQueryGroupByList",
    "PowerpackWidgetToplistDefinitionRequestApmQueryGroupByOutputReference",
    "PowerpackWidgetToplistDefinitionRequestApmQueryGroupBySortQuery",
    "PowerpackWidgetToplistDefinitionRequestApmQueryGroupBySortQueryOutputReference",
    "PowerpackWidgetToplistDefinitionRequestApmQueryMultiCompute",
    "PowerpackWidgetToplistDefinitionRequestApmQueryMultiComputeList",
    "PowerpackWidgetToplistDefinitionRequestApmQueryMultiComputeOutputReference",
    "PowerpackWidgetToplistDefinitionRequestApmQueryOutputReference",
    "PowerpackWidgetToplistDefinitionRequestAuditQuery",
    "PowerpackWidgetToplistDefinitionRequestAuditQueryComputeQuery",
    "PowerpackWidgetToplistDefinitionRequestAuditQueryComputeQueryOutputReference",
    "PowerpackWidgetToplistDefinitionRequestAuditQueryGroupBy",
    "PowerpackWidgetToplistDefinitionRequestAuditQueryGroupByList",
    "PowerpackWidgetToplistDefinitionRequestAuditQueryGroupByOutputReference",
    "PowerpackWidgetToplistDefinitionRequestAuditQueryGroupBySortQuery",
    "PowerpackWidgetToplistDefinitionRequestAuditQueryGroupBySortQueryOutputReference",
    "PowerpackWidgetToplistDefinitionRequestAuditQueryMultiCompute",
    "PowerpackWidgetToplistDefinitionRequestAuditQueryMultiComputeList",
    "PowerpackWidgetToplistDefinitionRequestAuditQueryMultiComputeOutputReference",
    "PowerpackWidgetToplistDefinitionRequestAuditQueryOutputReference",
    "PowerpackWidgetToplistDefinitionRequestConditionalFormats",
    "PowerpackWidgetToplistDefinitionRequestConditionalFormatsList",
    "PowerpackWidgetToplistDefinitionRequestConditionalFormatsOutputReference",
    "PowerpackWidgetToplistDefinitionRequestFormula",
    "PowerpackWidgetToplistDefinitionRequestFormulaConditionalFormats",
    "PowerpackWidgetToplistDefinitionRequestFormulaConditionalFormatsList",
    "PowerpackWidgetToplistDefinitionRequestFormulaConditionalFormatsOutputReference",
    "PowerpackWidgetToplistDefinitionRequestFormulaLimit",
    "PowerpackWidgetToplistDefinitionRequestFormulaLimitOutputReference",
    "PowerpackWidgetToplistDefinitionRequestFormulaList",
    "PowerpackWidgetToplistDefinitionRequestFormulaNumberFormat",
    "PowerpackWidgetToplistDefinitionRequestFormulaNumberFormatOutputReference",
    "PowerpackWidgetToplistDefinitionRequestFormulaNumberFormatUnit",
    "PowerpackWidgetToplistDefinitionRequestFormulaNumberFormatUnitCanonical",
    "PowerpackWidgetToplistDefinitionRequestFormulaNumberFormatUnitCanonicalOutputReference",
    "PowerpackWidgetToplistDefinitionRequestFormulaNumberFormatUnitCustom",
    "PowerpackWidgetToplistDefinitionRequestFormulaNumberFormatUnitCustomOutputReference",
    "PowerpackWidgetToplistDefinitionRequestFormulaNumberFormatUnitOutputReference",
    "PowerpackWidgetToplistDefinitionRequestFormulaNumberFormatUnitScale",
    "PowerpackWidgetToplistDefinitionRequestFormulaNumberFormatUnitScaleOutputReference",
    "PowerpackWidgetToplistDefinitionRequestFormulaOutputReference",
    "PowerpackWidgetToplistDefinitionRequestFormulaStyle",
    "PowerpackWidgetToplistDefinitionRequestFormulaStyleOutputReference",
    "PowerpackWidgetToplistDefinitionRequestList",
    "PowerpackWidgetToplistDefinitionRequestLogQuery",
    "PowerpackWidgetToplistDefinitionRequestLogQueryComputeQuery",
    "PowerpackWidgetToplistDefinitionRequestLogQueryComputeQueryOutputReference",
    "PowerpackWidgetToplistDefinitionRequestLogQueryGroupBy",
    "PowerpackWidgetToplistDefinitionRequestLogQueryGroupByList",
    "PowerpackWidgetToplistDefinitionRequestLogQueryGroupByOutputReference",
    "PowerpackWidgetToplistDefinitionRequestLogQueryGroupBySortQuery",
    "PowerpackWidgetToplistDefinitionRequestLogQueryGroupBySortQueryOutputReference",
    "PowerpackWidgetToplistDefinitionRequestLogQueryMultiCompute",
    "PowerpackWidgetToplistDefinitionRequestLogQueryMultiComputeList",
    "PowerpackWidgetToplistDefinitionRequestLogQueryMultiComputeOutputReference",
    "PowerpackWidgetToplistDefinitionRequestLogQueryOutputReference",
    "PowerpackWidgetToplistDefinitionRequestOutputReference",
    "PowerpackWidgetToplistDefinitionRequestProcessQuery",
    "PowerpackWidgetToplistDefinitionRequestProcessQueryOutputReference",
    "PowerpackWidgetToplistDefinitionRequestQuery",
    "PowerpackWidgetToplistDefinitionRequestQueryApmDependencyStatsQuery",
    "PowerpackWidgetToplistDefinitionRequestQueryApmDependencyStatsQueryOutputReference",
    "PowerpackWidgetToplistDefinitionRequestQueryApmResourceStatsQuery",
    "PowerpackWidgetToplistDefinitionRequestQueryApmResourceStatsQueryOutputReference",
    "PowerpackWidgetToplistDefinitionRequestQueryCloudCostQuery",
    "PowerpackWidgetToplistDefinitionRequestQueryCloudCostQueryOutputReference",
    "PowerpackWidgetToplistDefinitionRequestQueryEventQuery",
    "PowerpackWidgetToplistDefinitionRequestQueryEventQueryCompute",
    "PowerpackWidgetToplistDefinitionRequestQueryEventQueryComputeList",
    "PowerpackWidgetToplistDefinitionRequestQueryEventQueryComputeOutputReference",
    "PowerpackWidgetToplistDefinitionRequestQueryEventQueryGroupBy",
    "PowerpackWidgetToplistDefinitionRequestQueryEventQueryGroupByList",
    "PowerpackWidgetToplistDefinitionRequestQueryEventQueryGroupByOutputReference",
    "PowerpackWidgetToplistDefinitionRequestQueryEventQueryGroupBySort",
    "PowerpackWidgetToplistDefinitionRequestQueryEventQueryGroupBySortOutputReference",
    "PowerpackWidgetToplistDefinitionRequestQueryEventQueryOutputReference",
    "PowerpackWidgetToplistDefinitionRequestQueryEventQuerySearch",
    "PowerpackWidgetToplistDefinitionRequestQueryEventQuerySearchOutputReference",
    "PowerpackWidgetToplistDefinitionRequestQueryList",
    "PowerpackWidgetToplistDefinitionRequestQueryMetricQuery",
    "PowerpackWidgetToplistDefinitionRequestQueryMetricQueryOutputReference",
    "PowerpackWidgetToplistDefinitionRequestQueryOutputReference",
    "PowerpackWidgetToplistDefinitionRequestQueryProcessQuery",
    "PowerpackWidgetToplistDefinitionRequestQueryProcessQueryOutputReference",
    "PowerpackWidgetToplistDefinitionRequestQuerySloQuery",
    "PowerpackWidgetToplistDefinitionRequestQuerySloQueryOutputReference",
    "PowerpackWidgetToplistDefinitionRequestRumQuery",
    "PowerpackWidgetToplistDefinitionRequestRumQueryComputeQuery",
    "PowerpackWidgetToplistDefinitionRequestRumQueryComputeQueryOutputReference",
    "PowerpackWidgetToplistDefinitionRequestRumQueryGroupBy",
    "PowerpackWidgetToplistDefinitionRequestRumQueryGroupByList",
    "PowerpackWidgetToplistDefinitionRequestRumQueryGroupByOutputReference",
    "PowerpackWidgetToplistDefinitionRequestRumQueryGroupBySortQuery",
    "PowerpackWidgetToplistDefinitionRequestRumQueryGroupBySortQueryOutputReference",
    "PowerpackWidgetToplistDefinitionRequestRumQueryMultiCompute",
    "PowerpackWidgetToplistDefinitionRequestRumQueryMultiComputeList",
    "PowerpackWidgetToplistDefinitionRequestRumQueryMultiComputeOutputReference",
    "PowerpackWidgetToplistDefinitionRequestRumQueryOutputReference",
    "PowerpackWidgetToplistDefinitionRequestSecurityQuery",
    "PowerpackWidgetToplistDefinitionRequestSecurityQueryComputeQuery",
    "PowerpackWidgetToplistDefinitionRequestSecurityQueryComputeQueryOutputReference",
    "PowerpackWidgetToplistDefinitionRequestSecurityQueryGroupBy",
    "PowerpackWidgetToplistDefinitionRequestSecurityQueryGroupByList",
    "PowerpackWidgetToplistDefinitionRequestSecurityQueryGroupByOutputReference",
    "PowerpackWidgetToplistDefinitionRequestSecurityQueryGroupBySortQuery",
    "PowerpackWidgetToplistDefinitionRequestSecurityQueryGroupBySortQueryOutputReference",
    "PowerpackWidgetToplistDefinitionRequestSecurityQueryMultiCompute",
    "PowerpackWidgetToplistDefinitionRequestSecurityQueryMultiComputeList",
    "PowerpackWidgetToplistDefinitionRequestSecurityQueryMultiComputeOutputReference",
    "PowerpackWidgetToplistDefinitionRequestSecurityQueryOutputReference",
    "PowerpackWidgetToplistDefinitionRequestStyle",
    "PowerpackWidgetToplistDefinitionRequestStyleOutputReference",
    "PowerpackWidgetToplistDefinitionStyle",
    "PowerpackWidgetToplistDefinitionStyleDisplay",
    "PowerpackWidgetToplistDefinitionStyleDisplayList",
    "PowerpackWidgetToplistDefinitionStyleDisplayOutputReference",
    "PowerpackWidgetToplistDefinitionStyleList",
    "PowerpackWidgetToplistDefinitionStyleOutputReference",
    "PowerpackWidgetTopologyMapDefinition",
    "PowerpackWidgetTopologyMapDefinitionCustomLink",
    "PowerpackWidgetTopologyMapDefinitionCustomLinkList",
    "PowerpackWidgetTopologyMapDefinitionCustomLinkOutputReference",
    "PowerpackWidgetTopologyMapDefinitionOutputReference",
    "PowerpackWidgetTopologyMapDefinitionRequest",
    "PowerpackWidgetTopologyMapDefinitionRequestList",
    "PowerpackWidgetTopologyMapDefinitionRequestOutputReference",
    "PowerpackWidgetTopologyMapDefinitionRequestQuery",
    "PowerpackWidgetTopologyMapDefinitionRequestQueryList",
    "PowerpackWidgetTopologyMapDefinitionRequestQueryOutputReference",
    "PowerpackWidgetTraceServiceDefinition",
    "PowerpackWidgetTraceServiceDefinitionOutputReference",
    "PowerpackWidgetTreemapDefinition",
    "PowerpackWidgetTreemapDefinitionCustomLinks",
    "PowerpackWidgetTreemapDefinitionCustomLinksList",
    "PowerpackWidgetTreemapDefinitionCustomLinksOutputReference",
    "PowerpackWidgetTreemapDefinitionOutputReference",
    "PowerpackWidgetTreemapDefinitionRequest",
    "PowerpackWidgetTreemapDefinitionRequestFormula",
    "PowerpackWidgetTreemapDefinitionRequestFormulaConditionalFormats",
    "PowerpackWidgetTreemapDefinitionRequestFormulaConditionalFormatsList",
    "PowerpackWidgetTreemapDefinitionRequestFormulaConditionalFormatsOutputReference",
    "PowerpackWidgetTreemapDefinitionRequestFormulaLimit",
    "PowerpackWidgetTreemapDefinitionRequestFormulaLimitOutputReference",
    "PowerpackWidgetTreemapDefinitionRequestFormulaList",
    "PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormat",
    "PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormatOutputReference",
    "PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormatUnit",
    "PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormatUnitCanonical",
    "PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormatUnitCanonicalOutputReference",
    "PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormatUnitCustom",
    "PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormatUnitCustomOutputReference",
    "PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormatUnitOutputReference",
    "PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormatUnitScale",
    "PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormatUnitScaleOutputReference",
    "PowerpackWidgetTreemapDefinitionRequestFormulaOutputReference",
    "PowerpackWidgetTreemapDefinitionRequestFormulaStyle",
    "PowerpackWidgetTreemapDefinitionRequestFormulaStyleOutputReference",
    "PowerpackWidgetTreemapDefinitionRequestList",
    "PowerpackWidgetTreemapDefinitionRequestOutputReference",
    "PowerpackWidgetTreemapDefinitionRequestQuery",
    "PowerpackWidgetTreemapDefinitionRequestQueryApmDependencyStatsQuery",
    "PowerpackWidgetTreemapDefinitionRequestQueryApmDependencyStatsQueryOutputReference",
    "PowerpackWidgetTreemapDefinitionRequestQueryApmResourceStatsQuery",
    "PowerpackWidgetTreemapDefinitionRequestQueryApmResourceStatsQueryOutputReference",
    "PowerpackWidgetTreemapDefinitionRequestQueryCloudCostQuery",
    "PowerpackWidgetTreemapDefinitionRequestQueryCloudCostQueryOutputReference",
    "PowerpackWidgetTreemapDefinitionRequestQueryEventQuery",
    "PowerpackWidgetTreemapDefinitionRequestQueryEventQueryCompute",
    "PowerpackWidgetTreemapDefinitionRequestQueryEventQueryComputeList",
    "PowerpackWidgetTreemapDefinitionRequestQueryEventQueryComputeOutputReference",
    "PowerpackWidgetTreemapDefinitionRequestQueryEventQueryGroupBy",
    "PowerpackWidgetTreemapDefinitionRequestQueryEventQueryGroupByList",
    "PowerpackWidgetTreemapDefinitionRequestQueryEventQueryGroupByOutputReference",
    "PowerpackWidgetTreemapDefinitionRequestQueryEventQueryGroupBySort",
    "PowerpackWidgetTreemapDefinitionRequestQueryEventQueryGroupBySortOutputReference",
    "PowerpackWidgetTreemapDefinitionRequestQueryEventQueryOutputReference",
    "PowerpackWidgetTreemapDefinitionRequestQueryEventQuerySearch",
    "PowerpackWidgetTreemapDefinitionRequestQueryEventQuerySearchOutputReference",
    "PowerpackWidgetTreemapDefinitionRequestQueryList",
    "PowerpackWidgetTreemapDefinitionRequestQueryMetricQuery",
    "PowerpackWidgetTreemapDefinitionRequestQueryMetricQueryOutputReference",
    "PowerpackWidgetTreemapDefinitionRequestQueryOutputReference",
    "PowerpackWidgetTreemapDefinitionRequestQueryProcessQuery",
    "PowerpackWidgetTreemapDefinitionRequestQueryProcessQueryOutputReference",
    "PowerpackWidgetTreemapDefinitionRequestQuerySloQuery",
    "PowerpackWidgetTreemapDefinitionRequestQuerySloQueryOutputReference",
    "PowerpackWidgetWidgetLayout",
    "PowerpackWidgetWidgetLayoutOutputReference",
]

publication.publish()

def _typecheckingstub__682e86bb24811a148a4f3d2258896bcb6b6b65244baeeb92ad850ec956824c12(
    scope: _constructs_77d1e7e8.Construct,
    id_: builtins.str,
    *,
    description: typing.Optional[builtins.str] = None,
    id: typing.Optional[builtins.str] = None,
    layout: typing.Optional[typing.Union[PowerpackLayout, typing.Dict[builtins.str, typing.Any]]] = None,
    live_span: typing.Optional[builtins.str] = None,
    name: typing.Optional[builtins.str] = None,
    show_title: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
    tags: typing.Optional[typing.Sequence[builtins.str]] = None,
    template_variables: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackTemplateVariables, typing.Dict[builtins.str, typing.Any]]]]] = None,
    widget: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidget, typing.Dict[builtins.str, typing.Any]]]]] = None,
    connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
    count: typing.Optional[typing.Union[jsii.Number, _cdktf_9a9027ec.TerraformCount]] = None,
    depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
    for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
    lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
    provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__769f6e4b5b2e096f135c1862b0c8aa8519be9edd36cc36703c1430b06dc9c7e7(
    scope: _constructs_77d1e7e8.Construct,
    import_to_id: builtins.str,
    import_from_id: builtins.str,
    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__33bf8aaca41d90e63e9f653ec0be43a79662a8f3784fb655ed349e97b7e9ae57(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackTemplateVariables, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__586eba0121f83088a3bff0bf9b1691ab26904ec68a88857d9a09146ced02cec4(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidget, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b18eedd7d3ea102263036e3effb020b05e5e170d7f6c11fa86d74effb469d3b2(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d742c88ede505c5f7af19f871f9da0fee0a8f7766a8a40a1cc7870842da740fb(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c05f13c680dd58c84ed44f09347cc999b8d3d66441b2416cc28a941adb741f42(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e2727b37dd96b0c1e3f665a43aaeaa191dcb0eb370c486ceec26c4e0e780704a(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d7c1e59b50f775f0125266056c7acf2b11485a0527a8caabae814ca68c813a2d(
    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5c2b3b25ee374a5ac2ab60dc1ce5b5eca5a9b6843f451c5298855b1540c4779a(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__02799c950872d76d53d9e8b056f17223ca02fca5411e5f4e108a412d13a6c7a1(
    *,
    connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
    count: typing.Optional[typing.Union[jsii.Number, _cdktf_9a9027ec.TerraformCount]] = None,
    depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
    for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
    lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
    provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
    description: typing.Optional[builtins.str] = None,
    id: typing.Optional[builtins.str] = None,
    layout: typing.Optional[typing.Union[PowerpackLayout, typing.Dict[builtins.str, typing.Any]]] = None,
    live_span: typing.Optional[builtins.str] = None,
    name: typing.Optional[builtins.str] = None,
    show_title: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
    tags: typing.Optional[typing.Sequence[builtins.str]] = None,
    template_variables: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackTemplateVariables, typing.Dict[builtins.str, typing.Any]]]]] = None,
    widget: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidget, typing.Dict[builtins.str, typing.Any]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__10da6775a4e3e9b1a841407c6d50f21ffb0f12d1706dea3aa4b13250357ac0f6(
    *,
    height: typing.Optional[jsii.Number] = None,
    width: typing.Optional[jsii.Number] = None,
    x: typing.Optional[jsii.Number] = None,
    y: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__06b9ed18faf691fe8674c9bf3bab45d393894a30d3d141d4702ed7f54ea1a563(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__51ab0dd873b13757ba2f45664155cd48eebc85fccf6eba2c2d067cc431cd6190(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3c1eef5882a88dcc859b05b920148eb696f68d5667307837bf823bbffd360424(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6134b612b36fd2ce55362392b87db95c455f4aa9b4119f4ffdc3cc2b9a5a6813(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3b6c85e775d78d59b6a6d62ec97416b102c45e6ab11e9c15617f9d312b4f7b4c(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__96f8547ba0dae2a6381c1346183eb94e5ab2ef9c354c0d8662ba60e2e277bb61(
    value: typing.Optional[PowerpackLayout],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e7601857687ea35f174ca5fab4b1ce23bdd159a676a4f17789b3dc35e371898f(
    *,
    name: builtins.str,
    defaults: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1663087723d07187d17abe814a5c8c49c54e847572ac2bf3fffc1f60447dc9f7(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fb8162b221b3cc24ed26ebaa4866adcab7c792c7e29a2a3852255c84279da53a(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__573bc00a3dc9fd13149ead45ead220c2d825079ea922ffa2c2d372f51d60b516(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ff6200c5abdbdfc8cb4cfea66cd304478f348634886b5b28659eda6a6e5dab63(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__26f9ac5f3e7d0c5083be230d798068391a92ed54b65c1b2c8e3757f58556d3d9(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d53297c7cd8e100cada0f1c60809002531c54779032ad45a941a8205da3f1899(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackTemplateVariables]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a8f550005c8af583e1981cc10c0c3da2d09ec2b7c873aaef5ba613c2004d1ae9(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cc5fe0d98510831c3fc7ec6ad32411cc561c779da427be5ef13c5c56e4bc55ff(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e259029a48542cdd63a3f74ca5cd86d25cdb3f27ea4621ecf8cfd725280f201b(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__005e0426567a46d9304ec4d49b3c56ae480b7a64f7048f5f3cae9ce1bb07aaec(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackTemplateVariables]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e3a85f435536b9b174f7093c6eb1e94738a36cc6203eba45901a3cab0e88a745(
    *,
    alert_graph_definition: typing.Optional[typing.Union[PowerpackWidgetAlertGraphDefinition, typing.Dict[builtins.str, typing.Any]]] = None,
    alert_value_definition: typing.Optional[typing.Union[PowerpackWidgetAlertValueDefinition, typing.Dict[builtins.str, typing.Any]]] = None,
    change_definition: typing.Optional[typing.Union[PowerpackWidgetChangeDefinition, typing.Dict[builtins.str, typing.Any]]] = None,
    check_status_definition: typing.Optional[typing.Union[PowerpackWidgetCheckStatusDefinition, typing.Dict[builtins.str, typing.Any]]] = None,
    distribution_definition: typing.Optional[typing.Union[PowerpackWidgetDistributionDefinition, typing.Dict[builtins.str, typing.Any]]] = None,
    event_stream_definition: typing.Optional[typing.Union[PowerpackWidgetEventStreamDefinition, typing.Dict[builtins.str, typing.Any]]] = None,
    event_timeline_definition: typing.Optional[typing.Union[PowerpackWidgetEventTimelineDefinition, typing.Dict[builtins.str, typing.Any]]] = None,
    free_text_definition: typing.Optional[typing.Union[PowerpackWidgetFreeTextDefinition, typing.Dict[builtins.str, typing.Any]]] = None,
    geomap_definition: typing.Optional[typing.Union[PowerpackWidgetGeomapDefinition, typing.Dict[builtins.str, typing.Any]]] = None,
    heatmap_definition: typing.Optional[typing.Union[PowerpackWidgetHeatmapDefinition, typing.Dict[builtins.str, typing.Any]]] = None,
    hostmap_definition: typing.Optional[typing.Union[PowerpackWidgetHostmapDefinition, typing.Dict[builtins.str, typing.Any]]] = None,
    iframe_definition: typing.Optional[typing.Union[PowerpackWidgetIframeDefinition, typing.Dict[builtins.str, typing.Any]]] = None,
    image_definition: typing.Optional[typing.Union[PowerpackWidgetImageDefinition, typing.Dict[builtins.str, typing.Any]]] = None,
    list_stream_definition: typing.Optional[typing.Union[PowerpackWidgetListStreamDefinition, typing.Dict[builtins.str, typing.Any]]] = None,
    log_stream_definition: typing.Optional[typing.Union[PowerpackWidgetLogStreamDefinition, typing.Dict[builtins.str, typing.Any]]] = None,
    manage_status_definition: typing.Optional[typing.Union[PowerpackWidgetManageStatusDefinition, typing.Dict[builtins.str, typing.Any]]] = None,
    note_definition: typing.Optional[typing.Union[PowerpackWidgetNoteDefinition, typing.Dict[builtins.str, typing.Any]]] = None,
    query_table_definition: typing.Optional[typing.Union[PowerpackWidgetQueryTableDefinition, typing.Dict[builtins.str, typing.Any]]] = None,
    query_value_definition: typing.Optional[typing.Union[PowerpackWidgetQueryValueDefinition, typing.Dict[builtins.str, typing.Any]]] = None,
    run_workflow_definition: typing.Optional[typing.Union[PowerpackWidgetRunWorkflowDefinition, typing.Dict[builtins.str, typing.Any]]] = None,
    scatterplot_definition: typing.Optional[typing.Union[PowerpackWidgetScatterplotDefinition, typing.Dict[builtins.str, typing.Any]]] = None,
    service_level_objective_definition: typing.Optional[typing.Union[PowerpackWidgetServiceLevelObjectiveDefinition, typing.Dict[builtins.str, typing.Any]]] = None,
    servicemap_definition: typing.Optional[typing.Union[PowerpackWidgetServicemapDefinition, typing.Dict[builtins.str, typing.Any]]] = None,
    slo_list_definition: typing.Optional[typing.Union[PowerpackWidgetSloListDefinition, typing.Dict[builtins.str, typing.Any]]] = None,
    sunburst_definition: typing.Optional[typing.Union[PowerpackWidgetSunburstDefinition, typing.Dict[builtins.str, typing.Any]]] = None,
    timeseries_definition: typing.Optional[typing.Union[PowerpackWidgetTimeseriesDefinition, typing.Dict[builtins.str, typing.Any]]] = None,
    toplist_definition: typing.Optional[typing.Union[PowerpackWidgetToplistDefinition, typing.Dict[builtins.str, typing.Any]]] = None,
    topology_map_definition: typing.Optional[typing.Union[PowerpackWidgetTopologyMapDefinition, typing.Dict[builtins.str, typing.Any]]] = None,
    trace_service_definition: typing.Optional[typing.Union[PowerpackWidgetTraceServiceDefinition, typing.Dict[builtins.str, typing.Any]]] = None,
    treemap_definition: typing.Optional[typing.Union[PowerpackWidgetTreemapDefinition, typing.Dict[builtins.str, typing.Any]]] = None,
    widget_layout: typing.Optional[typing.Union[PowerpackWidgetWidgetLayout, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8af3159e18bfd0e3fb61adebeb31f485b95461f3763907a7cc5e1d4f88b26887(
    *,
    alert_id: builtins.str,
    viz_type: builtins.str,
    live_span: typing.Optional[builtins.str] = None,
    title: typing.Optional[builtins.str] = None,
    title_align: typing.Optional[builtins.str] = None,
    title_size: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__beacb426e1e51a6b9c6e5bc0513c3abf9535a3066c84a506c1b74c0c2d58b87d(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__93df006b3fe7fa3f706b8bbf2f9baef873a5e39f6e53c8600cdb514cac9bb1e4(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ad1992321ab1c7a664e3b2d4e6269fe687b18e99ee8af4ddd98284e25ecb2523(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0c5f79f6df16714cc5972c1a30412948ec79a66eb43c5f34b2f766e6e273e585(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3e59049b1184dc18e042cbd2e2c63f21a77c0fdf034d22e0e228742cd9ff0429(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5a090fff08200787337ba4814ca665a31685e238f2a49b2bc77e6cfa0366e959(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bb0a98e7955f9b526fcf495920c9c757b09a2329ad4d7777ed8ea266ce857985(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a25e08f1755b3b12b48f602bb2aa74c2021626ff4b111c93632a0dc54b39b21c(
    value: typing.Optional[PowerpackWidgetAlertGraphDefinition],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c02b99e55fc9ec4d7e393ecd943350fba30fa0d7ddf8bd133c7a7cbdf6d2f131(
    *,
    alert_id: builtins.str,
    precision: typing.Optional[jsii.Number] = None,
    text_align: typing.Optional[builtins.str] = None,
    title: typing.Optional[builtins.str] = None,
    title_align: typing.Optional[builtins.str] = None,
    title_size: typing.Optional[builtins.str] = None,
    unit: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__27b1ccbccc89714e5641c207b00dde2ce1faeb49f14cb472a1b6926dea75fb4c(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__168678d56a385a8191a2eae185b1b181ecb940c88ad4feb346159a484ed4e00e(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__184c3fbbe79b9a87308107d8e1125e4cbccb88fca70e33e1a286d29bb15934e4(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4b96f8d879f1acf21c783bfee994be8ee86910b2002a738e03ad384a28a678b6(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__74b1141c20a1b6a71638246ce5a9fae4dc453ac007717503f1a1912d930caf44(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6bd89a59116b792e6c14082993b5d5ddf7da0fadc14ce05ac53f8f0048ccdcd2(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a11f257cd3748c5cf1e87b37955c6120b56ec5a6d279ceca0f5db12a18ee4321(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e0d7855f2526cc9cbcbd439e51d8541c846d6b6c495dd2288c49fb3f41c608db(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9f5707fe7ea9d6e9761e7b2908493e3a5b3d92d4105ba9e3c351c0aa25af448c(
    value: typing.Optional[PowerpackWidgetAlertValueDefinition],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__33cc5d0526ac0dbc9bff49a60a9b441e62d37e785cfe520082b53120bfdeb65b(
    *,
    custom_link: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetChangeDefinitionCustomLink, typing.Dict[builtins.str, typing.Any]]]]] = None,
    live_span: typing.Optional[builtins.str] = None,
    request: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetChangeDefinitionRequest, typing.Dict[builtins.str, typing.Any]]]]] = None,
    title: typing.Optional[builtins.str] = None,
    title_align: typing.Optional[builtins.str] = None,
    title_size: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4ca7282347527785edc14b71c148155967c4380b78aae06bb70bc154051e21a9(
    *,
    is_hidden: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
    label: typing.Optional[builtins.str] = None,
    link: typing.Optional[builtins.str] = None,
    override_label: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a720d81d593313da8393528a7cba4cb7daf8cefb005cf68e7b188f4a7ce8b24e(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ace3e17a2e8511b031ab54e669572352766ba3250953ee8371f9a86643d0a742(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__422589d98fc105d5936075b7791a9c7dd9a69434f2d33c2f51eb784fffa3a3f6(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9475ad922600e3f38cd63a6cf02847c72e0131235e844071e32352107e321697(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4cb4c7f297ffd115284f58f58f87fba472b84197890bf15a99bc3e56f7d24b13(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8386fa850baabbdad560ba7bbe7a8c3e5abf6dd44c90e927b4d42f5f9dac04b2(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetChangeDefinitionCustomLink]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__58c2b8a2c9739ca85df3d854f9af2aaed899cd05a4dc955451328be9133ad674(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__785e3bb6ef3c4e4953e35c5c5113e56d7fdc3bd406fd756ae1d4301af25944fb(
    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fbacd7aa8af68d9b5b8efe674ff43aa4d80d61813c10b2f4424666d73d1019b8(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e743ae67777a94aaaf94262b32255f36efec2c743852e16ef2b436ee3229af8c(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c552895daae99ba2014b43bca1b7e6ccb69775bd9a537213e220b146b253b37b(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6c25d41e83bec396a5f7620078d08c7302a50ed97dd93c4a56b3097a3b6ae8d3(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetChangeDefinitionCustomLink]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fa9519d289f670469e0b188c2cd9b4e6b15fe32b74b324f23bb625641dec4714(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__72a4ff013ed5ec5fae37d1636daf9d9ed5ef87bb3cdf7e941a0943a378013872(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetChangeDefinitionCustomLink, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c0275aa72ac3740d7ed6fcfae16577bc2eda7cfbf4f9ca7e6a95f433112497af(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetChangeDefinitionRequest, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__09800b0f9b8fb20698a0c39866c4e3ffd19ba61941dc738f286ddda6fed5a00d(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5d77f754183366abef992c12eda7e5843c6834bfc182ceb754946ec4cdfca1d2(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__653074cb93d130414662e636cd9eee815255a8992b2c9fc7a2c16e7c9390dd7a(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a873c4b274a226e2aa3e0a3eaa494834098793594cda9301b28e97a07e198569(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8b4b756e1c2d3397e147cef492f7b084f153509fd26ce2b68b3b8632b2782c19(
    value: typing.Optional[PowerpackWidgetChangeDefinition],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6dac301bbb30035de357bbd4014c66166ccf78694c74280a6d1164aacb40f9d5(
    *,
    apm_query: typing.Optional[typing.Union[PowerpackWidgetChangeDefinitionRequestApmQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    change_type: typing.Optional[builtins.str] = None,
    compare_to: typing.Optional[builtins.str] = None,
    formula: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetChangeDefinitionRequestFormula, typing.Dict[builtins.str, typing.Any]]]]] = None,
    increase_good: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
    log_query: typing.Optional[typing.Union[PowerpackWidgetChangeDefinitionRequestLogQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    order_by: typing.Optional[builtins.str] = None,
    order_dir: typing.Optional[builtins.str] = None,
    process_query: typing.Optional[typing.Union[PowerpackWidgetChangeDefinitionRequestProcessQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    q: typing.Optional[builtins.str] = None,
    query: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetChangeDefinitionRequestQuery, typing.Dict[builtins.str, typing.Any]]]]] = None,
    rum_query: typing.Optional[typing.Union[PowerpackWidgetChangeDefinitionRequestRumQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    security_query: typing.Optional[typing.Union[PowerpackWidgetChangeDefinitionRequestSecurityQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    show_present: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0116fb2ac09206dca599e38f3e0e561841e61e7c5e84d8371717cc75210f4a38(
    *,
    index: builtins.str,
    compute_query: typing.Optional[typing.Union[PowerpackWidgetChangeDefinitionRequestApmQueryComputeQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetChangeDefinitionRequestApmQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
    multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetChangeDefinitionRequestApmQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]]] = None,
    search_query: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2345095dd7afd121906918ed7f1abe01cfedba9ebdcb8799aff98a65392e0d9a(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__43d7775a21a2c0ec1b90bf20131f1a7555722b039faada06687ea1d184f0ef33(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4a1ae72b6614770febea52f1402b73bf8b88dd44b3a9a2f754e8b56db1ff188f(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a3851bf0d691513ab7f4259c29d8988a19e6e28801602e299daf3295c4cab0d4(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__107b95079e3a2a968a34cbae859e53c7771350326b39500f96ffc71fb617b546(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__506d2b559aa3cce60d6fa51c84e833d2655d3a021be8219156111dc6e15b6229(
    value: typing.Optional[PowerpackWidgetChangeDefinitionRequestApmQueryComputeQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__84a2e7ec2710a7352f360859eaae412791e6f3417d1d924759ac463dc0d76d04(
    *,
    facet: typing.Optional[builtins.str] = None,
    limit: typing.Optional[jsii.Number] = None,
    sort_query: typing.Optional[typing.Union[PowerpackWidgetChangeDefinitionRequestApmQueryGroupBySortQuery, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b107829ce7c18ab19a5e29882cae6c3432d3ef6242d498e432f76ba3032c7492(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e08752e431002c8de01706f4754b992eaa8e2fd75e44f86da36f51fc49dbb530(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__89bd9bc97c05c42965a72b3a04f97a109c18f59da44d733c1de8457bd7981338(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__70e59f1ad1f1d256e21d3505dccf6531e47116f93da27f477c0ba4df7f63db69(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__beadb7c662b921cf154652d5230f9808d41f2e7731a75bc497f0d464f468e67e(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__99a736826c7c6705ba597d59fac216c0aa1978a43b59426718cd47b542ae2dfa(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetChangeDefinitionRequestApmQueryGroupBy]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__57d79e5bfd38a938b8593cebac04b7332b5eb9ae8d0054870a5e6ab76d15b850(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__39462667ce3f6e6bb1fa65a47a5bb051835122e7d3388733b8498774c43b7ea0(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1957bd861a3fb06b8dfc3ef7b07908b8f008f4b7533523f7284c01531e90b4c0(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e2f96b1867ba2bca7b056755be489c7992a183c3ce06a70ee4bbba1b31be34c3(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetChangeDefinitionRequestApmQueryGroupBy]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__61c9285722ae637810956a21de071465cfdb5deec464658835d2fc48c9fbde22(
    *,
    aggregation: builtins.str,
    order: builtins.str,
    facet: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__87e2c35959eff448b834cb5749ccf684cd5932ceec89b2969dcc1b44c3bf5c5f(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6854742cf175ea9a235cbd3aa54a655cd45fdbd026c323c0e0f0a7de0d6018ff(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e9e3a2e176879d6f149c1ab951726d6011543651d05673384ef68e3e739576fc(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7f35b99ef5c9009ecfd9ce9c9f781cc71b464577ccdcb07d941df696fa4574c0(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ac67a31cfa9f9af4c2178d9ab30f6c3e35c72900560a5bb62b3b1a87687d761d(
    value: typing.Optional[PowerpackWidgetChangeDefinitionRequestApmQueryGroupBySortQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ab94ba0c01f48e72b814240076ada2f6ebc81fad758544dc15b3c9a966923ddd(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bc8130868670c72fc2885be07431fe7a0fceede63c213a05c6b7723a7d06c0f0(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b5b8d53a242b6b528cad81b9401eed5eb68da426490bc5fec61dd4edeca742c2(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__be5a2fd65da5b6a51a11f7045dd967bbb60ce17066b403d7095120dab6abd3e9(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ecd8c0211ebc5128533a7af383b824cdbcfa631bd08ff6ac29d1f7673194b872(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dd4ae4ee6f1e707bb40f448575ca640f832fd7ac9f9b770b1c9ec4798125e660(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__79ac547cfe5a0d7edd165bd3ef8c69da9c316e40adc3aaaa0dabdc6485793c6d(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetChangeDefinitionRequestApmQueryMultiCompute]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9429c5f792861bb7567fceefe2df019a068aeb3bcd01d75fecb883077ab73a10(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fbce79f6994e9a59d1fac8f38ae0c511d37a923b0f98146fb5adcde01bb4ea50(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c53de71f4ac1b51e99feb926759a77110f611fcf10460209a44bcbda18e6b799(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__eecf0794f2bcb0c4a5c4979b0ac4bba20ca49a23efda48d0721edd66a10ff901(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c08844a9f0c1ea2dc62781a70cee2d205822bd3ba602c4c0dc50a896a47c96fc(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetChangeDefinitionRequestApmQueryMultiCompute]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__317c13ecbe9918608385248b0ada4666ca92c09e03ee3521cc68babf96aed0bb(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2c4fce86ed4894d2341fa26ee57e4ffe3bb7585db70201dd68118d20e5ce8ef0(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetChangeDefinitionRequestApmQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__31df7f8a793a74e403b03e6b4f4d7f5100a2b7821074845e8fc736b65a03ceb5(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetChangeDefinitionRequestApmQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bb4ec459c886bcb3db1e986658b703c9293891a172c159cff96c5a97a1cd5530(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fef196a23ddd73c91765defa08fe86bb1e96a4eeb6c0c11afc6c11ac2a1572e0(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__92b13d22f78aea485015e4a31b33af8b209d281ef4db9662ca517d82617b129c(
    value: typing.Optional[PowerpackWidgetChangeDefinitionRequestApmQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__55fd50d36bf2c6bc6882b61ef6b55837cd040181363212943091365d5ba44878(
    *,
    formula_expression: builtins.str,
    alias: typing.Optional[builtins.str] = None,
    cell_display_mode: typing.Optional[builtins.str] = None,
    conditional_formats: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetChangeDefinitionRequestFormulaConditionalFormats, typing.Dict[builtins.str, typing.Any]]]]] = None,
    limit: typing.Optional[typing.Union[PowerpackWidgetChangeDefinitionRequestFormulaLimit, typing.Dict[builtins.str, typing.Any]]] = None,
    number_format: typing.Optional[typing.Union[PowerpackWidgetChangeDefinitionRequestFormulaNumberFormat, typing.Dict[builtins.str, typing.Any]]] = None,
    style: typing.Optional[typing.Union[PowerpackWidgetChangeDefinitionRequestFormulaStyle, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__42bf7075d76e3208206b941c3bc8eed0550647b4d52038ed577f889d8d16ff44(
    *,
    comparator: builtins.str,
    palette: builtins.str,
    value: jsii.Number,
    custom_bg_color: typing.Optional[builtins.str] = None,
    custom_fg_color: typing.Optional[builtins.str] = None,
    hide_value: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
    image_url: typing.Optional[builtins.str] = None,
    metric: typing.Optional[builtins.str] = None,
    timeframe: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0a7a4b2384cc9622b6eab5d2a88969af587cd879323d70017bc5f1c4e8eb2358(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c7622d79009b53c74ef1bf45dde54c9a420a167b4fd3133f5ef93f1ddc60d15e(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5c1cddbb48220b22bfd4a9de0d0653126badb71ef924e157357e58a3668d602c(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a1e57e936155f2abdfda139c1ff6efa5894ec1fe9c5547019ffa08eb5b2f9c3a(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1e39b04e0da84c8d5a4a9a5f82b3afdf94e0d2af3d5e75e2ac6bdb256787e15f(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6fea580b879bb4e38b9db11ec6ad11ea23ce2609fa5eb8efe079528e18be84f2(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetChangeDefinitionRequestFormulaConditionalFormats]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e6f9a1b464647d2679f92ed52c52596ccd76b45713716a3074ff887ff18bcc17(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bc4e2338aa40e7ec965438009b0742c07fe56bad5f1d9a867af868a4397d51a9(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__38376e6f00e4ce446f509ee827bdaf532db472754a1571541499f0d031479b98(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9f7bc35644bbb0e2497b0fb27fb581119009687cedd9b33e4a5ece3024b3ad2e(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__665e51df0f4855e51a6b87473811305c321e69d5e45311ccf9e4f5bec4760f39(
    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__68668d2067b1d2ab477fd815d05daff45fcee02f927670494ef6f82b01de462f(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d9ab29dc7228c100404f1f63cf695a260b1bc1d64376c706649d9dbae970faad(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fc8729779ee63a5285b012daa0b2f8ec26f759367507ce91d471131e26940e31(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a30f464fa7636ee1c7ddfbfa040335b83e6f40fb00f65a5bb96c685018d8f71f(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a26de78ce78e3c05c53df044ce0db5fda967bc57f99ba4a368d86203fd54dfd9(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9239bca76c2ad41a1c53b44cce03c71620893cc2df88f66bfbdd425950a521d1(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetChangeDefinitionRequestFormulaConditionalFormats]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c86078caf28d24166b82959b50976accdcd5794220a76f70d78b6cd769561685(
    *,
    count: typing.Optional[jsii.Number] = None,
    order: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c24d7df37ab1ba8b5ec103788d02b5b32793eacf585fe41bd466e075dffb9795(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b42c6e8fcd3d739ae86f1142faaf61d25ad301bc3a0ffea8f3e5834f7a43fef4(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fd1aa6135f593606968e96afa60a6369dcac7567439aac36724c0adefa088644(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__38748684681f8de76f8b5ad9dc7fbb62af81b7f5d71289c62d06b24fccf3368d(
    value: typing.Optional[PowerpackWidgetChangeDefinitionRequestFormulaLimit],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c0aa6b05eed679271d862343945167ed8f45f4827ddc56e2902e8051b6a9c882(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__806b6feca0ce458753b028a223fe2488e2d040014751cf0f881812a38451cec5(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c79f737a83b0620699f5e0dcdc1dc4699c6a7ac6adf9f9ccfbf2fac54acc1fb5(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8f1656254c022439c8412574222cff596314e1cd19cd427e3e68fc584678b697(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__69d3c11cf7393a19ee59f41accc029e090428e373860616294abae9f8e85f5db(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d909a257d0677275341f70b980b7b436806508d4fefe307404875e0c6042ef19(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetChangeDefinitionRequestFormula]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1bce563587ffcd51a82079327ff4be4faf9fb573661ad86b012bbfb69e932e24(
    *,
    unit: typing.Union[PowerpackWidgetChangeDefinitionRequestFormulaNumberFormatUnit, typing.Dict[builtins.str, typing.Any]],
    unit_scale: typing.Optional[typing.Union[PowerpackWidgetChangeDefinitionRequestFormulaNumberFormatUnitScale, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5a71bf9fc90e9c4720f86b4fd2a8b8bc9833a370ef1e3ec24fdc817667bcc4da(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__04db5296ebf85d23fd74482f8a5fb5feb6dfadaf4a90e4381572984b69d4aa33(
    value: typing.Optional[PowerpackWidgetChangeDefinitionRequestFormulaNumberFormat],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0f7af4f967f70f23388486779b40b29de78d900e6e9ce65d5682edc903276cd6(
    *,
    canonical: typing.Optional[typing.Union[PowerpackWidgetChangeDefinitionRequestFormulaNumberFormatUnitCanonical, typing.Dict[builtins.str, typing.Any]]] = None,
    custom: typing.Optional[typing.Union[PowerpackWidgetChangeDefinitionRequestFormulaNumberFormatUnitCustom, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d9e552149db8cdec0c74155e689c2bb4234baf2ea74c7cf5902e0a9ceb901f28(
    *,
    unit_name: builtins.str,
    per_unit_name: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5c5c52aee196135f607b609122a3d11d225303a48b779ae66f3d31357572f731(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f78f8b66ee8d2e39f91e4033eb3af9a67b003da28e73d92d1db46d2d37f7eeb0(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__16ad90490e80498d8c817831fc16cceddb2229bdcd490e234198a0e7693fdfa8(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__897c10dcbdd9b6f1d89acf7b147d91f2145e9e4ce3e7ac175216224832cd21fe(
    value: typing.Optional[PowerpackWidgetChangeDefinitionRequestFormulaNumberFormatUnitCanonical],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5da005aa0dbf1b01070beb77d37e6e0aefe7e59a2637f0c1b616c3e1069c4779(
    *,
    label: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e4daffccdd0df6dc28d559db5397f8bb46927395259d87c4268ee99acdc66e50(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__93d6cf85c50be8bec13a9987c344777215dbecc062aaf0f223a046da6f939a89(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__86ea73db316ec95018b768621998a4dc0a3569b0040d5ff0f7f63bc8b9189e43(
    value: typing.Optional[PowerpackWidgetChangeDefinitionRequestFormulaNumberFormatUnitCustom],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__efe4f0ba4f5f003c03d118194857ea68d93ff1be171e1509b333c787891dc202(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3384af0d8469f49640ac75aad603a6a86c58f45bfc5ef2553a1f9af97d07b6bd(
    value: typing.Optional[PowerpackWidgetChangeDefinitionRequestFormulaNumberFormatUnit],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b42e12feb93625b8d8734a5bfb3a036903be1a33d0cf432eaccf0c2a8b5773f1(
    *,
    unit_name: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__94175bbe1da434401236f555a9772d436ff169a9a98fdb1d7cd877b2fb3d5909(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9f8c63cac30cb4f828f78f26542847527c036496d72fcecd364be47662bb8e16(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f47e313bf13ec7ee8c64b3f6c5315601354d1d45e40cc8efa4afeb004dc2b8fc(
    value: typing.Optional[PowerpackWidgetChangeDefinitionRequestFormulaNumberFormatUnitScale],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__95904cb0cc0e3642f4c9eeb46d034015a708fa98bfc0aa7965ca0aac050ef1c8(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__51017f2fcc67191cb8fa9a67c1b25253a4657f153eb32d5f87cc4b8c28ede151(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetChangeDefinitionRequestFormulaConditionalFormats, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d49a8378ce6b0d4707d788ecfe30920526e9727cfe98b61c5bfb4b63db3421c6(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__499325ff84cdabc941d5870aff16570609cd653dc189f561e25993d0b9fa01cf(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ee589b22e1d1ff14e29c12594d96fc76cb963d7dafdd784a04ce256f25b0d9d7(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ca68621a20074d4fbe686bbea713229ae864965e276dc11f63966cab43d9e1c6(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetChangeDefinitionRequestFormula]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__41a79bc9d8457df59c67a16bd43bbe0b99c33328102e8dc01277507edc514d6b(
    *,
    palette: typing.Optional[builtins.str] = None,
    palette_index: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__876aa9360c665afeb9b56ecc52892dffef20dc8ff5ff845ceabdc8de1fe95f67(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5160002f394992ecf112629275978a8330da8774c98499432a623932176eb6c3(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__55f23190f05b2970ec410706a92524597808f020ab4208ea7ef8dd6bd40b0033(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8c88051f0cd0f948a3c946da27412466af63dd9e2a65e672c03a2960f083e258(
    value: typing.Optional[PowerpackWidgetChangeDefinitionRequestFormulaStyle],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__55acb206c9f38eca53f8dd37e06ccef3883315a1f5645b8a859aecda50ea2952(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__60917aac89b63f289bce87351d5ad4b1e9b0beb57606561b7bc240f9639dfe2e(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cc707fbe556e6a53466d14d29958056a7b1abfdd2eed04466792b6e173c355c9(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__482fc90c52f61398aa49b9648aeab9df421b9c46e7c08cd00eb8ed3ddc459125(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a3e6813928a3a64da6c7c3271f00a3c78ec56ba5ef972c56a75e287fa03cf93c(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5e98b7bef70a496b2c002fb333f6119296e42b409e655f11ff940364a9431b37(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetChangeDefinitionRequest]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ddf02bcb1dbbf9eebb722cb94d4001c3a23664daca9a696580556b65b8437b46(
    *,
    index: builtins.str,
    compute_query: typing.Optional[typing.Union[PowerpackWidgetChangeDefinitionRequestLogQueryComputeQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetChangeDefinitionRequestLogQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
    multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetChangeDefinitionRequestLogQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]]] = None,
    search_query: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f1c440c64415471b60efe70dd3be39c4ed8be13438cfe50a2c0aef47e9c2db23(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__508125d1a6a4d3a19198825acffcd25180027840080e40d3319428e7c645582a(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0d149674dfea276f19a52f9b87b64440b9f804197ec47fa604ec1856b4fb616f(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3aacbffc6bfde3c345b0fcaad161d6c0ef0984da7aed42ecf3a7294b9cc4d9f5(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0a65374e7d12a99366f3177533db77a7ecaee36a24ed03f7b0e9790f2b7c2c10(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__44f0c0db59d58564644ff5c0b9e5b9dbcd01dba257618aad2bbe604be6b14af5(
    value: typing.Optional[PowerpackWidgetChangeDefinitionRequestLogQueryComputeQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6a7a00205962c76019c6a241eda84e822f8bbbb0b4c6f12f67577b8d399f1c0e(
    *,
    facet: typing.Optional[builtins.str] = None,
    limit: typing.Optional[jsii.Number] = None,
    sort_query: typing.Optional[typing.Union[PowerpackWidgetChangeDefinitionRequestLogQueryGroupBySortQuery, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__36d212496dd9718bff5df404d1d7db8184f723f79e067f0754aacec876d2cbc9(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1880dbe8955d584ca2f82601b54b6ae5543c9767a70a08c8af5ab1a6010cc25a(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a064be7488ffaa809c4e919c93c3eabfcb3216a65b3eb51a834b003ea6f93afd(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__113cbb7bca1234d7d993bc056b0d5da79159389697389d942c56c85fafe693e6(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c7164f3ebc00d8c5b460289267cf63582ca5e1ebf6396c8122aa8ff2db1f715d(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a56d909ef981b399250acb1d73ae76f88fab00a3c9de80d7d8c0f2068b221b48(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetChangeDefinitionRequestLogQueryGroupBy]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2ebc755f2c080d383abd575cb5ae3a5106d427106c82574584b599561cf4d697(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__951a5474764145488e12940441e407ce387b3a423b1e886b947032660d2d34a1(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__228fb84e3c4764938fa0fe95b55663c7dbf9c15680582117a3018dfd43f0b645(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__304f55c6750cdf9ffa240358d5af127c4351e9357033c41c22ba363a0ecff672(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetChangeDefinitionRequestLogQueryGroupBy]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bdab3c006e0574d7a28126176fa027b5beaf9e0a06a4086c3801178403aef2fc(
    *,
    aggregation: builtins.str,
    order: builtins.str,
    facet: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__353601b4f7457eda415a713f152e5ae8a35112dc72d4af15c3a86377d431e91d(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8e961b993d5e0459f8c2f0393b5bbf0312c62681d6c71230132c7adc67c0ee1e(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__03379a9dd3263f03afd1d7413d2b1180b82ee7f28c3f0b2613d1aa7be0275615(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a8ed87ef40f40281b5860cb6f05677db59d32cebc1f2ed514970081a5e7a6045(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a8ad93a39c2fe9b3e4c0283825925c830907741d6cd1abb21f5237eb39952b77(
    value: typing.Optional[PowerpackWidgetChangeDefinitionRequestLogQueryGroupBySortQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__27cce1c74ffe90ac6b9f1eda9db0e59afa5e62d523ee76e9ad9b260dae158759(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8bb9469a38728fb996bbd381e9ea0e3ee1546992274e93ac416263f230bf87db(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__df868e8b4738f51daf8330c3f2cd91fd91f1f788fd56ff8a0a77bd0263434431(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__70f1725e818de07062c6ebbdf354683a70d374f5c4fc9779868383176c74e737(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5bae2bfd90b10300f9e9ae1cbdfe9f959a6596b45e71b82fd00354e09163121e(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2c9f86ea544affe8c974c65ee9d1230a39a609aaf5e85858a24106e8aa3d80d2(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f01222309d3c068098e021739b8b892e312f451874a5d1f109bfb49c09351e11(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetChangeDefinitionRequestLogQueryMultiCompute]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f0224b7dd0152b8b7a4bf7f19245b5031d25690dea9c0289798ab1593adb8680(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__08ca982db5dce5b020ae8e46502080dd03ceca6d7b0a5d7fee29c911dd911a88(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__38bdf2df04a0587f1deeb4e03161c8ccc0367ad63b490f4e96a6329c01db80bd(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__66809b444ecacb96e5e283a270d222d07c66ee05e2541177e3ea44eb96ab43a5(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d4ec026ae9d5c8bacf1ccc8faa05685dd7c16213d4df26f92533053a542faac1(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetChangeDefinitionRequestLogQueryMultiCompute]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__630ac6326d862d9758ba62e1f07491f82b9a60accf0b662c2f37e880d6b2e602(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f220a7ea07171f134ad698bdc8248fed545c4175f8b53a6f900cd9d1a955b005(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetChangeDefinitionRequestLogQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b92392da1e5223d571230136084f7514ef7f719914aef168355772ed95c67e8c(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetChangeDefinitionRequestLogQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__82f4c75778ce62d4860d9a2d3c27297b8ad33a04c302a2717a523237fdd5ce1a(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f8ce28673287f7d91026ef514a009da9d09a0b48863a0682bd4e8e52afcd5fb8(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e50e49006569bb92bb2f07d549428a96b3f7647c3345d32b1aed1b6bc5df1f02(
    value: typing.Optional[PowerpackWidgetChangeDefinitionRequestLogQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a7105e686c64b7081f42607fc9da0f3c71b4c04292507317451326b68ecb1db4(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9410a7aca2baaba08e29a9d0cd9454a282c98847b911adc551c1d3b36745053b(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetChangeDefinitionRequestFormula, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e0b0c740ee177cf32c01610aef95f9a8516a7525f4dbbf821fc71f8d41f32133(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetChangeDefinitionRequestQuery, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__90110937299d789483ce7dcff088287a83fa557031c1dccc5693f1d6cefb5eb6(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a76517701a1360c81e3503effa87544c3830367559833f5e7174403938ea99c0(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bae0e201b41e2f891bde7f0dbbf45ee11c83193ff38ad96d1df72023a9bf8b4b(
    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3580057c304c17d13da75e42ff941a9d7d748883503536df0c2349cfcfe44c3f(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__260427308520845226f9e03cc1b0bd0b23713af4f97600347a9c124bea683616(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1adea2d0cf418c7c45690544b24e5625e05f100d612666d2f508228f89925e64(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6ad9caac2c855ee1581b65eb2408b246b6c8bc4e674fc5b59aabd6d1a9e8ae8a(
    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d6d2d16dd9321ba77a6ca8cc23eb44d418fed41e58da1324b0f9a7d64b3b4b67(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetChangeDefinitionRequest]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e973f28b56aa6392836731765ca99deb31b520fea843da563a7bfb3792ee21b0(
    *,
    metric: builtins.str,
    filter_by: typing.Optional[typing.Sequence[builtins.str]] = None,
    limit: typing.Optional[jsii.Number] = None,
    search_by: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e36be187f10b1e6ce9bfc73dc3954ae6fa88de12c64fe05df5ce1a2d5dce604b(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__333a32880f7501e633d3dfb90c82f783be4f933b6ad75a7ec0d8ad6787acd499(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__884670edfdc587705c2fb13991e21d7587d8bae5a0ac8c1de3b6e817cc90a3e7(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__eccb09f7044fb24866f76f82a7b1592747c78951f49b2aec7f99449e116d297c(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4475163052e63044ba9103bb5e0ac44097be76ae1e8ac943c1042eb4b99c43bd(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1997f73a6d8a82b6ab730344a86585bf73404b6d8301f130a5476c305b538ced(
    value: typing.Optional[PowerpackWidgetChangeDefinitionRequestProcessQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c9c03e4b5c273a72bd7fb4689ff14ce199240d0d2bd7298f711c66b804e30bfb(
    *,
    apm_dependency_stats_query: typing.Optional[typing.Union[PowerpackWidgetChangeDefinitionRequestQueryApmDependencyStatsQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    apm_resource_stats_query: typing.Optional[typing.Union[PowerpackWidgetChangeDefinitionRequestQueryApmResourceStatsQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    cloud_cost_query: typing.Optional[typing.Union[PowerpackWidgetChangeDefinitionRequestQueryCloudCostQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    event_query: typing.Optional[typing.Union[PowerpackWidgetChangeDefinitionRequestQueryEventQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    metric_query: typing.Optional[typing.Union[PowerpackWidgetChangeDefinitionRequestQueryMetricQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    process_query: typing.Optional[typing.Union[PowerpackWidgetChangeDefinitionRequestQueryProcessQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    slo_query: typing.Optional[typing.Union[PowerpackWidgetChangeDefinitionRequestQuerySloQuery, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__933701178b5520217377afae747ecf16667e69280e6c85cb0ea7c0647fad6491(
    *,
    data_source: builtins.str,
    env: builtins.str,
    name: builtins.str,
    operation_name: builtins.str,
    resource_name: builtins.str,
    service: builtins.str,
    stat: builtins.str,
    cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
    is_upstream: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
    primary_tag_name: typing.Optional[builtins.str] = None,
    primary_tag_value: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b4defaed05090cb8c0eb30503c02996aefd54b929c50eb20a66a9e8dfbad414b(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bdfedb3b860b2801047ce369d2e85b0d0af5341be17a3e628b1a3812c4bf4274(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__47ddbf75deb98b8806b136bdad9fef30bc9ecbbe626e8eddfb8a0fe946e9afaf(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a8e0c5b0359fbb37eb8c8dc6f742bda097043ea3b537b31a95ed744649c2200c(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dc272eb95accea866e826fe118212e0cb01b2bd7c444902a3307c90fdaeb8248(
    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__322c7e583eada8c84fed2df65f7abdcd1f1798f0a2c0d31971d5fd453c4788e0(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a94ca97363bb9f9b14a45e648c27c78eb82fcec3ca4379387853faf3456317d6(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d7ad6147594ada825e9ab30d66e5dac32845daee08f0e17a0e6b36d498bbe1c1(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__09cacdea4ef33a2352d35e38aeb728151756bf3f72827d60f46a8a335d66e794(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1e708369b6d241f3fe8ca3936d39c54e05269910c05fe8e0c4828fcd1a24c036(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a79a15f5f007d80bddbb5814f0209c8d2db6cd34e39bf42af14481b99ced07fd(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bb0af87a5bda72ec7d88ad527f30cfe13240c502276c449197d1ea15e3a93f01(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e7b4496814c0d770afd9a81bb6486e4f9dcacb7b9da880f84dce6f4a131bd5a5(
    value: typing.Optional[PowerpackWidgetChangeDefinitionRequestQueryApmDependencyStatsQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fe5192ec2c7eeca54e2c4f23d3052ea715bc580878f07d9d90b0354096bb92ef(
    *,
    data_source: builtins.str,
    env: builtins.str,
    name: builtins.str,
    service: builtins.str,
    stat: builtins.str,
    cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
    group_by: typing.Optional[typing.Sequence[builtins.str]] = None,
    operation_name: typing.Optional[builtins.str] = None,
    primary_tag_name: typing.Optional[builtins.str] = None,
    primary_tag_value: typing.Optional[builtins.str] = None,
    resource_name: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ad3ac082900086a2f0b50cf1acb3a43a458a30afe910677ca42dd1b2aeec2931(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__add5b83840d067a62e7da0225e7647c22f6646acc52983ee65f4b41323c50dd3(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e8c86ecf6865a25ce827529c7f8bb1c1616bc4fc3aa40dce930b46cbfb90f60b(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4394e2b8d32f5c4eac45842c633671400f7907cadcf56891aeb8d9a2729bdaad(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c51eec9a3641d1c5b8b3a129165a1a21e6e7d855c39541c500c92ff918744e1e(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a6c9041ada171b5604118a515136323a0e64e3e5ae62e7c9484f9990d91d3e7c(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0131a8210197b057f3ae3146733fd004fa763e47f5fdcb33585bc510e7f0f4d9(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__981002cd1d368a445f8f343ee29062226c2ac3251eef9c2230b49ea03142c6b1(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6d05a4e3377256e6a36a38e732ff5d31876ee8dfb0c66d01f45bcb3c1ceb0862(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__60a7af8c119d9ccdb5018774c15661d516666d04f7622bdd6b0891edc7d40720(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__45ab7b9ce6f6d06dfef7afd97eb88b9f8ece0576f420b8318f4755388a1af7c4(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bc4b0c90bad9caa68aa2572ed43da555af0a01103d0f55381389bbac2cd64cce(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d8d012079aece195431cf7d588e62710bc96e4182fe51afbab76459e9860ea8c(
    value: typing.Optional[PowerpackWidgetChangeDefinitionRequestQueryApmResourceStatsQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e3a6a8861c3da17998e451d352eb5dab4d69e51d7d10b9d388a90c6e04fa3e98(
    *,
    data_source: builtins.str,
    name: builtins.str,
    query: builtins.str,
    aggregator: typing.Optional[builtins.str] = None,
    cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6c785b59b0feacc98fd41c4afe47e807925925cbba3e4283ff4ba0a3fc83fac8(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cf54098f29415ebbceec27c7dc2ddc02b0e6ad74e9813432c58ab2d2c8e5e5d4(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d2fe8bade65eddcab59598ad677bf450337926ed8fbc1a31b7487c17f4ac2be9(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__59bd161b6511c7be970ba2e5366ee74d9361263254f812b844681ba16acb4962(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a697a9a3ddff808fdff9a6b1c1261f6d3fda9ef2a80150219eeb96f31854576e(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6167b9eb5be22dc373d81302218ea95a616811b359456ec411f8b75bc9d74d83(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e690970106709009267892566b746362e330b427a895ccc8925ea254e476ff34(
    value: typing.Optional[PowerpackWidgetChangeDefinitionRequestQueryCloudCostQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__43363870da01e3277339557f2464ef650b41d0961b5188c55ee181ce75d39ddd(
    *,
    compute: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetChangeDefinitionRequestQueryEventQueryCompute, typing.Dict[builtins.str, typing.Any]]]],
    data_source: builtins.str,
    name: builtins.str,
    cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
    group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetChangeDefinitionRequestQueryEventQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
    indexes: typing.Optional[typing.Sequence[builtins.str]] = None,
    search: typing.Optional[typing.Union[PowerpackWidgetChangeDefinitionRequestQueryEventQuerySearch, typing.Dict[builtins.str, typing.Any]]] = None,
    storage: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1d8892377caa9a49c297461f0b7a4d3c6e009664528d502d97a968b9cb31c010(
    *,
    aggregation: builtins.str,
    interval: typing.Optional[jsii.Number] = None,
    metric: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__015f550ed0c555bfd432d4dbc7927e9d2dfe6e8efe4483b8338178f2fdeb5205(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1508fd470556c094d8d8c4d519dd0c24f31b57f01379c885bf07861456fad31d(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__91c01c3e8a630fe9832c6462656bafdcf39cf8ae1a2e8cdadaa02fae8b819458(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ec2ae0d3e3a8624823547ea42d29a0fabb919b91216276be4f718971034f7bd6(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__26e6e9a559317915263d2be79127c4c4adc4353fd96fc657d4ccd0039b615b46(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d6e064bd77617d31d6da7890dfeb6eeb67081d32c3d69266df77ca33ea65abc7(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetChangeDefinitionRequestQueryEventQueryCompute]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b57f0fe83bae2a572f4408a9e74c2ad487e136f86fe129218b1fb8cb3f063ce4(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__37b1d5369d1c6cbdf7cac0a1b1e4f61f5284fc8209f2d63c963408026fa6d5c0(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d2b63724955a5eb1d67a28364769cc587c5a2c0672b7a53dd8566e4b2fa7e1ce(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f64f99719fd763b553971895dc8eb7a5a4f9b4c762117df008d414ec9731f386(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__28bf45c8c35bf05122733a9980d8be4d22db46e06ded8e10b92c14aa677d5302(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetChangeDefinitionRequestQueryEventQueryCompute]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7c247bdaf3ed1c77bc79872276889dda4d16453ec08c5748900ff5ac7b249700(
    *,
    facet: builtins.str,
    limit: typing.Optional[jsii.Number] = None,
    sort: typing.Optional[typing.Union[PowerpackWidgetChangeDefinitionRequestQueryEventQueryGroupBySort, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__95801470614c1cfaad108eeeaad004ad01f3a165f06645616f12decbeb9a687e(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bdbdb7dc702541c191ba31cd0dfeccf45bf4c88f81b38f3c920e7018d21c141f(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ad9cf0214da2a24a9371de181227e66cbc0dc7d5695e252eb90661bb6a27ebbc(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c0392a9f03bdaddafc9b58984e80fa5194c786a3cb54a2ceb6e02034eb1f5dd6(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0a0d7560cd8e71f40975f1a083f9bcfb0c1fb2760319a44e8d62c9a2d4938489(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4116bae4651846048a87e88b38da9ee055b20a9333cd51f39ccf00b3a5966899(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetChangeDefinitionRequestQueryEventQueryGroupBy]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__024eceb0668a832853aaa8cb3573279ef14b50847ffd58f9489a17893c904045(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9dcd26da6ca688b8bbf172e5fb82a5c6caab5d60ab0d2462c7516b49a71b0530(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4394bd7fed5c627b8b5d2cded235298077e3a7c46e1e3cdddf892f6cd5b6f2dd(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4f5f9e32b341c29269a4911af9971d70ad2f49d2ec25b1235f3786f02c2cf85e(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetChangeDefinitionRequestQueryEventQueryGroupBy]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__597061ca910f1e910b9fdcbd0fa7c68880b6a0d7d93abe92eb9db3ff5e6ed872(
    *,
    aggregation: builtins.str,
    metric: typing.Optional[builtins.str] = None,
    order: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__15272ad9abbf5ffeaa53f2c08ec8e6ac4fb852abd24d487543162d505ada21fe(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5fbec8f286fe1f2179a0e13f5455df96f288264f9a44bdaf8918836a84a9c5ab(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__663472ee5031d462131386874416f82fd80bc67cdc66033516fe2afd451cad83(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d800091786f27d0a005bc82c580621740a2bc7fe058a834ef44ef2305e5e6857(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dbaccb15bd6c2d58078f1b0faa5af99e3bdc4585af7946d8fe3ca9ae30d55172(
    value: typing.Optional[PowerpackWidgetChangeDefinitionRequestQueryEventQueryGroupBySort],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b5ba1bf8c4aa143a27a30e12f838a1bf3bdd06402bf2187908d11e2566dec08d(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8816b777e63f78a9009249580de3e8bd6d2af5196cef40dc5c87400dea82203e(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetChangeDefinitionRequestQueryEventQueryCompute, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9e3f7a14d86664e4cb5e1609ed46769e0ffbbc334b5731f005cc65798277c924(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetChangeDefinitionRequestQueryEventQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__98030ddaa5db99eaa794a8c2130884b4910e63508989629b26f089d8bc47203f(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__13d2d3058f4c4c6a40749dea56e41961d20bb277025d4097d35e08cee8825f74(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__45d3c1029095d09369f6b405130e303e8bcf6ec9557bd644414f004de8442be1(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__87818e7206babb11854bb6a206dea1b4ecfe43421215b9f8b2363053254a448c(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__622efad95a98f0461f209861207f0beeec5ea4eb7549a77beede9bf18a300058(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__68bf1db0da66b0dab41eceb1c72ab3e3b01d3071488caffb19885ef7ba32c033(
    value: typing.Optional[PowerpackWidgetChangeDefinitionRequestQueryEventQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__06a1495ea7ab82539e408c09a5a1d31f0d8cd94933175dc8de5a550576727b5c(
    *,
    query: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__099ebc532083f6254fc32cb2caa5e24d90b5440c684bd752a35fa54b5a7964b7(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__08b190124f019eb9040b925c63c7c8dc443be319164d6cef59d9eb973ca86ad6(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7034ea8cbcf87580c95cf5047d13cf60b6cdf5a738f438d72b1a9f6e737f500a(
    value: typing.Optional[PowerpackWidgetChangeDefinitionRequestQueryEventQuerySearch],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8b5cef205305ca68a8fbed942a56fa9d21214d2e89080348132a6239590aa7dc(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dcf861b6fe6b48152129ce237d07aeea6a0844be51565ed1c43c2569e7e6521c(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6cdf4bb87734cda223e7a100349d40a641f358d3e45adbc152f7daf5cc9e4fa2(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4206357466142aae19faebd688a6f605b8076798f2f1bafd6e0e30294f77df53(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6e5cff8cc364f7c987402950831e08cc69dade63b1ebffb00b66dabfdd5a3b33(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0f39bb55048d175bea4487ba76aaebccbdf3fa09f7526abb5cf3015dc4c25ce5(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetChangeDefinitionRequestQuery]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3f5d46761405f318608a029f0a2ee3fa3d62d74a7b4b700fab006475f853efd4(
    *,
    name: builtins.str,
    query: builtins.str,
    aggregator: typing.Optional[builtins.str] = None,
    cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
    data_source: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5c17a9de0fd28a7c24f257acde4d3a19f8fc0531235d72564713b15167223bd4(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a5030c7ca34a00574b5ae22bc7b29aebf181a664900379f8fd93070d09ad6d81(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2ddba80508c6049eb5937e7380e52ac7831fea85c04c5675df570c5f3c2a14f4(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__85c6e56abe8654a01341fdef9e238c8de00c1cdc25c6933c6c7d35992bc0a8f7(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__44b09f43faf76688de6f2c6db0bf19febf2555fa7bf7ea38e7200c4f3c0bea49(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7f900742f9558388e67f0275c6335457ba0d8f7b786d8c01a21ed9cabde28361(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d9f56e7126fa736d714884cc6dd2ef7f9d94c5c03d358b7f8ee39646240afd5c(
    value: typing.Optional[PowerpackWidgetChangeDefinitionRequestQueryMetricQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e3bfcce3be1ed1518f770ed5781799aa149a0b1a1ac16af4ef2101255df08316(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c41c3eeb97d5440b041799c6d7f5c230a7e7ec09297e26127b061eaaadf2602c(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetChangeDefinitionRequestQuery]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cf17447499cf44934efa039e62ff890ef14242f6f8a7f59f37e8d58ba9829326(
    *,
    data_source: builtins.str,
    metric: builtins.str,
    name: builtins.str,
    aggregator: typing.Optional[builtins.str] = None,
    cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
    is_normalized_cpu: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
    limit: typing.Optional[jsii.Number] = None,
    sort: typing.Optional[builtins.str] = None,
    tag_filters: typing.Optional[typing.Sequence[builtins.str]] = None,
    text_filter: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8118f33dc51172d14712889e6562c06a38be6864c31268179f27aa63287dc184(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__858d607cb6ec8080cc7e42b4b765aa33f223138cfadaeff6352e5353d2df1ef5(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4e9ce5d0e159db6cdf735646b3cff785d454fea8e2e7adac484861fa6dfbbf5a(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d5bed7bbb99cbd744204701cf4522abcdd551a33bc9f28c5b2e25d0e18c80bac(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b0d3af3738d19dfd52ab0a9f2defd52df94c7867dc0b18d22e6b7bb083c11b3d(
    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5b37bb5365e262bb49f327184c835bbaf84d43f5d075893ab161982749fbc211(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__31bdea53e268829e8e879c9443d26c3e1cf7dfbc5af6cdcc6bb9baf351be0df8(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__246a0f1e0b2fdff008574c7c2c833902a2f28f78eca9a69202047557f9762eae(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b5f216b57f35809d74e65c52e7a13cc49502e510e23b7e6996b0e97871585d21(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c5c578a524071d21c57b750a6688d25bd918d53953d865415f65667089c89b98(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__39d24200a417dbc8c11b7f01b9515ed0d71c716e721bbd1b94dee16ecf6f52a7(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f504246856e6a8d8192706ddb8fd90ed39be8a851e824d9261dfef59f73c2963(
    value: typing.Optional[PowerpackWidgetChangeDefinitionRequestQueryProcessQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cb8bb35a6d2779aa59f82cb8360ec0080da8329b0208d88c7f94acd3dbb3391c(
    *,
    data_source: builtins.str,
    measure: builtins.str,
    slo_id: builtins.str,
    additional_query_filters: typing.Optional[builtins.str] = None,
    cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
    group_mode: typing.Optional[builtins.str] = None,
    name: typing.Optional[builtins.str] = None,
    slo_query_type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c04d9be88cdb3f912cb1d9d7e06c6436886283c8455f9f09e64c93ab7c93020e(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__800f9cb369caefd0b2a0625239e0b46375ebce83f332782a4f730676be8a9d73(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ac4810ef7901c3290949411944deb3db65b0bca4a8826fcf03aa20ed822111fd(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f0c0006cffc45c136ddb9746014db171e7e7b9996e48cf1653a1557bd7a71cb3(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__eca4ac20cc58fd337895a28d7cddbc535267f7e428635614667832792232e6c1(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__021dc8782eec0443772b6f52ee20dabecfa47389df02b79deb5d5152a9fa39ad(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__28c0d3793692df6501ab3312f15c47102b3a02206ae4f61437ca227445d1e2be(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__60a2599df9d7d3115e38f150fbd773959bd4744517dc26ff4e5dd81f34ed5ef9(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__22f2248d7ce8c3b7e9c48d8cf8633966b7a7240e7d539a20b2d8ad81d43b6a88(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a3b4cf06ceb8729cc3df0f5270cad8d60ce085df41f95c54a83bdb75193c966e(
    value: typing.Optional[PowerpackWidgetChangeDefinitionRequestQuerySloQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8ddf477cff25d6311e3b37939e2097707a6130120fb230528c252b2ced5425f0(
    *,
    index: builtins.str,
    compute_query: typing.Optional[typing.Union[PowerpackWidgetChangeDefinitionRequestRumQueryComputeQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetChangeDefinitionRequestRumQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
    multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetChangeDefinitionRequestRumQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]]] = None,
    search_query: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9bb15aaa41334c359982e126ab518b350c57ba0a52b039b6eacd6c2dc43cc2ac(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__106c518ef784eb104aafab486c01bbe37578c39a77768186018a283a9765348a(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a001d5acfa0eaf499a4d4ac3ec3dfe765cf21a27f06af8eadd2b4d3b2f331a0b(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bf652af3d89c072993d3b79914a7e0e9f0e8e0866adf765dfa5d45c750a72fb2(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d1e0729b91b6d39f5c912eef7afb845e069cae38e09094cf2f787aadb88ff1e5(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e66f1888d4da22a8d44edca3c98ac3248546f1af87540ca1df9d62e626868403(
    value: typing.Optional[PowerpackWidgetChangeDefinitionRequestRumQueryComputeQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__463e8e7655181b2971174d6d60afaed3a04212edb804725b24a6d421cdeec722(
    *,
    facet: typing.Optional[builtins.str] = None,
    limit: typing.Optional[jsii.Number] = None,
    sort_query: typing.Optional[typing.Union[PowerpackWidgetChangeDefinitionRequestRumQueryGroupBySortQuery, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__457afb2bbb73b9780b80342edd50dc23c00671a7fa59e163b8d406c6c5f5420d(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2ef14e2fc63fb318ce34e5f8f93d2917e1f02b05bf47e509976a2944dfe04879(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f3906c3c5eec1e17ecd416fd42842dc860c2667835d42b90753131f6fcf626c2(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dae54872a860256632c16ad55db980fc184a41f555c1af29d15d561524a15c53(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c2b8d8c0b3597f3cf2a0caefad5928ea58b8ac1330ad005f9c9fb82a861b4fb1(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f16b7b9b6f695c306546e3af2447510ad044fc4a3d3554709d14612f92ed2091(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetChangeDefinitionRequestRumQueryGroupBy]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7665082b6b41af3bdd13a9c51d55b8d81a3430dc28f417d5b76ce293fd1b1618(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f9b44ae418f326ea2d8bf08b9591637b98b78f716b547d4bcca0f08bf70657d6(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ea0284dcaeb4604f858414b693ae44ce187792ea703ee331a2de7516f7746afe(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2d26f198bd749e9b61578faa82aaa7a444edd493bdb8f6156a58320c3018b962(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetChangeDefinitionRequestRumQueryGroupBy]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__105f74058809aeef995df649e4f486a833633bdc18ecf9fe3379960b86ec96f6(
    *,
    aggregation: builtins.str,
    order: builtins.str,
    facet: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__43e80d8091f2c79471532a2a708c73b77cfe49a56638ca979bb7f561b9bd2369(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__47587309ce22487d654c848d95dfe059cd6aa602f6c104e58cfc6e25a0adaf39(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__55260b8f951f188fdc1dca8fef6dedfb7265d82b06ae8793971d95db72eec7af(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__63b951a1ec7cda1aba6db797e7b2b0f5451498bd0bfd86b5c1dfbed69404b4f3(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7fad92eec20846f5eee50ab7e9a732b2d07932f71c5db8c4e4c94b87fc65a675(
    value: typing.Optional[PowerpackWidgetChangeDefinitionRequestRumQueryGroupBySortQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5b16cd45b82d6366d28a264edf37390146c2204335e9438fa9ec3fef0bf279a8(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bc83a90ee8101061c45e9380f6634356e1515ec4f155e62b503aa96295067aaf(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bc3586efe98def580bd4995d091dc3e0634e39c64a213986476db68eb0f73285(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9ada21390c89f6bd083b93778cbc29aa53b560094e5badd115be9dc582de3787(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5dabfabd5b050434639ce0e7041ab9f5393a1982e82e39235778bd10d544b9a2(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__79858e687103db0014e3173f35b4e347f823a468a622436799960124c407a4dc(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4af3c8297934d1116865f0dca3634693386c39b6227c5726f463e74a218156df(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetChangeDefinitionRequestRumQueryMultiCompute]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__80380a95e8a89896edca96ee6675c4e1f38225b3e02579e37f25d21bf893dbfc(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6da0b5728b9b34829f3c0975d3431b574c1a63c70af317d12ae807c93c574be3(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9e35980c9942e41eafeb187af4146a3a6b03fbc7f138f63c85a4867a084d0c56(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c279c295b45dbc71791ed64abea81b6ab15df0475fe6452f20960d7fa4d7c7ef(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__55a0aa50bdbc1b88b962d59f40b845ea65bef4e451c59d2851efdb5fe7837993(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetChangeDefinitionRequestRumQueryMultiCompute]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ab2747b1ebc3fc902f5dc7255d977ff1e547476ef7d889e3140d64acb0279866(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f40992a5337aa2cdcf6af346664415d40cd4d923a608d9978e6b2d46137eb464(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetChangeDefinitionRequestRumQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__aea0f9029c4d36ab1cca4b4e69144dc98183c613d623f08ad44557ab1665344c(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetChangeDefinitionRequestRumQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9ad74c39e0383cd7e842d25a28b22ec38ba9d0e9c77252c99f9cc13f9750789b(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__238ae78b0fbb38ffd8e4a7f0e5d444cc54b6484d38a791a07e99be2c01d3c605(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__80690955ed6a52285fa7245a419014a8dfbe91a1d2ae94ea1734531caea72903(
    value: typing.Optional[PowerpackWidgetChangeDefinitionRequestRumQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__61605098fa73ebc9ca540ea2b509f8c4031264543127e09d88f11630995073b9(
    *,
    index: builtins.str,
    compute_query: typing.Optional[typing.Union[PowerpackWidgetChangeDefinitionRequestSecurityQueryComputeQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetChangeDefinitionRequestSecurityQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
    multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetChangeDefinitionRequestSecurityQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]]] = None,
    search_query: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__505396dff28fc5949d57837f2255f74c36a82c8018874d3af88db9826c2956d2(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__097267bc72f4528c90c640b4d2198297ccac2bbd12f64eda3569a801eb139e52(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7846ed5edcc107f275aea24c8d7c67fb15a2cf989cb815456d1f39059c93a914(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__aabfabb459843d661123664e654d99b7d34fb963ae329705b71adf74a5920180(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ad32a1ac61ebf7e9b7b30c72d02e3289df76c0b891b06e97500b5f0b0d5e6c93(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__49d0ce0632acea037a0184ecdcbf7e674f6d46c5566380d0b7e0a803dc4125f5(
    value: typing.Optional[PowerpackWidgetChangeDefinitionRequestSecurityQueryComputeQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fe94348965cacf648584d4e4ef6881027110d759b3464bd59da632c66d46a495(
    *,
    facet: typing.Optional[builtins.str] = None,
    limit: typing.Optional[jsii.Number] = None,
    sort_query: typing.Optional[typing.Union[PowerpackWidgetChangeDefinitionRequestSecurityQueryGroupBySortQuery, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dac8663d9fac6f1f1b8e65a49322328ea1eb379c453c8eb0f2c4962ccb02faa5(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__40f739710e9c3c49745e5c638785da4a4f812c48d9b519ae043171f29b254de7(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__504260fb504eb77357e5767522958e581ab27bd61b4d5be582271861b4efd7ae(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1af7293747cc134cc6c480d07b1d2888344bebaeb8bfc499c504484c23bd0c1f(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3756a49df6bf3a32488efb984e82c4abf961e3ae62897ef9a7902ec45e3cd15f(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3489be53bbe04a93a8d527901edfedcd6fb14d7d60601bcf48994f3bd24d0721(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetChangeDefinitionRequestSecurityQueryGroupBy]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c2345150a1741bc6c457710f41df032a7b9fa0c38506e49fa7bd514e4224083e(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__835061259ab7bc38427104ba887e158ead12b2665d94ce3479ce5146e830b1f4(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__63387e73105ecdcba938e4198fc885a0da25da012d8f9bd33a6a537b0e382e94(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2b1c1a69c6fccff79ec6f65fbb5151b652319f3bcb0fce5aa42ab81c62b5ed27(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetChangeDefinitionRequestSecurityQueryGroupBy]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__91dcc69537592db09e5ec150d3f465867981fd17847fd35c96344d30977f3ca6(
    *,
    aggregation: builtins.str,
    order: builtins.str,
    facet: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4f343bff2f44a0f1187f8e0e3934638996327e645df5cc8adac44e78c779b79e(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3ab33252f74f7fce3199b5604829a592afdb885f8b592d4d4c22fd2f0d0ecd57(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d79a58e8560fb812305464d02def890b04f9da1d93bd0f89cbcb442f3992a530(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__14f161d246c538adf9d1cf84745ecf5a1b99108836d75b1bb7d638815776ded1(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4ebbde209c11738cf56192fb1c0f172d04061e297acc555a6229bd0f17b1891a(
    value: typing.Optional[PowerpackWidgetChangeDefinitionRequestSecurityQueryGroupBySortQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__799f9c787fce417079d84583f9a8b36064f9c728cb268e5b92d7bcdab75ca496(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5925c020dd143d09e396eace4bb8932c3cf042f535103e1879eed358befecec3(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c0bf5c59ff79e4d42335f5e72cec3821764855053b23b67052118b1122bfa763(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f3d6894edaaae72cf2785378596666ef12c23a83daf6d98f0502b75ef72ceb0b(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f1319957b3c4c4b1f3d0abc406d3f520e8b912ba20f505b8afd19d46c1047325(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__06881403d63c54bab7e72d7e1331b9ceb73daef7edaa4af4553d3c4fb90fe20d(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3807abb51b1d9df2bbd03bce218d7152259436a011b8e032df20924860a3f6ba(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetChangeDefinitionRequestSecurityQueryMultiCompute]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5a10471331626f6aa10b7667fc69c5529184121769b53953c29c8cdb31716500(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bac3bcec4e4cd625303b3c2fe538dbe4d70cccf51536ab54e7dead52b9877501(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ad805537cfcaeefaabc478c02ce32ffd6ed6a3739a1379d1e295bfc84836717b(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ba2891eedc6f18925b05c8175cd6d0ab33f25d74e91982157be4a3ea692d6494(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b709f0332e1b7c4bbe65f32cb8495024d538478bac4b78c0989aced0bba26463(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetChangeDefinitionRequestSecurityQueryMultiCompute]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c84e74ac4df542cd6e194052fba24fed61ebf88646fdcd40495d928fec173cd5(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7f72787e5c7f6d7060a3f432ba34f1988919c8ddccd778149fed55bef48b4fa5(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetChangeDefinitionRequestSecurityQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fd6e31fa35b34e65781479bc6185aca11d91250062dd0484cb4eb1f5a93a151c(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetChangeDefinitionRequestSecurityQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b61160a755a35cc706f778de244dc69c79017169316657cfcc0b81cd4c40e853(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__faa123158a10d55a70501cf16039d1b29feafeb78c796b3227f7205c0189b6f9(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__130a0d78374d458a0d5eac0466931d225cd2ea1cb6b76145ad8d7d13cd53f97c(
    value: typing.Optional[PowerpackWidgetChangeDefinitionRequestSecurityQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a528e93f0cc550653ec796bc7526fa478f422c9335cd5345947aa306cf68ed54(
    *,
    check: builtins.str,
    grouping: builtins.str,
    group: typing.Optional[builtins.str] = None,
    group_by: typing.Optional[typing.Sequence[builtins.str]] = None,
    live_span: typing.Optional[builtins.str] = None,
    tags: typing.Optional[typing.Sequence[builtins.str]] = None,
    title: typing.Optional[builtins.str] = None,
    title_align: typing.Optional[builtins.str] = None,
    title_size: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__93d43ee793989fa2a8db81c509cb2572e5ef11d7abd8049ea6b780ce67118228(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3c4497db654a9991174fa6ceebfd21bf4e7c7d4d844af113d46a4e1bd4bad9ba(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d8277402ec49ddde1df7789cb68c8864f57045c294ca0b9963caaa15d6546d10(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dfa493dca684ece961118e85431d9953642c5a1d0a332c618b106a430f5ef068(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4deed43ec01517cb7316a9202002596bd6b937de955930ed503d2bc02d42bd07(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f6db54589e647e38cd1f24477ed2ecfa4350a996244b6cc64615450b342d88a3(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__eaf56d15101646d134ea7f7ba0348f917e58eea325a76c7476777e4511cbb490(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__19181e8ce498e1ae597c1946e8c32d8c18f6a7d6ab183558e139fa92efe8b731(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2f08053c041876a6d9244867d2edb0d6d8cc3f1f86cb1768ed37d3ad0479ddbc(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6c9c6b521c77af995be3bab711ff7bfd2849664d3f9256021b3205cdb983bc12(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1679f90d7c2b2f9ff166c5d1bdf2c7442c64df8648aeb36de0e9028961db4179(
    value: typing.Optional[PowerpackWidgetCheckStatusDefinition],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2ae9045fde129508dcf294cf60ea38b65cd817b1bef589093c3a4d80be3b66c9(
    *,
    legend_size: typing.Optional[builtins.str] = None,
    live_span: typing.Optional[builtins.str] = None,
    request: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetDistributionDefinitionRequest, typing.Dict[builtins.str, typing.Any]]]]] = None,
    show_legend: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
    title: typing.Optional[builtins.str] = None,
    title_align: typing.Optional[builtins.str] = None,
    title_size: typing.Optional[builtins.str] = None,
    xaxis: typing.Optional[typing.Union[PowerpackWidgetDistributionDefinitionXaxis, typing.Dict[builtins.str, typing.Any]]] = None,
    yaxis: typing.Optional[typing.Union[PowerpackWidgetDistributionDefinitionYaxis, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__159ed33343ccd05f450789381de5630b9cb1d41b235e0c9a1c07261554ad18ba(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__64874e1a6a7e4a582af613587a9c2c5ae671935ec7dff9a3f25cf94733c67269(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetDistributionDefinitionRequest, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e04c0aba1e7d20df55f0aebcdc2809597e67ecd139d4e22439aaf87132c0eb50(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a70598be44d069fa1ab554c3afbe8b9d3ced26b4bb73d1daf21f4436d4c3595b(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1869623e06e34b06ce8315fc41131eb929b1787c42d259474ad66e6ab87068ee(
    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__51c401e104999066ed1ad5a2dad82bc41b0741630949ea05932df381d5d84497(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d195da01ec723e537c215e901afb90054d1d2c6f668bb7368c27b301946147bc(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c349fc2c8a51e6b70e24e172da4df2dbc38de63fc6c7420abfa6111a2ff348c5(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__68aeaa1b8b53f63a3c97873c122f4c903701ef80a1100fdf14f46139e767fbc6(
    value: typing.Optional[PowerpackWidgetDistributionDefinition],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8835ac2331f04f4fd4c8d6507b2ebe3ae4519143e28d939b29e6d79f252cd5bb(
    *,
    apm_query: typing.Optional[typing.Union[PowerpackWidgetDistributionDefinitionRequestApmQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    apm_stats_query: typing.Optional[typing.Union[PowerpackWidgetDistributionDefinitionRequestApmStatsQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    log_query: typing.Optional[typing.Union[PowerpackWidgetDistributionDefinitionRequestLogQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    process_query: typing.Optional[typing.Union[PowerpackWidgetDistributionDefinitionRequestProcessQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    q: typing.Optional[builtins.str] = None,
    rum_query: typing.Optional[typing.Union[PowerpackWidgetDistributionDefinitionRequestRumQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    security_query: typing.Optional[typing.Union[PowerpackWidgetDistributionDefinitionRequestSecurityQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    style: typing.Optional[typing.Union[PowerpackWidgetDistributionDefinitionRequestStyle, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bdbf6f7f57d55857004970de06b5a08abffb17766fa596c79f2888eb98aeda19(
    *,
    index: builtins.str,
    compute_query: typing.Optional[typing.Union[PowerpackWidgetDistributionDefinitionRequestApmQueryComputeQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetDistributionDefinitionRequestApmQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
    multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetDistributionDefinitionRequestApmQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]]] = None,
    search_query: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1f40844eeadc18b24b71e1681fb1edec59514b198ff18ccc32b5cf4124c0b58a(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8939ac30fccf7e2475e6c465edaf48b440cfc9552478a1e7ed53a59b235720ed(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cce6c5310151eae09d5a90d33dcd513989d4a6468c30c87920a7fb00b50db095(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d8b9d27ca00851d7b12cb3d14c349348e343070192823db3c5e26ca81cc954dd(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__58bf99777a327f912a5e1e315f49725f2e9dd3db9ceaf1145809c313e67fde83(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c14eb257e888188803676538d4da26dffdd6816b8fb32b003c1dd40ee0be034c(
    value: typing.Optional[PowerpackWidgetDistributionDefinitionRequestApmQueryComputeQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0a3d54ce3b20308f65213a763bec26aae7472a9f88c03e3c8539686f3902d1f2(
    *,
    facet: typing.Optional[builtins.str] = None,
    limit: typing.Optional[jsii.Number] = None,
    sort_query: typing.Optional[typing.Union[PowerpackWidgetDistributionDefinitionRequestApmQueryGroupBySortQuery, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4c18dc4dee0923bc33a61e9e23b79ea2033b07b9faf2bdff3cd67b4924e30767(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c33515fde65ee50e07abd18b5a05f8ddeef43c26575f539007eccff472710792(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2980e860482df45572b17c91e594575bdb385ad949a7b2120ed77c90366f816e(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9c09025afedcde966bd7cbcc6dd2ad8ccbc926a1ad97ea92a94b19095eb78840(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__190f3a15e4759cb97b2eaaf437e83cc4e046d7ede50097b569cabf4dbc2bda48(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d213c6cebcb62a832489b597f3976f860aa7aa3f489f83de5fa9b5512199adc1(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetDistributionDefinitionRequestApmQueryGroupBy]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bc928e37162080f1aa6e90965c7e8b7cee3201e9f6edd9a985a6e1ca283e5092(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f982d3480edef8789ad93f2d90456ad15de1e90a8e7c2d9fd88cba20686eec4e(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__938e189e5dc75b9fec85df00858f597cc8ee51cab5b99fa586f625d73fd0fb39(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__15df13badd283666e603f64926dcd43c1c3db141d66470ed42fae8b769da5c2c(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetDistributionDefinitionRequestApmQueryGroupBy]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__eda925cc00b1182427ccdf4804780f06c0d487443a9144eeb5ebc60fc34dff6b(
    *,
    aggregation: builtins.str,
    order: builtins.str,
    facet: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__11761c5f5851c043c0fd240e89dbea8efefeeb164c688083ffc1d2e49b92a568(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7e76f2fbaed85bd6d187c7af8ca4f3e37aee1bb80464656ed25a1c86b1cc26ff(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b9788e4a1a7e14e83046e26062d48a54886c107421c9e830c73383d377cf0c7c(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f65f04ec7fe44d47d1139f8dab41d464cec16ae725f757171d85949b0b7167cc(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f1f855dfd9c38280d7a1e22a9173e6de1131c10efda5b17992abf52e7fbb6022(
    value: typing.Optional[PowerpackWidgetDistributionDefinitionRequestApmQueryGroupBySortQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3a5d29a3bb2f34b06707a69f9492cb0f5282bbf428d2bf4d2705479bb169df7f(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3a387d4310592bd2c2e484c531f5a81823dcb20947dd05447d160ee90210fe76(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c2055819bb84a31728a37ebc755210a90842e1161a92b32e66f2b7c8a6e6f056(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d06f62632bf879a8f5ccf46120af0d5272c88312c7fb036ba2b966652afbf142(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9ab2fe944b860abff7014668da6b3535f8c9957efda8c06ca759959aa5e28672(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d5926acfd838731836df8560caa577e47a0d59437849ee76637359acdee82555(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__aa5b648ce63d073444aa2bb96339c377ea797c8c57801f8d2a5d0c48fbf9dfde(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetDistributionDefinitionRequestApmQueryMultiCompute]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__652b14194985fdfaa7e284c3a41497376b618f7b3b2bc82d6eb4a61f15ea8fb6(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1a558475833627a6666a2711b656be231ac5f16a90a8a38cdf3891f0588d0f38(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__905dfc054c3d0b52c7f4a8a76ee93fe80280d6e2d08d221234c5e85e6f286909(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__570abf699e9a0ea62e5548332017ee3df2aae62080ef9e22f49d96fc29e3f0ac(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f2ded3c48f9390512c7999eda50fcafeaf112b702d71b30284a744c1e038da6f(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetDistributionDefinitionRequestApmQueryMultiCompute]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3b511a603221a8cf310236a69fbadb6f707267d8660795178a5ce7f34d8fd1d5(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1540f78868cc006b539b31bf8eeb9da33428baf7b9bf1920d6c4d5111a435c32(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetDistributionDefinitionRequestApmQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__111dd4a4457bda863e8b250966de75fb01a22981db1460875b507f847f7f4c12(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetDistributionDefinitionRequestApmQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__059328f2c65ce72994da812c3195b7d3c0af7a25aab6aceace7473cd1e61626e(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5385313704684693821e1263559f3af6e74abaad5cea953561f07e65f517c107(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__677cb576b70cd819229dcd6cd702146bb35e7d6a05c92c64f773962974c89869(
    value: typing.Optional[PowerpackWidgetDistributionDefinitionRequestApmQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b5d3d1fada991647302ad3453691352b9fa6138628677a9027c6ed7c1c2227a4(
    *,
    env: builtins.str,
    name: builtins.str,
    primary_tag: builtins.str,
    row_type: builtins.str,
    service: builtins.str,
    columns: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetDistributionDefinitionRequestApmStatsQueryColumns, typing.Dict[builtins.str, typing.Any]]]]] = None,
    resource: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6f40f10bbdc312b639dea6f3fe404c74fda6e95396308097b2ededef2b97b44c(
    *,
    name: builtins.str,
    alias: typing.Optional[builtins.str] = None,
    cell_display_mode: typing.Optional[builtins.str] = None,
    order: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__130e7a6f467f086a6778f325de982b38738ec62f9aa01652da383408c84f7946(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9138e89c30cfe05d4bee040d339a90ef0a2e2057327b0ab3597739c6dea4f2c2(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bc905fd71da7b56a4ef4774505e6e375eb2c5da31d3e02b1047e7210b8448df5(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cb27d5b93a406de25e0b6912b64b823b357a533958f51b712525f80aa59d7b3d(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e4444f4f57389db1c9cb5fc57c10d94cf8cdbcececd1228a7b12115f7b7033f6(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__785adb3fd2ed80f28faa1cb979c76142637ec2aecf559ecd2ba07b766a7e3d3c(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetDistributionDefinitionRequestApmStatsQueryColumns]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ebda67f1bcb23129a9f06587637634047c5f76c88d1fa5907db918a00bac727c(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1f41ba022eddf78bb64b63e44335ea99d02ff28e273ff55be4273477b2d392fb(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__68489b48d09b12a945357223ffcc67be99097c4708e2dbd87ef0ef6d789746b8(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ddeebea026b89e5937e5621bacc38ad8863bb9ef95cf9d643ee709aad3974148(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__35c0c356e446c37d869b07d18ca9c9c5fa6ae2df79ed2b6c00ac3da8fb3b48f6(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2f20586d107d4ce6df0c48f91adefb2f4aba788842c57c216fec20b9e4f83880(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetDistributionDefinitionRequestApmStatsQueryColumns]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5ad0b35fca28f1bd6e28879ef06ccc2fb5d4e62de34f8d59aa0cda6b9cdf0c89(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d90113d197665c5304e6f5013c9417b4aed7925e82c15ce0dec7a44d8edd908c(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetDistributionDefinitionRequestApmStatsQueryColumns, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d3f98f5417adda48bb44bcddc05194393e28cb000ca08062825d48bf6a8ffbde(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4de0aeba6cb40e0bb41172c2fb891c5d900e91aacd13c6f6d7b6d7f1f106ad9d(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9ed0e2bedc9be93b9fecbddf33b5b1d2032c154ce984cb49e44efa833e5ab681(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c37f99a4425f89051e59ba35ec63e4cc211d4e2e16dc3d34637c27d717755e26(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__38728057d8a6cb6d421ed5b2e59a609c99a0b9efe392b9c9b2da1a268ab42ea9(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b50d5732091189b1304d96b87a803cc5b1efc3163e2e2bce29d22cb15a3390ae(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__430c07847a97d5045669bbc6285e1bb3c0e20c01a1cb92354e5f0537b8e18b36(
    value: typing.Optional[PowerpackWidgetDistributionDefinitionRequestApmStatsQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2ceaa207079e8cb96ce5f603c6b82a1b173865a929dff588c1ac8e58cad49ca3(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0df61af8700cfe802858e581810b1346ce646bca151dc38d7259636552634722(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__32ad7d15498cbace7a962086a836c95b5aeab359a77e77b589a9bc6871611a6a(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a3bf1da642cdd20414af6ce8d97668cb4ac8615ba864afa21022385f830d08ca(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8ac074ba6d711811ddeaeb23d7d7244fe576605da8e4049d8a22e9f35a5480d0(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__23b74bfdfebe0200c2e06b8b8a2f2cfa590438217065edb72d119b8dba487329(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetDistributionDefinitionRequest]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7a7c3e89ba648bd3a4bfca4454029a4f6f6e3e57565f72bfe9d1bc91dfc443cf(
    *,
    index: builtins.str,
    compute_query: typing.Optional[typing.Union[PowerpackWidgetDistributionDefinitionRequestLogQueryComputeQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetDistributionDefinitionRequestLogQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
    multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetDistributionDefinitionRequestLogQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]]] = None,
    search_query: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9809fde5b5d7fe5ec779f0f67ef3e5d592cb05e5fbd4a3e33844d4ff3811cc48(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__19e3ee3d92fdacd022fd6e196cf48fe425da88f2a610e48df501ae89561a50e8(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bfbee9e742a9bea7b1d09c5b680ae6e84b1026afcf142939c6882fb6270d01d8(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5389faf8503d96fbb37a86f653b6856758129295d8c414df6a0630fd7a128e1c(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4879559fce48f6b941002f7b7647af03236312bfc7c301a5a184d2941fba5f69(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a59a36d9a0f52ea4621cce5677e0a3c718f92a87011cec4c5f8117498a8e25d4(
    value: typing.Optional[PowerpackWidgetDistributionDefinitionRequestLogQueryComputeQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a08c98a331e33fddc9a415366f8dbba5820b4f96cfec7f9df71a0e01095bf1cc(
    *,
    facet: typing.Optional[builtins.str] = None,
    limit: typing.Optional[jsii.Number] = None,
    sort_query: typing.Optional[typing.Union[PowerpackWidgetDistributionDefinitionRequestLogQueryGroupBySortQuery, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__821461e22daa03fb23513c12c09b62f70c06df250175502577b96410767cbcc3(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ec8bb2c5fc4e2376d5903b42acf27265fe7109f6ba850c794df11cf376d615b1(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3dd8dfcf795886b01564bd853738ca9ff08987ad97dc22bc7fd2272c414685af(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__05a7a2f37693f5986b7f46ee7b6f72d1a1796c6e021bd1f11d035c96a03742bf(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a81d809853a03fb4f34f9154c915afada5c34bbcebb8db2135fb18457804cf7d(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__af9a15a5a6e05fda813cfef2d06f93cff7422543ca00527ca7a37e82ca12c0aa(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetDistributionDefinitionRequestLogQueryGroupBy]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__12f2eab310ca8338f225ff5139229a599ffcb819b0220e4510afa3902bc2a1db(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__336c3c5cd0d601ec775de32331d01c975ee7312ca10425c442618de2bde24b28(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__65971abeb53e52a2b8106654cda1123cba3260777073098d671dd5ee5ef320f0(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cae283f6da9ad5ebbd010e36581c2ea149a3c8763d04cbdd5dd2c13a88c29ef2(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetDistributionDefinitionRequestLogQueryGroupBy]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fa805ceb921d4d2508aa38aad1877e1bf1a34b7f02a7e9593584fbd61d88615f(
    *,
    aggregation: builtins.str,
    order: builtins.str,
    facet: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1aa7c20138943c84ce1c6965f5fe64c5581a3597b1bd4bf494a415903c9f9e60(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9a984ea281ec4f7ccf1694e2587353700e4f84700258c2cc805994015485c59d(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0015986bc4c07e8f999fe62292fcc25187556b67d7c06644d23ac1ab08d37d08(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d6f9d4d860a13af1dc87f94c7c73dac908000ad88764096517f0186076aa18c7(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__38f4667147c13e06f8ea974ffe1507fd7b33479bc9768993f198f745fc620ea1(
    value: typing.Optional[PowerpackWidgetDistributionDefinitionRequestLogQueryGroupBySortQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__57d5ec03937cb38539cc7cdb5b983a9c8b7bc7d9736d057ef294db5ba691aa45(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__14e8c62f04c9036dbad2854ef1b261f32d3052e9f6c30bbb46fe983739a6d74c(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__09402740356318834ff592172e93479f855da4c3f5eb95504acc503ca3a7a656(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__68c85e90c79551c47d4bdc2dd76632a154de962389850bc43d155775d55e265a(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8f7632e47702d20dcbc67b326af1e88d1e0ebf23f0b5aa21001892c2d0ae4a2a(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4dad1f48268da045fee8cc3824262e000081e6487a71b45ddbe09a9e453417fc(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__52ca00e9f78c2e22bcf328250c63ec60b10b10196bd7e55b5b7078ec8c384268(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetDistributionDefinitionRequestLogQueryMultiCompute]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c857a164bffb2b86359f50f06b0bc86686eeae6e69f85ab2ef5b1278dfa0a600(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c4fb117cce8b168f66a0db08a22d9f8f62c6080282b5213855de69747f29a695(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3fb9530aa5989e0855b61fea0a4a1c127d050e7885d0a87ed73d536ec4d35d17(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b940341a8b2b9235a743949afc729b55039234acf552e0e64af3c9cfb4204f3a(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b45af1f544869fa098252c93c1091e333dd32b959423df002ee6eb9dd4b743ee(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetDistributionDefinitionRequestLogQueryMultiCompute]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e0e01dce369d1e57fb083122e4f1b3fb4d7f72dc3dcbf0b49b7e2562875f3ec1(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c07aa186d907304e3e808d27a7b49dcde13ac8efe25c3c66bd67c09b5f348f40(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetDistributionDefinitionRequestLogQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8f80f1fec246ac95eebb2276665a7e720b0bb293b84f924fb192d395fde96778(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetDistributionDefinitionRequestLogQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__101248d76445d68ba6b7463d4e41a646bfa53e87e8fc9f42a5ffddc88f8c504d(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9d1af9d92e7a31b378fa623ca8e56a43a5965a3b49eb9e09c81f7cb0a61e9bc6(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1e8d16e0ce0ddece1794872aa3e569d40fded5c5c74a92911562ca2d5dfe3b8c(
    value: typing.Optional[PowerpackWidgetDistributionDefinitionRequestLogQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d1f0b798e2f798b4f5d0cd74c8933ce2be28a71bbeb57240022fbe6e869a40d8(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ce3fb5a5720818e8b76eef4faefad2bbd334ad5891fc2c474990b0ca1688f259(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1de13a6ff42be381e58e52fb48531372ba9eb9d84e3b5c184a348191aacb6409(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetDistributionDefinitionRequest]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__858d568179ee7dcc94a9b4230a002c749201d1e056f18b91e8c0eda39dbc0fce(
    *,
    metric: builtins.str,
    filter_by: typing.Optional[typing.Sequence[builtins.str]] = None,
    limit: typing.Optional[jsii.Number] = None,
    search_by: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9c768d89594296715f30f8234d2189821857d2067375f456d817c04ea4a88738(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2ea1a209eb269207059406d2a1bd6c255b0c7e7af90ba4ed3dda77adb80b3fda(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4d1e884077f6106acf004f7d780a4ea743e556ee3d6ab081c71f85e9da5be51f(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5bc5548d08952d3dea786084af819906cf82d2b008ae5c59b13b4650d4215e72(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ba4c7b692accc5c9f8a596dddfde6e3795a051aa4329c1bbd0373442a82afdca(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8be2fd0a9d9400c13a36bd991588fc810f414736f2648041637c1b09c44eb68e(
    value: typing.Optional[PowerpackWidgetDistributionDefinitionRequestProcessQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__926697fbe4dc4e3a6770e098cc84c811a53e4f1db653834444774c027e7d7d8c(
    *,
    index: builtins.str,
    compute_query: typing.Optional[typing.Union[PowerpackWidgetDistributionDefinitionRequestRumQueryComputeQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetDistributionDefinitionRequestRumQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
    multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetDistributionDefinitionRequestRumQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]]] = None,
    search_query: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a36466e0da031c01cc143588b8cb61adb94329f770c9aa8c44916177b5329455(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__be48d889da7d4a32af71592139c8cef3db3e49478dab924c18d9c8559dfd5ce4(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2c130f9f6fd7701799c5cdfeb6dc840f72f308cac78b3106e0e6b06a7e461bf3(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1ba8a0fd6c1d1005c166105087d77f12721fc2fd16468edf88a16e682fc047cb(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cfeb69259ab7760167a18ac7a79dfc4e0edbf2ad443bda2bf1ff4ce399ad976e(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__de5ef4b0ac1d9e75da1444e877e9e09deaa9138e7603173769e224d647a71488(
    value: typing.Optional[PowerpackWidgetDistributionDefinitionRequestRumQueryComputeQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4f6e15e080aeed35b87dbd4a61a1a90d42a61a3587106aa04023c769e7796e23(
    *,
    facet: typing.Optional[builtins.str] = None,
    limit: typing.Optional[jsii.Number] = None,
    sort_query: typing.Optional[typing.Union[PowerpackWidgetDistributionDefinitionRequestRumQueryGroupBySortQuery, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0b20ec9b3e56614a28265f7d4cb919ff660f90b9697767d1b2ebda15c4226d97(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f07d3363a275024c44d3ecfc5dbe8becce6e38f83db34e512a2cff2ff1c0d338(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3701985847313987a55d7dac94c834b8b3f7d6bd077c9442818803e99e8ec91f(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__33538825c340f09437f190fe286b4ad9e4f9a036483b16f8a147caae67fd9b81(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fb2d64e1b5368a09f3bc24cffc1762b48bb28f931792912a9fb7283825b11494(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__abed16f1e61e54fceaed8ffa97d0a59f985a9407cd610a0cc391accd646b6879(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetDistributionDefinitionRequestRumQueryGroupBy]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__35825156f53b0f43a787698c77f01b5c9a20fdb65e9cb6bc11e9a4f2dc8de26f(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4bdcd8aa7a3b35c353d954e2fd45b5a6cc1ec16e08f28d4e71e1b8a2501e5b83(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c6986212af8c8eee49bc224002df81b8aa5ad849542c8272c5b8bf539f039240(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0ab8340a2e7b5dc8e0fb848228c7d777f7047be1032d0fa83e13eb695572766a(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetDistributionDefinitionRequestRumQueryGroupBy]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c7c88dc5d802609a96418adae6df0702dcb6077474beb74ad19ea14f2ecda04a(
    *,
    aggregation: builtins.str,
    order: builtins.str,
    facet: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8f27d737108ea2f7a8dfa50e572306f25ea836bc961d3ad394c1dd58c4a18cb1(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__20b7e1b823a424991c05e9820be86f0cf4e55822d1014cd73a6e8bf9b0067c02(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__72eb783ff5ecb7bb1a2a95db42718ae17c6a0932dee877e51410cb76afb0e684(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__08ee2c92972bdfb6e2cb5d1eef0176f8b73f30426ea37dec88b45cdfcf0714a7(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a1b069d72a1cd2dbf48fff1516328860492ee693472bac7516cd68e42d9d2669(
    value: typing.Optional[PowerpackWidgetDistributionDefinitionRequestRumQueryGroupBySortQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0f3d1ed45cd0af843bdaaf05a28b6628ca7129e7484659316b5072387de6ab7b(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fa7e129388cad5afa21443a6b7da53c7c2271ef714ee5997062a6c4648c44dc3(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__150870c56ba2fe0553f341c41b5b022817d9ac0748975ba7ab9dec0c4c7edbba(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c5e67f675d90ab2ed2c757a39e378c01227db7dea166202cbf367ad5b8e22933(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3a3928f15de49231892106d0fc29ef68b83f1628bb9dcca26b5178ae3f070d68(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__011134f4005a57facd3859bf4c7af460cc32b817b0217849d028116013471584(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0fd780dd369632ec170f797b02bcb57657d4a9a8a8412f8c9db7bf64c24f46de(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetDistributionDefinitionRequestRumQueryMultiCompute]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d31eb88f18d3828d71135dcd0b1c8d6988109d5962f12a40ba65c0bc2b47a8c1(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7ea1c0b50da18f74e4cbcd54f9ea13ea9daaa485aa4e35e6e550cea7f8cf509c(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dcad637f65d5590c3f9e36aa8d4ff727f9c0b5e1add2009c66d22e69ef218ff8(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__93d42df763df64b562fae1c9d1975078f11e39f918bbd2ec42463be23c8a45ac(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5c20babd0ee8c7a93c1ce9d0ae9b8c6f60390ee2292be1c73cbe44867469a009(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetDistributionDefinitionRequestRumQueryMultiCompute]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d007d172b30f32802392da8874e6d72003ca6428abed316832a860068a6e5b21(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__91f231707c7faf9a7147ce8582e27c23a389dd2c783e345d4855138e38732e3d(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetDistributionDefinitionRequestRumQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__700a744eaca4a44c02036f25bd4d66e0a939f2c9974bcac52db658585ebdd00c(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetDistributionDefinitionRequestRumQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6c53bcb6bb3b3677e2dc95bc1ab24184a0eae226abd7460b701ebfa3636ec24f(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__13364d0213b1e20bd31d09e9fbeefef9fd000d54ac4aaf0a3895a9e31974683e(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__81d8cd1dd1f244d93e6d82556c926e5a71f4d780492035b9a71d4aaee25c0b36(
    value: typing.Optional[PowerpackWidgetDistributionDefinitionRequestRumQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__18b438204bbb9c67b755e0689bff80d14bd1bca2174c5e8be1ceb657132bb481(
    *,
    index: builtins.str,
    compute_query: typing.Optional[typing.Union[PowerpackWidgetDistributionDefinitionRequestSecurityQueryComputeQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetDistributionDefinitionRequestSecurityQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
    multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetDistributionDefinitionRequestSecurityQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]]] = None,
    search_query: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a7b2fa65664a7c4246f32ec95247500fdd1baf0e91c0562743f3055ede9b149d(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a3c0ab89a67d86259cc74f4970ebfaa7f839b539a74562e3f35fff157313f81b(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__79f34b5a6af482f30dd7be8134fef71900060e1becf3fcaeb006ef48653b1f57(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1419745fe2f740d074fb0375710cfeb1ce826035cc5c06cd13f958ea4a754ee6(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c6f8c8c58ddeb7ebe1379498538db3a9fb644a850745409488bfbe5228daa6be(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__98c5ab67d26dbb42df2bcd9fd1c8be2445ae68d8136290989a85c891da06a15f(
    value: typing.Optional[PowerpackWidgetDistributionDefinitionRequestSecurityQueryComputeQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6be9e50504eb1ce8bd82e25b81c3ee2ad45ac452eb2d0388a29cec7999af8423(
    *,
    facet: typing.Optional[builtins.str] = None,
    limit: typing.Optional[jsii.Number] = None,
    sort_query: typing.Optional[typing.Union[PowerpackWidgetDistributionDefinitionRequestSecurityQueryGroupBySortQuery, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__349706f736d32eb316da264ae6f3b1d5a511e51c817d9878cd0ac37fb3313b42(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0472149051d58ebf143ce44e4ea1cf8f7479831fd7687139782ea9246d21b7cd(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c9e360d8cfc867faed4d9861434a1df8a52238f2bdf95cf4f70d802f09afefb8(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9173e986922abbed81b263f7ffc9069b405acd7f7dad4a325d04df1d5b687ecc(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ffb671c19625e9f94a0f4855d4e6ad51bc3df03e26204abeebde98f6bf1f7e60(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2d8fdde895b9381578e8e9ec0d07642f02c35e412f5786cc2a7026ba615f61bd(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetDistributionDefinitionRequestSecurityQueryGroupBy]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1890092036ae69cdccc26f8425b90c439902168dcb2d871b5d0714318f78b50c(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__60422f6dbafecc449d1097dd82531d2091d83a986e7cf3cafe7ee329ad3412c3(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cf3f74ceabf136d6404e15dcd1e7362cb700ce9ef1d53e0051438378e05e167d(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__52d5c17735f6aa3576aaeca668ca9db68c1d5c7f505322163fc60f9a4e3b6f3e(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetDistributionDefinitionRequestSecurityQueryGroupBy]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__aaa98e948be4433cc68cef9364673d486d24971dd8be50bcc3052971003634ea(
    *,
    aggregation: builtins.str,
    order: builtins.str,
    facet: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c533f1062730cbb3d82ddc0c6c5f98b44d1f709903860db8620c1f5161b699ee(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__69c750c6c50f5c056f7ca4e4d410043a3d2040809b5189e8fd383f1944f63035(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2ec50e5f573c91d63cfcc598b828b014ea5730aa4102d95bcbecc3baaa775694(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4e5e201234e1d4c84c4354ded6cde22ab65f8a4ca6f6522386716899f7660b0e(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2c663b04a390ec9258bcc3434db707408d42e0319183ab57eed7fec1614c0b8e(
    value: typing.Optional[PowerpackWidgetDistributionDefinitionRequestSecurityQueryGroupBySortQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4165954ce5db1dce2a9910f13a3811e87c256cd5e74174055de4e3039604ffb1(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__517979109055766ea91e3a2970a829df9223c05d2e7634ecb68bdb5108e4d956(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3c1009e58a397d117e351242bf74de2da3476e801f59f0d1ff8f9d5927b74c3d(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6897fa1251de7ec7db20ec2eae2d6914c2368b7cd346cd96114c13813f41878c(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d262e1cbb5b48a74e95f2b62bf8c790a81f704281a5878289265d9686cae4b75(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5d940e7781362288d982e06eca2b7c5a5a9fb8cef36c101bd266cffc079819e2(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4e584269c40290cb3e74c4420832172c4640cd6e5679640ac79e9162ca5d9453(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetDistributionDefinitionRequestSecurityQueryMultiCompute]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4a5d5438c028dfa1d3b3b0955b1adbb032a8548464857116cfd0e66da10dc080(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f396cb7f00e04facb03e05f645afe34e1c603b201542dabf2f47a6000da24ee9(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b3e1e20577c679152037d873f6b9195a8b2efcad861bd5acf7c131cd303d453e(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__90d519a8f40dfda253a4eea44d3c4b8e9887e9a614aa77062f05e26b4758f990(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b7aeab96324b3ff9733a452a9becfa98d4c3eab183744d105830f69a7730df6a(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetDistributionDefinitionRequestSecurityQueryMultiCompute]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__74850e37078b8f54fc287c83ec2d44cc9d40050d83cd800078ea6bf9a0c24820(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__aa84505deac529c73ac7db4a2b58cce5cbe78938e459035aeb67327963484d03(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetDistributionDefinitionRequestSecurityQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__480649b730d6b212a519c8ed1278a35667da87917feec1a83aa15d9756a3f9ae(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetDistributionDefinitionRequestSecurityQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6d87a2c115c76acadad02a257e7327a62ca8617e29c4d980594485f2f5a014cc(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0b256754a1ee7086d74ef6eb938e8e6767ce9b29dbf1b3c020963e27a0ea0280(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e7e1dd8bafe4d259e2160f3f9c2d89e0e7f33fd68c18301ad0dcd37e25fe2fe8(
    value: typing.Optional[PowerpackWidgetDistributionDefinitionRequestSecurityQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__50ffd422e972c7dde1bc38bddda5cf46a6a6c43805d639c3a6853c529a204ee8(
    *,
    palette: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__84ae2c6f43c67dc37781a9efdcb8810cc31abd1899b19a4a978e89eb7a8688f7(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__90e74220d9b746f368b759b24f8a3a136f552e042ea7bd1668e14d42c98f3de5(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5e2cd8a6d23190cbeb9654e49b83e7a4a3ed70819c971a7d886c9cda9077bcc9(
    value: typing.Optional[PowerpackWidgetDistributionDefinitionRequestStyle],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e46ae4d309128c0505ed2b343d37a9452b4d7e1fc630170cf8c1cabff6ade60e(
    *,
    include_zero: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
    max: typing.Optional[builtins.str] = None,
    min: typing.Optional[builtins.str] = None,
    scale: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__70b16a842527ba295cac1c08bab705fd9745b5e313403471512a8c94c39a8bc4(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__503f224bd73cf309edd90716ca6548d49b6ce259c9e350799897b24ecdf8fd73(
    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0b0b6d5b29d3c6fc5b1ee6f56d1c409344e0f43c4d56c494fc8bd0e42dd205de(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__34787269caa4d458569d051c9197c1651e560373436d94adb693f91cfb8e0087(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__37902f5d45bd8561877f6db8976bbb04ef9b5342553c3dd9655934726e7ac843(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2d214d91d2c9a0764b662f8a02f3317878bedbeed0cd2babe5667d0f22d49357(
    value: typing.Optional[PowerpackWidgetDistributionDefinitionXaxis],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6b263f29a1e7e9d112f5ab7421eb37a99475069c8e8488bb221b98b6e7866de1(
    *,
    include_zero: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
    label: typing.Optional[builtins.str] = None,
    max: typing.Optional[builtins.str] = None,
    min: typing.Optional[builtins.str] = None,
    scale: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0e91015f7eec11d52b27694fdce9dad84d6a97395d694a94376c50ebe45e0125(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e4d877de0340e23e7696f2c46ff671c7e415ef69bfc98bb16be87955320ec57d(
    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__db1e2d15a3a8a3c6b59e30af9a61f90ceac039feee442e6a292318e35b2a8686(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b23f6950d651d228656329863c493c022926df9166ce7687c664bf36b342dcc8(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5745822b431561f0e0fa899d9dd196808845bf53a9b937b0c9f30f4a8ad3b389(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4039f5bf8b7510ea9d6693ab163a6f425dc126d889a99b4ec6eeac12f08fb49e(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0d5a5a679cb06e223c1d0f61be59ab17e5f6894d0cb43074f44777ee049bea9d(
    value: typing.Optional[PowerpackWidgetDistributionDefinitionYaxis],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d30e8788e11b9947f7ae095c375033143139482eea4d11942a6a6c2c87c65f11(
    *,
    query: builtins.str,
    event_size: typing.Optional[builtins.str] = None,
    live_span: typing.Optional[builtins.str] = None,
    tags_execution: typing.Optional[builtins.str] = None,
    title: typing.Optional[builtins.str] = None,
    title_align: typing.Optional[builtins.str] = None,
    title_size: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__13ff6fe32c70408d64e651b7d6ec203f8d18118647c57836cedbc9fb6d2125a6(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a55709921d655295d43cbf885bccbda60c8c5c57adf482ddb6a93192ecbbaf82(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2af12a3f3e4e0b35eb2e50c67ccf2b817d17c086ea1c82fddbbf530469f54cca(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b0e417b5aa597e8ed7dd2a1d13eb71fbc292251fc349d4dbc2ad04266134f614(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b42007a4d196dbba4acf782c36bc55e7e4c17981d0fa649a3beddeec0648152c(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8195f04cca70a759e568709561dee6a5b58728b8fbd950f280a2bca1d2086b31(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__081f1bde62a6fbfdeaa2ad7976be9af21f3eea5eed156a6ccc5cd49c17e9f1fa(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cc5e2c5249872d03cd48bb39d5618155c41af254d7bc290a13300bcb3ea91e4b(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d9a99d76c66efe9fb661aaf65a3cfef3c45cd719776bcea27b067e8a8ccf48c9(
    value: typing.Optional[PowerpackWidgetEventStreamDefinition],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b33b161f7d0faa2f9265e51b8289fa15571a5bb91f144c8bd46843e422b2ff64(
    *,
    query: builtins.str,
    live_span: typing.Optional[builtins.str] = None,
    tags_execution: typing.Optional[builtins.str] = None,
    title: typing.Optional[builtins.str] = None,
    title_align: typing.Optional[builtins.str] = None,
    title_size: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8a17342913a0ffc25bbc7240d4a472596c42af0abc868cec9cbcd433827a94fe(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dac0c2a02653bfc1beee78795d8d2ac18e1e1d19780880b6edd54e896d4101fe(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e520891e94feb5392839d28c4fae2de47a052a537fa65bb61b79f708d87e8f06(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3cd9d2d48dd95b4bcfb13a444a24ee4c4437f355d9c98a4a89ba7abd18de4da8(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c07ea0fafe36eace801cb9934f6740fe995019eff17916b0d81718d85e606207(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6e0de2bd51b986937a41f84f7678606fc19dfdc61b6ae86adeb80cc2ba8bd063(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4449565980bc7d3038aebcdc4e0ec2d64f17c5b51040cc12a62dc52a3a2d58b1(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2b7682cbe9ecac80383c181b00c069b299a0d728188feb20250669cce2fedaa8(
    value: typing.Optional[PowerpackWidgetEventTimelineDefinition],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5d310e3edf74d36f114dbfee47b9928a7504b3c04837428aec2ebc00d84138c3(
    *,
    text: builtins.str,
    color: typing.Optional[builtins.str] = None,
    font_size: typing.Optional[builtins.str] = None,
    text_align: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__74626fb5baed17ccb620adb404ef583ee6f0ed44bb3a7eb9f9f1acee715a77bc(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1d37fde3b77326540c1052d09e3d931f7ac41a411c80fe7a3686782e80d1ed0e(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c8215a8146245a00b1cc789b983299204b036386527421f30b9f919c4280c1f3(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c99692ed53ee22d99eff5fa682c7171550b8b9c61ace539bfcae112288c549c9(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__03fe783f18ab0cb44857b1ee11ab9b294fa80e7663626cfa9185131a73cd58a1(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7d7eea9e7760a23c23d31fac426c0165edae0458e0bea9c40961595fec24eb3e(
    value: typing.Optional[PowerpackWidgetFreeTextDefinition],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__28a78970288e602f92ab6705d1445e0250349741f4290d2d818740c908f31ba1(
    *,
    view: typing.Union[PowerpackWidgetGeomapDefinitionView, typing.Dict[builtins.str, typing.Any]],
    custom_link: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetGeomapDefinitionCustomLink, typing.Dict[builtins.str, typing.Any]]]]] = None,
    live_span: typing.Optional[builtins.str] = None,
    request: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetGeomapDefinitionRequest, typing.Dict[builtins.str, typing.Any]]]]] = None,
    style: typing.Optional[typing.Union[PowerpackWidgetGeomapDefinitionStyle, typing.Dict[builtins.str, typing.Any]]] = None,
    title: typing.Optional[builtins.str] = None,
    title_align: typing.Optional[builtins.str] = None,
    title_size: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__baa5bfa283643034662a94f0b616c78d5e8921ab5f2bbc899fec08761f4fff2b(
    *,
    is_hidden: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
    label: typing.Optional[builtins.str] = None,
    link: typing.Optional[builtins.str] = None,
    override_label: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4fbd771a7d1380746e219a73f3983e07fd7d7a7f3c8b455fad4a56a97f4cc40b(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__52b43ac895d9ecc3976d7dddacb7156ee25dbfacbc107f337f739b62e98177ee(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2fa097c575a37687f0a147ab0245683934d952d3064227327d677d0b821fbe6b(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__437d72f8671ab727a19f86365c4c7bdd48ae73586d3caa3f3e4d3523349ee874(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2a989443b7f6d13e8b60be22a57004506a021df977ed823b6cffa7423611cb21(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__38938566652487b54c7095b12c2a26e7db9be8aefa7839017b29915f0730ba69(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetGeomapDefinitionCustomLink]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5fb2f3d7b30aebd153b8f7e2505184791e0f14b108d857e2b316961c162b8801(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__97940fc8e37a94881a4d92d931551d448e4a9e5b33eae4d41352cf3a0f77b802(
    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8916a42b891dea06f1858db207b8d2221f80983c8891123353cd7e81a98d817b(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__15149b40e8a53d7ea9abe9674a7ca1ddee821905002d401ca371870001757aac(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7314b64678cdf66a6e96166c15771407053b882776a2a476e0596e9f705e5a40(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f588891238f4375caac58d792e870f39fbbbf7218fc79406c6086aba7f77341d(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetGeomapDefinitionCustomLink]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c73401babbf294282cf6fe6c22691f1522150b3dbf1bffe806586edfb9829ebe(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dd872b76fb7f05ca467c39b910b8209593ee1c89878d4cc436b8085ca7d24d78(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetGeomapDefinitionCustomLink, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__aa032425c2efd15ac4ffba127b55c8406fb200be8eb36b00d47c932d16ed6f85(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetGeomapDefinitionRequest, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e9dc219710daf54dedfdb8d0d9bbf4385a3ce234cada3c09fb050d5687b607c8(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d3976940a8b0577a73a71b14485d76f2d64cc84806a1bcf79cb3205a15e5f773(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__01256fd7a68322914db7acb84083a87367d35f99b9668a4e4e56beb1208096af(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__813a6db103751ca7abb2eff3573ae250973b7afa150e2021c399190d176bcf72(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5c53e125331efb2726a0c7cdf717a15da1284650449f92ef65608e18201a432a(
    value: typing.Optional[PowerpackWidgetGeomapDefinition],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3967da8f61e586d027b178add1ff2f1632f617de6169b51372146422e48daf2a(
    *,
    formula: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetGeomapDefinitionRequestFormula, typing.Dict[builtins.str, typing.Any]]]]] = None,
    log_query: typing.Optional[typing.Union[PowerpackWidgetGeomapDefinitionRequestLogQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    q: typing.Optional[builtins.str] = None,
    query: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetGeomapDefinitionRequestQuery, typing.Dict[builtins.str, typing.Any]]]]] = None,
    rum_query: typing.Optional[typing.Union[PowerpackWidgetGeomapDefinitionRequestRumQuery, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a2ca853103af5e27c9da6944bead07a50df3162863d24b7ed5b65c855a4e504c(
    *,
    formula_expression: builtins.str,
    alias: typing.Optional[builtins.str] = None,
    cell_display_mode: typing.Optional[builtins.str] = None,
    conditional_formats: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetGeomapDefinitionRequestFormulaConditionalFormats, typing.Dict[builtins.str, typing.Any]]]]] = None,
    limit: typing.Optional[typing.Union[PowerpackWidgetGeomapDefinitionRequestFormulaLimit, typing.Dict[builtins.str, typing.Any]]] = None,
    number_format: typing.Optional[typing.Union[PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormat, typing.Dict[builtins.str, typing.Any]]] = None,
    style: typing.Optional[typing.Union[PowerpackWidgetGeomapDefinitionRequestFormulaStyle, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0a2b4c134dbe4aceceb735dc8bc9ebcec83f05d1b60b180a12a6440c15a3d7af(
    *,
    comparator: builtins.str,
    palette: builtins.str,
    value: jsii.Number,
    custom_bg_color: typing.Optional[builtins.str] = None,
    custom_fg_color: typing.Optional[builtins.str] = None,
    hide_value: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
    image_url: typing.Optional[builtins.str] = None,
    metric: typing.Optional[builtins.str] = None,
    timeframe: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6b654f763787850566c357e0068c11d36148d8b4cf04432de0adc608883513ac(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1c7dd894095c5932919f45b0de7ee93154cd8d89a60668fa3a24811ff5c13e7e(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__119f34697c4082006b6cc5e58460622d26031211c9498342087c402f57d347c3(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9d48a914b4f4e22e26073215dc3cd2667ea4f19ea1576083adf14f835d29eb9c(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c53470577932ed983cd40da23b1367a99c96c86c4b1cb2ddb3d0484eaa2f6d86(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b00c57f04767b89e98372c9bfddd592a0f8657f9c7f35e2284817a5f0260c065(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetGeomapDefinitionRequestFormulaConditionalFormats]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__987302ebf3d527506cba31f461c5e886926b9b7e2bcf2d3ad2a6157d103e71c9(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__28781a2dcef916c15d6cd36bce4375f9c4ad8dbaf41011b7d9229a41c0a952f7(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5d80be96070859d181b239dd293bdaabe8c9efe8db253181af4f7ff5d9183b50(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__930e4c3a729eaeb14da75630f6aceb2a7dc9b2dc12ca4041676cf0ec654667dd(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8056146fe376ee411dd1af35109a09a08a0034355c97e20dbc8632047e10bf56(
    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__941aa531b6ae232a85cf289a0f2aa47c2252c9e09b4da5a55cefbeb952d58a55(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__36ab8cc7111966e4915479f9f2f5baf87900b70a6639af6deadf64cbb42ad826(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5ec793a1f800ec394de8a810e88b7e74899087d45fcb22c13687e5e64477ffc9(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f39a7044d0aefd48e4abd8ba59007ead1b63e25924c40579cbf07f6a8ead008c(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__62aa599c0d79dd0f0cfe9ca3ed5bc931899bf2b5b88095d76771d8d50db5655f(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2685c769d7ab322b1e6d84b39c4f4d7460cfc708095a1e66c7e4afc83bca077e(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetGeomapDefinitionRequestFormulaConditionalFormats]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ad257f50ee33ebc1d0b70c1c8fc5ac4b55291db7b5d33991c34532aa6cddb2da(
    *,
    count: typing.Optional[jsii.Number] = None,
    order: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d08aead0b4d893f6d93d902097c5ca63ddd14b3a96c0335cdcb2e0ad9872fb25(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__58ddfe54b18b94fe65a1c607491b45bb92a4eedfe367ae8ed10a817f37160613(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__06bebae2a8b820dea5301b79de5bf42c0ad10362ef44e39203a656bfdd866df9(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b2e0001315d9d4a0ecc235b92375e97910007d02c26235af3f382e681451b684(
    value: typing.Optional[PowerpackWidgetGeomapDefinitionRequestFormulaLimit],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b1d2199ae74c8ca9149ac6dd104a85882cccb11014e4f6e636d9b3d40e7a1349(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b82f31292d07bbd61a8ce55a323dde4fab2de97d57aea37333059c5d51edd9b8(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b67192428f66e32b4e96e70f80e1a839ff93fc6dc81d572eb33f338614567f28(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__27c9e4e89039599cab010665da4a05e541a00a91ea5ee13d466dea5a6cb5b788(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a27a97c5eca1800c6b9035bf277885610cbee3d2fc2e93c0df07a0c7a9dae975(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__41a9a8791bb077c6a2c3c3b22d21eed28aea5bdebca4c0b9f24301456c5cb3ed(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetGeomapDefinitionRequestFormula]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0f35e895ffbd43c367c7968cc49002ad740795eb274b8254f237e910b3f1596a(
    *,
    unit: typing.Union[PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormatUnit, typing.Dict[builtins.str, typing.Any]],
    unit_scale: typing.Optional[typing.Union[PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormatUnitScale, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7b78ce913694a53c8d8ab69f142a284fb3ac1a0acad2a8613a460facd60f190e(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__398742b3f2f616aed4af0237c44df9cdcfbcb939be6022d824926696f23480a7(
    value: typing.Optional[PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormat],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bb139f26cdf7c24923a09ccd1f9ead3f4e78526385e3ad5539f5fe111bad6cee(
    *,
    canonical: typing.Optional[typing.Union[PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormatUnitCanonical, typing.Dict[builtins.str, typing.Any]]] = None,
    custom: typing.Optional[typing.Union[PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormatUnitCustom, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d2f8cd55698c9c9c092a61badd6cf065e9292cefb70e5a0d35b953bfa0229097(
    *,
    unit_name: builtins.str,
    per_unit_name: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__70e79e02486c53b25d50f13dbf21e4791fef9b16fc99609fc8c231d93fc6094b(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0ec7188f435a199d27f3ba4e73d2fa4f76a901b7189e22309afd618dea0f9e03(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b7af477c9e9843c02474f6f75433fea67d3702afc09bd71a11f04f4cfa3e84f4(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5d48f593ad3e04f6d6070cf54299d175bc80209e4752c98e64fd42814acc9dd7(
    value: typing.Optional[PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormatUnitCanonical],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__865b3766172380dc6d79676996b9038c9c7a2f5365a23826b322bbf715b3d1d9(
    *,
    label: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bd44c3d334c9f5c01698624eabc1062f82afcf6b8ffdbde98b8039b857701322(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__356469c56cc8be8acd8953ac46b05d739567e95c0590aa56eeb89a6c250b8022(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ad39396631fc75fc18abb225cb0a7210591f26f7f3ef16eb290cedcc474452b7(
    value: typing.Optional[PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormatUnitCustom],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__804e21f641f37db6c86431ecaa336634c58ae316ec21bf27315e495cae262886(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7901505f7f79fd60c42f1e890f68e8d3e0e36008dc1251806b121f01b29c6c07(
    value: typing.Optional[PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormatUnit],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9dcbbaca0a699b35db81843ec384721b24806b6ce0abc3fdd28e26c827b19e16(
    *,
    unit_name: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9e3555ca875ec41b3851aab4933cc511153ab648e654a88b2a4716cf5f97c80c(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1bd7ccfe758f12935d7448985a4d4f1ee7ea86a16be72e52f4c9d4a7475b57c2(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2b03b39e4dfdd831af0f67a33ee34e7146cf57c12072c191c67e6776f9356d03(
    value: typing.Optional[PowerpackWidgetGeomapDefinitionRequestFormulaNumberFormatUnitScale],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7a1c30581958adec7f3be59670b479787174e39dfa3d7e4c7770a3ca10f84e91(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__32c2f979a6287376b51ef755c3b006ea4b2e6836effa3ab47e842d8a2979ae87(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetGeomapDefinitionRequestFormulaConditionalFormats, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b476f988760164aea8af56ffe449b305fcd64ade856e063e3c8f50b46e88766d(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ed02e8034814e3d1c861dfa135f00a8a1dab7f170a23159af272aae6f08a6c8f(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__60cc2f3451146c9cf970c3126f346409ea865bf3e9187558b54a8fbe95ea7bba(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__97312d5f433f0bc134a8005b4aa3a93044a45fe1e34d618636cdc8672d81c426(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetGeomapDefinitionRequestFormula]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5020be501265e4bc2ffcc1d32d8673efd7943917ecba941f8a1baefa95cc72e7(
    *,
    palette: typing.Optional[builtins.str] = None,
    palette_index: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e3ccf8ad4b5d03e3a35632df53e0ff1538ac317c40edd7965d7c8d9fd282ac18(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__01d2389fc6b2abf8fd34b037b35922d7ebfd3ce425fee1b40d8554c7ad622046(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e5e9b2bcd615c9f6fd91320b41b606c8f3261482d47034edcaa29ec7b770f3a9(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a2c3b6d1e12b7dadcdb93d18da03601e47cf0eebc5d0ff962b381d73925ec6e1(
    value: typing.Optional[PowerpackWidgetGeomapDefinitionRequestFormulaStyle],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8b135f8efc8e098c4f42b78d36b9790404b4884294bc2384feeb128d8d68ca64(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1645c737f0bb86bc13d6432468f0cf1895f7538368b9136e40726c2513d3c0da(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3abf091960f1240870e42dad7f0d292305ad576cee159eb37475c1522169c35e(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__167187c962db71a82ebd803c9df23a08b1332ba9b65a2a6bca85d2e644055681(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6bac72b52959ff48e59956d75690ebb696c233e7ed0756f81456533536abe4f3(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__49eb8c109295ad0aeba6fec23d8edfb28c4476fd69fa83c7d829252f52b2f0a4(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetGeomapDefinitionRequest]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f3917b81f2cc782750313d64e5b589772ec140e25852c442882092bd6a282acd(
    *,
    index: builtins.str,
    compute_query: typing.Optional[typing.Union[PowerpackWidgetGeomapDefinitionRequestLogQueryComputeQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetGeomapDefinitionRequestLogQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
    multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetGeomapDefinitionRequestLogQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]]] = None,
    search_query: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e62fde3df52992afaf9dc5787ab4e90981c6b3b8e6f4e0e5ea7106041c3f3bd1(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5e79e9ff14268a7c2efc7773ed4284bab46d3f12a89d1a62d8b13e5068c73e65(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__706af005befe3cbdb4a30c0678556c6375099cab2837cebb0379a77f15819e99(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0dc461f1fb7b6dc9042e8e44f569cb4eb3fe232f1f96b1e407e1f0604e009a74(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__448c2d816005b7241ef03884c5ba6c06d7f533fa3964b62ddb3f4192d9ce780c(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__96ddb6079db390ee0717d5999dc0ded902cfbf057fc885a8db814ddb924e4f59(
    value: typing.Optional[PowerpackWidgetGeomapDefinitionRequestLogQueryComputeQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__38bbf8cf4b6e6616a0a97ceeb4e4065dcbbec9314de44b00c53ad686b44d2be9(
    *,
    facet: typing.Optional[builtins.str] = None,
    limit: typing.Optional[jsii.Number] = None,
    sort_query: typing.Optional[typing.Union[PowerpackWidgetGeomapDefinitionRequestLogQueryGroupBySortQuery, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7a40859f853d15c4f836275bb9335b40fba74d99334970e5b0ad6c78a0c906e8(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__136e5ecfaffcc731b154ee94f32f5b0e2e5f56e05a4ce1f5cb5a6553320327f9(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2d0ca90767612171294feaef88c967cef17eba9d1aae90adb2da61745f1f4013(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__075538fcca04c9b9abe213737299b57dcc10ff6f31785586b0e0badb5282a290(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0fddd65a685b1d092d0edd1edd70e48f26da0d37c14e214c939351b3074dba08(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e84336d3999fb0f634fc8df511e9285f367b84499c232a6225cfa55574bb04be(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetGeomapDefinitionRequestLogQueryGroupBy]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ae1001d053cdc7b00092f1c80fe40f953577495ea5b304b6d794087e7c5b6785(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b490d43d3f6a951b1522777f23e5dbd0a5f3cd9d0c6b841b84401c7aee350f14(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1539853186580aa78e6c5867c257789073b11673679a0fd55d984068daa0b6af(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1ba171746917fcfed1325ab546af5f65f235ec59db5a21e07f584cdd94388ab1(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetGeomapDefinitionRequestLogQueryGroupBy]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__19fa660d233a9f29bc4cb31a1784b528b55e1f512f01a03992154b2c954e311c(
    *,
    aggregation: builtins.str,
    order: builtins.str,
    facet: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8be2e2c2351adc8484fffa412f02f439aaac3e8c752dfb3c1d908646cc3c4037(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0f19d6f39ca1d9d6a7fcb1b7e11d79726640dd1c77dad8d76fb21f5c89d5071b(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e505c12d343faf4a478ca121fb7965fbaa999bc9d5fb37e423f91ac3d05cce5a(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8a5702b93a492e6403f012260e7e76693dbcce88b39aa89ef8350497aab98872(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a063fe7e24d76338eb9f954b09f7bd3ab23244cec20ec1172da193938c1405c7(
    value: typing.Optional[PowerpackWidgetGeomapDefinitionRequestLogQueryGroupBySortQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cea0cad7ec2595da67cf983d5a1acf926b43bcce5a50efb701cba4f65040cf54(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9c75169e6ade58ce126a1977e754a923c57652ff096b7cc60256ebfe868a26c8(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0970ea719b7eefa229d102a52c3c31e625d290e9d5306e812aac4be934704375(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f8a8393291aab67b4403435eb2dc2090686ca3200cde45c57b2a8679e2d1cc64(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__16d6b51f42be8fe56e5f915f278b0ea3a9fc71a9a204bc177686603d5df275f1(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__147d285ad41088850a62388b0278f82e24faff7a42e9347b3eeb552738b212ee(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__498eae70f044202592da8f4d00470558b6b4a95f1c0da33f1aa0c13e0ab45e41(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetGeomapDefinitionRequestLogQueryMultiCompute]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__40e7200e994d11917b4ae280531a66eed9a1058a76271eba70af9221f8b08776(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__761ced6c303e5f6aa7190071f973c3bd301d1af05a4fe9fe46a4afd3df44d675(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a48f25c3dfd80c178d6a576b26bad9c87516851c8231fb821b85639a967bedc5(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__43088cb8a95d4cb6d199daf581e723a05c668ce05c7b581ef74c936e986bcae1(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7fac72bc3b1628b982f04d2123225ad2067a0fc208fa0ffc970f98fcb4396c65(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetGeomapDefinitionRequestLogQueryMultiCompute]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3611bbed7a1ca2ee700287f4a0e235020d7036b83330a596c6224d2097b3d0b3(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1d8a32fcf61c26e49921fab6fb5cfbb44b1955fe423ce48b8bbbacf58a843333(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetGeomapDefinitionRequestLogQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__aab0023cba58e644a24a9e96aff9d6ca77f974a7eca086f1a2af246347d0014e(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetGeomapDefinitionRequestLogQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d466ac5b24647f7077bbb81d8c10c9e4cd87a661dc6e45e044a04e44c066dca8(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2abce68517a003abf118a57fd4b362a9faadd2c5d61b0be34839158a3e5597c2(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__12fdd0e8737f7b8109909808f38e68a8b9a3e40d4811d70f14bbbef83a0935e0(
    value: typing.Optional[PowerpackWidgetGeomapDefinitionRequestLogQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e31cf41ffefd2c17c35d491101263d2530c68694d75e373e74a13aadd9dbcb49(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6fbb79bd390f06eeb1ea7f72882b2d048bbea6835b8b3fbfa5ff556b645fae30(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetGeomapDefinitionRequestFormula, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7d666c5172f5830a54156cde53e0476bad55cc058d3b4575cef78ac4c2ba578a(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetGeomapDefinitionRequestQuery, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__63da8cf88659eaf13a2bb6e9fe26f656d1d3c29b7c2198b18c8240f2968037ac(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__be8f90ecc6b2241bcd21244a9808885ebe8d233d8985d982adf8414357358268(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetGeomapDefinitionRequest]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d6a4ce7b5e2a63a774fbb933dfa96f03018bacd87061dd3571826988b6cb4359(
    *,
    apm_dependency_stats_query: typing.Optional[typing.Union[PowerpackWidgetGeomapDefinitionRequestQueryApmDependencyStatsQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    apm_resource_stats_query: typing.Optional[typing.Union[PowerpackWidgetGeomapDefinitionRequestQueryApmResourceStatsQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    cloud_cost_query: typing.Optional[typing.Union[PowerpackWidgetGeomapDefinitionRequestQueryCloudCostQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    event_query: typing.Optional[typing.Union[PowerpackWidgetGeomapDefinitionRequestQueryEventQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    metric_query: typing.Optional[typing.Union[PowerpackWidgetGeomapDefinitionRequestQueryMetricQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    process_query: typing.Optional[typing.Union[PowerpackWidgetGeomapDefinitionRequestQueryProcessQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    slo_query: typing.Optional[typing.Union[PowerpackWidgetGeomapDefinitionRequestQuerySloQuery, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8010868ec37b4fdb2a17980472c3adf565b808d74ccd341a77b8b67bdc4d26b2(
    *,
    data_source: builtins.str,
    env: builtins.str,
    name: builtins.str,
    operation_name: builtins.str,
    resource_name: builtins.str,
    service: builtins.str,
    stat: builtins.str,
    cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
    is_upstream: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
    primary_tag_name: typing.Optional[builtins.str] = None,
    primary_tag_value: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__77f34c2c639357c374a390e983eb7c63f214ed9b3fcf4d7b85fb1c0808bc4b67(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__15827bef2b2753cb3ea3f540719de695ce2018ddaef9414081fed83a8b53c934(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__440a0498b637f0cd56d52d87ce36467a48f0220fd664fa61ecb7260d1b98f0bd(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__302470a5b3c4003d071313eaa7f864077d80fa0aee21ddf984029e3b0ba4c3fb(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__768751bb84d8c608fca957fcd1dfdd359faa96936f45b05e370a4742dd58324f(
    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__451c6ff4d5b29ab3a8574ed30ee7569f29651aa61d03d0efb0712e487264e5ad(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0f1a2065e6f850310124b4d94ac39fb352b6e0f3d61973d91967b66a79036c99(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4e938e2b6303ed3c756858489e9cad14993854969619154424d83533e82220c1(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e04f69b96a0a77b0551d1f6ba242a2ed55d236ac388d8a8444e83a98a5d9c796(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bb341c7f04d53306ecf276c543cf075fc8349ac26ae5d815ceaea280504c2755(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5144dc1538207c06a44fc96754afceb0dd96a38eafb54b7e0e26739047994d7a(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3dcad1828c7d04870bfff7c82871424194376376215be8219ed4d6ae656c93a7(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e734d99a1691e2bcee47cb122dd2e88e848422a969015c16b686ebe2d3aa9bcc(
    value: typing.Optional[PowerpackWidgetGeomapDefinitionRequestQueryApmDependencyStatsQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2c652cfa836642f21ba3d2c136be2c9a2b16d3eedd9bbdfb1a2a80caa97b7ef0(
    *,
    data_source: builtins.str,
    env: builtins.str,
    name: builtins.str,
    service: builtins.str,
    stat: builtins.str,
    cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
    group_by: typing.Optional[typing.Sequence[builtins.str]] = None,
    operation_name: typing.Optional[builtins.str] = None,
    primary_tag_name: typing.Optional[builtins.str] = None,
    primary_tag_value: typing.Optional[builtins.str] = None,
    resource_name: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__74ea168c0a421c2348f50d221068168c2e17f4380b6cc6e31a33a33c35be5ccc(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4b74cb6495912ea2da327d0a1384c9d4a6ab1c4ea3d2643ce6ac171a5a915fb4(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c9fcef4440354a9b66221b4fede7d5df25e7254d58615d7d99bc8936e880e77c(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1b2eb46929d7a9510375afc45577c901beb376cb426bebd48e5eef7e0ed26d4b(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__43c11830219e19700a9058e34e8b82bbf37ac7d95dc54c89211d9920afe6da57(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c84320ec1fe82c6528028659c38544012c4d5ce07f7d5096a3b7555fccf11975(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0594b382cee1f9cfc7d91fb55595d2b8dbc4f387de75e1207d277f176e88029c(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cb44fd286e6d71f6e848c45a3ccd339a9aee746ce67d8a2b58b985e10e835a1e(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1defad82a889a99b9396be4ee3d3f33e717bff5b404af6104d76bc748397f7d9(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b1474f7bc1faf66da9e0747abd46d5c66a9dcd03de43f8887c06850103ff425f(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8226e989aea0f9049abec3b8b01a93c37a912c3867a29b9dfa08060af5a5e046(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a691ab271bdd208dd83d8fb102a3fae7d2bca8abfdabbdff135b88207ce554a7(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3ee85acdb5c2af26d12ff631d0e8e09fda03c3aaa94061e4290fc61e9f224eb2(
    value: typing.Optional[PowerpackWidgetGeomapDefinitionRequestQueryApmResourceStatsQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f73637b3a7471caf34463903671d0c038a82de0f4885667e207f6c2eceedcd8b(
    *,
    data_source: builtins.str,
    name: builtins.str,
    query: builtins.str,
    aggregator: typing.Optional[builtins.str] = None,
    cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__18404c8677f8ba8ef7c132c9b1f1501f5028646b72eb7ec5615201891a86809a(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bb6457f045759fa7cf1f7f3e1fe66324cfb04d7299ff9b22cf66e61f6969433b(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2cb9f7a7b469378368d3b7903e0ee434e2c771b26ed137ef6378f14eed490d34(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ba6cc48b4004b9505eb67f5ff23f0d6a279127b5841e46fa0820ccd868b25174(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dc31dab87c485c7f83e9052953d54e5bfd192a72e0c54fb8a75615dbcb6b8468(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0b15c92fe00cdf0d3430b18605c1f8823121565d4ed5e1f24035ea5804c596ad(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__df0b09638ef11184812d97117e53a45b0c0b1d3442eb16c6d30a48e753f9c1fa(
    value: typing.Optional[PowerpackWidgetGeomapDefinitionRequestQueryCloudCostQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2053b442e31ca0df58981a79409e7a1193fdeaa686f20d6f01a0da88890fe3c8(
    *,
    compute: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetGeomapDefinitionRequestQueryEventQueryCompute, typing.Dict[builtins.str, typing.Any]]]],
    data_source: builtins.str,
    name: builtins.str,
    cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
    group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetGeomapDefinitionRequestQueryEventQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
    indexes: typing.Optional[typing.Sequence[builtins.str]] = None,
    search: typing.Optional[typing.Union[PowerpackWidgetGeomapDefinitionRequestQueryEventQuerySearch, typing.Dict[builtins.str, typing.Any]]] = None,
    storage: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a23c59ecb93c5d795e2064f471dc2e4cdd48aa2adeb5862e94c9b58261f45536(
    *,
    aggregation: builtins.str,
    interval: typing.Optional[jsii.Number] = None,
    metric: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7dae259908034d6d6f79e0d287ab149a8ef877805c777ae052c49752438017fb(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__18f8b28819d86c9c88fc3e5e05344ccf8b2e2078f193fddda8d4c48280121587(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__696bd1fbe21c61535fd1ba43d32011e3caec3a1f137b0ed8eb2d34ac461131b7(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f17fc80e6b85e15930d1ce005a9aa419b35a5b93c5a6d8d955326217f4827c3d(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e7910cf6c4fa25d296311cd9d62f6e22046ba839ed18d161ae47d6e59cdd10fe(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1e138fdcbafaf6087e568fb09a440a89194cd66c214395d709cfee18128f06a2(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetGeomapDefinitionRequestQueryEventQueryCompute]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ec04a767e86ad364ab4b109c931687fe88d410496a093ec29e6093ccba923674(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e2ea2fb2b71c4c492a77fe3eeee85111ac3da6e061170a421e4ce19d15a52363(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__aa2cc1265afdce3f81246f2f2e970463d9f576b79aec63a3de4fecc9923628d6(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c870de12bb7f773aa760056b228a59cd74b35070f823e0b4617cc4771593548c(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5d9f03b6f856565685fd452d231adc50029a82c083c3d1875b3b744b321b24dc(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetGeomapDefinitionRequestQueryEventQueryCompute]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__642ea5edfbfbbdd0b6401cc1276980c6b4b65b0736958309e04f803a64db6de8(
    *,
    facet: builtins.str,
    limit: typing.Optional[jsii.Number] = None,
    sort: typing.Optional[typing.Union[PowerpackWidgetGeomapDefinitionRequestQueryEventQueryGroupBySort, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c2dcac9a7447687144a492073ef45f43fdcf2100c75d8d7befaf3c07dcffe453(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7b705553707b76e3d2894bf1a7e2d261a5da4a08206431336dfb72c94411cfe8(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__599a98c701ef78be090f198cd6483e8fe250940178014397bbfa9c6ac977eaf1(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__176c78b51cb982d1bfce6aa40d3c1da9db46a64996ba8623f17274ee31eab267(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fa77c4a4ffe53b99a625162e1ef0594dc6b0080eecf78c91691c5bf58459ff5e(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__90f05a455ff042dc5ec031cb9100e2f0c061af3e83685ada304d26796b916b43(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetGeomapDefinitionRequestQueryEventQueryGroupBy]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__53546784c542d8fbda46d6fbc3d70f58714838b633a2001874897bfd954a8975(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__421af328d3356b398f5a48dd230db18924f1096ec344c09158dac5fc5bf24af0(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7c8335625a72a6665fcca8ac4e15e9aaa15ec6075b1d4152c50b0e722dc49593(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f7d099b2dbcf39d3a570f213ef9a7ce5110820b6d84a589a1abc6df77e1a8fbc(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetGeomapDefinitionRequestQueryEventQueryGroupBy]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__42b9d6ab975ce2fafb053e1aeab2ae21570103645422b694d863c0ed2e30cd5f(
    *,
    aggregation: builtins.str,
    metric: typing.Optional[builtins.str] = None,
    order: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__05e6b82f482c5cd97d62b11b3b2c46d9bea0f58d612ca95fbd8263b99628890e(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__644e17757caa2db58b1871f13781031e4614650d16fbc29d58aef7ec135c5d8f(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__948fd3ee39d191d7a2938adf9d178db010e17d533ebebdde6daec0deb411fa84(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b666cd4e77be56bb368a7ecc94e9fbaa82ec4ee6eaaae203de946792cc66d3c2(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ab2f88cba6634286c66184ff969bb5d7396c31bfec1c872cab90c1aee0e4e815(
    value: typing.Optional[PowerpackWidgetGeomapDefinitionRequestQueryEventQueryGroupBySort],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3a58af5e36efcdcb89b382d0ae4861a08f3324ccfef8b1a981d244a1216a61b6(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f72de3b0fb436763eb1625b27a356b0666dac4dc08b690cdc3a58eac2e60f400(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetGeomapDefinitionRequestQueryEventQueryCompute, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4acede0469c65f578471002a9e2dae8b1d206ca2f31f5c78720ff4b83b1f1959(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetGeomapDefinitionRequestQueryEventQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c1bd3bdf5e1bb803ed53ff74f4e843141f318bd08cbca31a4a227248a3820c03(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2d78b6b73661abbfd8d3fdef1450e0aaa961896f01f2911387fe80066e40534f(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__174238d2f6e57bd2218a98427f2cae63b8c902c41792a61b90984d02d0424d9c(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e358cf36de247593a0ef0115b1205604dc61e63026398a4d83a750825ac8ab08(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__29aaa5d06439f77f594205fe76959ea5f4c68b5f927f9bf473a54900584aaf8c(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3a4d4eb7c8b8bc987a238da87a0fa5503b946dea1e91217d89e0415609a8eaf0(
    value: typing.Optional[PowerpackWidgetGeomapDefinitionRequestQueryEventQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__575e148090df77688e28b85f11f538b285bbf593f143501884ed0fdbf423c428(
    *,
    query: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c4c8ae7990471b74fc91e3c1f88cb5a9f05bd049f72fea69b7ab5637db202ca8(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8810483761391a5d173ddf45b4cf364b205de5ccf1202e76b5a04042eec065a9(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2e2a851ff32f996ac16019c3556a2c960fef024bb10e589f3ab448a3d333872e(
    value: typing.Optional[PowerpackWidgetGeomapDefinitionRequestQueryEventQuerySearch],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f92e00312e09ec0faafbab1f697471744a03120386415a249a2db04a56a5b58f(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__86af510f1afd9ed35668340f3dff85eef8fe5fbf6796fab6bd41f15428d74264(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2904f631774f138ee06699d7a64b5741bbf826926256c79a29b6f46f8bfa0982(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9bb2e38a17135216d81af4b1377ec711f4325f934468b4c8621c5a394a87ffc3(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a9b94262d82ea1a8dc6ef1d5fd085d5da1adb6329a49e3fc923e206eefb764cc(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1f8c65c762e8ef7c5c843350f68b8fd2e13b0b0bdabcc53999cbb4433d68ff1a(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetGeomapDefinitionRequestQuery]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c7bb9b39d4093adcc0a783f83ee24217f9c63c0a8ed3ec1f7bbc602b464bfd8c(
    *,
    name: builtins.str,
    query: builtins.str,
    aggregator: typing.Optional[builtins.str] = None,
    cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
    data_source: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4b9c531210b460d5a6c51aa645d3f992f449041d0b8794f0bdab4426561d4d4d(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__49f76c0dcbfe3ea478e076e5f360d592f76e0e8e307bc261e45037e8f33a17cd(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4616aa64650246765039788d79e13b8c543928757be19ae1b75d594e160130f3(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__12a254cd99c7030a21081c92cec5da92436c16cf4fd8f7b093f985ee9b417c68(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4c6a3347a2bfdd03ca9010b6cd5d7f6f73140d0d2c0f0a0c839785fe1d74f854(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__964ce79a518c80ec9139fac4d936312d3ff3c8aacf5f6af4e598b1d8308f7d8f(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4717a5a11295d8d5a5dbda05bca90a499213440677094e623b1d39d7d17f4e54(
    value: typing.Optional[PowerpackWidgetGeomapDefinitionRequestQueryMetricQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fa0c032d048fc60b651ead199d5c17bea8b583926d7a86f81e19bf42dfbc6ff1(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__467bb69adb09d0893a6b6e939179594e02c12b991bcad033c71fd8df0e1920a9(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetGeomapDefinitionRequestQuery]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__52f9cae55a860946bfd00f9f59bc74df403eb80830c6ab451f2faf25c3829f9a(
    *,
    data_source: builtins.str,
    metric: builtins.str,
    name: builtins.str,
    aggregator: typing.Optional[builtins.str] = None,
    cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
    is_normalized_cpu: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
    limit: typing.Optional[jsii.Number] = None,
    sort: typing.Optional[builtins.str] = None,
    tag_filters: typing.Optional[typing.Sequence[builtins.str]] = None,
    text_filter: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8db84c94f3c0a6ee718d9bb0cca6befee8ebb3f026bd229f993ced110da27f75(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cc16cc0d6db5d36e89b4125a7a0500ee10644e02fcf33a2ec4fc88e8a80b5076(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__49b8c8496ecb4bde06a734210f06f8f489fcd25875199f9ea0aa619b57e93023(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a4035aee36f1cdfd4725ee2e2733a421f0b474efe06f037af5b8da46beef609d(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9f7666fae9df8e6a771bdc8625199ee3d2d5be1d616e16c8c81c256b2c6b0740(
    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__77ef1ff4cedf001e6a971cdebc174c8e50f9fcdcd6f96cccbec8312e0fc61868(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bb9cc80c65930bf02e3034256df5b8b717ee3d00f9d61df0062331bec7cbc5e3(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4a4d128222593a643640eb26d3bca15c868c1bda1d578ecc458162b05b08c3ee(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cfc914980eed154ab269b7f74bca9604a8ce54f40d28d889e725b7c0ec8fa267(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3b79f5992dadd6d4d929b3584d4783c3e8a0b4fd1b23a1b1c23909dc66dd9a71(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ec23e07782d21f1388cf1726b575dfc9b2c566cd534dc35fef4c3fd59097b205(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__900ffb9e802152378b2ad95cb18849df766d675ccaf48a332bcb7f1a6c188844(
    value: typing.Optional[PowerpackWidgetGeomapDefinitionRequestQueryProcessQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__56a1b16ef1c7755a15cfd2291545b2191629fdefcac527d36bb795a3d425c35f(
    *,
    data_source: builtins.str,
    measure: builtins.str,
    slo_id: builtins.str,
    additional_query_filters: typing.Optional[builtins.str] = None,
    cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
    group_mode: typing.Optional[builtins.str] = None,
    name: typing.Optional[builtins.str] = None,
    slo_query_type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5ffd7ce42dfa6beac1c5f77146d4c0d1a825691b24f6229003dfaf24f68e9584(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ece0c06d88059eb87ae14552733f7c3055b26e71a56a0e15bb8f70d216c489fe(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__55baac6251ae540e1095c4dc2413097bcff02f222662ffa5fbe40de3a172bf41(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a83d27b019433cfbd62dd2816d0a32f0697c0f7a5388d9c3aec34fdec5d45564(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__11a752007a488e119713b4395d891ae5bdb1be557be87050bd5b5ca2eb31dbb6(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__341e57df3a008ccf79dc98dbe772cdeab931830315d74ab65601ca7281714033(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dee44d21bbaf479b24cea27b33adc47980f1165524cc3c3a3c3974a7127f253c(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f3178dd76d894cddf19e6719ffd3e3652ce751209bf22640c60f68265f1012c3(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3e0eefb36ac099e798db2b9c735db14dacf0dd320c5cacc8dac296be59f1186a(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b720f9bd71f0cae56594d4e75f35bbb96ed5e01812571cbcb2859089c9305e8e(
    value: typing.Optional[PowerpackWidgetGeomapDefinitionRequestQuerySloQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__587a84af720a880486539c27459522a6f3707c5a69bba918e36d47087d8eba92(
    *,
    index: builtins.str,
    compute_query: typing.Optional[typing.Union[PowerpackWidgetGeomapDefinitionRequestRumQueryComputeQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetGeomapDefinitionRequestRumQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
    multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetGeomapDefinitionRequestRumQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]]] = None,
    search_query: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__88488d28eed6ccebaf12ca5edd8cb5ce3fda649cd2a0991fd47d9ee50039b49e(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7596380ebc17e151dd455b5cbda38b0ba185fd5ec154237075982399a4f8f5c6(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c0691d53e3567e3e1a259dba639aa1cc10571326a209719e79327f0a5a8bac30(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1cbc5d561b39a683b29aa2d8d4ee8ee4eb785826a4ffeb84c7b73a7d2d85e804(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0896f5bb1d2928be45fb2c383e1aa396a19da83dc258daf487e0f96631b1aa58(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__efbcb06bb757dce3fa1e90510e1296318b1f08ee97e3abced9fe0c385976eaa7(
    value: typing.Optional[PowerpackWidgetGeomapDefinitionRequestRumQueryComputeQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__13d136923134def89511d910bf50bb5762b147e56cca91fa0614b69c706b97e2(
    *,
    facet: typing.Optional[builtins.str] = None,
    limit: typing.Optional[jsii.Number] = None,
    sort_query: typing.Optional[typing.Union[PowerpackWidgetGeomapDefinitionRequestRumQueryGroupBySortQuery, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3c8a4dbcfc385eb5bd8cc00410cbe4c0b30cbf494974d6b6746781cc99b1e46d(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9ef357be268ccbb45286d706c1632877006c4da77d675474d0b2052f7510efa9(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3fabaf2324f0e71a5b235ac5da20bc324d2da30b120320acfbec7f3c2a06ee18(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4d40492bdae1c7bead1eda1a842d1293cb34c4216a3cf541f597af72dbf0f95b(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__877d5563f30efedd1c329633a4b2eeb68dd0caba3afe5efb69201015b02e9c14(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f9ade2cb1a53b9341482735e41bf688d51e3394fbe3eabd119c3a658955151f8(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetGeomapDefinitionRequestRumQueryGroupBy]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__09d15f7dc2497241171ad06543198667fb8c3d9aed640c29b8365aea3e958253(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__233baf77a215cea3913ccbd848be43add74a6f14bb7f2f22a48cd3b946a7bd66(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c3d3f7959b9e06c37964dc29d5e35b6db754c2c230a654f7b543c4f8e1d3903c(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ab3c2eb512299adc9c2ee68cfc55eae7200f029144db16645d1a5c81ddd52260(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetGeomapDefinitionRequestRumQueryGroupBy]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b9bf572a540faba6278c65be7cbef952233f3b19d063c0c6cfbb6a69c74af8bc(
    *,
    aggregation: builtins.str,
    order: builtins.str,
    facet: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d8abc5cd65cc5b28ea80fd2e45e2e77153261393623bc6eefe79a5613c3ba7f0(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b3b92a428adb67205468b83775da92f02f75596732b8798e047eb9a6264b4399(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__315e0f46757e88e2e5fef194fa8302dedc6ac758b0e5b4855dfabe8adc7aed04(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4763159fc5f8883f771af6c0eaa83e4927461c020a2686cf755589cfae9fa0b0(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__08be40084c4aec48a7940d2666fbb3c466922927567abf89e13928126b1d1d82(
    value: typing.Optional[PowerpackWidgetGeomapDefinitionRequestRumQueryGroupBySortQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__97496eb8750dfd8f36ba0cd1d8ae077275ee37f8314e15f89cb3989154fcb9f7(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8c88471fd1e05e5e480d14ff3e38af17a2e1ca32e47a54e109eebfdb0a54ad0e(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__88ca1698c94b05f9df481d44480b848ef40026bce20a0cba529e584cd6665f2f(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8fd8a71633608d73b1a1cedf47fa0adb8b121bfffe4dff4c1fcd2b6800a31d57(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bd5c642172e91819123d5ccae038f7ea14ef8690970b4c64cbf99d201e3928ae(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__91fd1b4bde0784f6c03b1a168c7a692c0539b2e80b6ecd41c10571d4cac922bf(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a40e071a06ac74b92d69d2628018d7ae78c10309653bc1799436263e977bc9dd(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetGeomapDefinitionRequestRumQueryMultiCompute]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__822e5de7e69e36e18d054a2dd5f44ffe7f586db3aaeb8d517be862eea41c71a9(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c18d337c8a199808bcc776968922cfc1b00da9bbe1ac2114cbf465d502765282(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1b4f2ed0da46a2aebccee4bdfb2feb0aabebaa834ac36ac9d3e5513ed6fdad84(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9bdbea0f7fddf212b7aae11a7090a89d128c9249f0143fa7f4b0ae56cc532835(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1474b860075e80f6ee5cbac17201bc4e460094874ed564fd103607b1c61a33ef(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetGeomapDefinitionRequestRumQueryMultiCompute]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ae9753622ee9c0a44ea0e615c8a8e4592393c417ee9890a2748c9adb73a2872d(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2aa4ba4ea16745a2f2f673746244eb35aa963e64795750a4fe965b30122a96b8(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetGeomapDefinitionRequestRumQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d30604bc032e4ccb7f9ea23a5ba059616daa4979ef64eaeba7cac92e862c01ab(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetGeomapDefinitionRequestRumQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__93e25232930391cb2c570b7c50a63aece7954b005a60198daedd3211ec0baf60(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ea595d1dbee6c7a9568278d8de5488200d1afe103316675eadbb419bd371d908(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f7f6f36512bbc946c7f0a741cb3da82513e1612fb5ef3733a936ce7f67ac2dd5(
    value: typing.Optional[PowerpackWidgetGeomapDefinitionRequestRumQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ab8d95f3b77df54052804ec9f16f92adcb8c81e9ba8211aec0d1337354b2a9eb(
    *,
    palette: builtins.str,
    palette_flip: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__48908e8e75c342da8700792b20b3ac9861513515b735927a7472a094ca2417e8(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ffded09540e6f2f80a7d64ee0b936d476b92581da5510bc92767eb7c7531298f(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bd2a68d97f5794d4214ab81909fda0e050566c125d0573460c4531578e53a566(
    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dfbc54f59a4379820f56c292948824817152b118386079a36e670ce19230de56(
    value: typing.Optional[PowerpackWidgetGeomapDefinitionStyle],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8ddf7eac1b7ae94af68e62adb095f36966b9d74f6c30a1f959791225c1c8efa7(
    *,
    focus: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2baad96978f12359a74dd656448ccab667cb124e2a9e0b77a6098ad15c0267f1(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__62c654f86d551f9d1c063a18fd18952a99dfda13fe5f1a572eface9f50746b52(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fe60fba9293cf7857cc4ee5207d9cc5520528342016a1cb66b5b7b0e8713b9f0(
    value: typing.Optional[PowerpackWidgetGeomapDefinitionView],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7bbffb9c1c70f9d6ce94658f681e559e2792bac0aa28f98b3b8d821a05972e25(
    *,
    custom_link: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHeatmapDefinitionCustomLink, typing.Dict[builtins.str, typing.Any]]]]] = None,
    event: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHeatmapDefinitionEvent, typing.Dict[builtins.str, typing.Any]]]]] = None,
    legend_size: typing.Optional[builtins.str] = None,
    live_span: typing.Optional[builtins.str] = None,
    request: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHeatmapDefinitionRequest, typing.Dict[builtins.str, typing.Any]]]]] = None,
    show_legend: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
    title: typing.Optional[builtins.str] = None,
    title_align: typing.Optional[builtins.str] = None,
    title_size: typing.Optional[builtins.str] = None,
    yaxis: typing.Optional[typing.Union[PowerpackWidgetHeatmapDefinitionYaxis, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4bb03188e82f81a392c0dce817574c022fd24f7056f10ea469f5fa1462782219(
    *,
    is_hidden: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
    label: typing.Optional[builtins.str] = None,
    link: typing.Optional[builtins.str] = None,
    override_label: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__480d80a70526a8b26ebb29fb5e93e5854fcb8e6a8eef7d00d41bfff214e1dcc1(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__45025584adece1f5e21b7e4d4b84154221d35ca919005fa06d5f84355afd0d4d(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__05e6233e6f3801fc24d140df6977a4366672f043cf963e20f5e10432befc76ac(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3a4e842137549d99141f2f84bdf0770bc0ad5cad19107886d35bf7ebddb26bae(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__05430027cd8763e202b41966e2ba4b286b11efb1e08fe355fe56f3a432d7da3a(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__aea8f70c32564382be8f6e6f625bb4d815182b917bded1556da71cbf9d110eb4(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHeatmapDefinitionCustomLink]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b0ca9169c1d300e7b8990d2e18f3fb48d989343a6ac723b87b83b6bd3bd1820f(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__779fd575f61723c73c84fe0ee626a9655d1cc7e30bd9418cef9801b420af0c82(
    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__be073d17af47d7a97360d393374b2861df80479e04345e45bd1355d68da9a755(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__24e0f56eb99f59335f8efd6a864ea549b77264e200edb9a2e21fe907dd72136d(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__58f2a13335b07198f938d51d1c884b88280ce7aa07af10f90e282e1fb2eb67db(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cf9b01d868acfd9a64917d3b677cce543c6ba45614e81f9ec0eda2980b335579(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHeatmapDefinitionCustomLink]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4a725c94cfa4c426b4ace3d4efb5929929b572c6b81a46f9437ceb6cf460494e(
    *,
    q: builtins.str,
    tags_execution: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ce8bea8ef1a37bd48d3321599882be9e719fef546a3fd988efa9288fe67f2424(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__463ab6ec4debda09f52f4f9670bc1f97772110b9b653c98c58c6d74ea3b488a2(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c9956ca2e4050bbce44b6de2bf8de4a618180bc3e71803be706b818722267201(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f826385a2e9cad2a125996a31f206cfbaa8515c4ca1ffdd65de2880a14d5602c(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__695108c7e7d3fa2128009097515db132793f73d0b0105d94575aca1b5dec9d3a(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3e7f5610cf27386bf2bbef81308e853622375bb68211f819ae35dccdbd1ef033(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHeatmapDefinitionEvent]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b0865b75071d0d5411f55a6c13663b50c5379dcf19b07b7eb0a6a35a415a0a29(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bb36201cf55a8910f7c5fc32ed46102bba117955e0c100bb01f47dff1fab5db6(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1a2c5894f51b928bc0e11eecd5f2549ed20dd0bf5f28e1cd0c12c6e10329e16f(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__01ae49b77d6bb5e4219338927d823446eb46ab2cb036f3dc43ec559a06992a7f(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHeatmapDefinitionEvent]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bff8f266854deae33fd6b2d102e6f3707a748ebce06056588097db0f7ea35ca0(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__47881c44079d9a2779aad6e2e7a877ec582c50de1849213cb054b0462f484d30(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHeatmapDefinitionCustomLink, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__825777bac18deff3977568c97608871f886cdf7b73e6e27c4c206aa816521ab3(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHeatmapDefinitionEvent, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d9c0b0803046cf0c8adc664c03f9dd3c94542b24997aac067a7ed8e23022a850(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHeatmapDefinitionRequest, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8d51f3d97beb2ec2aec8748fafbbd6f953b3bcfb73cf8eca89bd4dcc745796ee(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d509ad3bbbfdf0e7eaab43637980a863cdbd2ddca60529625b2577df40961dd6(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__17fc17b88f3d89448cea073496a0452f410deeaed101f2b5bee48522cd93ea3c(
    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b2ee1da405ea861b5c50f6685875801bb2062bb827e5448f018b6b96812d6b16(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4af6b009290dae9b62b039ff477d069ec490a45f693b053c0869e49a791befc9(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__843e93367e238d6c731d1189cad3ef1ae777cb043d78759326ad3d2297f9e265(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6995727ef2f1dfe571199fa7d68162385ab5976cbe619141abdef63a2f5f2ede(
    value: typing.Optional[PowerpackWidgetHeatmapDefinition],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b81a656765f8206ed38c931754c8ea1ee90b7f8588739a1ece46b0c4e0f0bb0d(
    *,
    apm_query: typing.Optional[typing.Union[PowerpackWidgetHeatmapDefinitionRequestApmQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    formula: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHeatmapDefinitionRequestFormula, typing.Dict[builtins.str, typing.Any]]]]] = None,
    log_query: typing.Optional[typing.Union[PowerpackWidgetHeatmapDefinitionRequestLogQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    process_query: typing.Optional[typing.Union[PowerpackWidgetHeatmapDefinitionRequestProcessQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    q: typing.Optional[builtins.str] = None,
    query: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHeatmapDefinitionRequestQuery, typing.Dict[builtins.str, typing.Any]]]]] = None,
    rum_query: typing.Optional[typing.Union[PowerpackWidgetHeatmapDefinitionRequestRumQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    security_query: typing.Optional[typing.Union[PowerpackWidgetHeatmapDefinitionRequestSecurityQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    style: typing.Optional[typing.Union[PowerpackWidgetHeatmapDefinitionRequestStyle, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7525676279af0477ef4ff139b99acdd7cc7ad301ae861f4dd5f36889877bac72(
    *,
    index: builtins.str,
    compute_query: typing.Optional[typing.Union[PowerpackWidgetHeatmapDefinitionRequestApmQueryComputeQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHeatmapDefinitionRequestApmQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
    multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHeatmapDefinitionRequestApmQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]]] = None,
    search_query: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6baa2239d5cfb78f1795c7ad2969caa15840c62aa96ea667888d1257587d0a74(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__63fb9cb88c47232ed22afbbef47e4707d283ef35969161c5dc49105136481557(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__444879c6f3481d31ee56319b64e8a92794c95bb33d57f837a43fe1bb86e51b18(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a70c2c4b35f82744a878b950b583971ec2633f0b0b23b4c509877b28db00dc26(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__98359623937aa05ebff42cad1449ab007e29c4e71ddd447d8146e52b2e3604eb(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e3787af7f4e5105b5ff4a1eeb3aea5afb03fce105b7d76eba2bda3d8c5ee83f8(
    value: typing.Optional[PowerpackWidgetHeatmapDefinitionRequestApmQueryComputeQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__25309b1257166cd1b50dc2d8289e176416b015a62e6ca4f280583109e843cde8(
    *,
    facet: typing.Optional[builtins.str] = None,
    limit: typing.Optional[jsii.Number] = None,
    sort_query: typing.Optional[typing.Union[PowerpackWidgetHeatmapDefinitionRequestApmQueryGroupBySortQuery, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8e26c2a7805acafa1734474372254651b6e98aa9b30c1eb610b5797b96decb1b(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__09d6b794624f7e5821c01a589c5ca24e4d0217ae5dc8b920754d43ecfa7acf97(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6c47cac3dbd75231d4e4cb1767ef44ace7cf5c5938614a8801d80392b66af6c3(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3d621809cdf50b57049336d68544dd2e29c0b92449c92dc80a992c1315b87a00(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5d3405c5518eb2cfee791dc3d35baca889bf594ba3cfe47d5d8d7cfd25f433f5(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c56cdb0ac01a757097f150ad8bf78b26049d42e708ad6287f2ba875e3a475b90(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHeatmapDefinitionRequestApmQueryGroupBy]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9b8ed8f54f9effd2c3f6acefc672cee401f432b164867c38ef2d7402c031c6d7(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a71258ef1d2deff31bc81342e4e505ee0862c19b7bc1f234a22b4141e53efd20(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a2dd0ea0d868e1cdaac3b7279db3cc6480db01359862075a30e28124181a7fef(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5c49d57ebb6ea01a1a17b8f85e3dc95927348de52c098efaad9d8eaf45a130de(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHeatmapDefinitionRequestApmQueryGroupBy]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__909d86847e006f39c843188a5da8a3c7d5f302a112eddbe5d445213b63138d0d(
    *,
    aggregation: builtins.str,
    order: builtins.str,
    facet: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__283a3397914da5e307ea78ac4abcee32bee0be487fb4ba0401e3018f0fde16ad(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bd88854d198f3d1a370841c7272601b26453996a6a6e02dff48f6a37c9101558(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0b46c0da293af6323af8a92b60a8498f5d9ff4b519ba4a26c0b725a4ea25c937(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a348e453c61f1cc2016f4dabe4944734a454a069c79030521171b5fa4fde6aa3(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1cbde35b626d3ae7b0f07d140dddd3fbff43b1d38ad24ec3dcd175de6fda6621(
    value: typing.Optional[PowerpackWidgetHeatmapDefinitionRequestApmQueryGroupBySortQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3d523535c795d992a421938861dc1d1c286f35f0442d20a0d49dc568065b883a(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__16b8c368e464723dd82087146516e2c503cd8b2ba3476f3b86a1803dac93dfb0(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bbcbb0b597cf86becfeebd42c56ba77999f84328f764b5d73907772d4b7f9d5f(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8050e02cb45bc120f506c4cef25d8df348995257a94556e9166881370bb982cc(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__716260de6abdea5edcac2bf061c59dfb6ea0c12c6d26515a26d4925dd91d1472(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e86115b6dbec7758c22234504c273ffc1873564d82ad1f016e34488970c55a47(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4cbc2dedd6d0588c21cb4e1ace37f4bf1887f5783fa7e2e13ea96610659701fd(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHeatmapDefinitionRequestApmQueryMultiCompute]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__13420f7f634f74c1ea6969006c2bcfb303d1a325da453b69c22661e2b1475b99(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__278a41e5156b1ffc5d67898b9ddb90b8df8e1342ea4cb658925c6ecc77513cdc(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c720521479e1f1717c5222bc65f8e8346a94922e76d9eddbd571bbc70abb10cd(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e5bdf3e72b144437e83143ed0392f4f3882aa64a7e02008c51a90f13734305ee(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__56e9f62a17adee7034ab24bece2232ae18dbb86d870a46c89d8151fc98454031(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHeatmapDefinitionRequestApmQueryMultiCompute]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c9e114a375afca059892bc93dd721e0b6826679039ed6e1112a2bec24701f70e(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3204ea87bffb5ee84a8cf821d4e9bdbeeb026cca75cdcd841522f9de9cf82b57(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHeatmapDefinitionRequestApmQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1ba58db89c52a0c90f15337d4285f6c654a4bc8aa2becc7289b8952153a13f43(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHeatmapDefinitionRequestApmQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__29169977369c9775d0e66c460dd1f534dbeb2ccc7058699ba8d9a507b2b451c4(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b0c8591622298e0c75b51e0bbe56be526c87b1a4c80f2961585c039c6e8ed6c1(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e9965b468972870e6549b8b38d50ba18eaf38fbfda9e4c75c521252de9e91f39(
    value: typing.Optional[PowerpackWidgetHeatmapDefinitionRequestApmQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a996fbab5ca475063ccc6889e19da6bde4efea34a8aab4fb131d97f8e7fca425(
    *,
    formula_expression: builtins.str,
    alias: typing.Optional[builtins.str] = None,
    cell_display_mode: typing.Optional[builtins.str] = None,
    conditional_formats: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHeatmapDefinitionRequestFormulaConditionalFormats, typing.Dict[builtins.str, typing.Any]]]]] = None,
    limit: typing.Optional[typing.Union[PowerpackWidgetHeatmapDefinitionRequestFormulaLimit, typing.Dict[builtins.str, typing.Any]]] = None,
    number_format: typing.Optional[typing.Union[PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormat, typing.Dict[builtins.str, typing.Any]]] = None,
    style: typing.Optional[typing.Union[PowerpackWidgetHeatmapDefinitionRequestFormulaStyle, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3a8d153931af24804008d64c1fc77ed41c07712376fea63a9cbc66a714863f16(
    *,
    comparator: builtins.str,
    palette: builtins.str,
    value: jsii.Number,
    custom_bg_color: typing.Optional[builtins.str] = None,
    custom_fg_color: typing.Optional[builtins.str] = None,
    hide_value: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
    image_url: typing.Optional[builtins.str] = None,
    metric: typing.Optional[builtins.str] = None,
    timeframe: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__153bf94efcc02977952a8644426eda72a2481848f9bbe71b1e4dcffda3d67d43(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c8b818e1c62cf041db6e4a2e6cbfc2830cf7e48ad9f945daeb937a6802d56105(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2c4fc149cb381d68deb6e678e4c93188749d950b407c5a444918c479fd8a75b0(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7d0cbd684fca66c0d1558592e8754f9df47d1ae840bc517abda19a11b0b0ac07(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6e247b30765dc442ae61880ed4104b16c392a0d0e14c0ec6083087d19052a210(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8c455b115aaa603d68d5af4d48de5d923140236cb91bfb66a85aa7766b6c572a(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHeatmapDefinitionRequestFormulaConditionalFormats]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c378227ca718a05095284564455ac46a79fc267e117f623d91fc7ed6977aeec4(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c3a49a197c0cdcfd31ae2690ea1cc035d3042c29e31448b5d175f0199f665358(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f057fceb1f95f24afe4729ec7eb4d6adfca6e7d5074ebb14cdf7cfa77a609c52(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__94e0320b2331476b1e2bb6377aa0d1b120e5fa3791c0904d5b1b555c735e989b(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9d955abbf0dd3a19ca2ea9a9157d1d4e62d4863757770c1eaa8a5a35336ea0ce(
    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ad4ece6b39ee53584111679eeadd2d4e7459805b60c8bb6e916526d641004992(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4bb61b58a029b09ffd3bbf90d937a39f8808e4a07299feda3de23700f191a115(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__03f4b34ef78bff32d55a92a69478b3debdf484738dc4ef3a91d18e0b8204cb86(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7ab79c6a3dc461448a24ee34d8a70a4f96c3d7293ca8d68729f7330ccda997f6(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f3f2c504d6359617e46e270319f3bfe926f7efb04ef803ae78f5d2fecfa8b079(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f95321c23edc96533c44d7f2613b7220466a343ba79802fd2b00877a596158ba(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHeatmapDefinitionRequestFormulaConditionalFormats]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3df8f10772ba1f1565572ac0327158ccd5914e01f66e2f04309039cdc7b1caa5(
    *,
    count: typing.Optional[jsii.Number] = None,
    order: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bc32ce2078100a38b726a14dd18425313a9a432ca7ea0fabd1234878269d5d8f(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__546539467be86f72566f6b1763c7c8f77db1f7af10d23c4887be61becbbe6bb9(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__134dbb541659921fa23f446ed837bbb6d32f574e3b2c4b5a964dff2cc6f4d9a3(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ae24e4f96177506f68cdee1f04af68437a308b2aef471bf1657a05130bb6a721(
    value: typing.Optional[PowerpackWidgetHeatmapDefinitionRequestFormulaLimit],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b2c22bd11ffcc892784e2f33f0133b44bf57323c766741a5ab81eb4361baddf2(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__466d9d4afed54a0e711768bb58981ad81ece72b3d89814e8721b0ee073f69320(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3b89c3cf6ce575e6ed775eb469a8fc00e5da28f423720eebb77859b55d1d9e8b(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__65cd184011939cea6e9ec9b0f06dab625ecbb1e6b33c820dbec11f9a80cb3b27(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__36a61e963a71a3b5b4df43e6addab5db8801546df7f4e9ce9f11c1e7093bb753(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__36414f96fead330d2ac4185de9bff5494b614ed885a75063879e502b33c5abd2(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHeatmapDefinitionRequestFormula]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__558aa8e55034f2caf5b0f2ef949f5bd56c711257359ea57824112c4bc1ab798e(
    *,
    unit: typing.Union[PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormatUnit, typing.Dict[builtins.str, typing.Any]],
    unit_scale: typing.Optional[typing.Union[PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormatUnitScale, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0c49cd2d2fbf9c048ff0afb082076a112800cfd97fbc1ef10a4bf00da5a916dd(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dc97f3ec0798bd1ee34113d6ccfa9a8043d5481c8094a78a630a202911f9132b(
    value: typing.Optional[PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormat],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6ca2a252e128313e8e4c26dd39582ac5f927eba6202ad2995e410aee2aaab24f(
    *,
    canonical: typing.Optional[typing.Union[PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormatUnitCanonical, typing.Dict[builtins.str, typing.Any]]] = None,
    custom: typing.Optional[typing.Union[PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormatUnitCustom, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9551f618bd6aa2cff266d2a614de64f593dd64b4ddf0e2636a390db7e3b748d9(
    *,
    unit_name: builtins.str,
    per_unit_name: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0ceb3a8e8a9a257f67b4bd92aae706520d696960cb6c9e8f8547f2dad9a4a6a5(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e01f55bcaa8e56affb15a17e95fccde97a827d17a037fded369dccae596c1cae(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f7e931df744336cfc5aa46f79a060b559a54b49fc2c23bd1334515de616e1296(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1d0971ea087db1314cadc70bf2bfc69996d6193090e025f1628086eae862d3bf(
    value: typing.Optional[PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormatUnitCanonical],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__27ca40aa2615aca0d2d918e9639bcd9110ed8e72c8cd782f5fa04e0b5d8d3562(
    *,
    label: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__11115c1e3b5c46b0ed9f50b67faed807d9005b81b169907b3a56c95ed6656b41(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7cb3b879667a893fc054ddc5232400cf49d2f1d884795ed4b39b8f29028e6110(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fbc4300639378488e900f0d9176c10f3f7495966c6b77c77ba78afc16b71c86c(
    value: typing.Optional[PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormatUnitCustom],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0f032255ff5a410c83da80461c22b2179dd5a23e30c4e2542bb06c5e0e270392(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__acca4a7973c57cedf84c0af8bbf87e7f1d3fd11d27fd34fcd28ba8e1ff4fc1af(
    value: typing.Optional[PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormatUnit],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__75e582812addecf9072a067ef54aeede8c7aede88f7872e7199ad0020bae0acf(
    *,
    unit_name: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dcec20f1254443863e4de5b224fb97093604b253db526409649800141cac17dd(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7cc34154d64edfe060bf698be2d9670e0b9da09399a13c5b71608912cfb310f1(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cab76e5a1e2202c33d4101f90815bab620cb79fb142f28f3ebdf6da3ead68896(
    value: typing.Optional[PowerpackWidgetHeatmapDefinitionRequestFormulaNumberFormatUnitScale],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ef3e483e61274ba769b429d612853e6a71942296c1fa7bedee2489b9a9e2db55(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2f94282169032be02b4397457a71d9062b6a8db038fc9a20da77b5849c263cce(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHeatmapDefinitionRequestFormulaConditionalFormats, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e8aa3371414c9a48e9fd178f4971290c97a313cca2bd88811dfa073e90e82a2a(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2ea4b376b1e55ed58e7934d64c214f6e64ebcc8fd6e40049bdcd44dfea5a03a5(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__be051d5d334ffdf0bc3a5618e69e9f0fb2237c768e0c7fb5fa67ca24f492363c(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6ac18ceb856f73a87b67687210becc6394e7aa05217d1f59758b8c15641430b1(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHeatmapDefinitionRequestFormula]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f9f78f7c139a48905c7c498ffd579dbb71b4893202ff2c63c425a8cc8cc28956(
    *,
    palette: typing.Optional[builtins.str] = None,
    palette_index: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__43cd80df7d712d38686a4aa8b5b9a3fc3271c0e73a48067655eb0b51f965c79e(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__608233835e6c769069a8fd6bc85381ab691ec911f7795c02aeba4586b2325a68(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4601a8583e1792fd4f7cb4199a34691547ca6d188ac1eb01742f936fd494b7d7(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c432e303caf292c39e609230aec089647376e98ed1183090d5b0a00aaf8305e2(
    value: typing.Optional[PowerpackWidgetHeatmapDefinitionRequestFormulaStyle],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__77a0e7958162c1c2253edcbef7a1154a0f9c8c5dd67a1dcbbb0b9dd940ff18c9(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cccbaca314b6af8c9c926190d05dcc36fbb69c087b3b5e6f7fb135c40f04182d(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__09697bd2aaca26e34ff7bdb996a9308fae91f1533da0ffb6e96ec3d2cd2cb94b(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__57172e280b6d60841c9d2812cba117c1fb2ef29f52445e88baec93563718693a(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ad35041600e35b77e1697a144f1007ed049f277fba9216f2e1b5b87ae5888d7d(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__83d9e42e03cdf9b26455a9cacd4b660e88bfcf156d029315a7d1c501ffa101fe(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHeatmapDefinitionRequest]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__db13133562be5643b1a16abce0b5e5cebb28d9e54365530153c94ff978fc4910(
    *,
    index: builtins.str,
    compute_query: typing.Optional[typing.Union[PowerpackWidgetHeatmapDefinitionRequestLogQueryComputeQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHeatmapDefinitionRequestLogQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
    multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHeatmapDefinitionRequestLogQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]]] = None,
    search_query: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a81d4b2e4085d77e6dd7813435f2a1b465138b0fcdcea17d5cf56e8827c96215(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f9393e67378c46320c99e7896a9823fc676df7c473ae91be394cd2b88b3e1b7e(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__597e11609fb54584d26caca08916625884bb29b7764b4635a1a3ad0913e21203(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__935e34fcc3fb227f20f9769f51743bf647c31b2e0c29381e267726a4c0b44154(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__72be43034391346df771e7b7e29a12f75da67c81da9ff8f7235e20e5c1df318d(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bec8d6a1c6a5f6942c81772f06d793ceaca699f22763b8e23d7c3967c4d36e44(
    value: typing.Optional[PowerpackWidgetHeatmapDefinitionRequestLogQueryComputeQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__64c312f03bdad05644fb97d8ac6a94c2c9f7ccb02187fd9274c89573c261a111(
    *,
    facet: typing.Optional[builtins.str] = None,
    limit: typing.Optional[jsii.Number] = None,
    sort_query: typing.Optional[typing.Union[PowerpackWidgetHeatmapDefinitionRequestLogQueryGroupBySortQuery, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c4bd15f847cab96c99226bcb4ae2794cf5adf723b6699af47dc96e310ebf5be2(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2ad403ade74e5251a06c894c6f7036ad40d5c371ce04146cc12f396edd05b6e3(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a5a600d079703dbd9909640528199fcaacd782d5b4bd703af6115e9310df9624(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e85eed0b1d7c5292225d6a50b6be404cf9acf25e85d2dea3cd239dce8c947112(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__35b337da96b1a8364d7d07f4e3c3c150a4f8c4908f76f103c71a6ec3bd964098(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2caea8e05587aa181d70563e964aaea55b59e04127ba1696b99d70ea18c82ed0(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHeatmapDefinitionRequestLogQueryGroupBy]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d0c9900f8e9db507c7697805526dcfbb49cec84b9065085e40449c4d25fd2d7b(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__75b10452573df6bd35439af5c930bba46007137ab7c905cc360a2e2b8451d5b9(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2be85332e231f50dce249bd3203b0e501d8e3d4e17568fbe1d855c6a6835fa2a(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ed6121b31c7253baa90019a22219fa0ed4f7a2dd2c8cbdd483e2112d5fe82be3(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHeatmapDefinitionRequestLogQueryGroupBy]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__25b1f3c7752f80fe403b348f283dd0c8d18c99f6a50f31324c6801427b8c2bf5(
    *,
    aggregation: builtins.str,
    order: builtins.str,
    facet: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d65cdaa72e4d7e5ee77ee4f2b4e93af39fd6c2c9efe9aefa16c827e08369e2f2(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e1a3866d31216bc160df3436abda68d2cb4bf12120efa96b028e924fbe037ef2(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__eddf101cb7b8f990347bf6946e52b8a61a3dbfa37d1b97482a0e7dca007b27cc(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4925ec7c574f7813e87ebccd21a3786aa535f97563d162dd317d8798cffb3583(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__99b02b62ecb0836148a815daabf1b7e1ffe282d156020b7a2c462a5d139ad321(
    value: typing.Optional[PowerpackWidgetHeatmapDefinitionRequestLogQueryGroupBySortQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4031bd28b5cba83342a7dcb04cef1d91b3ec9c1a0521faf34b0eb7f4d4b8b2ed(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__78d1e6fabcf0a2edd960e78b965e1e649116d7474d77f72ff3112b68e63ba8a0(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__70cde8d3084522a602d78569577421d1b74832aafe4c2423546eea0da1b67bea(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__39e278240fa402683656d966ad4ae0c8938a8d81a19bfb14b0966d6f81d1670f(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c10e8bd776c5783f8c819bc34fb07132337e9f803d54ebab0f826335eedb8bf0(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__515b15609132ec1a8a53141e390fae03fbadf20b51c16ff90c761d410f867d02(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__752243b4dc22199bd571abc0374372118fef3133a0e42379163509d9b4e6cd9b(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHeatmapDefinitionRequestLogQueryMultiCompute]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e406df8fee18d70f91944216ccd7079df62a656703908f6ef8300287ed4e9577(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c8e313d298141aa3feddd4688dce6f555163f67888b7fae3a3c1476c9850575a(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__599fb95140c163a1507e065becff36f5c40e61cc1cc2e7064b34ffcad386e5ab(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d25d8872cf61e2c44af6751d2d6bc6863ee5f53fc4d573692b9d86a033dd3f8c(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9b37b6b0694f5303f04d71734e035b7368c42a789fb45ab0c657c6b15c7131e1(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHeatmapDefinitionRequestLogQueryMultiCompute]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ff7690252fa005cd5679682a634ff881d22eec8a577def9dda64597994628442(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__befb37dee1b5caaaa4ccbbc4581502aaab88e860bc02222731e897aaefee152a(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHeatmapDefinitionRequestLogQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__92a88bc81df15ff297ee81bb9cc6fed82900490e7866cb0f3f8f18163fee9b03(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHeatmapDefinitionRequestLogQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f05beccf7ee495f1ea2996444fd61f1132fc168b79e1cbd6217a5766663eab01(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c16659bc4d5f2d1d84aaac5519b5b9efdf2bc1d35d382e48f4187952f9fd9193(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3e591853e1e1890f9aad0ee63dad4d168595c8baac29ab9ef1ac2e6a7da2f355(
    value: typing.Optional[PowerpackWidgetHeatmapDefinitionRequestLogQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__80ac84e6e0aa181244fbc5b0b652a672da0242b137b9c32cd32b2a7d4c7714e1(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c0d3d7cec00cb61dfe750641ed4c53b8bb4b6890e87513725931caefd8028ef8(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHeatmapDefinitionRequestFormula, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cfe347caec10ab1e2df5bd27ea3bea00617e76b659e4783b07f602b0e3734223(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHeatmapDefinitionRequestQuery, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7a1d15e5cf584b4d65f1f6f96ef282a45a4e164f257748fc3200845df22414d7(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dd21424f41b82d329d025d782f471246a337a211211b07582e02680f04ffbba5(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHeatmapDefinitionRequest]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__58a5460cc2c148cf18d53fe170768e7c483f03e6cf38aefa4220f555f1922873(
    *,
    metric: builtins.str,
    filter_by: typing.Optional[typing.Sequence[builtins.str]] = None,
    limit: typing.Optional[jsii.Number] = None,
    search_by: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__67b4d8c6146f730403c4646635698d52d5ee723c102591d06957b520f01f17fa(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__870e5bf805be3bdede3622035c667282000004c11b5aa0de00858a614e056c30(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__899fec60f3b70a7e802f434b2e46c3f2dfd561011416fc37f77b591a91a1bd0f(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a2c8406ef4f411d972dc6e6d3c88be1ec482e7781ef01ae288d1f16316529172(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__42953e44b12ab78d6d7cf0e98043f43ef78f7b360505ac9fa503d9871560946c(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b6ebb918ca3e4f76c8301a5ca109aaca7c554403da94a8de7bcf679428868310(
    value: typing.Optional[PowerpackWidgetHeatmapDefinitionRequestProcessQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f09e4055b8316edb403a6c969bb9918ca3df3879fffeb88bcd1cbdf28c8a9168(
    *,
    apm_dependency_stats_query: typing.Optional[typing.Union[PowerpackWidgetHeatmapDefinitionRequestQueryApmDependencyStatsQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    apm_resource_stats_query: typing.Optional[typing.Union[PowerpackWidgetHeatmapDefinitionRequestQueryApmResourceStatsQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    cloud_cost_query: typing.Optional[typing.Union[PowerpackWidgetHeatmapDefinitionRequestQueryCloudCostQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    event_query: typing.Optional[typing.Union[PowerpackWidgetHeatmapDefinitionRequestQueryEventQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    metric_query: typing.Optional[typing.Union[PowerpackWidgetHeatmapDefinitionRequestQueryMetricQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    process_query: typing.Optional[typing.Union[PowerpackWidgetHeatmapDefinitionRequestQueryProcessQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    slo_query: typing.Optional[typing.Union[PowerpackWidgetHeatmapDefinitionRequestQuerySloQuery, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__aa7da6179480e17f18bc6ee79f37940c5cde7544827b96e4f8350dd22bad123f(
    *,
    data_source: builtins.str,
    env: builtins.str,
    name: builtins.str,
    operation_name: builtins.str,
    resource_name: builtins.str,
    service: builtins.str,
    stat: builtins.str,
    cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
    is_upstream: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
    primary_tag_name: typing.Optional[builtins.str] = None,
    primary_tag_value: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__842c1d17518ead6eb6b7aaca4c6609412598fa8e600176a6eff6b7c85d8b1955(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4d5f0acd1ec70794cadfeb4cd7a817944769299436d9284aa4485eaa88b42081(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ef3efaeefda82b7dd55ea433f8637e7f9630b02b50d92fbb5f486a3ef9258067(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__094bda402d5f323b5ade6962c09d242ea7b18a6b4ef86e751cdccedcf7538450(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4010c07b9bc852d91f021038ede57c86305b55d3197e374ab392c2cc9d8e9967(
    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ab63dc78f569929be5d91feae4a4ff1ae87c52de60f644af719bcf7c1eaf6200(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__25611818880935675d326e598bd22d3df8b5ad50735b83042131330f4ca8f462(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a4aba587d40bcdb6a4082610c0179c49af163aade34dd26e5737eefcf1a97dde(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6b7cc4ed4b28f720f6460b9d849d32572ea9aaf6433e5c3eb967dba268edb2ad(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__66a45cbd5221110a893570d28771f647e8e770b3c5af101713bee3a2aad16ec2(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__98f81fa724b47d0173e905e57013bfbc76f9282bdf9f37533145d38c6e357d04(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2ec5ab654655d5b7e843630a222c25f0767ea06c9baa5b576891cad2a411d04e(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fc036318d4dab1dcd4aadb4b7e4b3de5ab4ac967ee5f35c5c474503b07652b2d(
    value: typing.Optional[PowerpackWidgetHeatmapDefinitionRequestQueryApmDependencyStatsQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7d58d10486ab7cafef7a1d80493a55f1723b105cc81b42984147c8feecf0d580(
    *,
    data_source: builtins.str,
    env: builtins.str,
    name: builtins.str,
    service: builtins.str,
    stat: builtins.str,
    cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
    group_by: typing.Optional[typing.Sequence[builtins.str]] = None,
    operation_name: typing.Optional[builtins.str] = None,
    primary_tag_name: typing.Optional[builtins.str] = None,
    primary_tag_value: typing.Optional[builtins.str] = None,
    resource_name: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9596a24c2737fbd1e6d26658074866dc0331a8eff571cf42b1ff387b574abb7d(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b3971f1ee8ce76ff9a3b3eb07ba29c29264b8f5d3918277f54c1ff84ab6ac042(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__060de5e54945552caccd040ef49bded47a2c3a7eba679f32bd080a2c4f4f636d(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a1f5619f54b6cada34b186bbcc56013dfd5e3e00a83cc2b3e1b83b936db38cfe(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ebca92a0b9762de4be05555416cc06927ccf9b958dea482031bd40ab90905864(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f70eeee594282e7598e64bd78c5995118c66f19893e0e3c144292fef6e4f67d8(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7d1e11f46fe46b636cd5add7e05bf04363a5b8f9b7f53b719878d22f620b7423(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fad533ac091ced9e395c04606b011a12abaf7567e46b6cf89ecbdd37da15ced3(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__827133a8c3f18ed265dbe9fd9ed063ab560655b05dfb4c55fc03fbaaec3ec42b(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f43c93f61e6b96f3842135a0f066e2ee2147b988d9812b759ac1cf5a2f4367a1(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9a2d94b377250085292d71bb49a9645fe40c07668dd263913747e63262ee51eb(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__950908693f7696b060a8fc555d9729860e9681df10590ce9cc542daca9e9951a(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__899c9718f2d366e58d494201ef36fbcb8137d71782bb2cca90ade2e9b6c0de13(
    value: typing.Optional[PowerpackWidgetHeatmapDefinitionRequestQueryApmResourceStatsQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e29204b367379cb5fdd1ede6f7afe693bb0f0be920f80c6ecc9c532f3b9fa977(
    *,
    data_source: builtins.str,
    name: builtins.str,
    query: builtins.str,
    aggregator: typing.Optional[builtins.str] = None,
    cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4a902041579a099fa46c0b4750b6ed7fa2ba49cd5fa37c30650b127c3c397430(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4556ef93f736b73c1c6d486af7d8fcb02f05674e9ec096489660ba50f464d3a8(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__02e1c9b9a741018814d95f3318ccd575872ce8c79d1fd56db39cd181a58809ca(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d6225a47a938b037f148fbe997eba31b177bbd5612fe2e54d054d58fb26bef61(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d950ada4e6941d00d818f09cad597e6763302a406cf7cfb5733730a1c8d392aa(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c2d9125d20c770421f1e7b5466b6d3cb0b87e7a0880a27c73fbfa7ddd08b4f34(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1be973e8e452b83079f3991fd25e9cb860ba148bec4b4bc124201e359ef2c2fa(
    value: typing.Optional[PowerpackWidgetHeatmapDefinitionRequestQueryCloudCostQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7fdafe8f8b22a7afcdb4cf94a2366ec8b07cc09832bdef98397558042725a28e(
    *,
    compute: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHeatmapDefinitionRequestQueryEventQueryCompute, typing.Dict[builtins.str, typing.Any]]]],
    data_source: builtins.str,
    name: builtins.str,
    cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
    group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHeatmapDefinitionRequestQueryEventQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
    indexes: typing.Optional[typing.Sequence[builtins.str]] = None,
    search: typing.Optional[typing.Union[PowerpackWidgetHeatmapDefinitionRequestQueryEventQuerySearch, typing.Dict[builtins.str, typing.Any]]] = None,
    storage: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1789ade7ba3f1c98182af230fe04d172880d2947ee4e3c1f01cf39e9b401c73e(
    *,
    aggregation: builtins.str,
    interval: typing.Optional[jsii.Number] = None,
    metric: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8797ea07304fd44fe65efc1ab213bf15d2acd30ba23088bcc039eadb45bbdb27(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__84cb6c268e9b1664b0afa1da5dc534af04293d44b7b7712fba29c1b5465ea918(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a6b576529c25c126fa215d887de01d67c41869bbb661158d314be238d2f68ea5(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0055e0913b8c69b87d3baf6220f330041e2573c99a92eeb0bf646ab666c5e4f4(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__963423daba4d5b527f1a3b065e17cc467c79bedd019711bfe3795afe4c1ffab0(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8ce229c31dc00096414f765f6681d90c36a3e1d1d36eb739c72bc4f0652822cf(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHeatmapDefinitionRequestQueryEventQueryCompute]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a9e32b47ca1163d86e251c83916bf6f8e0d7e71f2af43bd39309049154307886(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9daac4b4fb5215f176bbfa11ed378f50f6a461d293b4ff097f964642951f5e42(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6ea7ceaf0ebab6e0e7820301ee21d2fdbb3f2e79522c72230bb2eba64e62a429(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6e3ce8de3fe180e1a2ac95e614cd85253e7a7020e809063bcc25141344ead0dc(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5957e6030a137b5e3642c6c47787c16d09fd88b38aaa84240bf888ed359d7f4f(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHeatmapDefinitionRequestQueryEventQueryCompute]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5c8555ff7d6fccf92db72a9a20c22ed6f7f61316e116a9311145f219533a834e(
    *,
    facet: builtins.str,
    limit: typing.Optional[jsii.Number] = None,
    sort: typing.Optional[typing.Union[PowerpackWidgetHeatmapDefinitionRequestQueryEventQueryGroupBySort, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2dc43b958e54efba377481daa45cf11225df6fbf133cf0f4187e80f59688cf11(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c3ebaf96b8021ef074750883e35f096803ae5bff4400786f54fb6b4b2a3fb022(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__10a95dad2fce857db3a027807c0934b9f90558bb80e67699de2cd2255d827a8f(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__af3e5d45b9d9e558a4a78f2ab3e4602b4cccc38bf98e741432938d2c026b4212(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__af062549c8d86e0393cbfebce9c6e90054c5e18823c5350f79775091e52195fe(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__07a1c361ebeca11f615284f902d2523c659c1834d3c7dd5208cd91a1dad17e95(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHeatmapDefinitionRequestQueryEventQueryGroupBy]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8a86297afe9f33593c945438332eb37d791e107b8718f228799ffc1ee1a3a0e2(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__234ddf5d216dc78cdd8ecbe5f017e4e0a939e732538dff541b1fca8a1f131d34(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4833992b2ee90db934d1fd2303a0092d780bab09d66cda5768ba690f6a35add2(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8ef41c396a11117a9766c79bad3056670c3cd8998b00722264d2ec8be2b2c2ce(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHeatmapDefinitionRequestQueryEventQueryGroupBy]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fb976e2ad571a1d64df131ecbac0235404a8514e67a799daaa9a63449be71bdd(
    *,
    aggregation: builtins.str,
    metric: typing.Optional[builtins.str] = None,
    order: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8edce651b537a398eaba02bf64220fab5fdc2f0d64d395c7d3728adc1510100b(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1676b63c5f9f92ca41069c934c31237acc6895c542a9a0f565e78e0b3ae44300(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__535b2f978a3b46290337ea37a298dccad0b55aa801be6054eb3ef5507e7aed0e(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e1fbdbf76f9e314dd58f9edba7d91c93fd91f8309e4ddc5a8054f43644454a56(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__daf6aa37694a44a260c20d782e7f8f7dac295d34beb3280947ced9a5d493bd5c(
    value: typing.Optional[PowerpackWidgetHeatmapDefinitionRequestQueryEventQueryGroupBySort],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ab154ec04e48d5ce389da97ba3deb7a6680455945cfa9affed72156f093a19eb(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a5cdcac96ed0a60e6dabdb041cc8a0da7c014ef1699ceaf9ff978c4492400da8(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHeatmapDefinitionRequestQueryEventQueryCompute, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a8e27cb11db976b7d46be8f998c47b1cf6748239b4f82676a63315562c1bc645(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHeatmapDefinitionRequestQueryEventQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3b6e1e9c631be0afdf14aa9b31b7b72e9425308cc3b3753e81b7ba5278105dde(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0437fc3f9ad2a454b8d7070174072ad737a5d26446241eeba896db20c5e76beb(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__84f12d7028a053b98b556effbfb76c12963853a04ea50aa26a44d8f7a67a8b69(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ca3bab05aca442b912f720c29518fe0822cd7526bbd2da0a551738c263ff4ab0(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__44e21a41a181ccbdcd2720abe0d63c55ef46f01931d53a2f98fa52cb3ec9028e(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a6200e88ee4290f5759228d1c2ca3d8b63c6009041b4576f00f0befba0fe8433(
    value: typing.Optional[PowerpackWidgetHeatmapDefinitionRequestQueryEventQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3f3bbbcc034f5387eefaae82ad54aaae2596b4cfa0018e1c60de232c0c1bb014(
    *,
    query: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1326c029351dd8a9d2f1cf56c2fef0db167e3da7dc5a9787f99db055f7d2c979(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c26708d4cc5e1924f88bd8262d02b2f9ab01c7b8f85c3f4f302c3f49270f2067(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6f27c12f480bf69109a851f72cf5dbc1793e7461b4a27e04ecd7da5c2c41c242(
    value: typing.Optional[PowerpackWidgetHeatmapDefinitionRequestQueryEventQuerySearch],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__39a34a29ffefcd65dcbaf31fedd8cb35ddf76542d3f2c844317e9275ca938439(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a6ce3d56d901d0d290db38cff33ea462bef29d90a3a7513232ba3d76c39a7e18(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__afb6e85983eee283235280ac6bb0a95efe47af44bb6f85574d77ace7ad167f3f(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7d96acfda853852c248c78e416b270acc9f8fed67d17aa714acd17e58f5fcb43(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f2e1de43aa08c2c5e989f8ec8f5e475c69672a391143ca4479717ed7bda34448(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cacc04f9e90d3e8fb179e2aa26926a014a8b4a5ef4ca5d2f19474e12cec40c8e(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHeatmapDefinitionRequestQuery]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a4c10c3e60727edb826fc9951000890a933214f8b8e69ebd4bf503b1ed2d310b(
    *,
    name: builtins.str,
    query: builtins.str,
    aggregator: typing.Optional[builtins.str] = None,
    cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
    data_source: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__18c40cf23410ce05aeeef7f370d86eb64ac2c57be4196f96f88fc7ae915e0ec2(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__55f204c8f509831b1a67da70cd3605998a2d51521dd6178cd01613c198b38d5c(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8efbf78349f50b09bba0a2ee4d47b6ccabaaf10d11fb49c064132e1549b13222(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__34de44d6e93a4019e3a925671326436b780d391ede396f2dd08d3606252f2383(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9f3b25c8f1e1b78327ad911c87c0b1664ad6b90f13360e314bb8a68e70bb54e1(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c7879fbe739ad281890fd15d3f5dffef8c31cf2485295fd82169f127e65b70a2(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__db0eb86c027dea1b4c7ce07c3197f7f2766b2ddeec990dd99cc75aa1756731d4(
    value: typing.Optional[PowerpackWidgetHeatmapDefinitionRequestQueryMetricQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9784668d921bbb667d3cf0bb10052273d034386047821c35a59f4381ad0e793e(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6937615aa9b6c53a0aa00530ccd7f17a8757bf9905b9d998ef84fa009edbf930(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHeatmapDefinitionRequestQuery]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9e376f017dcab994ed4f15c52a7441827a5f310708f820ba0d21653453551641(
    *,
    data_source: builtins.str,
    metric: builtins.str,
    name: builtins.str,
    aggregator: typing.Optional[builtins.str] = None,
    cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
    is_normalized_cpu: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
    limit: typing.Optional[jsii.Number] = None,
    sort: typing.Optional[builtins.str] = None,
    tag_filters: typing.Optional[typing.Sequence[builtins.str]] = None,
    text_filter: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__50e29e0aa453fa546bd0d5ad473dd154800de68652bcc94dad93c588a08781cd(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fca177f2f6e9685dc0f31478da6d175ffbb08188b81ba6b7b5f13380c918bb90(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2584ac66363eeccd7db2fd6b855cde197c9b1d56e0ff714d33c7b0da753056e8(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c3a07202b08cafded7d8a857b17523bd438bda0983d7d6234c8141153bc66458(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4354eb8763d5af3a6d31b7d28be5db0e12e1685a67c3f6651eb23615841e743f(
    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__62d35d7a988a1d3a860543c2a814dfa6674a814bb08374edfd77386ee3dadb98(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8b83652e6b80e773314d9e2605ecbb1d873f447cda7908883ac69b469bc795dc(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f190d65eac4e8a8a13f23be87c228789adf8a1e2020ffed2bd1963b5d59b463c(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__95da463081621cdf3ac84af49879f19432a2a1ef16e5c21641b46f9c966a36db(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d43d84ebb78dac53ce469596474bec02498018072d7756e5369a45282c8be356(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2499ade14057327cda4bb87d09a87dbbd7679c352601bc7eaa93edf39ba6d4d7(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dbe1b3df79aeb264f320deac85b2d7135794bbfbf4e06be21f1e23d6a9b69d4e(
    value: typing.Optional[PowerpackWidgetHeatmapDefinitionRequestQueryProcessQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__daa8c3c5f451ef2d03aa7647bbc178603a60daa59990a6f5287fc614fc59f1b1(
    *,
    data_source: builtins.str,
    measure: builtins.str,
    slo_id: builtins.str,
    additional_query_filters: typing.Optional[builtins.str] = None,
    cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
    group_mode: typing.Optional[builtins.str] = None,
    name: typing.Optional[builtins.str] = None,
    slo_query_type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__48c3539dd0dad5a96fb5be29902dac40655c9c332a08c9c2f2a06b6baee937d4(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__87ad2e3dc2975d7ff35da4963b8c032c3b452fb6d3d3edc810ccb9ff5d8be1b0(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6c708dc437f3de9eced59014ab55ca285fc89a417bc7cbb91c559bc419199e0f(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8701e09de96a32793a9ea2bf3f8eccaca4d86c933a90e1751e658df7c79b649f(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__834ad9656832cbb924d75c7e84055900ed5860838c064799d9c06444344e96c2(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cbcd553938e84a8bd3d690083917a8c79993e1ed6bd1a333d6a85dc6de393b47(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9ab47b3d7c46ae1596d6c8431e86d0fda69294c1c126588fdde09687cdb66bbd(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__af52610e165650f7b25eb86278ec2876a6e2e2da45c29c7be6082613c47e8d2b(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__73a6aad4480417208be7438c510133b39a8cb48d99ab682affcd488c6edffbae(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__92d69f587629221c22226d6066c7eb182bfa6f55d5e93896a1491efcbe43b1b9(
    value: typing.Optional[PowerpackWidgetHeatmapDefinitionRequestQuerySloQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__271e34a6b8ae0f1d200ad36f07bda4402a9c9221044988d8e541e28ea2494f3b(
    *,
    index: builtins.str,
    compute_query: typing.Optional[typing.Union[PowerpackWidgetHeatmapDefinitionRequestRumQueryComputeQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHeatmapDefinitionRequestRumQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
    multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHeatmapDefinitionRequestRumQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]]] = None,
    search_query: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f7fe9ec3e0529303d5e24aa156b65aafe192e5605c8938261e077cff43b54711(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5a7375190e70b195a5e0632b24174dfd393c82d1642c1320ab997eb829ad7b50(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1c131c0b757e08fa422e58ae812369a90a13c0adc4e9e3ce5acde9653b3e0971(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d3c44791ef70ab8fef51eb6da0b19af1a7e40e316c1c93c178f53e22fca1fe2c(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a71bd6e5500ad8d48466aceb77597147d6594b6a2d4fe80f96de0153c42824be(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a8445533b5d19e381f98833cc336b339f016b09b150c6f086a75ac3aa078bf60(
    value: typing.Optional[PowerpackWidgetHeatmapDefinitionRequestRumQueryComputeQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a43e56956dbbcfcae3ea02e3c1d9d334835f4f0897f34bd5c2c17db0b4618876(
    *,
    facet: typing.Optional[builtins.str] = None,
    limit: typing.Optional[jsii.Number] = None,
    sort_query: typing.Optional[typing.Union[PowerpackWidgetHeatmapDefinitionRequestRumQueryGroupBySortQuery, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__362fe3394fab902e6c7ded5a15355511ffe04cc958590a771ae24ab85135ad57(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6ba913c4d6f0139f77237ff1deb1cb04e5e5881a474f886586814379495af2b8(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__446b358177cc2549ecb4eadba18f6d088932ff2f27c2802c6b888ef8ea08a8a7(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__008cdadc526ba0bb0fbcef98a33b9a959b186d8505f1cc2e6e70a0ae4c3c8390(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5061789deea63f61706694c1a98e4766dcf341db11b97e593ac419e55d7365cd(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0270a50b8d79d8fccdbb588823856a6e296a6cbb33498bed9bdd4a0b28755173(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHeatmapDefinitionRequestRumQueryGroupBy]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__659ad72429216e2252d40a852d7562e9897631bb9f1514cd85f0787b6b508235(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__80619c6adddd58de491940dc8eecc29f0573d8bd113258949ba03895b4392b51(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0062edd465606333bfd661c75fb7a33170a15430882f6da8dfbf748829d6e5f4(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__be9ed37c47a939a877314970fddb40d3266ddea0b08d60de2e24d1c918c24cd5(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHeatmapDefinitionRequestRumQueryGroupBy]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__638422331b48fd4c9520281dce777e9d96923dd16da9b2fe251ff987ce96891e(
    *,
    aggregation: builtins.str,
    order: builtins.str,
    facet: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3aeafc44dc7dc0196e0a868c267a8a9609d71f4895b07e5b865e61bdf27de6d9(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a4bf20aa804fa4a01ab7863f3928091f466e246c3c054939002f2d4318b0d5f7(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fc19685b7b4c73b3a5d77390f59c03d44a2d877495d0e4178be2c104ecdaa1c9(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e68e53b71883a4e211c48e5728c27540ab070f47ae3db133bc95d272590dc38c(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__910e7cc7c91ce257a90cae6350ab428738def240bc18d2f00fef7ffc3079deb9(
    value: typing.Optional[PowerpackWidgetHeatmapDefinitionRequestRumQueryGroupBySortQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b624fb89e1c2cea4950861b458935c21e9080ef807587c66e2dcac0430a79c02(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4a7184877d5683bf1f47690b134524a4d7f0bffbc88d47085226dfbfe5dc0eb0(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__93cb129987309f1708a9690582a60fc4caf28b822fdc7c3b90d8855e9eba6135(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f384d5e793b598701f59ea4c7b0d16be7e21344158e93fb8323f018a05143d07(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__96afe5aabb102902375cfcbfc03af9a316a038c9ab6218899c1ecab0809ba90b(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1f23d5e08680371c40e0640767e8139d60032bb95cf89480aa6a3b8f5edb357c(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7f5c7439fc61b0e30089b613d085b491602d88d6d33aa654c7904584a8f96f00(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHeatmapDefinitionRequestRumQueryMultiCompute]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9f4c5194abf95c02179c363cf3f1af963d29987c36cf54a15bdad1166af8b7bf(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4882bb36054cb8651d2167cdb2c7195f6a6f4a7e72854b1c5622a355c24831ff(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__76ebd9a235c83895c47752728f9d3839c911664a5f722a777a3e9ccf71a05918(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__74d581cd7356ea89dce62f27e4bbf7e74f64bfbd17e4f16073b3684c0372c3cf(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1d373d02ef6d16956ed4fdb03127241caa71a2b1c3bd760d73ff75bc44a1146c(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHeatmapDefinitionRequestRumQueryMultiCompute]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7f7865c00e4871d5e819caf9e3f02ad35cf724c2e4b754d4bf80a7fcd291fde4(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__15d50e1ecdfc58849929c6480053be8076df68b486a0b298f4c836c8424b81b3(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHeatmapDefinitionRequestRumQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0878c1197727d54a681f3d205f2d644864bcbd66995cfbe8cbef766b501ade3b(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHeatmapDefinitionRequestRumQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__08d4defddbd965ebfd9de7892c75e1ceaf8ac34b633806a1010fd6f0b34b4a65(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9ed0e24146dc6e6ef6caf562229bc489c128fe2525c86224fb9faf0e14438300(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8d2b4e43f5f63c0f6682f27c37f62f00f13c881c267b01e9425fbb575d0e8acb(
    value: typing.Optional[PowerpackWidgetHeatmapDefinitionRequestRumQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__60abf27a1c4abe214e6e8701faa7281ffb281019336676949f8073bd9c56e63c(
    *,
    index: builtins.str,
    compute_query: typing.Optional[typing.Union[PowerpackWidgetHeatmapDefinitionRequestSecurityQueryComputeQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHeatmapDefinitionRequestSecurityQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
    multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHeatmapDefinitionRequestSecurityQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]]] = None,
    search_query: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__69ee706458403a4c824e59fe1ee6921b34e877cc7a2d1070f2b5cf6be57bdb7d(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__90726409b23064f4719bf46b5314a0921f90d3b79c8f705652bfa2e7c72092f7(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b256f572931382ebd2aa26cbddd79ef91489d5e659b2de3cae963fa0c447a842(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__eb240f5be20743357bfadd707c9b93c96b6198ad83a5015648bd97b49c33f1c2(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__79738cbdb3cdbc6ea1fb7afb080d9c5c9ebfc96938e228f96a41c4457ab1923c(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2f4406bf4c0939d410a671f58974e7e20a6fb4b8fba71e2b22a0b10d77ea9d8b(
    value: typing.Optional[PowerpackWidgetHeatmapDefinitionRequestSecurityQueryComputeQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ddf60d45c7230a1305d6dcfeb1412c33a77f62fb5192181921719e5904b2c00b(
    *,
    facet: typing.Optional[builtins.str] = None,
    limit: typing.Optional[jsii.Number] = None,
    sort_query: typing.Optional[typing.Union[PowerpackWidgetHeatmapDefinitionRequestSecurityQueryGroupBySortQuery, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8eedca56c0ad62e0b0d5403029af526a9903a5d807a9819449e8e8a0128f2a62(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__961b4e2c1ba6106ab27dfc9a3887cb99e498d96164c0cce211289cfb37ff77a5(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8b7ef5d7a47e2c6ba43e16c83e9b07f3017eab1a106e196c857399afb43f2ffe(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4daf88cc47fb5c05318c2f6776263ba41deaa66b6c939e64a35aba27f454f07e(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e21a9a666d862b9b0883a2e73fa8c35f86fd10844940566d5cdfce2d1e62c977(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c4c427935f32e859052b9631bddac0e38254cee5d3adb44f6b4f980f57136c26(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHeatmapDefinitionRequestSecurityQueryGroupBy]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8b66af30599222d4cedcb1e4e0fb513f2c187b32ea0031f63f81792d83c13e67(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__298f9f9bdffe9c37be4d4fc1a2bd56c1a52db3e7a5d4b180faf31a3d90f75f6e(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f5fe19f6373f3a42601cf46673c29092c528e6af0a49cca7f0c03b92ebffeb36(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__31dfa147c6632ecd2e02668524cd466c76eeb564854d8a76e893a39f4411d0bd(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHeatmapDefinitionRequestSecurityQueryGroupBy]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1e333ad0baf239d011ca3cb3bdeb310b73ff98786835f3c7779056d35e8d1871(
    *,
    aggregation: builtins.str,
    order: builtins.str,
    facet: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9449a06e9a462abb9bc95d549e697c93274a9c330962ba2d882872a9334af2c8(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5bf4be18d6990fbfa628a3a9f18cd31ab759126c70214849136b229b11221f90(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__99323aa32f71fef730cb7812b6228069ec4753e129935ed935ef2ac57b4fda71(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__619148263c3636756891c816c2ae426ad279ad18a01eccea9930ca592a941b0b(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c819ac0c0e9dcc0a525af97968f531336d45bb612c903c3f7226c5d6ea637934(
    value: typing.Optional[PowerpackWidgetHeatmapDefinitionRequestSecurityQueryGroupBySortQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6d06d2a22a6b0c486d90a7eb86e68072844f8cb404c5b5a38ac724977d8ab5ba(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3a47326f029dd2ddcaa5b244fe4a0191890cd341ae5dbd37df4e351a990803da(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9e9b82410c219e292737eb96391a05ea45482bec5e11a07646718109eeedde4e(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4473b78c1cf9f2058afaa10d2a72a753a3349a73ddacd9f84984145b7b027b82(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__92997c93b64261b1318ace7303546c24b7fa7103669e6501a5964f0304c0ca20(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3649b1fcb4255e9cddb0bee9c8e70f75b046c9f3740adb4c690fb4cc676ea884(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__aa907f5c45e6c545fd7aa80c66f8336fedfb11f450fbee31857e88c5d6853877(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHeatmapDefinitionRequestSecurityQueryMultiCompute]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5eea41214ad981fb0186d82ba9c35704b122feb41e6969423627c8914921a105(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ef74dec2379c147e6f332db9a43d2358b069a739da7cf58ed2adaf3dfc42ca22(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__38fbded4f8670eb24a9ba9a7d96040ad895046740f1ac7d43dfa84640d64d819(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f6c371a1b29a35e95e37c07254c0a32ecd4b5402e234b75e2f20486c2b7113e3(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a59550f4a25da86dba5768b05bd5c376d72402b99ca36d24895552437143dc06(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHeatmapDefinitionRequestSecurityQueryMultiCompute]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7f027f4e9e4a69ea4a2452701968a49cc4e4b859c7dd31653afa331ac9bbb4e9(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cbbca7c71f2aefc6be3e2b4e8806aafe660849ea0105593d6499e8a6fdf96206(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHeatmapDefinitionRequestSecurityQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__726491647a588675a7747f06fb8677dbb17fbf2c5b40f7d93d8603b3901fa2db(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHeatmapDefinitionRequestSecurityQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ee7285b3d29900b5dd3e71860fff69f011c2a468db1b3d2bb3f535739139ab05(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5a7cd37a7cfe6156d0d92e6404092a5fb1c48d38a85a08026af7752bc5ce04dc(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__98e3f3091628c94d5f51641b430395940379c0e17f8315865643fb69aeb64cc1(
    value: typing.Optional[PowerpackWidgetHeatmapDefinitionRequestSecurityQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__94e530ed242174b3fa02e6be8aa963138243ccd9950e8af4fd810b1c87b1f934(
    *,
    palette: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d349302271f10d025a2a71c0fdc2e4a9da9c3acb8a005d344e3621e44bdbbda7(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d1f4d7c985eb6e1708f4e307678d010148492b75f4766dc8b6a56d8cf4d54c9c(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b00ef504bdae25c228d55bf931808bd5e9da4ffa464f8cfa51ed06c074458ae4(
    value: typing.Optional[PowerpackWidgetHeatmapDefinitionRequestStyle],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4c2c395e5f7219919007129fc1b7403b3b5b134f75064c9121297fd978553cdd(
    *,
    include_zero: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
    label: typing.Optional[builtins.str] = None,
    max: typing.Optional[builtins.str] = None,
    min: typing.Optional[builtins.str] = None,
    scale: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__924430423807041992382c94d492584cebc797bfa8e2d647d27a850b035cd071(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c89bd24c171ad2abf1fb696da15d8b77909925d142e647579fa67a5c8a9265d7(
    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__aee66e7bc39518b756b04d7e2c40639287552ce34e0071b62283207d704be305(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__acc9612e20adbb44379f216c706bab36870181508355165e8779fb4028865a63(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c8328e59ee3550f349207297fb9cbcdc15dc7b66819f7d06fd73aab751d5c6fa(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a4051a86571a1e653c2bac840af092fd2b8733fa7e9dc904ea90af146b65dedb(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__25e58053a3212eb1dc90b18598c2d555aa4ae0e5b9f9ed2e5aa0532e48d90d4d(
    value: typing.Optional[PowerpackWidgetHeatmapDefinitionYaxis],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4ffcdc694d1b4b6be6d5c719bf6dc44efa78c8d5e72e8a80fb19c342bdcbfd64(
    *,
    custom_link: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHostmapDefinitionCustomLink, typing.Dict[builtins.str, typing.Any]]]]] = None,
    group: typing.Optional[typing.Sequence[builtins.str]] = None,
    node_type: typing.Optional[builtins.str] = None,
    no_group_hosts: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
    no_metric_hosts: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
    request: typing.Optional[typing.Union[PowerpackWidgetHostmapDefinitionRequest, typing.Dict[builtins.str, typing.Any]]] = None,
    scope: typing.Optional[typing.Sequence[builtins.str]] = None,
    style: typing.Optional[typing.Union[PowerpackWidgetHostmapDefinitionStyle, typing.Dict[builtins.str, typing.Any]]] = None,
    title: typing.Optional[builtins.str] = None,
    title_align: typing.Optional[builtins.str] = None,
    title_size: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__da178905759cb5230fb0092e435290834440740c579647e5555fb2abd3abe399(
    *,
    is_hidden: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
    label: typing.Optional[builtins.str] = None,
    link: typing.Optional[builtins.str] = None,
    override_label: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__70df2fdf5b7087b5f55b9fcdf33d4470d6c7830ceb2bf23ffe2e57254c512aad(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ecae0354eb7e262295ef87e2f6efe5604586d1b9797a1f3674e4e9e46ae65d82(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fd91e3b9e9e696f2712227827071c0fd9df6574632bec35dd2599b128610583e(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b33836ddae020800fe648301afc5ef5458ba0e4eae10175daf4447d6eda9948f(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__61510da9811ac43ffda8aa163d1b1bf684638a58fd7529f48cc079ca878203d7(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4227f2c976a5f5108d6049b084d553ce5619758254a73f5a7147cbd8d13f2ef6(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionCustomLink]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7e502cdebed239b509fa21ccc2bccb956d402ab82076e83b39d1449650862448(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5ab148fed33dc86236b343fe889a9152b926f2f4c93154a034a511eb0db1b43b(
    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3f69b7e0bc17297c76bdc2e0c047c6f6c67679ec0cf5cd9756c991fe38cac33e(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__29e299791d5a817b167b75216d457e6893e0b58a6ca03246c8aee37262e41af3(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dcdd38087223586c27fecd733e132a9a7df3671a87365a7954bb90e7cf1053ee(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9e2f096ebc21d429399c2bef077561f7c3c646bdec0ad24bcf3968f47c950632(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHostmapDefinitionCustomLink]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__aa9acd695b04ab7a37e35ba496e35755a8160ce4c01d3864aaa41b0ac187a7e7(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__00a61caad7cd72fed7b8111c0e30f06e0fff5cc6c04cfe737285bf8597b8c1c1(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHostmapDefinitionCustomLink, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e41b223302901141d9bdfb64966cbebe91799e284d8babb175766112d23d32a7(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5b1955ee9931732cbc78ed246cbac6c1c444b5ae5fad2de200fc6cf554aedf63(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__577fc28e1f9a878ae0b0f0c1b8c50471f3d3b40e0b91317f48dc62b60e6de48f(
    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c7617373783df85881308c4b924c69cec2f2ef0ba6dc9f4e735cb2c56a640892(
    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4e58887f027ed58f17f0d988fa2baf81454ac7aaf156d9fb36535fcb215f1dd6(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0278a60fd04aaa45747f2d593acca763cf89fa422b0667c4311952a58f87b481(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__08bf9282fd2c67d412867e6bb8557d2af9804afe5edfea9bd64fdf8d42636126(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ffa504432b54ac2b0ca9b7a56986aabb776a2fb84205b9b3c8eb8dce8e136798(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__87ae5bdbfc6d996bf778a1302a1671685525928ab2c19dcc1460ddde6ec5fe94(
    value: typing.Optional[PowerpackWidgetHostmapDefinition],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e31b561284805d8a11bcaf17250f240898d56cc055229e05ccb122f111789507(
    *,
    fill: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHostmapDefinitionRequestFill, typing.Dict[builtins.str, typing.Any]]]]] = None,
    size: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHostmapDefinitionRequestSize, typing.Dict[builtins.str, typing.Any]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f36ab04019b875b38031e67ba55606b576dffd3ff1c4e2d1fa0ac09d6a2ecfd6(
    *,
    apm_query: typing.Optional[typing.Union[PowerpackWidgetHostmapDefinitionRequestFillApmQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    log_query: typing.Optional[typing.Union[PowerpackWidgetHostmapDefinitionRequestFillLogQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    process_query: typing.Optional[typing.Union[PowerpackWidgetHostmapDefinitionRequestFillProcessQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    q: typing.Optional[builtins.str] = None,
    rum_query: typing.Optional[typing.Union[PowerpackWidgetHostmapDefinitionRequestFillRumQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    security_query: typing.Optional[typing.Union[PowerpackWidgetHostmapDefinitionRequestFillSecurityQuery, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__371fad1e34de2733160d9bd5b19d61486822a8f8837fe1ce39fd3f2e0b16c3a1(
    *,
    index: builtins.str,
    compute_query: typing.Optional[typing.Union[PowerpackWidgetHostmapDefinitionRequestFillApmQueryComputeQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHostmapDefinitionRequestFillApmQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
    multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHostmapDefinitionRequestFillApmQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]]] = None,
    search_query: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e7656e2bdca41524d492e6eb5691c9767dbe32eda69d53d47aa0cb955c4e289c(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8b4bbf0a29c430517959df9f471e58d79a76f3f248c624f620668c8600b36572(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a2f84f6bd0ac01821f9928cac74fcce025cc7c49b08a41ba5101658cf4831b17(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__20b65852b15a83b0f0d36b8edd6f8cedbd96670916b37cff7b288b15603cbd90(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__40bfac7fb7b550869d6a52d31ef573e5297b2ec2507f56d05ea8dab6629d15aa(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__49c3f6d22e43b41414100e746deaaaecda264d839898a1dc047ff9aa0458a0c9(
    value: typing.Optional[PowerpackWidgetHostmapDefinitionRequestFillApmQueryComputeQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2b3b70c1588cec081e4e457bba014d6393e91bbc415eead0536828daddb0cdf4(
    *,
    facet: typing.Optional[builtins.str] = None,
    limit: typing.Optional[jsii.Number] = None,
    sort_query: typing.Optional[typing.Union[PowerpackWidgetHostmapDefinitionRequestFillApmQueryGroupBySortQuery, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__06fea99295731caa48826eebe76a2f99a2b3a4cb373c79dbe2ce4ff0cd3e126e(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5582d8784065cb64aebd3a848ddda3a79c21cf500e7c4668c8a2b3b36e2b0616(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7b2bccf735a2427e89a8dd8d1f11542c3faf3d2291f3130dce12efb3423ace8e(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__de97645544a1a339231ca81bf6edf408fc7fef0d48726fc2d6b05f2567389c72(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2ea7304cb2c1bc4733b2c24a986b34b987e72103727a22a274284bd62b81c890(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dc2babecef6dc6254543dbdb983d2bbab81b4e05d8b89466a1ddecfc01184fcf(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestFillApmQueryGroupBy]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2f36a46347fbc842cebb2cac3f432d4fa7bb5c327e2af08df374788ec7fb5033(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1781cb9137be78a8c997ea72cc6fb1da324acb72bcc9e799ba1584a848b4c7e4(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4c9c5f1a134e64f30548cb0d46b760a5365079d2ae6444127ed6dc5426880763(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0c89803b06a7513fdc6135190bef5e3c7b5170b868ec6691b35d1d2b78a8b1a9(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHostmapDefinitionRequestFillApmQueryGroupBy]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__80071386eac19d7fe3a2988251fe5c8e4cf1b915d620c2e863d9a62704d13c90(
    *,
    aggregation: builtins.str,
    order: builtins.str,
    facet: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e1e11af5673718e380f7489b4eda33cbb621a12afbdbb3a53163dd28f0f2d230(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7e13b548e04930e7e6a633f86997764a3b8c604aac5001828a2b5542275e1cf9(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__27216ee1bcd57ed34941f0722183408e9e328ed7197c71a20e3900104a8f5186(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a9ffae64475bb04b89d15b3e2db5311a8d5e75be6741654710947ceb51e35251(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__afc16cdf937876decb94bacea526cf5599d3820f815ac8ea5610ee0f2ad3f490(
    value: typing.Optional[PowerpackWidgetHostmapDefinitionRequestFillApmQueryGroupBySortQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5352a825a95a51ac3243483dfb6d8afe98f0a7616ffa72206fff066b6ba6e290(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f5086915a1756c7e824327073bcf60acca9d908b0b15c92e78b4209dd387f6d3(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a1176a7cec3b788b9268ee011789829e856d220b89273fe009ade976363475c9(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e1097da010b6179a2c5f1114df37e5b67e009e7580b5b7257a7ed71329c1786c(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f264cc5351375480f5ad7f17ae1e5b7d401a4215dc0c55f71ece557db208d714(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0ccbb000d66622362521aa8e629ccaa5c4a3e7afd2892d9bdd52972bf81b9973(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2e86bd1811d6a8409fc8e2bbcdd6a51ec03733fe621e2528f3a91daf6ac54662(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestFillApmQueryMultiCompute]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cc9e0f115bfb5fc4e15ea9e7298808ccff3a2c04d749988ed5d82a580b8ac637(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__025393ae60d9da1906a5648bb5cce3bb8be84cfa107149cb880ebf6fc69705ea(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9e90faccd75a57a821ec8afe7699f87729133d204c271f7d0321ee82163226ae(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__88aa8825fbe95bdd69eb99df6721c5a31f9e90933d891bae208063482dee0ffe(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8591d15dc6fd69c58b0f2d5eb39b184fdd30607a70b150f71dc3c0db56d8a3ee(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHostmapDefinitionRequestFillApmQueryMultiCompute]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__787605443151948553e163a3244d5faa8d6d1bce7b8933feb56e5258b26bdf3d(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2e6fb2a8eb87b3e3eeafb4585a2cd45b244be0671da6677561ac290767dd465d(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHostmapDefinitionRequestFillApmQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a75d7d05a4e28ff75e4bcfaa4764526106ed50dcf24dc596ba3577e6ec797549(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHostmapDefinitionRequestFillApmQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__68d6231444f0d94b2900002c90afebf63c7d0e7da07adc353df0a68f899a8321(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7400c6589fae05f6d93e08cfc208b7c03484daa86f37d147ea64b2e8a456ca23(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__544cadd31a97c5523e04c94a5a4a7a6c184e74088ee739f63a84a70fa5fec804(
    value: typing.Optional[PowerpackWidgetHostmapDefinitionRequestFillApmQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d882fd37a6a307411125d65b08d16cfa72300274438072db2db2548562f9af8e(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b41ff3a06c154fc64138cdab776df19a85a4651eae80b425fe35a63e236532e9(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c6977203821076795bd0c179400dbb02ce48fcb82812d2711d826e70d3162a1d(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0f6af6b187e205368c53e50458e47a012db54bc862282d286dddb1f0e0921b68(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a8f9bc721f0e4b0b23407e400db858299d7239fe51a804c1b9d6758cc2d17909(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__03958fe80e50ddb907d08ea6b4fb8a99029c701d6841706de22c44ef355b7a25(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestFill]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fb65d41bf0eab8847607bcc0bbcbc50de971f9c6b6edfa1686761810c3e63442(
    *,
    index: builtins.str,
    compute_query: typing.Optional[typing.Union[PowerpackWidgetHostmapDefinitionRequestFillLogQueryComputeQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHostmapDefinitionRequestFillLogQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
    multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHostmapDefinitionRequestFillLogQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]]] = None,
    search_query: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__eb761ebddb044f5209379549267d7be6c0cbe573242348c5d7e81ad52256879d(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c69061cdd612807acf0ed7a93002e4981baf3ae1e12f252fb05a2fe83b15bb41(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bda80db04f17a09b982f2a7306e585cb19de080f20910a86b10d084ade982cb1(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__00fa7c66b92b5248b22b96167a56de1119f146ce12b548133a722c7e492feea0(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ab71b779af262f63331f95edd3199ff727d872f72382bcf90e921b9a5089f130(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__acfc3880fa8533e81fe1d38ec021e44708b10b2497a2fcf599619ee26efe8461(
    value: typing.Optional[PowerpackWidgetHostmapDefinitionRequestFillLogQueryComputeQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dcf3f388c5ba1ace6aa529277dda2a24d50b091b1850d6e532379793904c8812(
    *,
    facet: typing.Optional[builtins.str] = None,
    limit: typing.Optional[jsii.Number] = None,
    sort_query: typing.Optional[typing.Union[PowerpackWidgetHostmapDefinitionRequestFillLogQueryGroupBySortQuery, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f7dbb9e078f0f160065e9aed084e96e5daec118643825d29c78d4b904de97955(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a127fa13c2fcec57df975fbfdd366deb0a912ae94b11fc82b268a1bc1d093227(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__824ae013bc5fa93ef693ea60f41c87a5e67c30b88fbf7518e6e4cfccb4593046(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a8b1886227f638db7da21eaca3a0ab8e201cf6e33d88a10d9d518b3ca3d1116b(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__30a0df30d4399d170f631f6e92939f4930fa339a862335c1b5d14d8de8334ba9(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7cd9b5f3ce28fc1123dd5b542b3fc05c0204d01da03da4a13358e35ee90526a1(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestFillLogQueryGroupBy]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8126be4e1a69627af41fe51852bb74bc4623a44310ca3387a9863162e3b25b78(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dc9b32a30fedbbb13306f55c4e9b9f315f99796109ef81cd8364084b42c3026f(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4f3aca12fb2d0f4281e75194a46a43c2aaf299a2c5054414d138a4d8f6fb89b8(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__570f8813fbd7def51f9cca90f34484674bc454db576bfe87c02b838777853f5c(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHostmapDefinitionRequestFillLogQueryGroupBy]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__609eec2ea09a550812d63049ea9bb789f253c4096523e64d68b123b0393e5dbc(
    *,
    aggregation: builtins.str,
    order: builtins.str,
    facet: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c09605abdf4fea32af18f93535bc698a17b1406b53557e9ead131599c9801dde(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dd9a3e0321b3a17a6aa62145ff5d2658df224c9a0ca006902ad6b7eb178361d3(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__39666e2cb29d520f961f4c8a7ffd75383938956992eb84cd1143ec34d8d8497b(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__576356724fd46e36b8a015947e8ea4c509f79eeee7813906328b7a8b5a03bc33(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1a8c84c518878a14aa4adcc60677c1cfac799806c069124c4510ac6a2f000bee(
    value: typing.Optional[PowerpackWidgetHostmapDefinitionRequestFillLogQueryGroupBySortQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4c470b1d25781f1b907f880060aa51114ef27a23f590260a4be511103d532590(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__26215740528ec1c055d402593bbc628c79cab4f01c261ab5f71a8cee9fc983ae(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d23b2ae0909700e72d02b4c6a5e79510bfa5c68a45f90eba1a6c78ea9fbd6414(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c7fb6a0fbe068405acc65502f5d5fe1c7830e21693076705f70b03e18ad5f000(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f87397b828d29d5a519b975d9d39d04080be36a9304ed10c6a05e459be33d947(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__745ec349e43b70dcc1ab3a1fe3bd28890857a982b0709095ce08b6f25dd34d89(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8b932f520772a43364fce7009866e36e0ed3f0e19f989938b0cd837b7c4c2ee1(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestFillLogQueryMultiCompute]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__669df4d26835feb9d5c5c936921a76031c11c2c5b1c15a5daf627c574d4b70be(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d529f6cbd35426e8309dfca3a1226bc628f66c213c1ca6289f74c807ba0ee3b2(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9d4750dbd549102b2b0fdb25b519f865fe82d6852ceb0e8933407dcaf88fc0a1(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__37c8a621f830f675a29a5d54d899a1d08fb893521302501cf8ac9ed7dfa1856d(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5b12dae4e03bde333a5bbc5d0e335638b8b8086d1c0d4f21b2a9cfd41e149ed8(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHostmapDefinitionRequestFillLogQueryMultiCompute]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3f4342ace258b5aea0e583782058c6703f5957ad775d17a7842aea344ca2712e(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__509eaf6d4b319c1e7a91184412291c8a4f871e37f78c0b1d6ae3f5ec6c210a35(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHostmapDefinitionRequestFillLogQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6ee5aea20ca2d24e694c384e8a3d507dd1942c0b9edf669b4203c1519e208307(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHostmapDefinitionRequestFillLogQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1475bb6525f9d19b68ef3f41ce565c90a2dfa788d9428ed9268f2c89464422fa(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__acba247e74e15331f1c1255928440dd8404fc1036df58195be98ba544ae1f532(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__681581ea7b39abb7b8040e76c3b61cbeba4f4f744fa58e8b7d38eea30a4e25da(
    value: typing.Optional[PowerpackWidgetHostmapDefinitionRequestFillLogQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__717bd26e2cea7d318778cf43234395fa20b59d018e7bf1efea6b783cf06ed396(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1e14f849f248ea0641aeeb874e1a834c4552b1a804f2fe5a9fb7ca8c195e74d9(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__591fa03e3359fd5e6c288bd133b8bde36100b630693963f92f037e426a6ca84b(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHostmapDefinitionRequestFill]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8169d3d5c24ef5ee9cf6ceb518b7f5642c2fa7d4ed52f45a512c12535946f5e7(
    *,
    metric: builtins.str,
    filter_by: typing.Optional[typing.Sequence[builtins.str]] = None,
    limit: typing.Optional[jsii.Number] = None,
    search_by: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bc0722b3b8172d454a78042c49b0173a011ed709337c48e9be716ce988fbeefe(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b037af6c9496bbb4e4c9577d0433d45ae29a0abc8d91b2b2130d0e956347795d(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8966636ec8090e53a23e891234b86f6f40dae33ad6019da203f980b193009246(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__eddb35e9bafcf44d95952d9dbe001aa792128726e109849d3ff373e8bea9f5d7(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7c2324ec43344d1695c5aefbd3923fa038ee64fc946466a89eaaa47273d7e0b4(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__040d783e6561995fc62f1856fc26b82f27376d3ed5062f41755dc002c5338978(
    value: typing.Optional[PowerpackWidgetHostmapDefinitionRequestFillProcessQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__81366e5aefbd7bf48b6e069935106fcee879588e4a5ad611faf46dcb1deb4d85(
    *,
    index: builtins.str,
    compute_query: typing.Optional[typing.Union[PowerpackWidgetHostmapDefinitionRequestFillRumQueryComputeQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHostmapDefinitionRequestFillRumQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
    multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHostmapDefinitionRequestFillRumQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]]] = None,
    search_query: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5945af29cbf4710cc63c82a12db89d9ef0cd6b133a0f11eb4a3a77f987bada7b(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1db23e21898b8b58e8113d81129954c72847db3bc95a456cfb13db453b74cb09(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2c30c761108b5f9308686e24d2c1a4c683bda1649dd34583b45dbfa65f67e804(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9f2fcc940a6a7e6ca701f089bd56007b0f90f7a3c11c22d9b8ab2a5d2ae29bb6(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__eb541e8e7f9f1bb4020933ee3abf09b01f0d9f3825251679863da0db208dd90b(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b03a7f7552390e62d12d7865f4cfb45c6445496fb8c7691aee405ea68dd6f1f1(
    value: typing.Optional[PowerpackWidgetHostmapDefinitionRequestFillRumQueryComputeQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1e74ad9de40702945a6ca7bcd07d2bd3af013a3c9b26a92cda42c055fe5c1f42(
    *,
    facet: typing.Optional[builtins.str] = None,
    limit: typing.Optional[jsii.Number] = None,
    sort_query: typing.Optional[typing.Union[PowerpackWidgetHostmapDefinitionRequestFillRumQueryGroupBySortQuery, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__972bffc5767b6ce1ac93ec1f1093c059f5bad9139338d4c4ec159252d554a2a0(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ea7989fb609929c65e76c1c64800fb0cdba3caa5deda242345a5b669df4514e8(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__342c9bc55e383f2f2a093e95f9eb645caae7945a6ba95cd988cc5bfedc6cb8e5(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a4d30095425c031e3cc90f4a3a8657beb7843fc4eaf38ea3508b9f3bc9243776(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b60e4686fceb7ab1535e1ee03305d439043def0ad085fe50b510f5d6d1e264a3(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b3d99ead1d82b81b24827958baa2f480b1bece1fbdb865ca9be2baffeb2ad8e2(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestFillRumQueryGroupBy]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f76aa1f5ee1ac23f5fe5c76984d6da07e6cf6fdc237b7afd298fa81a5527d94c(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9093069a3e68dfdc9776bb6a22d0f6160d98fb7c8f71fe173b74eb03c2a96065(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4b8277385abf223f19d61ca0b3c75643f7228b1b16181e5f64143a47d6fc8614(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d2b2bc769645dda32b0a8654adb7b96024e8c506936a4365617d7c61524883f6(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHostmapDefinitionRequestFillRumQueryGroupBy]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bdc368fea38af0fb1ac97abfba902e0eb5d06e22c214d589cdc64da3f4296a03(
    *,
    aggregation: builtins.str,
    order: builtins.str,
    facet: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6f17a7f16005ea6f1a37aad5dba234ac3316662bfcc7c1cae44418086277d41a(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d410a47c1a0240fe236ec5bfdbaa7151e99f74c778433fd5ffa4b18776479bce(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__64f6019ab5349e3e6b69727260c558def1161abac191568e9e0379ffcb0e73c7(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__64d28d921d297fb3fcba6a02ad815cd817228afd82b20b0fe20f764774c1fff5(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__929b1805014dc096a24c8a36ae130147484fee87702780cc296779867b456d49(
    value: typing.Optional[PowerpackWidgetHostmapDefinitionRequestFillRumQueryGroupBySortQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__44bdddb1abd2020c62991ade8265db8f84057fda6edade92d7bfcb0cad937ce8(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__17c0cc5f0aac89ed54242ba2b30a96e8df50d9a2971ef8cc3ca80984c7c33fc7(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2771fa41ad4a9988634bc2d76a2153d33499028fc2cba9726bcbc5edcde9d737(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__78c4c131f8f34c738b58812bf354a04b8569f465e1cee7317590c082716de277(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__494effcccafd546b3130ee3b11efbe07306a9ed6a9ae8749bb0fc5609349106e(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__96e045cca7210325fc53df4b2f60cad03b7e0619cbc4a959085e897f8c5d2b6e(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d20451e30eda5b91073de16979d84bdd21c872585d6099beea7987222ae4370b(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestFillRumQueryMultiCompute]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__62c9ae30d72249b777c323b8d46fa4e91c0baa8446748e6010fa699504f6602d(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e92bc0535908cb527ed273ec9588521b89f16d80c31667f24b41730ed7c388de(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dee396142abcaf780506d71c4c6f898c700a175dfb1f54d5001099b26e2ff757(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a2d2781a291525226251b06508b7c866e2cb5567421fe80197855b325fafed4a(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__46786a9ba01c5f73e0bf5b1689da800808a19cdfad2c79c9a74e5dd8cebbab16(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHostmapDefinitionRequestFillRumQueryMultiCompute]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d82a714663490a512922e07fdd1497452f2a32ce4ca29847ecf5ae620db4c1c8(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__716da044d748e5d2ac0741f4e2c40b66d8aab2602542fbcb2706c191e7baa031(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHostmapDefinitionRequestFillRumQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4de97775d236e5d19fe5c24208db8fe1673b0d427758a34cc3ed7a798e2fe914(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHostmapDefinitionRequestFillRumQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7d8aa57f85e2fb71063f8f416529addda0a49e5294d15bbb50849034c0ca8cc0(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d1ab1110be3788073f20b19c4c99a94d544e6514762786af0b8e7d89b8e6dc97(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ae68fd5c5d0e43d483d039c9a37bc5d2f354b4a73527f3736ac6c8cd012e1955(
    value: typing.Optional[PowerpackWidgetHostmapDefinitionRequestFillRumQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0393d09c939789f442079f4d1ced404b91d299ebcbd05d514131601b80698a46(
    *,
    index: builtins.str,
    compute_query: typing.Optional[typing.Union[PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryComputeQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
    multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]]] = None,
    search_query: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__18ce7cf28d7ec03926c0c86acabb9d3ffcc7e4803adda54be0023aa81d53d375(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6d05c08c4732edd4d3efa77426a88c842a181b26e8e0d70bdb5bbaefe36c7176(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0da8d30831e8f0f04172b93fdc2bbf70c15fc9ee8db953602f187ecd85ff27d8(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__93a6b5c1c5a046fd86503254cf7eae6356b49bef2d7cdeaf7c47dd3afb8121ec(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0eeb94867905e34fd192f2be8eb2f4a3a20c5e919fabd45dd85156e759e55830(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a611500346f930725bf8f9708ac9c4f9e3555691ee31c5d58f66dc31e9a0a710(
    value: typing.Optional[PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryComputeQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__50664a0f193bf766da8870e98600916d8a166221d36081d9606ad5f9b3f53a79(
    *,
    facet: typing.Optional[builtins.str] = None,
    limit: typing.Optional[jsii.Number] = None,
    sort_query: typing.Optional[typing.Union[PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryGroupBySortQuery, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__060ff07c872f28f92d2b8d591c3dad9baea7e03ef5d458bdc61cdb6d8dd3fad3(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f1388994e77976b3683973bf29a083bd7bde9e3cd86163f05c936c5c15094c41(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__95a7d5f33f6571fe36db403af7e440c1ae4e167ce4ccaaff554689d4e4676897(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6b49f415609f9f2daf5e6a12fc852954a51dd4173622cffb8fbe31c09af4c297(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__170b1265c0c6377ce37736b6dfa3c3a20053a7734c0cc47fbbe6890914df5540(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__078ae5a7beb946e253480897f157b85fb2dd96a935d9eee36cd206aedd4af5e0(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryGroupBy]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__09070f5e8946ba29a184168fe77483e96b1eb920195af3bf1cdbf4fa1e40720d(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4dc7dd5e103417823ea793060ac34f170dcfbd9ea941a865cec4b19d19d211c7(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5995b646650a1b96fdfa3c0d37f5b5d49b13d36623207873fae6fb4a23d906ab(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__be537967b7ef5963133e74ef0df7490e18414629ef796b9a24ba4d9269976581(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryGroupBy]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3ae386bd8386fa641e7df89a5de6538e0d88add836310f7bca54ddc4ab0f437c(
    *,
    aggregation: builtins.str,
    order: builtins.str,
    facet: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c68778a9ea457dd078b2e3f39fe495044de9ee81cafc4e188ece02e0ac1455d6(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__901e672c171c15690703986b681a3d4d3566b404fd3408edd4f2f4280f8ead75(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7b9128023f325d8283db6e6e52596a9d2c733a7b331d30d1e8470a8e2cc6232c(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__01a53007c12f49f95a38c070352905a7dcd6924e71decaed549ff3a1b886d59c(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e4f1f09c30023721b0c7955d3b0f02746875d4265d367e14cf5d6c728dc81914(
    value: typing.Optional[PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryGroupBySortQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b0594908a176ed770bf2420457f46af5fbeeffa26c54f965321c565f723a77b5(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__aaaee644869782536c2e0dba8da09e504e2911b73bfe7c3b0e2543e638f32da0(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dcb7d1ec78c4902599f02982c1cb937eaea0209d07f879de7ea5aadd6d93f657(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__113f6187b8da135ca98fe47e7c5ccba91c96709ee9a11cc5cf5932e250ee351e(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b7d6ff3e2837b4ad6188323b61ffdefbab897ff5b5fc571cd51b70a9abfbf114(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8f9d25f3035f661ee6f25dcc6847c066d9da48a18b686268f9609d9948515ebc(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1ba683f00d5d1e39977614a3b13f4583b6de5cba18b2cb9b695ba5fbad164d00(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryMultiCompute]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__eb42257ecb6a8fba7a2c60bdf554450667b2fae960c2983322f6007015e57b5e(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f91d69181c3d251d94723b1bdb034e2d9e72898b4e6bbf7600646c70d8e0914d(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__923d664dae3879f99a9e940bfb97d1010c227fcd1de704a0571da0fa60cb4a97(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c262e8c7f83e68813ea144e92e9e84011b59d777794710ba296e7072ee604e1a(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3f246d29341922789577b61b713ecbbfaa2d4c1a4e9ef255f7c24dfdd3d9c8bc(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryMultiCompute]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__59d6d8fb920ea993e63e9eae9cfe0cc27b7b04c2f051eb0829ac96b71ff8dc57(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__aae15b80ca22ef5c11589ca4d909f2d2369c7575ec0f17f01eb184a9c0b244b1(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ebbc20f3874aa0c089fb3af344ea024b57f3fc0f447a6d5f298419221ffbca57(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHostmapDefinitionRequestFillSecurityQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__45922bf09c97655f5b8a4408177fcb3b21834409858dd180fafdba69559ec854(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fc3888ef2cd31d88530fba77d12c3c32211ecdc6d378b24ab4bb7464e14a65f1(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2a87644968baef047518413ce4cfa44f5ef9eff1a9cb9025054c313d987e2382(
    value: typing.Optional[PowerpackWidgetHostmapDefinitionRequestFillSecurityQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__395a75e3c1a635a8a775b2b3b768d44ce546bbb5eabca94cda63d41167b89914(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5ca6f5d47437845ad65a225bda378d3d84a8e1bbf1c8f1504a416b0c0f3b4668(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHostmapDefinitionRequestFill, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__63218cc50fcb6e1cdbd87dd2815e52b4721ddf85fd7eb6369b76a5a83010a3b1(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHostmapDefinitionRequestSize, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dbde4e761e1f22c3fb80903c82722213864571f175e2477f885670f79316b83d(
    value: typing.Optional[PowerpackWidgetHostmapDefinitionRequest],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1c0ca097871328734c1b54bf50aa03dfb4ede09ce66b9cfcb21de560827ff14b(
    *,
    apm_query: typing.Optional[typing.Union[PowerpackWidgetHostmapDefinitionRequestSizeApmQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    log_query: typing.Optional[typing.Union[PowerpackWidgetHostmapDefinitionRequestSizeLogQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    process_query: typing.Optional[typing.Union[PowerpackWidgetHostmapDefinitionRequestSizeProcessQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    q: typing.Optional[builtins.str] = None,
    rum_query: typing.Optional[typing.Union[PowerpackWidgetHostmapDefinitionRequestSizeRumQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    security_query: typing.Optional[typing.Union[PowerpackWidgetHostmapDefinitionRequestSizeSecurityQuery, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6b42df22a2feb224155e2d3dc72fb11b11ea23a88d489fbada3c58e053d7df69(
    *,
    index: builtins.str,
    compute_query: typing.Optional[typing.Union[PowerpackWidgetHostmapDefinitionRequestSizeApmQueryComputeQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHostmapDefinitionRequestSizeApmQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
    multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHostmapDefinitionRequestSizeApmQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]]] = None,
    search_query: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__524eebcab771d84833df2d471b8145f6bc4624313051224281592954887355de(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bd532e3601268d071e64edbd281318ecaf0b02b439e2625b29775dadbedef7a4(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f3ac0a1a3d67d5825c63d49a579b5991426f5526fa7fc6af120429377e04a664(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d0f9e0d532555940122fa2f5afb2e36b6263b73745bc8266162ecbe5167aaf60(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f779097ff52197dfcfb0039897fe4f10c689c84aa3b69e78cb518d7f8f10945d(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__072362508eb6103af2a866e024699e958aac9dd4244c63d79be5e5373bfceb84(
    value: typing.Optional[PowerpackWidgetHostmapDefinitionRequestSizeApmQueryComputeQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__427740761c2e681f2fd99d4def736c3b3b462acd077f99311da0053f5bf2becc(
    *,
    facet: typing.Optional[builtins.str] = None,
    limit: typing.Optional[jsii.Number] = None,
    sort_query: typing.Optional[typing.Union[PowerpackWidgetHostmapDefinitionRequestSizeApmQueryGroupBySortQuery, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9bb67b97ff073db89ca65c376ed948c2e07f3fb91f5d8a1ff96c598bdf858012(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d7986569ae261379ff80f73ec49c2e84521219f87e91e73f1992687fe1e8ec11(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__63163e64ec812fccbe24fa887f218d519f5414907b665db93f8678fd276b9db0(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b73105f36f58f534db6b8723fa318acaf59fb3ebd149e844f6dff45b8173e4b2(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5bebc86e5fe7d575bb109f5cffc329ab802d577782c298b43f1190cdb92025bd(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9fb394f64d47df84152f5f424e8cb17ac4e998f76e0b0717e41806433addea67(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestSizeApmQueryGroupBy]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8caa0182ea37271d858419046fbe5f27c4a4930b02691e2037e3ba1737f5f56e(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f0ba4248fb55dfc65bea6f053fe32dabe2527a371f2c9699492ac87f103f815f(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1b541450fedba4e74f4fa5cc56156ef7bad2d5eca11ec714801c6ecb195fca13(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__48c7de265fc8806840d2dfb672039dca1a38964583112ac06e4241b24c564768(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHostmapDefinitionRequestSizeApmQueryGroupBy]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__37d99a696204444b0d81e98a706f5fcb5edf31b497d5c0d03ce45b26a13a283a(
    *,
    aggregation: builtins.str,
    order: builtins.str,
    facet: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cf2d723673d90e2a765f2d0f8efa6895985c643d3d13a9226eb1492b7941d845(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f06e411e8e57c32a15495daffda726f95f76261e8a53ba93330d391b7539b327(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4f574ccaa58592391137b0673e39fd4732919cb568fe96eb81c582768c0c37d4(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d6374c6702d5bef3e6dc74594c95619cb8b02408c0c46ff0de01ad6d10b02f19(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4727b8fe76c546819b967af261578be6a69120669322140d49580b2276737134(
    value: typing.Optional[PowerpackWidgetHostmapDefinitionRequestSizeApmQueryGroupBySortQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__00f37894d346b5292821ada27e73d6a2a5d48a161ec6f5a057b28d6c99f9277e(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ec15829640e025bed8f7f05bf2fde7b08dbe4ea5195746405a49ab7750607610(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8fd4ef50ebbc37ee8996f1456aad83239a449fb586459340ae3cf19eb2f8de73(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__273315ebdff4636278763c5693c4cfc31a8421a4b90199fbfaa1ecefecbcadb8(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6cb4523b3f5f72669ec2b0cc862690bd666e777be40c9796863ec21655a1a581(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b7dd983afe7d6a4d11ec99ee55d45f3a237bfc3660190ae2959b806f6a99f817(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7ad0173f4044c7dbf37c469db0734eb64a924957c58269ea7c0f9777684242c9(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestSizeApmQueryMultiCompute]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__305283374406d57d9c19ec6f3c92282bcea51ca14d0c1fd5b65c4814ab383526(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0d4b8e093f1c7fffd5e0a4f632c5ec595c7c2378f9599d00d3c48a504aa53687(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a41a5eec32038b1e43a007e7e314868c2a526a9ef5376faaa0027508fc0d388f(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9bb69b200e3d7b42e294938076543b62586556bf539b00b264479bdced964d64(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__10a822a96fd1afe47d4a4c19291ff3cbd2a346d594cdf7ae4a84a0e9c038d26d(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHostmapDefinitionRequestSizeApmQueryMultiCompute]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__01556d2c1acf7dc25440a805f05dd56dd3e67397960e76e2e77aa559770694ce(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cd06e28ed91b2e51c0134c5f91e6e85badb6b01e543b757d1765e7ecbc0048c2(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHostmapDefinitionRequestSizeApmQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a32c3507475c57b4bea80a3acbb4f5ed9895b857bb852db9734e805a72ef8b21(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHostmapDefinitionRequestSizeApmQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b0e397220d56bd0275355b58f69071aab5c9ed1e2cb1da15947b635df921ff16(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e5d61de392381a5ab597d36f5696cb82bac75d690c93bd969f63042c3aa7ab68(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__24025524a0070463aeebaed39d343931aef92d66d82f40372471ca5e3598f6a2(
    value: typing.Optional[PowerpackWidgetHostmapDefinitionRequestSizeApmQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f4c732da51fd060153e1bf1e6007de82704d990caee858b47867c3c3156188ef(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ae43da53eb31aa5b30f9f8ed70276ca8e6e4bf7f2fc5b50252a65fc2e3d27775(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__012bf6372c938cb7cca98b93198b368a862d83b5fffb00480982d75454fa950f(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1c070294f6adf48728f314ee3e6e85cb9fe4390f54073cb83ff33e266cbc2b82(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2fa9101eab04ddc78e851d240f44288798397b71f26d585cfd27ce5e3a26475c(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ad5706fcfa737224dd96d065243366077f68d78a6bd72a373b24739bc46d2d0f(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestSize]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f60d6dec0b5c62001d1fd76e8812e8ad1e9e6cc261cf290de732b25b3a606e3e(
    *,
    index: builtins.str,
    compute_query: typing.Optional[typing.Union[PowerpackWidgetHostmapDefinitionRequestSizeLogQueryComputeQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHostmapDefinitionRequestSizeLogQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
    multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHostmapDefinitionRequestSizeLogQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]]] = None,
    search_query: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__baecd524f805cc893e0640a3c223a4603c9594f4ab1bca1b550ca8612e27f410(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__35730ac08e1b973ccdadb1c5de4c24fed1e9aa28488a45bd48b44deb16f0ac09(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a34c88ed10f7509e27ac0081fdefc5aff1d16c687740d179a77ee07ce5f08ed6(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__577de92b50d151ff4b2be3754cf13e70b60f68e208c974c0592a186fc500b8cb(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__da469cba3bda36534aae39766d37e5da30506e0fb4d729b494df179b2805ceb0(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f85b1aa928c9aa3bf41153881f40171c2bf46b1d5bd0e27e14901f78c9a6f4e3(
    value: typing.Optional[PowerpackWidgetHostmapDefinitionRequestSizeLogQueryComputeQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9df1ec37a5405d80ac556bc25a93c13cec7783233c9fd24537a627f11be07b66(
    *,
    facet: typing.Optional[builtins.str] = None,
    limit: typing.Optional[jsii.Number] = None,
    sort_query: typing.Optional[typing.Union[PowerpackWidgetHostmapDefinitionRequestSizeLogQueryGroupBySortQuery, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a8f245a0868ac91d3a1ff27cc92fca074f80f814332f68adab2b4c3fe34c5341(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__605ef55b80ae69d6321a9dc13b46536ea516db323bdc8113e09df18e404d986f(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e8ff7cf9ab76e8d67fcba9a121238d61bc8ff3a1a7e737679db2c1654ac39b80(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3b2963d60e91d188d8d689feaf31569672009a241d1b54e812ebc87a32045637(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__785edef4715e0c95f6201b0c89b1b47cde785f8c46e23385609607dd06a690d6(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b0ea91adbfcb449ea694c36c9fa08dda3e0e91d2f42bb27c91b8742c5e7d240d(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestSizeLogQueryGroupBy]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5e1ecc86babeae4ebab14c50c754d003389b26e36a1a909e9b03a2aac9d18a66(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9a5eeea3e8aaf684bb39147d31b78fa941e71cd9b2c659bfb627515dcb0ba8e8(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__86038e2e346d596c15f36a1bab4e64c8d4176942c63373cd5a5cb659c156719b(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a494d0ad94ec497546b3c8057344b00bce334d204ec177a56dfb6221ce91b71c(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHostmapDefinitionRequestSizeLogQueryGroupBy]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__75c1659906629331f45df6ac5cb6bb7cb66e38827905a33e656dce50a21e2677(
    *,
    aggregation: builtins.str,
    order: builtins.str,
    facet: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7e7a73aacbffb638810da2f79e149e38dcf0cb3d6681718457a774be504deb6b(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__211ce7e9f0469b7beace57e3390da57b74cbd0904e62d7321d4953711960b6fe(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c5e33ab238f08b0a11d7b904d55bf3f94eb8582ed54bea7d2695fdab9086da52(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e410ef15c7926731fcdfa4fbad9aab696efd6e9e704d646e65fc8e26e80890ba(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ed597722d3631e5f48d6cc68eb17272407c284d16df9fc21842aa8055ddfd01d(
    value: typing.Optional[PowerpackWidgetHostmapDefinitionRequestSizeLogQueryGroupBySortQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c1281dff731e7dca75f6f37cd9cca8be442b671259a7a589356b0d37f788a08e(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__afa2a1998ec5b10e57fa18c71633f6cd05b08be825774fba8a324b73686b66b5(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ee29e19a4a86bc6385f850f5e040b5c80ec53c83013bc1702904238e225bf387(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1e466e2c1626d85b2cb75b9c5a31887d521cba4aec34880fa96ffd1d91fda6c2(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8e8e71f5a96d16e74b7929b0c1c9bd08f4947c95fa6afe016f1949e81268f21b(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__98db761634b3ef60ee3dcc75eb1b65cded41a4d660f2d32c2ccdc81aefe9dfb8(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__98287e9a388e6ea02ebe47e500226a81e4f847a2d17c4e2ffedc7becc765c0d2(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestSizeLogQueryMultiCompute]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3d6fa6aae4b1f223ab262c0820313286262873eeca6cdd41a97962450a92031c(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__391383a241a0cbb589355019ae33fc06c62bdbcbc0e06a9ec6e9a63c48275567(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6565785689e23449b346ffef73990e258fe8cf8fba2e8b1f23e8cd0217cd5eaa(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d66aac08f7bd63d572b6ed7c5ed8dc730c289af3f54b3178cd7a0fd3fa68de7f(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bffc4e03ca89e18b72d396b95b33c5c074969437bc210d1d42b0b6543a212d81(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHostmapDefinitionRequestSizeLogQueryMultiCompute]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0fe08c52533c81d766a9a8b1211abbd129903670ce7b035e3997d7c059a7a6c4(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ed041b58672c2e401c2f1d34f9f6f93c6ee5e81216f9013c3f83f457f328e66b(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHostmapDefinitionRequestSizeLogQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__230e66242e2c647682082da5575889a82f746d9d18c25cff2d85c8528b798e68(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHostmapDefinitionRequestSizeLogQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__696380f9de2057b2c8bb4a2018587e2c9fc5ef3417c32165a25989faed5c59ee(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6b6b843cd55e28e24fff5f74646778fc889e1e76187691373deeeb0fb2ac0959(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5497567d465b10de40037d445453613a6df1cf1d3e0c420e72d1a6866f2967e9(
    value: typing.Optional[PowerpackWidgetHostmapDefinitionRequestSizeLogQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__764c340426ee5c26f6f4b4a335a2625d34cfb2df69ec10645cbaf8d96734fecc(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__39e260c3fe1591af0d5434ecfd3ed1adab74fb13525a418024935765b7260aac(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a1a8336d1e30a1f455db05b79680df740454282bbcdd46a4f0ee8a53df0feade(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHostmapDefinitionRequestSize]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b042ee62256dee91e1766f1b5f267118ae9196016061b604c5b1e25e3670ed0c(
    *,
    metric: builtins.str,
    filter_by: typing.Optional[typing.Sequence[builtins.str]] = None,
    limit: typing.Optional[jsii.Number] = None,
    search_by: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__54fab8907dbadca8c989c794754ccc38a4e3ad67795995d0e24d7b61d75e962e(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1e37dae4cb349ed56f6c1c9f60cf3ca477085c2c3a35112c3b3c1683fc14a10b(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6864878d6f2166736e8c51f72e3b29b7186f2ddb906f61b44ee05fb792b21792(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e2f0bf6fa52faeecd0be0d1f5726c6dd64949646ee64d120187aea7d29d390ac(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ed30faaf214c7ac2f469d6fde2df9b493589b40185856ccf26afd6b7be37c205(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5d09df00e67da1113ecd7d427fc79f96db3361c9e840d2c6f155dd029a4bdd66(
    value: typing.Optional[PowerpackWidgetHostmapDefinitionRequestSizeProcessQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__696a841f0def415fa8b7b590deaf42c16e60d7c8ac44c7798e440250bac51328(
    *,
    index: builtins.str,
    compute_query: typing.Optional[typing.Union[PowerpackWidgetHostmapDefinitionRequestSizeRumQueryComputeQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHostmapDefinitionRequestSizeRumQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
    multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHostmapDefinitionRequestSizeRumQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]]] = None,
    search_query: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3ced772bcf88008b8b7943c3056e6ec89c6388a40caabef0916f02370c61360f(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__98b3973122128b84bf1650363c82a7a47923ac750563134e3ca441b1631f1350(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5289b0d70a3eea96a04df10b607a3cf0b0e69e4a296da77dd0263a477ac803e7(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__98ef4ff7221a2fdd685cc9c0ba22bf799c3098977f71b431384670584d9bf827(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__796d87a81015261cfa84a30222bcd7d33f2275d8ee62f0d41bd1dc123e722a7d(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9715574f15e40a25b0ce18ed193ddb8e4599078bbd75a6a5dc48b410e2ab5c5c(
    value: typing.Optional[PowerpackWidgetHostmapDefinitionRequestSizeRumQueryComputeQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c424fa0806ea31835a4464e232f830df486dff70b67599761e7f7657eeb1f90d(
    *,
    facet: typing.Optional[builtins.str] = None,
    limit: typing.Optional[jsii.Number] = None,
    sort_query: typing.Optional[typing.Union[PowerpackWidgetHostmapDefinitionRequestSizeRumQueryGroupBySortQuery, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ef770337113598fe3149ad1f73392f2ad403470534c009f5ba5e1d07fb743e66(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0b8d799757768945f7c6d52a670a2361cec7ad43c99b351acdd89bae7be30158(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2b148b1c4993cc8adc5c23f69fca17fb96bc196f3f7c31e74af0f97c47bc6db4(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1735d05851fdd9b3ad532e1f90fe4d1cf1b2e9e5f0e907ea7b7292d0e94db9d8(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ba4f37b82aa159c58ac016224d919f16b9b065bfa27797c138e196428c6859e1(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ff8023dc64d76372ad5d4d8c3a948c64f01860bc0c5cf2e49b4dfb4217987f10(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestSizeRumQueryGroupBy]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cac435aa930beb397bccae82adf47dd47459d09e13ec944941f7a57c0b5dcac2(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0807e29d65c1467b9fba0ae7b4394aedf016ec3d80d22914919bb2856dd9d0e0(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0e5dfc28c2c064a5c57b3c75f7e154c242c1a26139229c3607f7a67f5f67622b(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__874a52533e9f8eaa3a1b68846a611e6770d3b9c864712bfbe80bba06ab95752c(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHostmapDefinitionRequestSizeRumQueryGroupBy]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7382ee3eda4497512e06d87d4efa3352c4d2473cc30b6f68cf4817aeca9076d8(
    *,
    aggregation: builtins.str,
    order: builtins.str,
    facet: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__14acb95c6169212d9d2a496de44aef20fc296e26d54d937cfe7416af93d00c10(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f03f00f431dd3d30053d8fa69b02fe9486af367e8a90093abd2fa8a26c29125b(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1ebb5566ff211a9d1c32b6cb6482e68f38c4c21291fc8e456c9dd8cec0e83932(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8b502da157149a8c7c743d7bf38689796507b10ed328fc9469097311908641f3(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3c926e080296ada8ce3d3c1cfd8021b1948bd60d24c161decbc2da074c1d7f05(
    value: typing.Optional[PowerpackWidgetHostmapDefinitionRequestSizeRumQueryGroupBySortQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7240361676408ca4ebd63375c6cb7a3a371b68d04eb4c9e8cc8e48f6c4f57746(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d02da6637008517771b3b255ac733d7e33d3192f48db654d93ed557a5c822ff6(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f2470afe92fdf3ddf7145122a7e80eddb7c5f98a365f488e79da22009fbefdff(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__302f719ba6c8962a07a873fc91089d74efc40aa15a4d8c8d5f111b0a5a12db65(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e60e63cd7a1f34eabf9aa7e7b2a9103fe06591325ce9f0d8a33af6a600c40897(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c5decd7939a98d7ace7e6ab2111aa43fd3f36a62a01df93b4c895bdde807da88(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bc86a089e522b658957a1a032fa8d78e8d1785218fe6b6e28acc95c069ada163(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestSizeRumQueryMultiCompute]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fbe14098fb383f004491492386356b655fe0bbb8a59e23b6a3f1879d5b411a0c(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0e1559899a519cde1df99505bda95fa9e461b4a925ccf12e550100c77f2b8944(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ec2066619512066564666b7448831d36ffeac6e7899280646c2e17211f66df80(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5a1932d005ba69224afc679c5360066bd397b78da7d7d6b9da98d21dae8974b5(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9e57cd54f2520e8327d7e73bea001ed1a53406d1274ff80d11d95b419cfbd420(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHostmapDefinitionRequestSizeRumQueryMultiCompute]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__26b2a8a2cf65d7bfac2202ba7e60fb73306eb2bc375c3d44ae9035f07dda0737(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7763121c9defcaf1fff248a60f0db291ea794b31efd02ccb4e5909418d1da0f6(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHostmapDefinitionRequestSizeRumQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__443073d189a5d13fe461714c8695213d0133019a155e4fa4510c8a9089352ce7(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHostmapDefinitionRequestSizeRumQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4fbace557b3d757816cf81960643c83d3d241902cc602dd3ab9372b52dfd20a1(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2aeb9fbb7ebabfa671e46e7c3d4bc148fe1cd6991502b59c8c77c511626b0c3a(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__01bd41d0b67efa7870924971bd58aa029768e1d45257b98f541ba4ab0a308886(
    value: typing.Optional[PowerpackWidgetHostmapDefinitionRequestSizeRumQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b9da5a6b20fdbccd4118084fbf48c855b6782973b09080361cef539e3f187fe3(
    *,
    index: builtins.str,
    compute_query: typing.Optional[typing.Union[PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryComputeQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
    multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]]] = None,
    search_query: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a14dd5df330ca36bfd0764095258e06fde751350dd144af2c30c51bcfe621a7a(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4ba5705faafc24a407ae11cd8c20c3cf3af192af41ca71f34e3b3362889152c6(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e1eb5c0409ce0014228383d4a821903ff703d568c976db3c38d102e551e1be71(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cf8e3b0481c0c7eca30f5ef9939a9dcb25417a2970ff98e2cb1c2df38d120dad(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e2286e516bd4e4be5ca0650813ea4d90644e4dc3fde6d4005abf8dc877d5f68f(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__375995f3bfb4fcace4a68481b7009462f7e0ba8934b74d446ad748f5cfc72571(
    value: typing.Optional[PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryComputeQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b1a14fbe1457f4604cea4a83d511f6cb02a8ade569d015e95ae3dc89d5874740(
    *,
    facet: typing.Optional[builtins.str] = None,
    limit: typing.Optional[jsii.Number] = None,
    sort_query: typing.Optional[typing.Union[PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryGroupBySortQuery, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__99c68b11ef0b549bb5a3730289c74847b3d68ab3337e7cfd5f7ee4208ad6632c(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__03cbf05803c6c44372283e3e687ed252e3149989e7a84f794644ea270a7871b6(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__365ff2cc386cfc683c2c96413b6a72ed58cae01d5bae82ffb1cb4655ad99f2a4(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c27f3d1c7b815d387708dcfadaf0e3b3d0b88fcbab350421c86a624503d53090(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7fd04307d9a67f3b7421da4414a730896c0babb9efb5e019ef9cf7c5749bb255(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__00d538bdb6e606c95f67b41769000c68748bb4798e7ed2e743ffd38113ec3bf7(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryGroupBy]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b6f5c07a5e3447f1f6fea8c6f2d4134e0829e61e5f1a597caee089a8f645c698(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__604f8f0b7369dc810f7135d79d73c405d31c991a03f6f93b2c3d8d9dbf11bb59(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1fd7abcc44ac33d8f5c6fe758fccb79ac850070836f092d9c6c8e1c081754a77(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1224d8e4a884cf53d39055e929097b6d285b77d7f7f1b95ca729f0c19f064465(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryGroupBy]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__87e499c146295b29bf1e7dd09731e994ebba700f6c8d1f0521a6bbdee7d0367e(
    *,
    aggregation: builtins.str,
    order: builtins.str,
    facet: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__99b7d32b863b92794e0b7d02904ad12284f79c3978440263bd72962d343522e1(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__63540abbd16443898a976006b8f8ebe900b93b547cf5412119b76a1ea47c5803(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cb52f20cc65f352021ac40363af40284091f2b677da6d3e3ef13dd36182ffe93(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2b8f21e45f0405b5bc0949ddac4bf59b6b7cbc819a28c337e65f65a3b1e14990(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7a55f42a77afc4abbc843e070f2f143e762535303f86ce08d7e53027e25392f6(
    value: typing.Optional[PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryGroupBySortQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f1ae1d63f6c1d3c389a009aaf23cd25583ec42b715d29ea4e0a10e0db13d381c(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__523295f0032b5cd813fac0a68274f56aea2b38cc236a67da35ba4a7a53b5e203(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d3bda3fa4f04ce0ab2786760429fa164d687fb66f6f622a03513548015819a9b(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__310e99ab85e86eb116cf575991dcd86fdda0b25c9548358b55d50147d08ca5a9(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__640b64279aba93e22444b01efb03001854558151862df4ae963e6b13175f038c(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c01a2c11076328b4174d661d2459baf09fbf1a33b0061b9cd84953873dd4f6fd(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5f58d645ad7b04bf300cb2b4b59c9af2165b132a2f45849e5d63cd9279f05d81(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryMultiCompute]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f4c2a28cd1fd97950227243675c2c5294c4ab9488d0a8a1064496b80445f7657(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__eea7cf82ece21b51a23063e1490b9e72c9d246abd8613900aba3d9cfda3b35ce(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6372b07565b9cbcc9458823d930c9c9e8a1ed96e81931355649c7dd6481a8d90(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2769769c3bc612abf44a7603085d0eb372459616a850c35e5b6b5cc798dd8aee(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f47a5cffcfa55dc014e594130861f9190934ec70a058ef13ba7b51ff8a5266f7(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryMultiCompute]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9655089e5dd0029f748e0b5c5118aa702a7b8670145e3f4eb120dce135ca8914(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2d3fafa4f822dd9a73e550eef71c2e3ac57056300e65e77dc83b9b0a09611633(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f3e73503d230afb6787d7532afc07966358bb342dc437eb65d4afaa37f9b4434(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetHostmapDefinitionRequestSizeSecurityQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__92382277665d4b5f2ceff1fee9920864a903685846c9d9a9d15ac60953b9b7a7(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4e82aa4469ef78bd1d15950832fa994618c0882d9a7035f28b6ed3383d56e4e0(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a3f7119071690b2b4a46622795d46a98264a3c311c66d642ed2901b6e4e3015b(
    value: typing.Optional[PowerpackWidgetHostmapDefinitionRequestSizeSecurityQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1eb7f505b0285db8eb95ea33ffdd2bd22ca7296124019b3bbe97705ed1134f32(
    *,
    fill_max: typing.Optional[builtins.str] = None,
    fill_min: typing.Optional[builtins.str] = None,
    palette: typing.Optional[builtins.str] = None,
    palette_flip: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__11e34c2d061175fbec649089d276731dcb21a27a060995f22b1875fff3634dce(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__74f1bd84e71355431703985fac3a11795872b925de1682f4aba4e6a5c945af96(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4ae1aa6b25189f9d23d7519737e4b8edf2d390467b2239cc0984aca9ce8e5d79(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__655e7043016b802357d4670a54e1872c3a064ac34c8a60c952b58f7618df7f6a(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cd057ca686a7b323dccc6a256b9f84883365047e60ae7736231dc80e6d95d7e7(
    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4cbdafd35badb65c723bfd93c44370cd155b8513be553d80b063090633418a2a(
    value: typing.Optional[PowerpackWidgetHostmapDefinitionStyle],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4c1f252e38b2f48faa4b7b87a41137c807924e33600237d7dedce097e9ee78a1(
    *,
    url: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4bc8f5284b50a5e391a8c7e87da1d86fc94fafe75c4f08387c1d1ee7f8414733(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5546535a977bc7853db444d267c93d80320b1ec2ed0efb5079012f26e65df190(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7aaee0701846a06a13dfa700cc69a7d278b3ac36789873584f98fd2927765c85(
    value: typing.Optional[PowerpackWidgetIframeDefinition],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0d3a8e594c7f889680501a7ed91ca553dd3a7b65136e395a6b48b44abad824f6(
    *,
    url: builtins.str,
    has_background: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
    has_border: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
    horizontal_align: typing.Optional[builtins.str] = None,
    margin: typing.Optional[builtins.str] = None,
    sizing: typing.Optional[builtins.str] = None,
    url_dark_theme: typing.Optional[builtins.str] = None,
    vertical_align: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b800633df8937fbea0df0f8a8ab251064fc003270f72fec9334998eb129255ec(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6aa5136f7b2d557b02d82b955f8623b4bc4985ecceaddd1f8882135834a172ba(
    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d34d107c85f182c3b1ba1444c2843f9a65e52df45310ba335ed719ce781bb890(
    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__465d96e7fa4f3f01258b3fdeed05941ef53dc8bd89b2331324cbb46a780d0438(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0fd54931d916daa4850b246c3c0a8244d8a2424b09cc371e7ff927899a9aaf67(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4970a594f0707d1524e4e88c50e2873ed1e9f1df7681bac7809f7d1f41495b0b(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__46410917e739ded6c31f3c1bbec5ba589519313b12a093f6fce489dd8806366d(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e3015ce24945c09c0d5ffd8a09029c08ea926fff0ca2c5ec4768ac0dfc62c772(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b47c400bfa33cd85ba0882f1ee858b9ec627060a3399fabf3ec0be63b89a2466(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fea9304089e00eba46103a7173ab222ba2f165fa6272374a3bf99cada7604949(
    value: typing.Optional[PowerpackWidgetImageDefinition],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__965a963fb2f3c0458dbf95f722d2255f68e3db4d62ffc832baf4a7c62959d473(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__11a21d92fc6666e13bd356f096ceaa995ba4388ccded7b43eedbd6f8c4676b93(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1a71afcf316c80ebf24c53b126f8a969b34e2550f434d2f2500e9eec46edaac6(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__af765e02d275969fd877e6d529bb9a3936eef8b12b09056ff14dcea9983ead66(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__30eb9ff6c2feac2d2705d94ce0c6a1d21b69a8368f32a0ba70b6ddea02305d64(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__67f43daca88f94707a4627823bf473235401db2d5aa1cd3046104311201fadb4(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidget]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ac199788e84f6263bfa343f3da4aaea8840973bb53d1ea5c815eb86de5f6c917(
    *,
    request: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetListStreamDefinitionRequest, typing.Dict[builtins.str, typing.Any]]]],
    title: typing.Optional[builtins.str] = None,
    title_align: typing.Optional[builtins.str] = None,
    title_size: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bcc5bd0bd3e09a81ff98bd58e91ec74209c1163141f0692562b63794a694ae4f(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5ebf09be36319a406f544c69a9ce76a680ec27f719593f44dda84adab9e24dbf(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetListStreamDefinitionRequest, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__951da5ca87bb71febc98128db5d31ed0953a7d19c1715876cd90971bcef4295b(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__71e2831ad188ce45bc48ae1a96b106fc30eff5d996ec9480b9f117f86dd7de77(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__53c475192a763c3a2a61682e11dc09bb6aeeb930c9cf824e79b377f64a36ccc2(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2c40e9855b3f4502e15577e53cfc2e39d45a6a24d9448630d15e2e4112ff7019(
    value: typing.Optional[PowerpackWidgetListStreamDefinition],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ba70f75d3b12fea7db875660e928abb1da2e9887cf9733c5ca95b3c081ee9ae3(
    *,
    columns: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetListStreamDefinitionRequestColumns, typing.Dict[builtins.str, typing.Any]]]],
    query: typing.Union[PowerpackWidgetListStreamDefinitionRequestQuery, typing.Dict[builtins.str, typing.Any]],
    response_format: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ca54d788d9888832b16e2589e817637ae9c7c6cf3f83d1383e1bfe8f03efcc74(
    *,
    field: typing.Optional[builtins.str] = None,
    width: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5a238d78347d1fb498001ddf97de253be19a442f56cbd38aa5992a90e8c69c54(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f0ebd3491e67d93f8c75870d295616081c1a6e67d18f9db83207676a94ea65ba(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__02c42df9d529ce0e20ea39345882bf2b316527ab77f1a53998bf19d444fd3ea5(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d644d4322bb7a7d8cccb56e2a2b4f526a785ef21909ad9370f0debb52b157aaf(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__15685faa990e2fd42d9cb0f5336cdac02f65998c398ceeaedb54d09617401928(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a74465ecc3ec654b6572578062d8f40465e657ed7ce49df6f61348e1d96371a1(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetListStreamDefinitionRequestColumns]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__db7bc3ce8e3025fccee669af45b05ea52d4885f78431cce6bb1ef14ebe1088f0(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__93cd9e028cc155b909e25af3d76029a1b92003d2318a35897e2d6057f00f44da(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cac831adb6c300270df2116e3b0acbb98579e42dc67f385078182b80589bab1d(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__95c67f954061e1c9012ce872df1138d188a01c288d8ca9b91da0da8b2c77dd89(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetListStreamDefinitionRequestColumns]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__51ae49d37e0c0f17e0e8e73ab61533352bd24a0a33657a0d8d2f9d601fdcc27c(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2c3a3de436a777c7f0a7080f924b6949f5de92bb5c343f8b7ee3a2cd053664c7(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f9ae762303f8bedcaba22ecfd68919f140065079bff918174601b616e79e267f(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9c90a05b69ef18387d18238dbe0aa74ff99a490b1c1928103f60a35b907c77df(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4a8a42a2b2739d2ce7ec523742f4915f3b040a5ea77d86ef081725fef366825d(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4eaafad551bb7cdb4bce0e08c6630aacada310bcf4d4f194db04be93581de3f7(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetListStreamDefinitionRequest]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9cbcc997d7ba7d7454ae997f2c23b1884c2776b3f7c5828f15e1e820035e2dae(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1a169398da1be6a6a9857c3234c680905db5adf02506c7746953831f2ed8a4b1(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetListStreamDefinitionRequestColumns, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4741d4b7940152694b52a86a786729908423d030eafe23084f34987d4589044c(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__434aefc9a99f9102aedf2d3697257b742bba095ddcacdb0774e40c3ab0ecd151(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetListStreamDefinitionRequest]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ad55f558a3f9c7d98424ced9e7d9e3dfc88b3f66eaceb9795ff88a4bf2cb79ef(
    *,
    data_source: builtins.str,
    clustering_pattern_field_path: typing.Optional[builtins.str] = None,
    event_size: typing.Optional[builtins.str] = None,
    group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetListStreamDefinitionRequestQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
    indexes: typing.Optional[typing.Sequence[builtins.str]] = None,
    query_string: typing.Optional[builtins.str] = None,
    sort: typing.Optional[typing.Union[PowerpackWidgetListStreamDefinitionRequestQuerySort, typing.Dict[builtins.str, typing.Any]]] = None,
    storage: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__36e1a4bea414fda02b5c5f57c53b25d6fe6e39bf4c05a0601d0102d5c3fe836e(
    *,
    facet: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bfcd71a6efb46a61dee9d5baa27539786b523a86ec9a48735fc8212a02d9e07d(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a6ef9d3cc72f565273d77ff0d9b22318e56c81482119a2e9cae430323fea9a63(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0cafdc2a50fddd55c737d8c0477741c27cd02541c09d9f7d8667f421d1594c03(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6d63268013c4c94edbc070fb7e9f5af9e85bb4660d3803c8243264869ef8ac2a(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__11f87d0249f0f22a97ba3032a9f66889a340cf1b2b77a6bd7d3b7e16b8625b01(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__146b586248e56fee363cf695d40721de77f07a6504035257fd4de2f807bec357(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetListStreamDefinitionRequestQueryGroupBy]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__192ccd58cdf5e4bfc8cb8254001f6341c77c955ff57609275c5397af219e9055(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a0272eea5c178a96cdfa5035f860ab177c1f9509cd15e13191d2bba42535087c(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a030b195494c7d33408cbdbb9d5b0c1281d61ff8ac75a6847a33c734c3ea8bd2(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetListStreamDefinitionRequestQueryGroupBy]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b5e941f40fb96c63f593fe56eb4888e6ed0747ad244a5618e585eeb9a1a63b7f(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__94e369493424c00dcdaea964521ee2a56ccaa18cdeb7b292e7e42ad507cc19a0(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetListStreamDefinitionRequestQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1be90d555c163dbfb58ea4e461fc3e62aec517e9accd13093ac078d34c8db430(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6704dfffd1d965025e12bd5c250ad268024aeb0a860bdfa9214bbb86ce1af0b7(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__051a2d94d6540888db10f3358727543f32b126dada0eb0b02ddc7dfd3d57c15b(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a8770c2f0a1a649cc1a0eaa475bb05584f6ba143b04f7e579547924b8cbdeac6(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f464e362ed76ed526960f65e879fd160d33fc5bde4f0fececefa4039a45b7621(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9a1adf3093d2caeb5cae2166caa87d8d726933fea781d7ed12cc915086eb1778(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__02020b309a7efa4f3a9f2cb358c3260ba1ec2be75716e7b27d87134710b4f560(
    value: typing.Optional[PowerpackWidgetListStreamDefinitionRequestQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0faafc630db6417605186ed17c8e320c46166828aa1a06155e6b006df0283b07(
    *,
    column: builtins.str,
    order: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f7bc382d7040db6308f48ec351c3967f03a50197c4f58e74902f72829c60cccf(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ef658ba55900026440ee1832f386617cd34a79c3e9bba3e7da0eaf97d36d0b0a(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__628d059b6fa92a6549c3a538ade0d78c532e945dc0de24bb06df2c3fa3a2f83b(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1f561a4cf037e2c5b4be8ae2fe6fe84103d31c9faa066697d4e56bfe562e4ee2(
    value: typing.Optional[PowerpackWidgetListStreamDefinitionRequestQuerySort],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6b81fe2da378a00f43cf367eaa3cdb448a3affa06fbe30fde171815d1e00baac(
    *,
    columns: typing.Optional[typing.Sequence[builtins.str]] = None,
    indexes: typing.Optional[typing.Sequence[builtins.str]] = None,
    live_span: typing.Optional[builtins.str] = None,
    message_display: typing.Optional[builtins.str] = None,
    query: typing.Optional[builtins.str] = None,
    show_date_column: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
    show_message_column: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
    sort: typing.Optional[typing.Union[PowerpackWidgetLogStreamDefinitionSort, typing.Dict[builtins.str, typing.Any]]] = None,
    title: typing.Optional[builtins.str] = None,
    title_align: typing.Optional[builtins.str] = None,
    title_size: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7c414186bc5bb8dea7fb1fbda57ad2f7daa240fe04c9738829b1b8b403f7c1d7(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__872f5c4e8e746692dd77737c2e4fd2d2192ebf64e047858b256782d94ee0b473(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6621bb8d7127a5742c9c1518dcae3345431eda3541f06f5ea79c02473cd884fc(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e18a9712fe256c2735292f175e3f17dd5613e83cb83a712b409a1921c8bfbbbd(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__36dcc12645ecc1cce09db053a242814fca6e7bc1d935e17b9126a77d7306deed(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__49e714216e5bf66a61537ff9bb33e571b2a1c9c137e3a21a60e65adaaa4704bd(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8aa1a1e88280a99f52ba24ab45215b6b4a8a571ef60c590b3798cb454fddc010(
    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1d212e6d6bd597f59bbcf99c9b4b50e38c92352cee3df0f83480227a0d8e7121(
    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__72d6944c522b82f26c178b6c6f8ff6fae5e5e0562a99cb436d449689ef0260ee(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__34718ffdd151ad2e21854ad183701feade6073a5917fc6e467530d49690d4c57(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__61442f3ffafb55d5a9d80c35b66145d7c54fdf32e8073c178a37b8c56a7d364f(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c22f4495346063f8a06728cf37036f0f971fbd48cd2dd2cf4c7b4c8ade72007f(
    value: typing.Optional[PowerpackWidgetLogStreamDefinition],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6ef8b32f89891b90e00abe61c2ada54206dda3e31871c7536f8f4e0dfe07b478(
    *,
    column: builtins.str,
    order: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d02eca4311d3cac7d24bc97260d32f3719f7bf3789ef3ccbe4691b588dc189d4(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9a6f32b767fa2c2d35a1ae2138722ff64ae9bce12765f1b83390bc4115f7cd01(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1e501fe440126d5089689196002ee8e8e90866f3100b75258c3ec2376395e3c6(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cafa46c3fc802fdf41599469e6acc52cf9d81b1865737111da9545ecbf43a38f(
    value: typing.Optional[PowerpackWidgetLogStreamDefinitionSort],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f2853d3277878db44a572e291222037556563e9a6aacd252b48d2c33ae01c5e6(
    *,
    query: builtins.str,
    color_preference: typing.Optional[builtins.str] = None,
    display_format: typing.Optional[builtins.str] = None,
    hide_zero_counts: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
    show_last_triggered: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
    show_priority: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
    sort: typing.Optional[builtins.str] = None,
    summary_type: typing.Optional[builtins.str] = None,
    title: typing.Optional[builtins.str] = None,
    title_align: typing.Optional[builtins.str] = None,
    title_size: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__25f0c74cf1ad8ef8f78f4332baa391d088bd58d9bf5236ac5b2a164e95342fd8(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b95b8bfba435737a11ef3db41b50037d1e6e089798a6091374594127a8207b04(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__10887afdacf2293d77d4898cbea39f4b53a2d47a5541344c93c3ad4326d4e4e3(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7aba4958fe10f27d59165cfe5e4246177949d253df93f9e687346df1534c17b9(
    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fc091bd1f9e051187b624ef685a27fecf51259d012f0d86422ac1f462bbad2c6(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b13bab9acbf7781b2745f999ee6a91457af703a0c58b9cd2197aa32386f436ac(
    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__688929ed746acbb110667f6603ee11015548226ec4fe028ffe26c3caa5c61bf1(
    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3144bd8b0b8c5dd5c473926e3ed3775f7966c2abded15f9313402a3f368dffa2(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5fbac87bec5e17ab8bc2c6fa3b663cf7fb779e1501661513835968ac057c9616(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0302c9d66be8109b1fabad79b9a565cf8f49a7ee0568dee59f8e43c58da0e41d(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4d05ebe9267617a81328de845a6470fc021e27ae5952694a2bbc42e3808e6852(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__edd8c302f2408d9ac801a807555846ab7b61c06e0fa1dfe4595e88d5d2da0eec(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__533bbeff3dd8ac3b3a27ed8163aaf3bc867a4d0d0960adc1da07ba146db4c5c9(
    value: typing.Optional[PowerpackWidgetManageStatusDefinition],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c7303db97d1be881bb05d4f60ea78c03fc3388d353f5d5e3b7c89d47cb939edd(
    *,
    content: builtins.str,
    background_color: typing.Optional[builtins.str] = None,
    font_size: typing.Optional[builtins.str] = None,
    has_padding: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
    show_tick: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
    text_align: typing.Optional[builtins.str] = None,
    tick_edge: typing.Optional[builtins.str] = None,
    tick_pos: typing.Optional[builtins.str] = None,
    vertical_align: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__49f67fb10943a6fc02570281f6a284cf2dfcd0d3a1ce8a0928db7422786ec313(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a939fd05517e872ff8b35fac55a6b7b1144e27f657e1fd07e170b8170c9ff786(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8c91d7585ad789cf546e24f8f26f2ab9c99a3d72231383e6b8cd02d1f3d20e7f(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ee98c6cad88e04368f79f8ae268ea4c784543eb1018d647f92854b105332d37e(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1857d14f6e9db396b1f152365c1640691382889363cf363a764cec239bbfffdb(
    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__66f656ebe31ee9706684107383b4547c9a345884e7c9d6f1dc7a0475f199e5e3(
    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bae039aa6712034c048263808308de3ca04290b0b48ac9ef712c095c3ece4c7e(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__82b33c8b4d2266f296d9a3101f5ebc5d1e2e8702896576d3e3a79fe24f68d3b0(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d1a188bbfa32c9f3907443cea9f55017546f305c7e27ceff1492885c66a58120(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b99f3453090a022b3f571985eecdc2c2eb8e486babb1445764501feac314f701(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7e2f770ea8e942ebecf11a4c4a15b6487559c70688c0bd7b12b9c08e61599088(
    value: typing.Optional[PowerpackWidgetNoteDefinition],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__90c47c37308ad37f1a1c7958548183fc41350a2b39dd9a8f3296896b502f2827(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__416f8dc993c7d7b376a689ac59bebf173096753875e013004a1a05e8ee797c14(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidget]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b08789cdbc2d3fac67b96d64dc244d780d5fb4d30cdd177e5a88c7a0aaccb2d3(
    *,
    custom_link: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryTableDefinitionCustomLink, typing.Dict[builtins.str, typing.Any]]]]] = None,
    has_search_bar: typing.Optional[builtins.str] = None,
    live_span: typing.Optional[builtins.str] = None,
    request: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryTableDefinitionRequest, typing.Dict[builtins.str, typing.Any]]]]] = None,
    title: typing.Optional[builtins.str] = None,
    title_align: typing.Optional[builtins.str] = None,
    title_size: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e9aa2a9f56b3e42c525622751f85b19039b3d49e5e8567429e55869f1008a28d(
    *,
    is_hidden: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
    label: typing.Optional[builtins.str] = None,
    link: typing.Optional[builtins.str] = None,
    override_label: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dafc7197cf3f51f1d97555949c1bd45035e6c3857b28a0febf60b7a8da62b774(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bc6d2d01783fa4b3748a681aef594ecdb9c0d0145fd137c311b69ef498512333(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6b645229995ccde1f1436fdd14c674b0145a3b28fba12d4cfb56864b03e6c96c(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2c16ddd9dd8c39d63cce3e9a1c2a7ccf1ae52a1435c803b4835a725786bc3732(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dcdf7264533afcd65932b06530f24b5ca79aa8abaacdf391445712a4f962c2dc(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__02e87cafe85121320d53193f4c86304568e21116c8385a6de5827dc2c9c30f50(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionCustomLink]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__80a4c9682e51e1de64f1ed23e82a09aa2a510032c711412441c9f18485af1931(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5128402f0a8129a93c81d958f03886aed33d95c99b45af6e86afcea0aeb782eb(
    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5233bef5e2e2ce5ad3a209459d2d3ba54508f6f0b35656ae0434e7d682420c41(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__098a082c5b46f00ab115b2b5e625ec8a20d1230dcf618743d9c630826f52f275(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d13359b230181fcd65034a263571d3695219a11f920eeadcf77d1ca632df0eb2(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b08dfabee1a6ad13f25f36d649632da31f682d3d633a0d57e5970c6e3f951c76(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryTableDefinitionCustomLink]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8dd65372b12388e65b4f41d5ff48caa175317a0d655336861e5303ddaa0947b1(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4a370a23a65de221bc5b189c5da5826bdba78ce282e3b508754a450b7328419a(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryTableDefinitionCustomLink, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__32b1ba8377b1eaa08835bdeb5b63254defaf31c577facf3758daf0650e5fc351(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryTableDefinitionRequest, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__115d8586c1c734f2096c3a12ce822f979fe2cd6ef95ade0fffd72c1ffa1b82f6(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2bb7e30c6cc7b28e7ab687e472f5fcfddb3a8540e5f8edd1f5d8d2cfcc8b600a(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6f33063fc3ff2979d32113ec1ab1cf3358ec35c7fb41f089dcd1c8aa857c4e4c(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d782b3b3832ec3d434a52cc701391b3a74bae10e7f3121fe2c790c3e79491711(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4578667aaa48a5e3ac46c1d5e61343f8e120e4eece886fd5b8d399a40ae811cc(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f386d2fcf384009e73b625c4f2370e9a7a8c586ba6ca6c487a6aeea496726aaa(
    value: typing.Optional[PowerpackWidgetQueryTableDefinition],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d79f6986f6cb59f8b9111da690a21e0b39907aae8a252c6c79ac94c9a511965e(
    *,
    aggregator: typing.Optional[builtins.str] = None,
    alias: typing.Optional[builtins.str] = None,
    apm_query: typing.Optional[typing.Union[PowerpackWidgetQueryTableDefinitionRequestApmQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    apm_stats_query: typing.Optional[typing.Union[PowerpackWidgetQueryTableDefinitionRequestApmStatsQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    cell_display_mode: typing.Optional[typing.Sequence[builtins.str]] = None,
    conditional_formats: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryTableDefinitionRequestConditionalFormats, typing.Dict[builtins.str, typing.Any]]]]] = None,
    formula: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryTableDefinitionRequestFormula, typing.Dict[builtins.str, typing.Any]]]]] = None,
    limit: typing.Optional[jsii.Number] = None,
    log_query: typing.Optional[typing.Union[PowerpackWidgetQueryTableDefinitionRequestLogQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    order: typing.Optional[builtins.str] = None,
    process_query: typing.Optional[typing.Union[PowerpackWidgetQueryTableDefinitionRequestProcessQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    q: typing.Optional[builtins.str] = None,
    query: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryTableDefinitionRequestQuery, typing.Dict[builtins.str, typing.Any]]]]] = None,
    rum_query: typing.Optional[typing.Union[PowerpackWidgetQueryTableDefinitionRequestRumQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    security_query: typing.Optional[typing.Union[PowerpackWidgetQueryTableDefinitionRequestSecurityQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    text_formats: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryTableDefinitionRequestTextFormats, typing.Dict[builtins.str, typing.Any]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__42fa91f177b88eb2632d5c7eaf04bcd8b551fcbbbb6868102c57eafe19098993(
    *,
    index: builtins.str,
    compute_query: typing.Optional[typing.Union[PowerpackWidgetQueryTableDefinitionRequestApmQueryComputeQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryTableDefinitionRequestApmQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
    multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryTableDefinitionRequestApmQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]]] = None,
    search_query: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6e9a6062e1d87bee0491c14abd3e1149823ee939aa3a84de6559863b8fc7bc16(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__47168c22326ad9ea6148dd4e5645ddfb881ec0a8346261bd389a7a729708e370(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7f02010f45f87016115599ef35d41742c3a63304193bdcfb81447a981b6823ca(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cdb2a76b11aa7d89effba048b75cd4f9d200b84e67ab3f8f0a4bde619a72668e(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__76eec39d4f3a8cfd6b4b201f4158e7abf7638cd461573721cddb7a3188e6c3ff(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c9355a8c5a2fdfe4148a5cf39bc44512e3988653686f4d559fda6071aa770399(
    value: typing.Optional[PowerpackWidgetQueryTableDefinitionRequestApmQueryComputeQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__644031880a0b82b71c67791597e9f145672ad15250e981349767b33a1ac83431(
    *,
    facet: typing.Optional[builtins.str] = None,
    limit: typing.Optional[jsii.Number] = None,
    sort_query: typing.Optional[typing.Union[PowerpackWidgetQueryTableDefinitionRequestApmQueryGroupBySortQuery, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4fa4161935db1f3974c4c3f160fb022bd1b737f5277c87749596f214c191cbb3(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__037241aaf900b5ea45912c6fab778e05fe266d090bbd78af897e63c4a316832c(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f1151b5fcc513682a0533fc2e1fdd807c1e6d2f7ce9a8c0e12bc367f2942cacd(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f384588f0972eb4570a05919f9cca4f59cb57608d5761cd6e45223347ba889e2(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a2d519914ce1c5c20f5e3e4b5f9f86c3575cd8535082e72dc97e1d45bd8d5c6c(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__897b9607019863682b44a224e763fd709204022bf401964c9c1582d840bad6b9(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionRequestApmQueryGroupBy]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__252a7bf86cb6bbb9be55191bdb270d6a804993be42165e623951cc5dac78cb14(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__92171a397762d835d79af119fcf2f09757bbf319c819bef3f7039c770194d6b9(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2533a65870252dd0a6fd53f8a21498f23853d84413c3ea6cca3d963eb4b9cf6c(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e7d75f4123b3e0de4d17ef95cb587d64ab923268d81de879b533a3226cbcc8c4(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryTableDefinitionRequestApmQueryGroupBy]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7c0ac2f53bca6ce250abe4f642b5b90245aa934b3a0b3e967351129c3d4ba777(
    *,
    aggregation: builtins.str,
    order: builtins.str,
    facet: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2b457ed9bc6b7dcc373edab8614aa585d1a7cdbb0d4d0547f9554ae7236a40ba(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__541519e825ab9585c5a51e127ea26948c18df19bc7f52a50bfa52fa200a01382(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ca9e86f4728c4fe15e81ca038257adc0e203767b9cfb6e7ee768fd0465ac7a48(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3c92146c7f2e6ac9cdae97464ab53b309785ac32059866d71006cd6215ad49af(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__03493f3340bc8513be5a36a3589817d72d6503abf5aee02423710dbd755fa993(
    value: typing.Optional[PowerpackWidgetQueryTableDefinitionRequestApmQueryGroupBySortQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b2845eef83d6e1d1a42986794faa2e858098709d1ce2b147b48c0f0547bc746b(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6e0f379a709cf0f6f386c88395482ac8fc09e6c6b85c9c200bf8957fe9017be8(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ffc8fba663f7e9645935e05261c59baca664e3bc585983315e84d99cdb0537db(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__65b188c53842f46e994cc1cb85d933c71fc36d443bbce78308f6aa7b442da4c0(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6e9cf5b0702e0b154c313957b124e35e43238736933d3816f28fed908ac70143(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__51e2fec3c87835936fa994bf54672e644c539e395f32e3048f622f589193a5ca(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__768528065a6e96d18406ef1e94a7889d7a02439a66820ae765b9813cb58bc676(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionRequestApmQueryMultiCompute]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a6c4839740446ef1fb684fe783272649ecd286ea45b59cd2f2afcbe4b3b0f47c(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a5565e105f74c8682a542c26f25687b556def587d180a26e334d67f479611209(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__246618906ab86e0829b54a08d18eccf5cdb2a11fb2ddc169681e00b943d76afb(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ae2dbd7b5ffdbddefeecb3fc995868b14f0e8e0b0c8461253ea64cec282441be(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fcb3a1cf9f4cecdaeb5d5c02ecea5f56e434b4261ea87c464cdb19eafc15027c(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryTableDefinitionRequestApmQueryMultiCompute]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__49820b34baf6e28902ce6361a5fd4551bd2d351e164f8cf48f8c68493356df19(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8313504e6f7370bec33bb42a3324cf6fee6ee71055ebea173a3ebda72776deda(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryTableDefinitionRequestApmQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__74930203ab6b7f66ed2941994905e15d46ff583a6dc5c0a947b01edd3a628cca(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryTableDefinitionRequestApmQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__176d7b0307c655a7cb43709000190c7780ad8079e49197ad6a327a8ee6ec54c0(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__760adbf6ac2d17a5ae00b7f64429002b9247393a5d4a4edd8f362ad4dd0ae25f(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__916a85586cbf5d84a9c90a3b0b024fedc0cc22fda6a6478246c936c5f4567ddf(
    value: typing.Optional[PowerpackWidgetQueryTableDefinitionRequestApmQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ac3b621d1cb4f7f2ae822bf99196e4f94a415fc7fb8be5223c6e4461c724b965(
    *,
    env: builtins.str,
    name: builtins.str,
    primary_tag: builtins.str,
    row_type: builtins.str,
    service: builtins.str,
    columns: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryTableDefinitionRequestApmStatsQueryColumns, typing.Dict[builtins.str, typing.Any]]]]] = None,
    resource: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5f49a5463591a2151bcd5c540dd65097afddd5f358741f55512a9cc60cfcaa01(
    *,
    name: builtins.str,
    alias: typing.Optional[builtins.str] = None,
    cell_display_mode: typing.Optional[builtins.str] = None,
    order: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__17bc74b71ef84806324d3d00fdbbed5777cd3190c6d7f4eb489f428e0903a364(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5acfb40b874131d2a3098796d64d8f960d54a013c4942bbf3893ca88a86ee0c1(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1c2a576ce9a704a1b06335d6d2581526bf1c5ed3fafbf7353819200843af6276(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bb7063b2a18129530946a35f0d3b6f7e6a40c29329e27e55786dfb9699cbe700(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__20ff51d4670529836bbfb0c5672c60755b5f9656bfb5ab90fe48b059ec83ffec(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__474330139309cc15cfdb0d1f2cf0b8187fbf49febb0071a1504833fab8a1799a(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionRequestApmStatsQueryColumns]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7c20703f118e228c37e877260a320ab8db5db90d19ebe7e5312dd00826c3fda3(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2bf016722247b84e3b2b706d16197d70f72dd0b7d1d63ce30c07fcde7da486ae(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8e9b37812bfdee3d81e9fe609dd6531f70dca1d6b30c3c67519bdae418c359fd(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ab09708b8b55918c46fbc1a46a3bc1e22685d6e3423fe036135422fd2a2d1e0d(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__031f7464ec6163fb8702141790a903d0115ed94b1a5bfe3836f5d9eb8337df73(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e9746debc01514c35b75e4f2af06ccae23607a51e63f58f7f6fc7d6042c98d62(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryTableDefinitionRequestApmStatsQueryColumns]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3ca6880d1dcdce4a405c515bb85456221eccb949f31366bb6ac3b00efd437e94(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5c01bfc0bbccd29723263fc3f6b40ac6eceefa05a5d9aae67a99840b1f2f41cf(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryTableDefinitionRequestApmStatsQueryColumns, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d3397795acf37e54bf28a88fb61111a05780383ff183d93c9e5851cacd21ea7f(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__275dcaf4ccd022172cb9265225f4682e0812e747154bfdd6d1badc4fb7c5556b(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__41ff25b9ee178578610657ff1510eb98ef4bb17aa667972713de202d0093ea78(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a1ed71f28f5af26b738e427feba9512c947e48a245b98591af5236002aa6ee4e(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__81856404325f643856537585885170fa83c61e3c336dd1d5ce67c8d9f34b65af(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dd81a3218b87196ee4696fcccc41efab7d844ea9b49c6d098699fac99b99709a(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5fc5addd3afe5fb859764e0cce93721ba7cf69553ed5cdc845e108f55b4db9dd(
    value: typing.Optional[PowerpackWidgetQueryTableDefinitionRequestApmStatsQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c7bb30b5cceae25a94cb387e2cec20fa8fef290f5c6489955afc7823cd06d5d7(
    *,
    comparator: builtins.str,
    palette: builtins.str,
    value: jsii.Number,
    custom_bg_color: typing.Optional[builtins.str] = None,
    custom_fg_color: typing.Optional[builtins.str] = None,
    hide_value: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
    image_url: typing.Optional[builtins.str] = None,
    metric: typing.Optional[builtins.str] = None,
    timeframe: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__57e045f93488e6efb82676a985f3fc5ea775d9ed8d38d4689ccef6b94c4bc06f(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7294de63dcee74ebce4f998002f4bbe2dee22ab19d47476ccba3cf7ef3337f40(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e4040b3c83a1a66c60e7e8c9326344c0c66bb9c3cf6f664a46fdecfae76057b1(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dcef8f2a63977f7e9ac19b143eba67d1ba6c3ec7e9aa9002c15c5528d6ec47db(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f1707ba7d10660a3c9d42632606ce2f8e23871a62094baa985599e1af613f939(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__078850f069fdb3907ece17ef3bb55799811002c374317a137968e9d2974ca8fe(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionRequestConditionalFormats]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4e350e63248d241d43836ec7b13e73a656887eba0ae4eaf92bdec6ce62563083(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cdd2b47fc2bb10055199772b9bd57ad3f543c2dcbbab20b358d72e58a6457191(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a8ef05683c550ce63dc20220c2c8ccd57f25373fa3d149c617814e26b996c2fb(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a0ddc7b55aae3ef462b11629d3151e0072fb6a1ab98cf670dc11e5295da2a862(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fd2935bb52cc9cf8f1587ecc3151c26786ab1cfc61bf8777ccaf2fe20a9ae79e(
    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dce92b5c292f70bbbdd014b4e77729af1bab5032205c99284a12227329a6bdee(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ef829497898a67ba08da687168e7f2f64c85252bb2d747b891839922c9630984(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9358a537aaa3a01132031c49fc9f9ac289d59b56b55387c57bc078b5780c2c95(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__093c2fa040aeb5da4d4d5f36516fc3ba6e45e4bd50a5ac60f2b6c795e5100f42(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__74fb65771cbba35c467119743701ff71b9b803ffc0a1205978491d873cef3296(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__727b327ef5cd31af33ac7f0ad5682be59afd2972d44bbf9610990ec97610919a(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryTableDefinitionRequestConditionalFormats]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__81e01fa81fe369ecc5188234ff523eeb79cb24387691e9f336c04119dcae23e7(
    *,
    formula_expression: builtins.str,
    alias: typing.Optional[builtins.str] = None,
    cell_display_mode: typing.Optional[builtins.str] = None,
    cell_display_mode_options: typing.Optional[typing.Union[PowerpackWidgetQueryTableDefinitionRequestFormulaCellDisplayModeOptions, typing.Dict[builtins.str, typing.Any]]] = None,
    conditional_formats: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryTableDefinitionRequestFormulaConditionalFormats, typing.Dict[builtins.str, typing.Any]]]]] = None,
    limit: typing.Optional[typing.Union[PowerpackWidgetQueryTableDefinitionRequestFormulaLimit, typing.Dict[builtins.str, typing.Any]]] = None,
    number_format: typing.Optional[typing.Union[PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormat, typing.Dict[builtins.str, typing.Any]]] = None,
    style: typing.Optional[typing.Union[PowerpackWidgetQueryTableDefinitionRequestFormulaStyle, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5c7166396ce6716d564bb0c43911d68bed4c9245294986f3865d0cc06b6b2fb0(
    *,
    trend_type: typing.Optional[builtins.str] = None,
    y_scale: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__da43c074c9e56af84120713afe8660d837903264b2bb68cc15305f3af2d32ac0(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4cf1a31c52a6025cfbbd9e008292ee630de68c25ad3d3ec90eb79dd4104fe46c(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__86a97005d9f2feca3c87aab83fc9e5cf0fad162fff0ed35f916f8822a07e7ae9(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__814e1011a89987e127840b1bb768d76fcc45118bb4b9700b656f7f8d8e7a8be0(
    value: typing.Optional[PowerpackWidgetQueryTableDefinitionRequestFormulaCellDisplayModeOptions],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3a383747d45579ec7422dd4c0d3302a7a75a1182b42ea061274fd346f0506c9d(
    *,
    comparator: builtins.str,
    palette: builtins.str,
    value: jsii.Number,
    custom_bg_color: typing.Optional[builtins.str] = None,
    custom_fg_color: typing.Optional[builtins.str] = None,
    hide_value: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
    image_url: typing.Optional[builtins.str] = None,
    metric: typing.Optional[builtins.str] = None,
    timeframe: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ff9d339e802a530c5e883efd9614a05198c04e16ff882a2f491e7eb037c965f8(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bde252ac2ea124f6e89f94e8928810da296fe4e50186e065a3e42899b5596d1a(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__985917859b82698026cbfa876354f8b195a37280d61e49263cc55a6d16e397b7(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__93327080af408dc805b702c55541a439b75fa1c04f19cee863bd5d1103564895(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a5f20d8e662821d578ad40565f6e4ba92de6891bbc4a23433937a9120c31ab8a(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2a9e9f3b22f77158a7f3fb14c08a0ebd06908e19b125db752aae74c088f5a7bc(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionRequestFormulaConditionalFormats]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__513ee38dd503bcd13eb52e6754a2d851cd5a3b1d7587530080b8147f97b20d68(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1e6f246f5a8690f18ea88bc96d79f3e7b4f03071d3b812b30af94690e89d3446(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__287c8644a0417f85c66bd16c0308aa17667b7f0baca4a3729b9a2776d486099d(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ba4ee9790f148342d04d00c7fe09f5d70f4a1b28413624fe44ed6a5a2a09a407(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ea590fd07105d5940ed912aaa52f44e919af368f6d28939d73ca98593330808c(
    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d919270e80645f925a8a262cbd464ab858a8c5c6cda0fb7c28d64727aed2d930(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f85a43d681bd5f6cb47afdf4e943b180d4796289afc13cf9bf83d68078a3d486(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__58d42e027c949e2ace2cf4f2c02df2a748901d968c8d52eca612bf45d9a7d126(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4405cec0e517718001974242b6aeab093a8d6b9a9ad0708be8307e544c2c0d05(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d0b092a9c43ee9b69b2811b9872b2fee893fda5345eca5d8c8fe00d2e3c72c8f(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7c11999f7b66fbfa0fa5051a9592c0516a397b13d104b944ab16ce01ef4e6097(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryTableDefinitionRequestFormulaConditionalFormats]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7831b0b36685102c953c36282006967cb1a7c940e1c1ea09969070bc869b43db(
    *,
    count: typing.Optional[jsii.Number] = None,
    order: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__94aa4453129d43848960b51c3d24763c54a2e6329da4d903cd9dfb00c41d7c3b(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e771dc7f9a35fb777ea6d81499f08dfd2403bbd6bf8259acf412a3de8441ce82(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__492d1658b09f25d8844b08059e08b7de44c3e4c032a6a3b514cccfa3c6ac85a4(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7317ea44466f3d178f5e86f6a35b4453398ac343186284f1d622bd8846bfe945(
    value: typing.Optional[PowerpackWidgetQueryTableDefinitionRequestFormulaLimit],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__39e8cb0dea665585f33495f926947de5296f616b01c59f75c38afac5b725f58c(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b929f1f36a5270191739a8a05cd98b9ee1e7fb0ccaf3cb777ead893be1113f03(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__29bd3b8c3a5a76345b537abea9c018e8b39a3ecac49f7f7245349904e0144a00(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c0e3cf2fd24bdc407e50e9834872dcba20544e80e4a3cffd9f8ff43d91b82c0b(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e445f00a3fa116539abc59bed5f778f0c5205f460e3c5aa166019773169a5a40(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8fa167b8ccf4d59d956709ef70c35c8af462f13c98916258c15699d20eac3a88(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionRequestFormula]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__687eb8eaeb43370a850dde7651344ef4c11dc717a06ed89041c9c95a681a8026(
    *,
    unit: typing.Union[PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormatUnit, typing.Dict[builtins.str, typing.Any]],
    unit_scale: typing.Optional[typing.Union[PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormatUnitScale, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1cfa2a6dd4a70a9bf1190819a60cae131d63c43e935d5ca8161251f3e3290c14(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__95f99a447d82f0306ec8c4d50fa63d8f7fa8c9123a9f16d79f34c36e8cc1887f(
    value: typing.Optional[PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormat],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3c3d579b6b0de7d1fd1030de63df1babf1edf67db66bf708428f0da8fdd6eb2e(
    *,
    canonical: typing.Optional[typing.Union[PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormatUnitCanonical, typing.Dict[builtins.str, typing.Any]]] = None,
    custom: typing.Optional[typing.Union[PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormatUnitCustom, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__14872c65db454d600eac7bc62133be70af071b0acaffe8f67a560718b2ab48ea(
    *,
    unit_name: builtins.str,
    per_unit_name: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__49d50957f8f2a95188964e0a51cf02a9cbee0c92e50a9f6a919d831600fb6adc(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__da71f7fa36ce8e597fcbc3739d0585dc5b7102c761d0b500908711b27f0d6eb3(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__99369e8ab3d1dad0670396c294b2f4c796aa50a8653d350fba6f4c2e2c83dadd(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f59a4f6b656212efca61b989b29091ac06d5da40d695a62a3e80f7aa75d43f5f(
    value: typing.Optional[PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormatUnitCanonical],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f8c1c1beed3d581646ee1d6a5680b7672e7ea310d5922b0c73db655596cc4ac2(
    *,
    label: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__30c4486f6514802a4ba2dfdc5f6c148adfb9a8338b96fb1a2f836da20a7166e2(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8ed2676aa60579d00b3bcc6435d11452f4e41786a74d6ccab5c0477fea8510a1(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3ccfdf7e5e11396472863296a7bbf9de58551ea51f4ecd756ffdd83efe57e4e9(
    value: typing.Optional[PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormatUnitCustom],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__42c5ac889850a1276c354ddec03226c98429de9e6bbdcc2766fee8c70066fae7(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5447c92fcd6a808b8b8748b14cc1c7f40fd6785503eab5693eb16b3febf076d6(
    value: typing.Optional[PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormatUnit],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2b700329fc6612071f2a259a024f794c0a240f5bb457181f3af261776ea00481(
    *,
    unit_name: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__32adba3d0c1262dd40a503720f4eca5aa018404b379b6d55a5a8ac5f5aa741e3(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__930a6fb6f4fb93fd24c00638fa88b2a12411e238365d0bd0df15b29f799b0c64(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b38db0af8472ec5fbf798e8e622d11152bb7ee035739a2d8fe672cadfaf0cacb(
    value: typing.Optional[PowerpackWidgetQueryTableDefinitionRequestFormulaNumberFormatUnitScale],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ec8e999631aa5c7eda0c2e6adc54818081658f0f6d50a4df19185a62a7487057(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b01a3708e47e57cd9c9e6c007b027a4c7fe391c8a29b1c417dcf0cbb23d6252b(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryTableDefinitionRequestFormulaConditionalFormats, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__64fca3d8d4f995f6b4bf040c02dd13a929a43e15cf807f89219d0337f71320b7(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2a44454f27715074a685693b31930dbe0400d65044c121ee9b65e2cb0443e082(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__db314c1e7fa537e30c1cecfc4fe4f17ef761820b9beb1a5f123f24dcd8934537(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__63e84c9bb90b188865c71aa56e61eb1f349ec105014772c4e7b861a85063ec94(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryTableDefinitionRequestFormula]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__40fb9713da94c15c14a8f659803163c1acc55b137ecd3bbd0da40ac54edee15d(
    *,
    palette: typing.Optional[builtins.str] = None,
    palette_index: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__944c5939c6ef5cead34d8ce682496077f60a1926ffcf5456e1e4553fc010dfd0(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__762022e995512bb70471ee2405a121e48cf3c17309acf68939a9e09ea1a0a97e(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d3f68d39c0b170a199957b2582bc49c570bef0c5e5acb91532d7ea4b4195cbe0(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__627361ab2299df459b25f5eb9e42e9d45234cb22a40883fb891cf0be619c0b25(
    value: typing.Optional[PowerpackWidgetQueryTableDefinitionRequestFormulaStyle],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__20bdb9f800ab8ed19aebdb359123770627cf4addd3676af083eee7c49193f162(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b8b0d5dcc71dc390bb8fd80b6e55f15eb3aed30044c03fdb228bb40b4ead0bbb(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3fe548a77e71f04ca3645fc97c0b240246747d133c2b667ad2a1c991ab83c3ff(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2736037ef790be1335b49eb3f0f42744827e846b7069e97a3d0e4eba4698b3a2(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__32ec4206eac397f4b14ee4ef8fa02f6e992159ee3f1b854f4dd757f0e170e3d6(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fc3542198b4fd5dd5005c9b6759d923f8a51797d322f5c161abdcdb2b6e19f44(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionRequest]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fbf80a0d93aacdedebc834f151f800c7d74f68a5e72d95f62e03eeccade3f5b2(
    *,
    index: builtins.str,
    compute_query: typing.Optional[typing.Union[PowerpackWidgetQueryTableDefinitionRequestLogQueryComputeQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryTableDefinitionRequestLogQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
    multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryTableDefinitionRequestLogQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]]] = None,
    search_query: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7897d93f8f519fd60a3e2d8066b6f08162b32e1a579048d3bf35eaf31b1f8bb3(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b54122b718235fc15d9084aee96b144a58d666284006eff8a0006073b1b0ace2(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e875da36633c4be1e48a8af08a21bc00a7fa23add4afc053372c62b3ec304a1b(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0dbcd0c0c6caaa98a86fec8ebef305d37b2678c630b665a9ecc145e1a6147aba(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b0da63d705a9f54ce76264247d9e8ec937fbb1d3149b21f0bce690fae7c06240(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fcd8fdf2e11d5dc1506eb21de7f28c890d021eb47f3c20b23c1b02ab693b0673(
    value: typing.Optional[PowerpackWidgetQueryTableDefinitionRequestLogQueryComputeQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ea3776cd1d2cdba96896e050f0328f46e93a057a750a43d38691eb2c3d33aae8(
    *,
    facet: typing.Optional[builtins.str] = None,
    limit: typing.Optional[jsii.Number] = None,
    sort_query: typing.Optional[typing.Union[PowerpackWidgetQueryTableDefinitionRequestLogQueryGroupBySortQuery, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1f8ada28cca6ec54b394f4eab84ed657086c224cc87bddf1e5e636c2fe39f58a(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__56d4ecf3753318abf55eef03158bcb792d602711e959238e4362aaf52e9b8460(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fef917689c7e91e38bb2dc9cc30e72619ee09c8f498a47a5961e085868db4490(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__411f2afd727f6c5eb594fbb639e1cae2a0986c5d4095eaaf4e892c449ee7f3e6(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__363266372e885feb54151c00878ee27fff057fd375980b424fa593bfa521addc(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__380e983ef2a710cbfe7c88aa1970cc0cc1d812bde6bb264d1749a09bfec14c1d(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionRequestLogQueryGroupBy]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4cf8d084044c9e9718793ee037c4af7c5a506fb9efde2a5b672fa9c5c00add7c(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6abe64ba4adc306f31ba02d2607a63aad84e7d89c176e4c77499aa4657b54336(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3c9e0994f9c3e7e2a041353b5ca08ae832a162ce3fc5b6fcb73ebaf8be30067e(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__73d796361a581c1061ebcefbbaaa8fe6382d2c5969a6ef5d2d1bfb1b127a7d44(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryTableDefinitionRequestLogQueryGroupBy]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__45733c902c6dd9c946d624acad6e2ef83d9f325ddb07f15ce3c95e51aa2a1656(
    *,
    aggregation: builtins.str,
    order: builtins.str,
    facet: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bee115771a1b2ed16b1588e15264bb8e1a6f7c4c6310debb2e5a57ca2364f6b0(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3bb08b54d8c70b3810776feb01e56f4c7a4019aa1dc2b0053d828c419c67fd40(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6276070f9bd6ae8b142395702050f6327279acce7b5761cae00332e3043859bf(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5aff92ab2ead4eb35b4d37d44b63b1ee203d1d0ba0a6bdee4e692a4f2d6122eb(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__94b37e306ead7c2f7ae35ce234b701dff936524d6835a0220167d95243ab6442(
    value: typing.Optional[PowerpackWidgetQueryTableDefinitionRequestLogQueryGroupBySortQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1b2647f88650578c9f4ace8dea223fe3ef22f69a50dd387b0aa98fa728565eb3(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__78e7034356f3f9213588af6c2afa817cae2e24c1fa832ede493c3ca0e1882a50(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__79dc39aa80148a457fe21808c8d11d801c62ed3efebd3f4a0348e1e91aa0c708(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__852e2b001e25d818759812b16f7b300a9cd737fc95e4df0382a6a053b10086b3(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0cd764251ad7bc104e9e07680da391a719af26773955dc646d88812e3de94fc1(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f01eb1ba8aa697d90750df114286f8281ae2c1f45f131a18e96d150c92d110f9(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d6ddd693381ec587e3d39cf5ac712b4e73951537cfaaad8e5edaf02884bf78f4(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionRequestLogQueryMultiCompute]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__43b4dfb0728c2c5f83db638d2a2f6b311fcc9048a91adce0ce4fe5144ca6aaf4(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a8d206bb1895e49926f00cf30dbf9f9b4c09c5cfacb6eb9145a5950298cdee9e(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c963f4d3e4b3beb530744d9ccac59e9e878b2dca71df4fb66f29d60e60485dc8(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0639ff82942ce74e7ee54daad7773e580566d811f211219d42b76a3db2871e81(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3a60e0f86da9a68c54dfeeba1d77881ca6ba671a69eeb2d69bfed9be425a0f0f(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryTableDefinitionRequestLogQueryMultiCompute]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__54ce6e5d1f37d27af9bd5ed101a2d80c00b65917f637ffb3205f9ac993802455(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__896dbe03d7d2d84f6b8a29aadda818b902f7027b15025a6f987fa6443f775e9f(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryTableDefinitionRequestLogQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ed18e8dcf1f67f677315247ceb2f1e0f3be526f8a2b6874e4daddde44f3c869e(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryTableDefinitionRequestLogQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9473779c8e64850d0226443468707fa7f9987c6c074a2167c86e05450e7c7c98(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ca24a81ad2df9daa31f487d411d34e5699c8256695f192d4f4fdfcbddbbeaf4e(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__05b89ca7abf4b20537db51b8fc6fd5551a7be2bfa4576c0279d2a616f6707d60(
    value: typing.Optional[PowerpackWidgetQueryTableDefinitionRequestLogQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__58b684aaf1d754509fbba3cdec8fb103b47cd4dbb3703b38d3f35073d0a067ec(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d79faffce65de29dc82743fc9dd0808d853cb5b97409c48ae85d6627c0501b34(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryTableDefinitionRequestConditionalFormats, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2761e6701c91473ab513448e52ecf27f5e2e85a987c0cf5c4f9bb2dea39f7a9a(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryTableDefinitionRequestFormula, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__11cb3c89728a5338836fa4b230709c29386503a764469000bdd226e1b454dff0(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryTableDefinitionRequestQuery, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__08c0babebe6043e73dd2fe9ef29e89ff60dc9e588df4c3700c23f074ec27ee7d(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryTableDefinitionRequestTextFormats, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f56380a0304f3854f3a52687d3aefc78f35b1efb65dd4dabde35a21a70630161(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0a01ba3e380300160e6677ec9055f91d0fb54d7e99f84992356dea97d8483e21(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__175c54cca84e2b5ffb31dcad72d944f766468ae8154d4f66e6808676e68edcf2(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__759d29c41d6c9b21a34ca3583d21563178873457e3eae1387003b966ade9bb4d(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1141994aee0ef697d8c4c199aae201c4d88206c966aec13de74eff82bb6b4e77(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__adc91ba07fa4fb88f3d43aa9cb0d126679c63d803a88a2d2eb3e9cafa637b5d4(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8d4b758193acd28763491169221ef38b225666dfa501d55bedd794a5f47d79d8(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryTableDefinitionRequest]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8ca6c475810ad3e89bea42427788a237f73775535babe4df49d435e77b3a3b98(
    *,
    metric: builtins.str,
    filter_by: typing.Optional[typing.Sequence[builtins.str]] = None,
    limit: typing.Optional[jsii.Number] = None,
    search_by: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__29aac02f7b028bac0715b30eddb5f93e063e71628e013d40638b10a831ec321a(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__86465005af0e09908940b067be330eb9d12b53d63b154cc54303069e86ebbebd(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__15c5ef7c83aeacedf3970f86f4b275fb8500e37db06d02c8487afd7558dfa64c(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ef11c1591a32c778e722e76252fa7200bf13e40b81d38d57f738765a0c0aef81(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d3ddc19d2fd8df6e794f56e6fad371b694b99ad04f879a41d54a1e14b83451bb(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a36c7675eea94b6570907ff265ce02ffef5808f617f5917434e43135e4adf64d(
    value: typing.Optional[PowerpackWidgetQueryTableDefinitionRequestProcessQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__73174199126ef72cb5aa991cb144a39fc47bfba7449a9db5de2943baed19dc2e(
    *,
    apm_dependency_stats_query: typing.Optional[typing.Union[PowerpackWidgetQueryTableDefinitionRequestQueryApmDependencyStatsQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    apm_resource_stats_query: typing.Optional[typing.Union[PowerpackWidgetQueryTableDefinitionRequestQueryApmResourceStatsQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    cloud_cost_query: typing.Optional[typing.Union[PowerpackWidgetQueryTableDefinitionRequestQueryCloudCostQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    event_query: typing.Optional[typing.Union[PowerpackWidgetQueryTableDefinitionRequestQueryEventQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    metric_query: typing.Optional[typing.Union[PowerpackWidgetQueryTableDefinitionRequestQueryMetricQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    process_query: typing.Optional[typing.Union[PowerpackWidgetQueryTableDefinitionRequestQueryProcessQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    slo_query: typing.Optional[typing.Union[PowerpackWidgetQueryTableDefinitionRequestQuerySloQuery, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a1b9d2358d4936966ef9bd0ee3a01cee706541c0e94896f876c3a7e309353f74(
    *,
    data_source: builtins.str,
    env: builtins.str,
    name: builtins.str,
    operation_name: builtins.str,
    resource_name: builtins.str,
    service: builtins.str,
    stat: builtins.str,
    cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
    is_upstream: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
    primary_tag_name: typing.Optional[builtins.str] = None,
    primary_tag_value: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d26d812ca6b51350753d9a3ad585b4120beb7e49a6bf617f86bf78be86282d0b(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9a3057f83a027b127aca0ac93d20544a5a326676e07cefff1f4bf14bdfdee59f(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2dbdc39afef3a432c21f4edc9dbcfe4418d61ce529d18030c45160dde60e3d27(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e2da9038e85f9888e7ce2b2a1ce8337f7ee86bfcba4463f8bbbf52a122ab8a07(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0a923904645f56f8c21b98a02998e403a0f42bebf27e860192991907a6386904(
    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bfd7e6698dc39e4994161b98f50ea6d4a3599e4713dc5fbaa08a47932a75d2f3(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cb215f961820a72904a4b2772417b0231451d16584fe107db132c2d02237e669(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__27d0faffdd59b12774b41851bb623036528310b552b28bde695cad08c61382cf(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6b815befa03c867b202fcdb30c84c3318d30fac4806d9910a42ee3171f932128(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__566227170711c18137b1fb223985094c5151d79f2e2ec4e4db1ef1c94114240d(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cf47d3e2de2d7fb9113cb9837d828088e081b685a82ffd951e438f1fedaff80a(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__15cfcabcf809f4cda52d73f2e208350f72c2abb22457ba082452a944d9430833(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d91e018b2ecb86cb08a83e6fb8151e106fa5c5d98469eaaa973560b19705a2d4(
    value: typing.Optional[PowerpackWidgetQueryTableDefinitionRequestQueryApmDependencyStatsQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__945a837745f963c87641629c5fbe27fd65d0536c91e430921345c57006b102a5(
    *,
    data_source: builtins.str,
    env: builtins.str,
    name: builtins.str,
    service: builtins.str,
    stat: builtins.str,
    cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
    group_by: typing.Optional[typing.Sequence[builtins.str]] = None,
    operation_name: typing.Optional[builtins.str] = None,
    primary_tag_name: typing.Optional[builtins.str] = None,
    primary_tag_value: typing.Optional[builtins.str] = None,
    resource_name: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4e5a56e06027b55d7ef112986e766ab612de116b4720d54a43171aca60ea1390(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f53f31b4c5b5d175a9ae61c6794f34b67de25f9b5cd8d7203d053beb3cb5e4a3(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c960c98b0b4d18463c7a9a1c5ff4893c2def05dfca3b70a7754172849a9560c7(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6f85e8a757217c2c04e0630bd87597c4f51ceff44e55470aeec3bef85128ec0e(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1d585adc48cefd0fa5a54178d1ed83dee9322c4dcb4000ac120b1421a6e74d00(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5c5c1e5470ffa939a448ff0b8de1f13eb3cd01a423e736ebeed50aa6c7b98525(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bf57df06714d056b8edaf4283e41bb527d323b118d231f3d269d37ee63882191(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f477c1b981b680dc8bfb715d353a39be2a17c8fa9296422c165b417c790f3097(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e084171bb8be598c79e85e2e7a16e1baedeaef5d1fc5fce4dbeb9eec25111716(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9857ba664f8feaaeb71c35d0024a914be68df34c96abaf6ed03593152352ebb5(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6a3bf281af3c3e32a523e47d1836ba74eb208ca6d0dc8129264984e2d7b5fc02(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3f02aa82a2029f29d8216289c3dbcba1cf58a0f7f094109844fc666010907499(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3786bcc7f219eb260e70a1ca52fa32172e212accaecbd4f9cbc60a8ed130cdc8(
    value: typing.Optional[PowerpackWidgetQueryTableDefinitionRequestQueryApmResourceStatsQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3a2c2641d15205cb77582fc3bbea9e7e06c0325313fb78062cbe907117f9cdc5(
    *,
    data_source: builtins.str,
    name: builtins.str,
    query: builtins.str,
    aggregator: typing.Optional[builtins.str] = None,
    cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__208869ceb75d9588d7bc5cad53e9e6105f1a1c8ebeaf57d59d10c6047d350497(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__58aa65861e88f1590077f1fcee71b75ae0620b6cf10e797773f048c734a80e05(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4d0cf760de690d29b96c6ed7e3724ceaac443230ced22ae63019726da256101d(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c77c6c6e73a60884c88c478e20fe949c149ebb96ee40e896cfb4cbe1b001fc51(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8eb4fba5ed72da1dd82084b944ded149c5baa6bbf1b979d8cd41379e3489a62d(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__282ab60622cb005a8cbc9b240ede4a9e38c0003edc5353894baee3b37f4df854(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__341076c33f6f5844b8b2a4ed367fb5a3141305dc52140ebaf2f3bb319136e437(
    value: typing.Optional[PowerpackWidgetQueryTableDefinitionRequestQueryCloudCostQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d134459f519bac9d2f3e30c8f0b3ec0b24d84dd05897e79374eb70b1202e530a(
    *,
    compute: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryTableDefinitionRequestQueryEventQueryCompute, typing.Dict[builtins.str, typing.Any]]]],
    data_source: builtins.str,
    name: builtins.str,
    cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
    group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryTableDefinitionRequestQueryEventQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
    indexes: typing.Optional[typing.Sequence[builtins.str]] = None,
    search: typing.Optional[typing.Union[PowerpackWidgetQueryTableDefinitionRequestQueryEventQuerySearch, typing.Dict[builtins.str, typing.Any]]] = None,
    storage: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6f81b312850f33f1993485fc15dbe456534300d30356b235e10206e1145c9a3b(
    *,
    aggregation: builtins.str,
    interval: typing.Optional[jsii.Number] = None,
    metric: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f45ff148d3c568b269621f45f3ef9d664a64ac7db32a2c89b01d466814f657a4(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b78402ad7e12a0194504b73817d378ed7df6cb6e416d58710ff3d51cad7d2439(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d3a741fcdfe3dfd111ed5eedb9593baee7e9bb6bec39291f2012e93f33d7ce9e(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__04a94fdcf3f2e52cd4ab42ac43c5734487efd0b6b25b275345ae6aa3a40f0c36(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7aa9318dc675018e3d2facc99b59919d5eaf64ceab976147eda7819fd1f25c63(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__80d31b41a97728c7fc70d725fc3436ae2c41d4ec5627585888993694b1484340(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionRequestQueryEventQueryCompute]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__59ba06231b19d52e2857faa67038b72287129ce01097912aebc0fdfece67bcc7(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b23b24fc0a6dd5979b174755df00f5c4b6c0218bf8f320a22075e6df15fc1527(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fd91ee515a1bebe5f227d1f19790ebaa39f4879e2d382ac163f5c70b58e09f62(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9090de4a0b2a98c909508fb73b0c4ce1dead8f0ef64a44620de8bef39ca6b3e1(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cedbcd03890e1808920a42116318f295282412aa283aa2ee175d25503987b8ef(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryTableDefinitionRequestQueryEventQueryCompute]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d063465d994784fd3d191a7784f649d1ca334b85482eba23111421b69a7d4850(
    *,
    facet: builtins.str,
    limit: typing.Optional[jsii.Number] = None,
    sort: typing.Optional[typing.Union[PowerpackWidgetQueryTableDefinitionRequestQueryEventQueryGroupBySort, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ccb3dd9bda4989bca68f958d9d20a68a55f561224cfd577cef85b29b1f4fbaf8(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6b7f0a06ef513161ff2d5c154c552a592611ffc0357fb7b249e72c5f6306bf48(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b6211c2068b698e37000f61c5b024f0daeb022844e430f88640db6d8f9d7737f(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0a5d2a411987ed667314cb260254d7e899d3f13c7581b6846911daacab21f7a2(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__09820e8dbf2d6a91108736e0edb0619bec114d6f9c3a0ad2e3d0948cbd3632de(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b65bf5c39e2251d0fd06ff707faa516ac784d61e4b9c04faef0214318c483621(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionRequestQueryEventQueryGroupBy]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__74bb395272986725e34cc09ce02634545625db44d6d50742beadac5965009446(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4552d4c8d7f7f0b9f513629ff85a41606a2b2a42b7ec95f8e0647cb722e43c76(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__26be0d926e67f6ea574791d6db4068d891abe6c294d29fbade8fa34032de7e93(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__26c2f0e23deb7940f0ef4e6db4c33489899e1d672db612c530b1c6ebb4af1b01(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryTableDefinitionRequestQueryEventQueryGroupBy]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b704ffba0947582b8fc74a84ff8cff88d060bbbc10bc2883e7375db56ab9c3c5(
    *,
    aggregation: builtins.str,
    metric: typing.Optional[builtins.str] = None,
    order: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__94fa7155d2931dbcb5d94061c03c926a33cf290f40c9757e38d5c8cc1079581e(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f6fdab0e7df42740540ee6c2673f638131435876cc84683775215c016d372029(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8528e4d8e29a1be264019be7b31c623871f8b88b0cf199fed0f921350a0864a8(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e024d953b7868e8ba357cda59ed45cce9e73344a6242e60300600c3c8e4090e8(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ff4ae8e6c0ce0557f67ffc02ce0fd20fa396fad0f6646972e7b624529218a2e0(
    value: typing.Optional[PowerpackWidgetQueryTableDefinitionRequestQueryEventQueryGroupBySort],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bcf3cd2fd9bf4a3b8a2fcbc0c9819a90362a2d38ca6191820fd60a940e05318e(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__87ac0a438b699332e469fa0c917850f7786487191c393c766a64d2db3ccf77d9(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryTableDefinitionRequestQueryEventQueryCompute, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ae49e1af3fcb81fddece100a63a8d8f82c35020b39f2129d3accfb8b0e97e547(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryTableDefinitionRequestQueryEventQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__693168fe130e083febea40939a16d0946f79ea7c4e9fa8dbebd2cf7f7580b24d(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4f26424f205e9351130d24acf072abdbf19d4f7a8b883045400af04146033d97(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f6efde42245fa8bf5d5ac1e77a7bd7ee03da9292de8e24430c3a55fbaaf181e1(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__024216014dfaee7f541fc1d1c3dc6ab4e289641682a2a20b32723729774f2581(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9a1c91de48668a3ebb162599c80152b1a8b7efbe7bafecd10266bd093ceb6a20(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__91534f52ff854e9f90296fe5d04c90d66a4250615a9ed6836e8797b8964c2534(
    value: typing.Optional[PowerpackWidgetQueryTableDefinitionRequestQueryEventQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__29b42643b0d827ea73f0e981644fed7bdbaefdbb74f9cfdfcbea7f41818872f8(
    *,
    query: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__68f1ba9bd3303ccce8726e0459cd1063ede3c2b8be5109cfbc7a0fc8115f418c(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4dfa01a3d013de788f546a0f13a655ea3139dbb4fd68c3164a736bbf247b8ac7(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5445b50bf847d138bda5dd404dd3a038b9cc84118398ce2ea429c5d94256442f(
    value: typing.Optional[PowerpackWidgetQueryTableDefinitionRequestQueryEventQuerySearch],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__35eb9e51d9445e83aeb5b61b5d77d1af46b0618bca507f7088467094fc70fbaf(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d0f7f8daa73fbccc49c5afdf21d766b4914aa77541d688facc6bdfe21223d057(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__43a20ee665c2387afa0e7df6cb3454798a546fe2f8ef06279ad95956de5d4e58(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6c79d04b8e8e517877bc11ddc2906e7f62ad35cca6d3b11379f1dc3599881e98(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7e803853b9dd10ec404d81fc10dd56ddfb0198cafecf1be4a1f2fbee600f8a32(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f9543f81f5d642dafb2bde9ea2969fa00ea787215764d904426bc66a55ed2ea5(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionRequestQuery]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fad421ecdddeaf0147063f87cb17cdae8c0c2c9502227602fecf0831c00b1969(
    *,
    name: builtins.str,
    query: builtins.str,
    aggregator: typing.Optional[builtins.str] = None,
    cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
    data_source: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e7dd5fcd2132d1bdbebeecade92616fcea9b2e77f4d61850e47802246dbc0b0a(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8351cd2e077bcd6879402fc2753d2f193c603a17a0e85a435ca361c7a107d3b2(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a989e2f027c04bcdc7e17143791c9628d4b01e2737587fa5f982b53d4d01b8df(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__97cc6b39acbad8afb7cef29ad4da360a0800117da0021e9cf3d2be54c1fb8bf3(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__186c4b111724a3b7bf108ed4db228463369982befe0900a3e591e44adce0a4dc(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__abb395f3929424411e444ed18f05293a35ece34c4dfde3a445a8679425b5000e(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__50cff926c4f756b816e471a07647b13dcfa13fdb65711ed76463ee89a245e8b2(
    value: typing.Optional[PowerpackWidgetQueryTableDefinitionRequestQueryMetricQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9b39b27bd5138d4bbb9307cd1a19aebd8444d1d501f3621a5882627860aa9ab9(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2196510c2c991eae805b9eec20ffddf6666c854123ce429a5ed397cd53b07d03(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryTableDefinitionRequestQuery]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__326a29aa8dbd207402b23010fc19b8f0f6b495086728c97d69b5ba6f443389c9(
    *,
    data_source: builtins.str,
    metric: builtins.str,
    name: builtins.str,
    aggregator: typing.Optional[builtins.str] = None,
    cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
    is_normalized_cpu: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
    limit: typing.Optional[jsii.Number] = None,
    sort: typing.Optional[builtins.str] = None,
    tag_filters: typing.Optional[typing.Sequence[builtins.str]] = None,
    text_filter: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7208908033ae5129ae52e20cf44c143015c44c8c01785e4b94882a89b5748e3a(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bfe1fd9afd88b5e8361d6d7f707f3b9925770d858a3d3853d44da890d98163d1(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4826325bd79065163b2b77cf82f16b4e0a066691b74e5efce514952845d236d1(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__89f025c51d65d37fe47b33ab860a20251586f8b7475caf349b15ffb390f607af(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e81141587ee9841a571469c580aa997db25c869b283d0ff75adb9d21c2dcec96(
    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c8a7e22178a38911c7661e9364e27594c75efeeda25ee4c8754ee45658c375f9(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e4e30456fe545d2ca3ed3810b922fe99b733bf6a2fff19d334e1bdecff973fd2(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__adde77a2a2edd145f4d370d423c431eafaef2e83310ad0b7d1a82e1629d73d99(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c053df742da9a7f5ed266738311d11214e7590e9912e588d4cfb147e30c7b488(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0bafdbe0e5c6dc4c1ec6c7a0e9e90e4fb365a75c79ea22bca119fefc2ca4fdd0(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fa8cdc28981e33d074903ef42cb9125ebb61fb59ff119709d6ccd9d643ca98ca(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__14ff4c5d348d1b95013d1dc217b7734158bfa923b5439e2f896e70585524bae1(
    value: typing.Optional[PowerpackWidgetQueryTableDefinitionRequestQueryProcessQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__25f1981fd78db2beb656a6036b38a25c0d5a97604437a3f61bf70fa533e3e84a(
    *,
    data_source: builtins.str,
    measure: builtins.str,
    slo_id: builtins.str,
    additional_query_filters: typing.Optional[builtins.str] = None,
    cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
    group_mode: typing.Optional[builtins.str] = None,
    name: typing.Optional[builtins.str] = None,
    slo_query_type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7fdf1632ca0d0451641b181367c6bd4376c8bce4fe1b8efb4819c48bb3f92bde(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ba9a04f472a9ceb39ecfcd1e1a5979ac1a8e5fa9c59fd0ec75e244a061f86bc2(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f97c38f3ba010fd7bc83633daf024c322da41c8944bbc9e0e4e2401a67426524(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e3babebabf66a0d6321121d5c33e98aac3142a70cecb442b7d8fe2ff3e1b1bd2(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__981f6ff0bfbac290706889817a0b791e1d55d22cc03cbf6913dccfd5802e60f4(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a105ce01f2126aeb484810fc86a625c3b670faeaea71e08407368e01bab2f895(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__99a55068cb2d5dba115a45b584fe32e179f1d10c21456ef6793938a376cdcb05(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dca72e29cf6a901b5b96d3525ed018ac4b7e97032b6b608c4ac3ad0f0501072e(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0a1416491dd7147e4a1e082f247fd1b2fa326da08fa3e4a60c2198a4bc56d55a(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a6ab87ad862b41190ffe7d2938c3ad85d348a293081fb5db406f1e61750b6c0e(
    value: typing.Optional[PowerpackWidgetQueryTableDefinitionRequestQuerySloQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ee68d4afe66831466f09108e5a2705edd9f59010202740b571fe14561bcef956(
    *,
    index: builtins.str,
    compute_query: typing.Optional[typing.Union[PowerpackWidgetQueryTableDefinitionRequestRumQueryComputeQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryTableDefinitionRequestRumQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
    multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryTableDefinitionRequestRumQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]]] = None,
    search_query: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__462ddfc00a86ae0ab4d4f44ca801825e4ebeac1fd1108d5cab32593a20732b85(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6b9ccfaae436d9662b1f2a5b1953ff04eb1ab8e5af15f84f16a874ccc65b5733(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8350aa26358e79aabbaccff8ef0135ca26359579ec33f87a5ba6e19feac8f85e(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__69597dc872740ba9103caa43af33458d48132fc516da8a5f8730213e6200c66a(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__30df64ca280b564b924d83765693c1b195635d144c51d92f6726435dd64a1575(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__36dc59900b99a182ca622a8e1380e3fdb0075910b3c27e8321e7e061f8003290(
    value: typing.Optional[PowerpackWidgetQueryTableDefinitionRequestRumQueryComputeQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2bfdf3a18953c2cd114bf618c835eb05f5be80c9e220e5ba6c4df07e9ba00a30(
    *,
    facet: typing.Optional[builtins.str] = None,
    limit: typing.Optional[jsii.Number] = None,
    sort_query: typing.Optional[typing.Union[PowerpackWidgetQueryTableDefinitionRequestRumQueryGroupBySortQuery, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4ef594a518ce9bfd931486e0bf4e21a0012b329a329bba5d32666ac6d480cca3(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4b3d8e2db264d0966c9623b8ee43c2b4cf575e7a804fa3c5083170591fb3547c(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__72c9459b00f1ed4358d2337d8279260cc80166a85d1684bf55e34b9344d37704(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a51bd31d4282a978b6a7b600bda1d4f59df8aa16c804f39cefd6fa6277050eba(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e54d96cc79eb1de28209654cdda4f0a7ac2ef18387a1257d1d5e8617920c5bd8(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a3665967afba47cc472bcff8088a50732bcf4a412ce715ca2b0808c439890d6f(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionRequestRumQueryGroupBy]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dae8136fd4d809d50994510028fa9aada6275b56c44d750afef1a7cd01457da5(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__01b8ff5ff52c48ded9dc1a8a3e56ba9820a41a7282061426534089783b9f3fe9(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__956cdf048dabd1002a53079dd5f23becc25fa90b438cc89b3b92fc560b18fed7(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4ce36199569b29aa1821afb5a6c9e699310ad64f891215cc9421be70e94d4de0(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryTableDefinitionRequestRumQueryGroupBy]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__00a2fa4ab36cf23a89e72605c7380f322bd385adf6766d1df241c54d333789bf(
    *,
    aggregation: builtins.str,
    order: builtins.str,
    facet: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__30ac34c3404fd96fe700cfa877e519b1c602f0457667b7fa891605e58b09519e(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ed153a857fbcc7b59242be4fbc52297c7a216cf31eebb2f07438331681937578(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6ea11171394ba495d3a1835b3c92bd987f4abeebbb67b5ab104f490fe57a3b4a(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e77717026bc60f60f82f01ba55778df4e280bb0713fd3e7b9ed620dc6aec4e85(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1a7123420e914f8cd4cdf2950823e7745c815b0198a094f49d7c2da809a2d1c0(
    value: typing.Optional[PowerpackWidgetQueryTableDefinitionRequestRumQueryGroupBySortQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__603f52a5cacd0c9999a0f580067429f8175a613b0cdaa4b8c97fa93679e4220e(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1496f3d733d28fe87f5581871afd7bb376e63c9bf22b4cf2546bfb94fbe68a60(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__de182dca575f5346648597a0cd42d845455701f4efbfe3a8df40601ec1d57241(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3cbfacbf9a67846825febfff1bd59fd0b74518474f9d8e064b607bf737f8813a(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__82dc8a15d023a9df5ec132970c871a8f5f3ac818a852753b0d20d2e9ee1312ef(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__02b1193ba01a509abbc4717028345170ffb7ca4456b0059325830910f55805cb(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3ca7feb1490c1f366b6b28d28463b3587af077b1f51174350d387706e74b7190(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionRequestRumQueryMultiCompute]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__840ed1f0c4fed7593407cc89904ea6d150af08920ed648436e65a71d2d9f1577(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__12d4ca9a26ac4b93f9299164a3a87d7bd0501b657630cdd49b214583b39be47d(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dc8de752823454e9de25f7f404ffde916b4c2adccdacaf8950ee4f07d85dc7cf(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__58ea0911c19cf29868389de46a061a0cad7302aedfc0809f2c0a5e0ce7cdcb2e(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8e9123e2bc32019f243b0ad0dee9916a5e1f7f5601bed01bd7808613ea45f1f5(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryTableDefinitionRequestRumQueryMultiCompute]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8d3212538bd804e7c521dce343c628fe5e25bfd03313d1d1dd611f28f2b3e323(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f4b9ede13ba36dca4aee61dea4b4783cba9c81281ba74c89a8f85149b342f194(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryTableDefinitionRequestRumQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__18baa7f7d27fcc94ff6d446c1075f8f5e17b954a8e779f33fd7602469be7a12c(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryTableDefinitionRequestRumQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c9499ea2b6592d6363527d6c5c13ac2d35a85f5ae8fda19368026b717fa2f49d(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6dc570fef305db1cc2926e3579dad3ea428f2e316a775cbb95482d53dbd44954(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__761632ef89475ffd0b140b7abfba7b53d146f56c62dcb1154e77335d5194a1eb(
    value: typing.Optional[PowerpackWidgetQueryTableDefinitionRequestRumQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__aeed11d1580506f81ffe240e8d1fecd109e9a4b118808c3621e88dfb4f05144a(
    *,
    index: builtins.str,
    compute_query: typing.Optional[typing.Union[PowerpackWidgetQueryTableDefinitionRequestSecurityQueryComputeQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryTableDefinitionRequestSecurityQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
    multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryTableDefinitionRequestSecurityQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]]] = None,
    search_query: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e04de7de2212164663ff4eccb844ce04966503c92efa7fb25cee91543a6a40b5(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b2bd61ef5e0143139a81613dbc677fa6e4522b14dd6f179557e399f5bc5ef63f(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4721597dbe82c0bcb75ccc59b47e8570e51273fbb658ffad47be0614d2a56c63(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__447de83ada2350462548da30a474b32bf27285f227045c0cfc720e83460fa9a4(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e7b1108c35a6a43718fe35baadfbc3a9485eb564231493f9e82e267660bc2383(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fad64f413f928e34652b9ece946378ac9cda1bb0d58d67abeb86a4b4cbe0ea5e(
    value: typing.Optional[PowerpackWidgetQueryTableDefinitionRequestSecurityQueryComputeQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__054b4d5226ed16d1781b4c5244e11bb96fc292d71b46a75b45e35d279328a6a1(
    *,
    facet: typing.Optional[builtins.str] = None,
    limit: typing.Optional[jsii.Number] = None,
    sort_query: typing.Optional[typing.Union[PowerpackWidgetQueryTableDefinitionRequestSecurityQueryGroupBySortQuery, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b37a3aa1b9a8b357910aff435603cb7d2907fe74add327e825fd7550d62e75fd(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__533b12f52b0ce2626610f73e992c522c00c6ca5ef3ab2a392644c9e7dabe2db8(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5f2a70380463ac14d612a845b9404ad495e55232c67fca3cde0ccfc597c21c19(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__23f14f7249c8d019187edb5905ca306b33f2abc77d7918b3cd5598b254e9c0dc(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__85cc972590dd38b71c20e195f6f03646a43b2b5c4e8989727d18b402cb9fd4bc(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e7fb8a24e821d19921f2a3f7d04da86f5810c9b7f70bf08510768652544a32a6(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionRequestSecurityQueryGroupBy]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__45c3b6d4882b7ae877cfcc283b9d192e5c0a9b465036aff1d2e9ece2946498fa(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2abbd70e877be8c503c5410e441889c714f62ae89373303a7afe118b2ccb3a5d(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1d93e18325f343b54853f9bbee968e3064d388d67e0d5cdaafee2d33f0287468(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9fc139bf74e1492f465edfdcfe8e4b9f3b2dc0baaff6e480e07cc36d8627c9ec(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryTableDefinitionRequestSecurityQueryGroupBy]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8a4bd704d37529ad1ab07fa07b2eeb20f60b33dd2dfce755336a9fa6de5d199a(
    *,
    aggregation: builtins.str,
    order: builtins.str,
    facet: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d601e6e5c9f8e7a4739eb010164e0e8622334fdd0d7803671dd9ddac1af7fdf5(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cf8d4a453885d3bc4fea90c06c2425e6fd2e5e18cd87750c1d9a1eb2d2865ba2(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5c40ac6a5fa77af19c870f8bbcf232527a866da7b772bd5d9e6b51dc91e4ee96(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__22c266d74ef1134d1d1bfd1448cb01f13ce8c4666079be2ee5d46dc2b76c0004(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a61b35e7076243f1bc8b1a4a6f9349747d31eb61072dad07e2d69cc1af38dea3(
    value: typing.Optional[PowerpackWidgetQueryTableDefinitionRequestSecurityQueryGroupBySortQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a823ae4eb42de7a134fbbbeef5805e56c9e9786bc097b221d666e5f3edbc56de(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b2fcaa2c9310508af1b57f1e769791462b79c636ab6dd7130ffee9ec0dadd989(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b7254d57f0eb207f5b6fc3df11ccf88d26aa59b39c0a095caea19b4b6cfd509f(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d56ed4278ec72127b43246457288fcdf3d8289ba7ac1d8666039edb8d45606ce(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9c2c1adacd3fa3c467738f8dca9dc2ff6330cbe82ff6c14e76170580c135a011(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c02281fa551f825cca86238ac75a8e6851646e266c12c16c5674997a3c38e4fc(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1991cdbb3b4919b0fe7c1e6ecb1828c2ac752357e44d3a805fe2a78b70d4fe0e(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionRequestSecurityQueryMultiCompute]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a47370af69fcb118640186d0d4f10beb7422d66389656d22a569ca96fdabec6a(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f614a022c7a8aad0db70a5c096e7a434b4c82426880e0fe45a20fcb64be168d6(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d2a3edea5ead5eb089a5fcd4d3f35a4e4cbd3825f8ed017c1f1c83752611f4e2(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3d308501da217617cb1b758319f889ac89c20339274f9a3d6ab0330f66426e66(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fb4d68d10719a8ce151697c09369181ccb346cd70c647fb38286e549ddfbbe94(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryTableDefinitionRequestSecurityQueryMultiCompute]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f26d0e7bedffa940045970b09e76335075306f423bfa2e40398f701c82049aa2(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a430c4796d972d2115c147ab1a6e04850dbb0b0dec1a2fa70e451078a70f1a1f(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryTableDefinitionRequestSecurityQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c8b592b2d3c134afe9a96adab090f688f3d7a39dd19dd2e35443fbbbb4f7ab97(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryTableDefinitionRequestSecurityQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__db5c9478751548d5c9a2a63313b7e150ba49c45f467fbc8876af3db47d595f85(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__20228f0f458c3c44398173248323fd6be17f1a99fa6db1ed8e9b49e6e2b5c054(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5b49dd1305c5293e645a4ddd333f5b076953c1c44e06e1cee4e54cfabdd7fc13(
    value: typing.Optional[PowerpackWidgetQueryTableDefinitionRequestSecurityQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3f0b4a61c8f4c3e6f114ec238c211926e98489585feb678ec7d253eb58886fef(
    *,
    text_format: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryTableDefinitionRequestTextFormatsTextFormat, typing.Dict[builtins.str, typing.Any]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__149969e8c11674f79ea78b89979ce773fede623912df3d5b41151b38fc4d7c9e(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5e555e47af618157298c50f9c160353b2ac366e0fdf6906df71aa4c09f317c05(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cc596856de65609be933e95146a109b3c3f54f06ce6be56d4cf3f6c04afe882d(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__83dca426985f2d2d5c579a965cedebb3c316aedabcb70dd2c9f8f0f941c62e06(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8170d9ea8c0be42282f5f34719b8a6053b08d3c128630cddf9ed396dfcb03d8c(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a7b7a0f3bd44010c9df35466f765b205935b8e3fa0153b35da0d7cdd41475bfb(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionRequestTextFormats]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8ee6ec5b453672112d51dd60a46244d5a0139198dea56f7901d1ff28b0364607(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dba45885c31d4e81e4fd211cbe4cae4da885090b4d7cdbaad5c2b0a1e92805e9(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryTableDefinitionRequestTextFormatsTextFormat, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8e412b07ac12c8d800d3bea22f18480a3991131435cd65b7ba2459b229443d6e(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryTableDefinitionRequestTextFormats]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1b84555894bd04faa0e927cd7b5e19889449974663f26a6f223730352faaae4c(
    *,
    match: typing.Union[PowerpackWidgetQueryTableDefinitionRequestTextFormatsTextFormatMatch, typing.Dict[builtins.str, typing.Any]],
    custom_bg_color: typing.Optional[builtins.str] = None,
    custom_fg_color: typing.Optional[builtins.str] = None,
    palette: typing.Optional[builtins.str] = None,
    replace: typing.Optional[typing.Union[PowerpackWidgetQueryTableDefinitionRequestTextFormatsTextFormatReplace, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dbf2e381dfc69b3100d0663a4eb69dac0719ff987d25535fc1b6b40486f8fda2(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__845dae9010a031711f633b91d17ed4d3b9e909faeba6b4192905c5783074c20f(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__81447ef309394ed9570c0599262b48395c2847c7b5ffd6832c2422db76f0d77f(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2f6d06cdbb1a9a992bc06c79b52a7f0590166797fb78c8d15d80ec402cb76287(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dd437af81146002fef98c146c95e325799e755e85d4ff7b06fae7d9099712508(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fabf6fe088a5940615b81ac10823d37d16b674ef9407aa9b6667b8b568c284cc(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryTableDefinitionRequestTextFormatsTextFormat]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0579b04fcdcebf1a6d97f6a99c707619a30690034ee42f91aa17f520b9a95de4(
    *,
    type: builtins.str,
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__97d9761c32cedcd8888317b9efbd583e44c50a210faef9cf03290155282c9a8f(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__80337ca77f33cb9026644e7f41555a998cd6eab9beda87b972b0f9e83fe4ab6d(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1a3dc99bb1f62a2f0cf44c0e7cce24b084dbbf48b71239825e961050b3afbbe9(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6bfa25ee8faca13d8fb3a994ac74ba00f4b32dbb85952475e959ad78aff8bd09(
    value: typing.Optional[PowerpackWidgetQueryTableDefinitionRequestTextFormatsTextFormatMatch],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2f9de0c4d8b7340ad6c100f2733017d69d08927a2bdb7110b3d32d04d57b8b22(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bf5c06c10e767b72212ee4ac0ae41f65a93df39ceefc45d5f1227fd3f60789b8(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__41000a02431b4f43b887d5a2ed2ac696b983ff2053418d26687c827303c4b52f(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4a1af9353cdc77fed5ca67b321f855f9096d8f6a8afe7688067c5baa8350df11(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c68490ca3013df5d05f4f5d5d733fd97258c1cc7889a8420ef2fe2859c31c73d(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryTableDefinitionRequestTextFormatsTextFormat]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__823eb0cb66a3c77d6bd343eb90ad883e5198995c6a0a8eb616ed98be0b37b4cb(
    *,
    type: builtins.str,
    with_: builtins.str,
    substring: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__67eec1668c92f8c9571690bdf30b1235318a55b5fc8c4a3dc19f014f57401ed9(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8b5ff9e066a0902c9fdafab085f8dec02962967d7391aa12b97418de2fa6b20d(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f6b96049aa3a8fd89c4e842b877746fed3e0634ea52dcf9092a4ee9edcf1f4b0(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__83c10734da9845b79c5c1447480056e40d9f0904b21fd8a29fc655b2e0a2837a(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a675c15c0a0ea56a3ecb04970d665d9f57441eca5f8381944bbfabc56cff2378(
    value: typing.Optional[PowerpackWidgetQueryTableDefinitionRequestTextFormatsTextFormatReplace],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a99ccf2ca9b683ebe61c49cea7b1843a232569d685e47f4d4ff9f70aa6fae0a0(
    *,
    autoscale: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
    custom_link: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryValueDefinitionCustomLink, typing.Dict[builtins.str, typing.Any]]]]] = None,
    custom_unit: typing.Optional[builtins.str] = None,
    live_span: typing.Optional[builtins.str] = None,
    precision: typing.Optional[jsii.Number] = None,
    request: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryValueDefinitionRequest, typing.Dict[builtins.str, typing.Any]]]]] = None,
    text_align: typing.Optional[builtins.str] = None,
    timeseries_background: typing.Optional[typing.Union[PowerpackWidgetQueryValueDefinitionTimeseriesBackground, typing.Dict[builtins.str, typing.Any]]] = None,
    title: typing.Optional[builtins.str] = None,
    title_align: typing.Optional[builtins.str] = None,
    title_size: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9ac79fcd389b453793f3e92c79572375a7538d1db0bce63734bb6d47bfc4de06(
    *,
    is_hidden: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
    label: typing.Optional[builtins.str] = None,
    link: typing.Optional[builtins.str] = None,
    override_label: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__504a33e7f1b670f3566cde0539b535ceefa12af61956fbe508b41b78671808de(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__847345a43a4fe8b48957e61b7d613c6387ea4bae1078ef11448cfb2fd01d6942(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__14a55cffeec17418a12dffb42c9da7d20cc7405012ce147a4ae9da8854969907(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f74910e062ab30e3cec60292d58d9cdc40f8577f95fac16014f6ed634f4534fc(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__50a6fee26543bc306b7b256e34d3d42f6330e134c4b1f35064b7f7a3257cca0f(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__352a54ce72cfea76a2b84b5a486744757d38cae6fcc856d08bfa2f2c477e6ee0(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionCustomLink]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7df26ee7fb24f6918194dc2e613d831527db07b02b10407a6246cc099105d12e(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ace57bab8a3cf3955fed49a6aff667f5f9d9a636edeb5d10d2ed12af236e277b(
    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9619b493ee7a2ab6d259d9e288f6b6575c042522bb107d24c03d490c023692ea(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6afe4673c7d56c1d29bfa42c9e7e67d023a732da0d050d2766fd062878bdf4e5(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0362a2dda45c34c733b61c560a037f0096b7dbc157a4a1a6eed4a0000fe933ef(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e3abdae3536b6d34dd9a635a664596b506b1748d7f761d424d76697ce6adc14a(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryValueDefinitionCustomLink]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__77814b2b54d571779dda0a3ad94f02e1973319c7cc97a032454544dec9d09c2a(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bde55d98c59414d405730a6609872e42e58a2ebf9ded140458579bcbfd500f6d(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryValueDefinitionCustomLink, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dcd0af970bdb3f521678f2048d9018fea075dd8e206d8eef117336cd4952b36d(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryValueDefinitionRequest, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__50ee9bce9554c1987ed922e1e38d2acf540cfa8d77a8d5a5f420af3801e214ee(
    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__493b3878bf627132a3293a185b0f7ad42de68014e3c4bdd2ccddc516b6e17747(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f79219046bf56a7123e3f7dd0899e3a31054b2b3ee113bbd6281f6eaacd25adc(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2bf2e54304dcf5f35003ceb52c3002c7d7a1abf57beef84ada5836a44bd91cfc(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b5284dd38c1d74d8934116bbec69aec873eb781004df8a1eccd10a7ebf597d11(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__01910f370f624a53f1348389949c1339cca39f179257ef0e3897c4ac893e1dc6(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2b480ddbf3e75f57a334a47504d61d4699cf4e16d1d94f8970b2df1da24b3dd8(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f6ca66c3830ee8f7bfe57c86565aa2ff2513d2c184208e2db58da81c87a334f1(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__66f9f09b327b17a8460bb177635b883d78a3298fe8325b09e426eba03ea32a10(
    value: typing.Optional[PowerpackWidgetQueryValueDefinition],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fddc52cefe13a8b4c739a6ed2aa52fba254d969b416e6914d5d87d78da038dcf(
    *,
    aggregator: typing.Optional[builtins.str] = None,
    apm_query: typing.Optional[typing.Union[PowerpackWidgetQueryValueDefinitionRequestApmQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    audit_query: typing.Optional[typing.Union[PowerpackWidgetQueryValueDefinitionRequestAuditQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    conditional_formats: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryValueDefinitionRequestConditionalFormats, typing.Dict[builtins.str, typing.Any]]]]] = None,
    formula: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryValueDefinitionRequestFormula, typing.Dict[builtins.str, typing.Any]]]]] = None,
    log_query: typing.Optional[typing.Union[PowerpackWidgetQueryValueDefinitionRequestLogQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    process_query: typing.Optional[typing.Union[PowerpackWidgetQueryValueDefinitionRequestProcessQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    q: typing.Optional[builtins.str] = None,
    query: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryValueDefinitionRequestQuery, typing.Dict[builtins.str, typing.Any]]]]] = None,
    rum_query: typing.Optional[typing.Union[PowerpackWidgetQueryValueDefinitionRequestRumQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    security_query: typing.Optional[typing.Union[PowerpackWidgetQueryValueDefinitionRequestSecurityQuery, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e55ad88cf201fb9c09c16dd86b9f0431122268acd798d4604acbd55745e16c93(
    *,
    index: builtins.str,
    compute_query: typing.Optional[typing.Union[PowerpackWidgetQueryValueDefinitionRequestApmQueryComputeQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryValueDefinitionRequestApmQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
    multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryValueDefinitionRequestApmQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]]] = None,
    search_query: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__eccd6fb959607696ab383072f92fb03c3b2e22bf648fa0dac3aed8b6dc562383(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0d681a394d8dab48ccff202799bf5f878d441b65c18be39f24ce1f73644c7c84(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__260c6984e79449542c4dde2f068f62498c30a13c60e0682a092ec97978d27e0c(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0108d11258489499eed95b03cb0cccb22f0d13ec46a804c00ad9d000459e4f92(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__81f6653abc4e1f03b4f2a15f853eb8c4e2e3a2741f7417a83b9eaa6a095a7525(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ef43875289e4835c33f111d1e79d2174242ea5dd07d367990bed4c68b0a50f5d(
    value: typing.Optional[PowerpackWidgetQueryValueDefinitionRequestApmQueryComputeQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2bf4a5a4d9ca0f24a7895edb47b8a930721d54390137918e01349430df5913c8(
    *,
    facet: typing.Optional[builtins.str] = None,
    limit: typing.Optional[jsii.Number] = None,
    sort_query: typing.Optional[typing.Union[PowerpackWidgetQueryValueDefinitionRequestApmQueryGroupBySortQuery, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d9813d2d842005d7af9ae265cff7945c1a7829f0a6eec8a8bf35abfae87ba969(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d311ad8468182fce68f91b5ba2f829eeaef780432b56e2e0715e9ad4d214bbed(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e8f3c42d30c88d84c3c4680c69973d4ac6f7114879fddb1bac782d3bb7faab67(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__96c71872ff6ead58af6689c906901b0a9a13978770948ad132f2a727b33588af(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f00f0bc44ac75bf6d9a4db470cfdef534e01d4bf9c9882557fd5edc771c5a7a1(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__73ededf572a0cfda03621ba467904fc2da7087d45d70632bfe144126cfba41cf(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionRequestApmQueryGroupBy]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__95e7e8a404608900fa5b5bbcf66609bcfc25de412e60c456772ef129450ace71(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__31b171ede32cb397d04b903416451482a3eff36d04605640c18cef2de0a19365(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e32afe6cda241926730bdc2430cd6b8e8d7b37329b5865ea62be3ff77615dd8c(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__848f4713f39b3661069b59b3b3dc16b1fc8f42ac0cc22fe14eafd6d1911c393d(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryValueDefinitionRequestApmQueryGroupBy]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c0f2a66ccb9846dd0658220a6ee0b067c3e9180e4343b7816a8187966f5f4705(
    *,
    aggregation: builtins.str,
    order: builtins.str,
    facet: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b73141f9ce358d36186f2c096909f65d94c53bb6689d7c89cca05e8ef678f8b1(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__99c932ef0086a94b46ec1c09f5614650692625ff37a178598fec5277ce4bb177(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__800277f045d1e39afee8dd95b6461ce0204f23814aa12d224abc437d6803e945(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c1286bc993937844746bea6cc8abec03c3d153022c07637f54ba78b7071ce617(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__74736df49988a16f1f580dcb43123fad397f58b70095af6953526cfdcd5ee36b(
    value: typing.Optional[PowerpackWidgetQueryValueDefinitionRequestApmQueryGroupBySortQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__45444d64566299889c78988651e3ab1c120c31c45af43f4d0c9cf43e472ef101(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ff70f932fcd82b67b0511c8dea942270c9f1ccabaf5cd333214b957cd2ed80bc(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e6689037ef35c6eb6760cbbdcad25b2c837b024cab89e90017473706cd2b4e34(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6a2e578f201472f523043268e34852f4d29efddf74182baf213105c68ef110a2(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c85d9aef974623ea6a6e407703764217638d6ad4446500c77427ac19914f6c37(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__19bd356dd9feabf8e454841c7cf6482d49524e9f3a4111d2193866cea982f533(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2e876c0a761ddd08a319c7a2723543172729445bd3194fc70e4af266505d71ef(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionRequestApmQueryMultiCompute]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1ade347b15b6ece80bc83e76ea1f89ea3e8cbe3f6246a33f7c7e781c0224b560(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d814778d629654b15cafc8a430c678798a59127bde3b994198dc7a67feb2fbec(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fe7db11109b413c2db28f6d817059b98b7f72c3e516ac8385c7b5b93104861f0(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1ff6a83b24eb8926986d508315b219631d8a8d57f36b28c7eadc4f3550c24892(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a3d7112ce7beaf570b74035420c923de8c8b7aaced9678a5da502c92b9984fe6(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryValueDefinitionRequestApmQueryMultiCompute]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__762ad782adcf330d39a61124ec6fdf75755c90b353e1b007b257f81e0d46a5d9(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b02f6f95d7bfd22826e42304cd676a74a6b0ee55dddc4b5c731b84a9f6272dc7(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryValueDefinitionRequestApmQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0c0bc38fa55bdfab7242bf32ebe76b59a3fac2eaefa6dff615f6cfda2e655bf3(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryValueDefinitionRequestApmQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__54f94ad801ffa794042d17eae53564cad751bd9d2dfaca38126e4be693ebe2fe(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7c5962f0d53e20cdede878c60c86a975c474578e0be6ec9e4dfa7d0fc2ba222c(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__51a122ef77fcfa73fb6007d78aafb6ff74d57d73f8fca455809c17b3e3d2703c(
    value: typing.Optional[PowerpackWidgetQueryValueDefinitionRequestApmQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__42881c6d2582490dd46016ee572a05b94a54f8659245e09f51e951beeae461e0(
    *,
    index: builtins.str,
    compute_query: typing.Optional[typing.Union[PowerpackWidgetQueryValueDefinitionRequestAuditQueryComputeQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryValueDefinitionRequestAuditQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
    multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryValueDefinitionRequestAuditQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]]] = None,
    search_query: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__19d0abef19cc0703109a70fa7ab013f1c67acb81875db7e6294cb4a9c0f65285(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__38c5b6920f8ad2193d50d679843b976a7a9d10d14a5da18f93d9fa965705f779(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e520ed1cb04cf34c869e6139b17cce58ec354d8ab369f307662b57b7046f1a98(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7977724be04f914668ec400079647c973ee9bd2a6cf808074bfcc87bc71e7c64(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b3b9611e41a79f14677be96993d720e6a34529ac30f43092850cc7ab75f090bd(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__817a78b1c1da43156a735544ff1a9ce6fc8a423eadd3078fbe4a76add443c299(
    value: typing.Optional[PowerpackWidgetQueryValueDefinitionRequestAuditQueryComputeQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a9a79e042a834bbcecc0851ef3226cdf628c86745b82ca2c7ce9d6f1f0382f05(
    *,
    facet: typing.Optional[builtins.str] = None,
    limit: typing.Optional[jsii.Number] = None,
    sort_query: typing.Optional[typing.Union[PowerpackWidgetQueryValueDefinitionRequestAuditQueryGroupBySortQuery, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3d4334a11cd030528edb66d7bf908760cef16cb500672e4a7060eaa48798b166(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__adf2b2cace889446479a4accb6ffc14d167588f88afa88404df5e49990d0fe1d(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dca5a38ab882e366914e1260e1b494b65270b6ae0e5547abe01e3f11a7e1b400(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__38d82dcd87cc58dd45d1598f534688f514dabbb503420a7a52d93025e3b5dad7(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fdc7ba0504927a5a6b9598d7a306ba5010515f9cd0b0df0ebd947e80de479fe3(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ef7678439c08c741e4e9dec2d26677b312ec2c7aedcb3793beb1be2fdb098acc(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionRequestAuditQueryGroupBy]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fa3358ca23ad2d14ac83b24fc6720d410e209942ec183fe9a40de4b3e5e1c606(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4ca7cfae616be1bab9131e5e5798431f50098683a90588604e1d1eb570d7e82a(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__58e648ab98eb31722a19fe04a3a7b00d640fc68c43e2bcff9da33133213fe87d(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__958985440b836c05232f5e64b8c86a74c25c34cc8ebda9698db86b3b6731656b(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryValueDefinitionRequestAuditQueryGroupBy]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__995018ffa1cc6117ff81e54fb8ea8dd9c9334c090812d35d7799cc22d53839d3(
    *,
    aggregation: builtins.str,
    order: builtins.str,
    facet: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7c3b7f46b560782f0991a38def9be256e3eee06a7cd2c98ef903a0f276dbd20f(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d63cccfc02de9f24d49b896f36792fee01f10d8dbfd39e2444d1e78e5a35bbb8(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9978def8aeb746cab4d6cee3b3cd5b911da37c0407e8a1f7ea4c9d4d30696b84(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7ac0bc32c77a48d4e5f9e6db85b61f6ecfb13dec18da0fd1c8fe9593958d99c5(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6f6e575e24d49090088b09b3de213ec91d389efcc49b922d0f6d50743eca3a53(
    value: typing.Optional[PowerpackWidgetQueryValueDefinitionRequestAuditQueryGroupBySortQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ba55ae26d44fd80110d4dc430b87a7fe15a2947033b49022127802d20cfb333d(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__902d35499be986461c1bacbb6fdf15d50811a4840b3200f0092ace33156cbfcd(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__608d70b0dbd6be7f4f1f0dc1bf3d0190af0450c8536c0a6a210ae0633c6b22bd(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a1f242ef70a3421a0f946c1861e4f78c25863373740dd59e4e2b5d5c5f633693(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d05b0226638953899d28b932d27bf8382f4fc9192499aeee79f46c129390d013(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fc83011cabbbb4ff82b8ca47e29dbd9048cf3fa0344a125f9db579f4027caf3a(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6d5864e6dbad51b5ad599e8176c508c551072cb4773fac59617710b696c52da5(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionRequestAuditQueryMultiCompute]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f72d922f9a1dcfaec5b132173bb6b6fc6c4752da64ccca46180dcf3494ffbe27(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0ea6a1a3220a5369526b8694ff0329a2c631fbcb67a5e25aa27172e84f431aad(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d9e653cf049bf8ed1edce9e21abaf40aa243a500f0f253f82a89f113a254f5d4(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2952569fbdb093f7216095334a9c236d9fab7ab1d7f852ea29486db6e8343918(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__19f18bfa55a3cce429acf639a62dfa8b694b571c355eda53ef3c9b00c49bf37e(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryValueDefinitionRequestAuditQueryMultiCompute]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e659a856f7b18b9313405d8c257bd40d453047740d09ffd0a19af229dc47e734(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__84a421ce05dea1a2ef1f083f6d45c9bdee5552e3efef1adbc0179a9a8b9be30e(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryValueDefinitionRequestAuditQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c0be0d73a313948de3f074341b15bafa4ffacf3613ae94a8ed14918452570d3b(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryValueDefinitionRequestAuditQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fe8ee682469e353514158fc60c3673ffd3f20f32670a981f55fb8cab8d624b7a(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f5c854ad29ccf27896ad0b604694f1427724dcc88041b808f2c9779b81f94582(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__32c457a1f48a71883b0528bfe5fb27b71809f15f757c152ab0c742ed04525003(
    value: typing.Optional[PowerpackWidgetQueryValueDefinitionRequestAuditQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ae816cb54c89b1f5a0bf2b1cea5ee7859957a76960dc0f4940808c420cf38494(
    *,
    comparator: builtins.str,
    palette: builtins.str,
    value: jsii.Number,
    custom_bg_color: typing.Optional[builtins.str] = None,
    custom_fg_color: typing.Optional[builtins.str] = None,
    hide_value: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
    image_url: typing.Optional[builtins.str] = None,
    metric: typing.Optional[builtins.str] = None,
    timeframe: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fb779e4408bff83d4839c070b10d486d954af973440e71e5c5eaea6b78cfb1b3(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f480aac56712d1ec8e519a889e9b372332428cde35d114d9c56e84fbfe089510(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__42e5b4d3a0a61c02b64d978595cf848cfa9679f42beca374d6d56059aa6afc1a(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e8e97c4c9dd0316be75c97eb49a5f2ed2b8044c4e2d755fae89b8bf19dcaad2e(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e5cf716a4962091d2dce156e80c0027436d7d5e465632be59420a47fdc2b5c95(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e50f94bf360afa4ee2fe13e61abbbab22be020c42b8698e44384670e62d5ca74(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionRequestConditionalFormats]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4d7e912385b6d020af7d3d6a5e0db18a09c1a24623265f72cfb8ed9fb69bec96(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__07b071e86737ccbb335f44a0146a4d6f586709ee0927e636ad05ce9bd963007b(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6a71327bee6a2d3753b7da28ad6121bc7e2932e1ebfef92cae8e3805e9993460(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ef142ef759525b5c91fc1da56bed7528b84c28455f99efa95be406c678a9054b(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__da939bedb671b383c943b0168ad28ecb795814cc7a8b3eea054dae68b1270b78(
    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2891571f3c8682fc31ea55fec5047d2e8ed36d4ce356e9778436d798ff3d5d70(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bb081f97ecebdbddabca2c0337fd419fa2ecd9deab173aaf62ffe25300c74211(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8f110d8b555624a613fe4d764532c47641981a15d96ee3c6411e21c848ed1a1d(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f26e3d7f9fa98132cccab26f759eb27009cc66f3c845a5cd184557952b51d54a(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b9ff9f35e24e0d3afd65090ab74e486046d67a6ec1f01c00fa064c9c72a05dc7(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dd3f99ba66ca04f08e429affb2e551f2444581c3b59264ef7e6d2d9028d96cce(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryValueDefinitionRequestConditionalFormats]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ffd4fdcc94e70aa49a00e5ba6f7b34b69e6fe72515a3c6d6f07c5c99a7360cae(
    *,
    formula_expression: builtins.str,
    alias: typing.Optional[builtins.str] = None,
    cell_display_mode: typing.Optional[builtins.str] = None,
    conditional_formats: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryValueDefinitionRequestFormulaConditionalFormats, typing.Dict[builtins.str, typing.Any]]]]] = None,
    limit: typing.Optional[typing.Union[PowerpackWidgetQueryValueDefinitionRequestFormulaLimit, typing.Dict[builtins.str, typing.Any]]] = None,
    number_format: typing.Optional[typing.Union[PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormat, typing.Dict[builtins.str, typing.Any]]] = None,
    style: typing.Optional[typing.Union[PowerpackWidgetQueryValueDefinitionRequestFormulaStyle, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__80278a6fee8382c22e815b09fe02bd3221bc844f4644215319beff31f3ee47f8(
    *,
    comparator: builtins.str,
    palette: builtins.str,
    value: jsii.Number,
    custom_bg_color: typing.Optional[builtins.str] = None,
    custom_fg_color: typing.Optional[builtins.str] = None,
    hide_value: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
    image_url: typing.Optional[builtins.str] = None,
    metric: typing.Optional[builtins.str] = None,
    timeframe: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1f5285ffa03e74340fc0e8c15ad3cfa916dc05d29b4df23bc4c7dcac2a17e9bd(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__da98d75dd58bd5d15d30cae2244f1c896282322bfbbe74f2191388fb4ede7522(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__aa7323461678b7b628e23aac97eb8ccb1fe9b71291ad6a152a58aca876c0776b(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8ea4730693e627259ddda0c1eeae55438a22f5420fe3518aee3c8f141848d21d(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ef499def803d29e933fc30c782c3f827de64a8912644914743b5f7fc4c4911bc(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__01f3408cae5b4912463b5742191b2929e658a1dc8b74a65dea2c3974280d5f5f(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionRequestFormulaConditionalFormats]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__11e66e422591b94aa474a2b28c8b2ce816c0de32b935e87fa68cd847193ab44c(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5ee86f85a3dc01e9fac15a75deafd2f88f77f077e0bd1a3ee895ae2a512e2d16(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d4511fe123091d67ac62e7877c75b643f18c0411375c7ce79608b7abab180a25(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__38b2798368836b38d734fbba68f928d1d20f4caad2688362f0e28f69955f64ba(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bc3e250b4ebee06b7ce59bfd9623127f7d654a12b98db50cd88e81ec8c0597bc(
    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e7123d568b907847b785d4c1e61d7bf6a419c7cab08af43ca5d9dd4c396e8990(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8bf76cf64229bce3a7d9d365810e8d0945d017db5d621a6577d08bf8a77a429f(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__92c73cfd3f79b5e9a798c1a16f448750d80073d9925753c54fa9c43dedbd8453(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e32664c56a02ee188b3d3c716d3004f97765702a9004c25165dc77ea8a3df553(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3d4089616dcbff2752fc3f030b133acb9677eed3c4dab27b16fb94d4ddef63f9(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3c0076d1b63dbde826da797d25ef0ad81f09a2b5d82d685eccc9492b74250d0d(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryValueDefinitionRequestFormulaConditionalFormats]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7385639bf39d3854d468b2c26d0af1927dd13ff3aa26305464b95ff4896bb619(
    *,
    count: typing.Optional[jsii.Number] = None,
    order: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6ec2ec2a8a33a104ba2965e0c852a9593d7c68dcebb73787894f080219d404c3(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e573a167cae6d75c2d7622c54f6437ce58fa33d6154e2652d3b657ed2902bc89(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8dfcebccbd8d2993e8f94798e59d7b31a67a0615ec05e6aa1f56f826802250c1(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3d84d9d47c26ea87c5738c8775dc4f6b29ea942e9305995443643d373154f6be(
    value: typing.Optional[PowerpackWidgetQueryValueDefinitionRequestFormulaLimit],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__83975d552881908377b62f92318c08b830625ef87ec516b1b7e93f6482972337(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__219a1dcf511487566a43075c27fab7d12201136b62c55cd28fc18ea730a87e73(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__86d25a1afa576160f2f1e0793c0f59c6690973651020918f7518d1802081ac01(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f538a83d338a8ab4684fe52283392b3a5ab826e3ea75bffe832e0d5072e7a42e(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__75f9709183323fcf6bd891e4a8d3563753cd3166f8b463d774ddd56200f86e0c(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2430ac1e41cffb132a5102498c0f939bb8601a6ad820811672eff142ba705f13(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionRequestFormula]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9bef1d69ecf89eaab18a82d8646c48db8a09de25b132811143bf1977d680f21e(
    *,
    unit: typing.Union[PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormatUnit, typing.Dict[builtins.str, typing.Any]],
    unit_scale: typing.Optional[typing.Union[PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormatUnitScale, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__08a2d0c923053cb1ea8670d6da2ef7c0231c40bff5c4473ebcf853d31f45ca09(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5fea8957766c6bc34fea8bedefbf81083523d4e9c0e769a7447ce087c8668162(
    value: typing.Optional[PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormat],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3f5ad7a3fb0ec2c85844364e3c00078a7fbb1e0a46c4b33a87a970528e1dcd3e(
    *,
    canonical: typing.Optional[typing.Union[PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormatUnitCanonical, typing.Dict[builtins.str, typing.Any]]] = None,
    custom: typing.Optional[typing.Union[PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormatUnitCustom, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6b01b59e61276a3e589f849af587441e3e67f4bf5f31da254e666a1e01ef52bc(
    *,
    unit_name: builtins.str,
    per_unit_name: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a77a51cff6879893467eb615b7d43980c390287ca265083c43f088fab4bbb4e6(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4e49e7bae67649e624e8b4574958ac49bb13ae7c1eb62ed684db94e812702989(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__eaa5f5e76deaa545024d5cea0eccc439c76d4178f4b64f64315d8883f9fd4dd9(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7e4ab2251c6e210ed9ef39c7ffe297327335aad0b26d4d971c561209547a19bc(
    value: typing.Optional[PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormatUnitCanonical],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3fd5c93456f8047e6d18eec8523b11abc9a20b22a8242798eedadc029da967ac(
    *,
    label: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__eb3747349d7751aaeef2dd5b5e574673a45031da44fef6a555e3fcbf2809e0d5(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__95f35dbb8c72956eeb2be95b764be50e400a6f048a2bfdc98b0728b71217e283(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1d6eede99fcbb28b5bbc2e9c4ff3279c4fa444aedf71ab3b118cadf0465f23c2(
    value: typing.Optional[PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormatUnitCustom],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f9c76a32172b432dd0a6d0ecdd43c744f4b9359afc639c7b428c06bfef1d0db5(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f17ce5536a017770143dff05480d3b5eff308af7d486bff71bf28fba3dc5ea44(
    value: typing.Optional[PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormatUnit],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cc6122788916cb67acd8868e2a3ed06dbbe338ab4fa62733d9b243fd6ecf93e4(
    *,
    unit_name: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fc00126a7702eab2f0a25d39fe25f3696548731a02e537e6f643f5c22bac3480(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__48f931715006d8797ce8b7147a9996fea7c91a16d634c5e7eb5b6d307b7a724d(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e6df7f85dcc2db343cd569d9e9ddffe17c160805d01625904cd97e4d93f50480(
    value: typing.Optional[PowerpackWidgetQueryValueDefinitionRequestFormulaNumberFormatUnitScale],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3553bd0c186d08f199c97b5e52fd5763f73c3a3fe9f2da0c9770d5b00ffcab70(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__afca99fe33b24dbc322ea2eaa3f666afa587b0eb9eed61f90205c895197413ef(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryValueDefinitionRequestFormulaConditionalFormats, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e96ac9f440a4f93ad71db42124b91f651fd66ce33f26de73a3971b8622c72941(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a2452e946051ee60ff6d7d91b6e3df1811d2ac0851d49bc6893fc0224320b267(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9dc58abfcdaae46a66758e38517955ec7acd4de4f3003654f3a7fc3faa334854(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__38ff5c9cd6b7fe7e90b862425f7be2651d281615de7840ef245a31ce00ec7b95(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryValueDefinitionRequestFormula]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0086ec2ff84c385925ee2035cd49a081a0b97b7adefd1bd1a4eb55d2b6e4cd82(
    *,
    palette: typing.Optional[builtins.str] = None,
    palette_index: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1b03adbd8da1369f7db65a8a4173b7e972867d04f0afb0a02b2528e0b6ddc288(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0abdae024e91e90879d498cffd0eaf40db3767f069712aed820c79abfde6b670(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__592fd9515d26cb95e41171cc12461314e8bcf6b05f4b1c6d980b5107d752f0da(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7bc77d30e79c962a5b0d24f7c3ca6ed3599d55cd3b90606840a1bcd5145fc098(
    value: typing.Optional[PowerpackWidgetQueryValueDefinitionRequestFormulaStyle],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__358f7ae2316c966b53752efb287a0bcc6899166e4a9ae69b8c5b8b4b3e231cfa(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f5ff2814cfe6a9514a1603aae194b9219192639bca5c4ff1be3934d0a97840fa(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c76ab593542a55041e586b7be47a8a92c8569556b0dfd51c2b0c59a497ce76ea(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__42cf929feb833879d3f4261328f9012ad84061befa12c518caee8a99b2da06a2(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b539f031649be4fd781884575b17edf6d986020639bd7a4ea7f9c4b918689203(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bd56dee1b87f7c5a7c063ed9348deadd8cc9fa777447304bfe87c884bd67758c(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionRequest]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fd362fd3e154284723b4842982936afe6ed64d272012732e10c16ffeac4ec8d2(
    *,
    index: builtins.str,
    compute_query: typing.Optional[typing.Union[PowerpackWidgetQueryValueDefinitionRequestLogQueryComputeQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryValueDefinitionRequestLogQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
    multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryValueDefinitionRequestLogQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]]] = None,
    search_query: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fea818daaa64e8511ce114aafa5bd9cefbb1fc036d215aaaa689f34189a9ca43(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__59a269f1477becfebe59a5be62ad9ae1a65ad7a6168f64f9634196e168ea969b(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__88c7045e8a76e36fd050ed5cd2cdd7e2339455322fa010ea0546a81cd4a79a69(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d6e1ec82854cd1f708e01eba68f5f99fee944dc84a3aeaa1c7d17b9e8aeda397(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__982faa7a02a76fe51848990d47f30865fa4cbc5a4dd90891ff5a4eb91c7e9492(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b79a9c446d6656a93b8d0c301d32458af65938cccaaece44b006acd502173cec(
    value: typing.Optional[PowerpackWidgetQueryValueDefinitionRequestLogQueryComputeQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4ad01ac2217ed3e4cddb53350e6e54931a9941c565e6a26ceec2504df9083682(
    *,
    facet: typing.Optional[builtins.str] = None,
    limit: typing.Optional[jsii.Number] = None,
    sort_query: typing.Optional[typing.Union[PowerpackWidgetQueryValueDefinitionRequestLogQueryGroupBySortQuery, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__af670b6f45d0a185e61893e46beb9c10562dded20adcc0f92a00b0837471ceee(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e7c7b9fa818f90c21613d00f77422d2908236b8ef7ac1cff622f3c9a67ba5488(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ba19b74b8520bf66eed06888f1345f6a50aff2f54bb8875c9097140352c49508(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f33961da8e066ad7f8da1e8fb1e87274cbfe667e0a5f514f6994d8bcefff7bd0(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__29fd1ff3b6bb4e2a395d5a9dcbf4158ae8de391b9487f7e4d3c98f50da9e678b(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1b663b6fe7a8af87280f467babf33d5e9c99e3f6b38ed913532e02ce91b9d911(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionRequestLogQueryGroupBy]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5b2081188c9ef3f6d79a5333869971ba73a1a6f955fd0cd430307ae25c47c551(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c470795ec665592fe436026ec5c2f7e591d4ac77c2bb4f45c02e0023519eb372(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b93aaf7985f9f6cb2a538b139899252ee53e18eee56210a54dfeade9d8a711ad(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__93634c7775477a096a72a968bd4f63dc6a28fccd2e4306e036bdd32c33246d6a(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryValueDefinitionRequestLogQueryGroupBy]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f986ef97740dfae5769f36336632573b51072fc94d8e3fba491dbe3bbe859565(
    *,
    aggregation: builtins.str,
    order: builtins.str,
    facet: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5c7f5cae54c55cb502af9543118a24aedcc98397bfb4e4f306006d7278e0b0d5(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3b5ae501b0cd22e157a909af749a0c0b35cda1645b2afe8f5c64a773e30a4eaa(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b3b3eb8829bc3b779e09dcf4bb737157b095e29eeed0b3b417b052a33912e1ab(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b226773c961d7054916169a9e0e4d4fbef2225d6d5b4f6330ab6e82773816f49(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__51561904f883528870dba0dba8ba914db2358bd77fbc159349bdaf04d810b4c6(
    value: typing.Optional[PowerpackWidgetQueryValueDefinitionRequestLogQueryGroupBySortQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4bf9c24b0f81d700e666f46f4a91a9f8797ff3e837e0f609428c88ffa4dab394(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5ab33761a7230269860d2aad30618a4bdbeb506c255f339a32046556e88f02a1(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__35eaa7d7b6bf41c47441c8f7e2b205b036977f94bc421970a12b7c75737bf8a6(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__74771a684c96dd8d268308a84c70f4a26fd392f3653ba12cbc132f3228a70e70(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dcae3b14a3b405abcac440161e346e4c4312886a1c069de5343f3020349e6e99(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2c5e368f4ea30c56e34f3dd4a4c5ddf31592182e98c79adc5301d5c85c012313(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__78da300d651eafb163be58d5cd3743b45b4eb3a55241984f3691a4704841e9d9(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionRequestLogQueryMultiCompute]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cae330ce8ea2b4ed443f9e01c2fe7e99c953948b5e736d33204a3ce2f1504483(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d24832601fcf718fd9eff1466471da05a675988671935bf6dd165b9f34d142d5(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f7bcc9d1aed54a3593f130f1fb967bd83136f92bdfe849d1f82b6c36e3e933f1(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__552fe5114be2aa99b9b93d18a1aeaf27b924ea07bb7349ef7011260e77619760(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c671c88e3da5e7c79f169cc2c568777baf7b51d669460da8c5848beb4df391a3(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryValueDefinitionRequestLogQueryMultiCompute]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b59f93ad1cd06fcc288b19135664b4c005e6c548313fc683d8cbfa102c62555d(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__47a9cfb9d211a80a6dc75a7b83613d6287126e17e7c1bdb640126d1bd08d1806(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryValueDefinitionRequestLogQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b5a3235a55cd48a26dca25620ad298dfd8a9179a22a4fb1ba0424bfc1485d44a(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryValueDefinitionRequestLogQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b99bd4a450e91d114e7201f7826064027ed213161cc93b294346cd6621a7467a(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0ba71bb88a7e35cefde15bb7dd524468968fe221fdec262c55b192d0c1557920(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__329e6209c18a2089fcfe9d047f70ef40f035fdc3a709609a1b085ed49f30d764(
    value: typing.Optional[PowerpackWidgetQueryValueDefinitionRequestLogQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__baf2f70a7753aa3ffa3a9ccb92bc79d1e4115a55d2f32da427aca68a943b7e93(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9f157bdc70236b9f5f572be1bc01ca178138ccac0acacef31fe2ecfa68490386(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryValueDefinitionRequestConditionalFormats, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7091afd47e05449f0698bec6549cf6f7e896f3591f85342f783c683a6b007523(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryValueDefinitionRequestFormula, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__063d0ec151118dacc0d9edfc26d9631c25b6f640cd6118d9f755a73d5cb12ae6(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryValueDefinitionRequestQuery, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1d3026e14612ae3f1a7fdba9edee3e4c3bc59b00f1eec5530d5bcc739dbac3f4(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__251cdd3a1c49a2ffd3c0985dedba7651194a31d0307e7aa2f56d7d64a8cf88b8(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__19a28eeb8c159582159dec3845eb5c99dd9a8790ef78b366a0aad8a3e51bfebe(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryValueDefinitionRequest]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__da78e5f15b0a9a00f767b554ed565a420edc5f5a730d7f660e9aecac03918be1(
    *,
    metric: builtins.str,
    filter_by: typing.Optional[typing.Sequence[builtins.str]] = None,
    limit: typing.Optional[jsii.Number] = None,
    search_by: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__003b968039c9c9fccc29dddbd4095c7e71c599c46163656bc13a25fbe49b1093(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__56ebc3900a1b832e13773e7404120ac5baebbbaf8ff4a14643c4003f53e797c4(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cda97fe2b44ae4fc097b5fcf75e5ef13ae2ab2c34c51f099f84c65a67df1760c(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__03772cc757681e389960493432d2b8875c203e74322ce733abd37c5911e08d1f(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3d8d37a0b53a943e01ca227fc22925bafefd28d28543c499267aafa555e84bda(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c252ca5e1f1327686f51ebda5e4ae3bbf2ac4ddbbd6ab90053f1fbf83ae76f60(
    value: typing.Optional[PowerpackWidgetQueryValueDefinitionRequestProcessQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__250f35a40f348f03c42936227025012e29664e3bd5c334ad56030f751d8d46c4(
    *,
    apm_dependency_stats_query: typing.Optional[typing.Union[PowerpackWidgetQueryValueDefinitionRequestQueryApmDependencyStatsQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    apm_resource_stats_query: typing.Optional[typing.Union[PowerpackWidgetQueryValueDefinitionRequestQueryApmResourceStatsQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    cloud_cost_query: typing.Optional[typing.Union[PowerpackWidgetQueryValueDefinitionRequestQueryCloudCostQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    event_query: typing.Optional[typing.Union[PowerpackWidgetQueryValueDefinitionRequestQueryEventQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    metric_query: typing.Optional[typing.Union[PowerpackWidgetQueryValueDefinitionRequestQueryMetricQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    process_query: typing.Optional[typing.Union[PowerpackWidgetQueryValueDefinitionRequestQueryProcessQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    slo_query: typing.Optional[typing.Union[PowerpackWidgetQueryValueDefinitionRequestQuerySloQuery, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9bd0517699144f92edbb9ecdbe13e18f3a3deb7ba455d259cc782dd9f37133b7(
    *,
    data_source: builtins.str,
    env: builtins.str,
    name: builtins.str,
    operation_name: builtins.str,
    resource_name: builtins.str,
    service: builtins.str,
    stat: builtins.str,
    cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
    is_upstream: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
    primary_tag_name: typing.Optional[builtins.str] = None,
    primary_tag_value: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8c2663255d9437b58af786ffb55c295ff7de21e32bbb6dc76ebcafa28a1fc0a3(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2fd02f8b494f9f1474173afc3303789913d02507df75b7ffe622dc5439acdf44(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e057b6344e1d643b5af4945b845683e2cddac1610b5626523ca35f1ffc37b1f1(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a9157f5616c07b0b9984ec374e967d763a2c4c02e651bea236da26814c1404ca(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__22f79736bf602137f769c92cb0a6c4e26168dc6223a35efa371ddb86a85b5829(
    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__87cd96f9da9a6f491d377befbf3144fb6989f2be59357e1ea4e4ad7cb48eb7fd(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__059b05d0bbe320f75038316d07162741492fc3a3ed2e6a03ac108a6ff1f06d0f(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__82ee39d01c73d2ebcdc1061a2b4d3419eecc18aa55b178e5ae6a8d71ba4eac48(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__de4bb62f637216f20bec1944194070806c42f9f18c396c17b49a33c2b9e66aa0(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d4f8f11e29b6e2bc969df84955280f294905de563d5f7d40a4f12b1d1e6f6370(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__321ce53a3b1be89b458fb378979d00a032dbb9f4bcda6f3d6b5e64b8a5656e1f(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c0ab40cb3b007efac2e37b5674684af19ff2b4b073976c8502a94980138e2b37(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b027b88294ce59ed53334e2d6be99a6df9fdc8cf2b093cf043f1763bbf18595b(
    value: typing.Optional[PowerpackWidgetQueryValueDefinitionRequestQueryApmDependencyStatsQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3d29fe224d3adb955d571654dadeb54bd4f22bfd5c105982accb8a491406be8a(
    *,
    data_source: builtins.str,
    env: builtins.str,
    name: builtins.str,
    service: builtins.str,
    stat: builtins.str,
    cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
    group_by: typing.Optional[typing.Sequence[builtins.str]] = None,
    operation_name: typing.Optional[builtins.str] = None,
    primary_tag_name: typing.Optional[builtins.str] = None,
    primary_tag_value: typing.Optional[builtins.str] = None,
    resource_name: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e1ffe0d36398af52d2500864571b1746a91e3d9a92756b4d2ce98984124ef206(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a4369fc5fcd1593e41a59d9a879cc0a4b920d441aad9ec452bf0cd12108649aa(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__070997f57b4296919237845d3c0283eb528f0da5afdc9c5e474b132520970c7b(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8a8244c2f3669e5f8546de1cc3b0a5c930b34390e97797cbf16ba64243fab625(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5d11c492320b1edab1ae365df54c6a157aa39612e6112ee8f4829e7b6376493b(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bf0e2c20951462a185985c723bb68c9bc1161ecd0add436bb48afa7182a9b854(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__077c1f15374dc4f8e10a9670b4432131354091b4a481c1d3554f2dafd3a530a0(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9342bed67c3d93f18c6664ae7d60b286ba3f9ab59be8604a97aed15d2f1325d4(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c04e037fd9c74ec71c136cc621ff29e08bea96c409e8b4ece0a3b9d963780287(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6f2149f48e349b478d6a46fe27eefaa91f48829b2f614973ad8fdab14f1b685f(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4c01814ff896733fc59afae92eb460f1ac00d8b5756e65e0b3aaab79af0eec8c(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__061bacdc3592f2e26cd0bea0017eec9c740cabfa2649c3860e203877151135ff(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__359861c816bf6890c846260aa6d2cd5f761ff1572b9cbd902521eeeedfebb90f(
    value: typing.Optional[PowerpackWidgetQueryValueDefinitionRequestQueryApmResourceStatsQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__eaea6e22e1858616523822d874f21483870815d9bc44db5e56ef7ba05f3998f2(
    *,
    data_source: builtins.str,
    name: builtins.str,
    query: builtins.str,
    aggregator: typing.Optional[builtins.str] = None,
    cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c09368a02827f8304f4458d6b475fdd669fac73ce20b20305ef5a28b96847557(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__35190afc09abfdb5a63f82bf510b68df1353baf5861cdc628ae3d51d13319d1d(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3b57d03537f1a6fb7f717173e165b11ef8ee91701074b2f31afb2fb435176952(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1acab92244954bf354798abf6e9772e463a660e2bd44bebfbb122cfaa0f9b545(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5f8b41e28ebe5314437bc8a540a6ae8bdcdae54239af4863a16c6738cff93029(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__23cb7408cfa360d4aa16d1b7968fa21320d039723cd5c9bc4ffb2f1940001818(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__26dedfb249892fdbe3ff6d9008e61c9d06fb0a561aca6f5980609283310bcdbc(
    value: typing.Optional[PowerpackWidgetQueryValueDefinitionRequestQueryCloudCostQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8797ea815a7555e5aa07dd86707224e68fbebadb1e7f2cc36ce6d3cda843bfaf(
    *,
    compute: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryValueDefinitionRequestQueryEventQueryCompute, typing.Dict[builtins.str, typing.Any]]]],
    data_source: builtins.str,
    name: builtins.str,
    cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
    group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryValueDefinitionRequestQueryEventQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
    indexes: typing.Optional[typing.Sequence[builtins.str]] = None,
    search: typing.Optional[typing.Union[PowerpackWidgetQueryValueDefinitionRequestQueryEventQuerySearch, typing.Dict[builtins.str, typing.Any]]] = None,
    storage: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__97825189bbb5cd51bed45058bdd0c8c6a104ee3e9525da17a45060e1ebc33bed(
    *,
    aggregation: builtins.str,
    interval: typing.Optional[jsii.Number] = None,
    metric: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6ab515ffcd2a98040e5cf4e403efbfc7d0995a696c423f5e61aed95cb1a40b00(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f69da1266ff85408552c7909037842a3297c4327b5fb8fe059e4ab27b994bd23(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b1aad7233a9d813039be863faf9d943300bb532811c1ac2d7de90dfc23f566d6(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c9fe80ffaf62e03ba4a1c3f317fd6cabd572aa6ba9e99bbd0cf908b905c8810d(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b27a582d9b25c52ddc45a1226ceaf75001c3ceab94e8e3e1cb44bf7f5de35c14(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ff4caf54c4c5f600ef1ea1808de66a2f6ca74697969458616e66d0e28672e785(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionRequestQueryEventQueryCompute]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__acf960a500096f7f983a2ad69d6a0aa42c8a2e2f98cb4c8c4cd4bbcc09c5d0dc(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__982abf2f1efa638c51d71afd44d35e7c6ac4658cdc7be865bfde23b426a6c81b(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__75847addb6ed0449d9ca9bc3854cd373e32a6f59ce18207870670ac2bc4ed432(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__314f1c6ed74e7211eabf24ad9fbd5dc592f909c0c62f611aaf02c561f326784f(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b4be1ec4c06d3408fc4f948aca4efdf82e3356a38b7256d1347c1dda3aeee627(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryValueDefinitionRequestQueryEventQueryCompute]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__58ee3dd36e95d50403a202e8a1e1638b8e355995ade9557252123793607fc6d8(
    *,
    facet: builtins.str,
    limit: typing.Optional[jsii.Number] = None,
    sort: typing.Optional[typing.Union[PowerpackWidgetQueryValueDefinitionRequestQueryEventQueryGroupBySort, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d5c33e646903e080bbed8ec6220928bb6ebb8eb428a43df783c5576358d2d35f(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0c9c2846b2bc855fabceb883eca3eb01ac787afdb4f2dd526fb8ebd3d6a888a3(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c868f2ecf58e83c31f7d0e882ff0cdb9cf4650f28a48a413a66e2e0a6a47a656(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b29a5e4b4e111bd4ef438ab292a2d8045ff9a78cbccb4ef1655039e90dee4eb7(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2452fec94b710c498e7ce73483a8a8404aa283d4be49f2d4e2b4ad01b63c574f(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c6f04a17b02963ea290fbc30f2e7768c46edf555c4e915356f727e00dd4cb84e(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionRequestQueryEventQueryGroupBy]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ca929fdf8ffbf0dc575b2111f528d23295c26872dd36969c9ee0cc68ff2d0635(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ca079fa93e2289f5be4b1d063fa14fc1ec39f9c959a8b6b053be432f7ff8a0f2(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__633062a5197543d8c4c6ee2f72c092256d0ff62b5ba13e6b10f81373db42826f(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__611e4c4469a3deeb58e3f252bd13aebf34db695d50fca9b3b22b4df3da9d927e(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryValueDefinitionRequestQueryEventQueryGroupBy]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a79e099fc4e7379a6239cf0b786f8ba16cb0f200595c3f8f6470f91c95d09dc6(
    *,
    aggregation: builtins.str,
    metric: typing.Optional[builtins.str] = None,
    order: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__312dd0c2d55e2f69130652e4b1eb146bbbf10d26e0b3e28581f5f1ae25905a2f(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4f4d66aabf5424b67c7e850fd32a97f28b5858c0164412864131930184174891(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__496960a3962933d635f674dcc791ac6fade49881e1851179467fb404f3bd9f5e(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ec828f832f6ca9e84b4a0a0dcc1ef07ac2bc4d1481cd6967541eab05b6b463ed(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__05bb1e0f46521f62dff4752848d780a5f1159058e0fbbc76ee0b5d2097538486(
    value: typing.Optional[PowerpackWidgetQueryValueDefinitionRequestQueryEventQueryGroupBySort],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__032ba2aa8dec0a82441e01646dfb8c28788a1bab2fae4ec2e2c18b25b6ee8078(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d58badd9eb9a6b6c6b5195ba55098cff224ba1ff63a6646e302c4e3be7473ee1(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryValueDefinitionRequestQueryEventQueryCompute, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5bc302625831387dcfdae5485c3f4bfcabe43b60a102155b4d90c74320d0c98c(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryValueDefinitionRequestQueryEventQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b65787a59f9759dd8e991232c5fb9703d185470f131d8ab535a936688b368fcf(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b258cdcf2a3c34e67d79e95cac21b2e54a2d9a55f752d91c888a8225195f2b36(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9b28f6ee8a2924ba1010100204b957be43f5f35fa4251b0184f8ac9bbf8031f6(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b586fa874956e6fb44259c06a2b74fbcc0bc16880e99318dbd933bfbfa4ae128(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6bf52432a36ed66535a89632afa846aa9dbe5bee752695644af32cb4b469cb86(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1be0e98448a80b3b9d84294cfbb3f6da89704f0e09ba91560337e20b826c4f29(
    value: typing.Optional[PowerpackWidgetQueryValueDefinitionRequestQueryEventQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__88b2c5ce7bb3e4067126f4536a69c15c4f6370e57efb64436f289a325bb4cea1(
    *,
    query: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2e51a05a776e70dfadf05a728c4e2e3a606c6f3336612d9f616c174ff1b6b584(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__313a991252b0c4f57a29016640d4ee7888cfe8c6503893931f850e0101a17cba(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__20fcfc66dc9dea273e2f08f3c8679ff279b58492a5596a2da0f8d2e1a44965dd(
    value: typing.Optional[PowerpackWidgetQueryValueDefinitionRequestQueryEventQuerySearch],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9d1c3717e547871c6fb83980068d0853905596ba8410689998086ceee729960a(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__821bb32e518f00b1baf3fd746da6547fdedeb3cfb4d7696cd33cf15551deaa24(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__725f9ded0b15a1de75907eceb329ebc0fbed229b6cb12ac9c220a8ad5ed6d62b(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2db87fcaba818e2134e99fd3957b1eb285c5abcc62a228f89b48e24322470835(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__29bd1a24a95af600d9db77eeb5beba7ad67540e5c04323ee679d1424251697b1(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__015a78fc5249bbf6368b194bfcb017964d10d1c30827f5128dd60abb4da640b8(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionRequestQuery]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d5516dd97814a52aa30d4087502367d1a7327599c720f20eae2350946d475dda(
    *,
    name: builtins.str,
    query: builtins.str,
    aggregator: typing.Optional[builtins.str] = None,
    cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
    data_source: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__38a661dea927b3ca6ce82799655c7fab4ead44f4fefffcb7d6c5caaba3af84c7(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__73f913845107f208a0eb7c688728aee4fd1a44cba5e25db1558f009a17136d52(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c922281d6a268339d3f39f7b127d58c5bdd490ff5f38c38bffb3d01c2d73c24d(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__31ce03d8283c3f9d7409840447d6326ec6605f570baf97c8b9f3d6423c333283(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1789e80164f0ea0dc847ac5bed44a05c129732f6be114875cbd04f75f9d0cb0d(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7a308688c2866ff89723c60058f97fad667fd11bbc2aa72cc614315d379bd015(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d842cb52ed6a4bd5a076c9b020aceb1a8206c894a2c5dc2db95de51d9edbb03e(
    value: typing.Optional[PowerpackWidgetQueryValueDefinitionRequestQueryMetricQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__76864561a84e0130c5ed7c320dbb8f5ac6f0f59e9d6b2a7ad514139aba1c33f7(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3f6365fd5cff139361e4c3fe79b870c497e088fe39bdff2330bda7ea38ecbfbd(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryValueDefinitionRequestQuery]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b5b6f1c78d195e4bfe7e8f56fe5ea1632820ac68a63b6c2028f403e7d382f126(
    *,
    data_source: builtins.str,
    metric: builtins.str,
    name: builtins.str,
    aggregator: typing.Optional[builtins.str] = None,
    cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
    is_normalized_cpu: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
    limit: typing.Optional[jsii.Number] = None,
    sort: typing.Optional[builtins.str] = None,
    tag_filters: typing.Optional[typing.Sequence[builtins.str]] = None,
    text_filter: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d9941fa8a6c3da3d4f4b6eadd4662d076c7f83ee89ec2a9346b883452091621d(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__911d852ad7a6eda7ffd5247066638a89b9e3d4e61ee78d41d9402762e6c4e6c4(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6e5a2c74a0ab3a21fbca7e2c4e0091e30df1c1434e99ef84a016330b46d96ded(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fb353a32976a337a040bc7b358d7fac80dbdb3a183ddd2cdde57540912dfe4d1(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__58ce44771290a974378fb362c0740d3bd585d02e240ea1db01f34e26eae1ce1a(
    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__76b6e9a82925bda7f32f51c7f76390e196327d9ef1da56cf54b97e51c9ac182e(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d05814c23ff553bdd64f2685100cef9bef660004124c55303e5ddb2d51da3071(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__47a54fe36350942ab0068c071ac12e7fb09ac336118abb8d3fa55a28468fe49f(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d37d95ee208bdbfc3df3f5ce719e5a02b26891251c580c1740a57c35bc93a88d(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b148190f7dc1b9995b9c84f43df127b45a581a48741e164cb28f87ea55ace1eb(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ce2f06c98fb36cf8daed84ad2e5f99ce196056d557fd60b6271bac973c3c9b53(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0a9ef981c1a0c81259e150ee9c9547a6679bb71d11898f0ea093bc2a292ea1d8(
    value: typing.Optional[PowerpackWidgetQueryValueDefinitionRequestQueryProcessQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7e8ac8125fb20380f1860f4a5a0f7e93961142f43141ecd24c1256f55009ccc2(
    *,
    data_source: builtins.str,
    measure: builtins.str,
    slo_id: builtins.str,
    additional_query_filters: typing.Optional[builtins.str] = None,
    cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
    group_mode: typing.Optional[builtins.str] = None,
    name: typing.Optional[builtins.str] = None,
    slo_query_type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bca184e64bc61cf509f30660ee5c695024889ad04670ae984a450d731fe733f1(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__61c1ff364c824656065f4a1b62767d817ae473a10131b273a49d305776815f17(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e8d6148e2b5c15b5bce68f100309ee9d0d7d8de65f60fd74538a0ba018e8b5ed(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f59d641fde0457a298a0c6acc1f08a61e33229015d4c673ecb99dbb347efb29b(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__492eb2ef04e8470fb452b90eafb5acfb6f0358bc7a574c31c9be513b3f300e13(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a3ab408a128fc16b9693ea9c23e224ae27df3fd0f877286071259c2803962460(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__91e453d484c4c21dbdf027b4ce284a044283479ad8548a0102d9f0a04eaa2f67(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3866101c0175b8965d61d377776f4b5035272e2120a12563e0b119346c55e59a(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8ba178222b38a5524295737519d24a1af6f1c47f4daea45a5901cbe5619ccd63(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3e95d82f2a7d93ced31c1e87e79e569acac43fc0ac7b41a68404fdbf4bab031d(
    value: typing.Optional[PowerpackWidgetQueryValueDefinitionRequestQuerySloQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a2f05e0062e9d5027803d93abe6f450dd7d3f7df322cde557c58eaeb5c4f2bd6(
    *,
    index: builtins.str,
    compute_query: typing.Optional[typing.Union[PowerpackWidgetQueryValueDefinitionRequestRumQueryComputeQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryValueDefinitionRequestRumQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
    multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryValueDefinitionRequestRumQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]]] = None,
    search_query: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b11a5dc8808be7d7b4084d0c460143ac7670e97800287c049ae42763964f9115(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9a59c66ea74e556b240f5735b76219970cea655ac9d7b1c6b972d76a7330767e(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c29829addd78221cd8eb42287c588721b5f4a498b33071d4534bf0450b032016(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bedc4f1a44f1c4ac957f40de264243f213c518ddb8720dd5b1923d24e3ec781b(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9734c50954fb64fbebc661d7b42557e25fe6cb9b9b4908f19085a6e3938fe012(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1b0e3c9283ada1bb9fa8e22570872cfe737f00b8bf3db7870ee544be81327c0c(
    value: typing.Optional[PowerpackWidgetQueryValueDefinitionRequestRumQueryComputeQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5fb884831a39675b65f894580b8f436a3487ffb4b24c7b58144f23765d234172(
    *,
    facet: typing.Optional[builtins.str] = None,
    limit: typing.Optional[jsii.Number] = None,
    sort_query: typing.Optional[typing.Union[PowerpackWidgetQueryValueDefinitionRequestRumQueryGroupBySortQuery, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__efead7a16c6e9d5eae9797b3735a7592fd8a8d9a444ac598912012d2c0f43743(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1bf270630cc3c0d6c3163d8d407d6fe00ab5e47d85b11800373a01b2cfc9c08c(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9fc18a77104e398e207fda291cae9ed254586137bb57f6149692fb235b4b6590(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a3b3bdce9aff057700af86f423d85e7c2226a5d08f8918a7ae60ef32c6a57ab8(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4cef083d561903285113d66f607c17c1c40c8d393eef328805e30b0f19811a72(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2080aba88fa2418969ee31197a53fa3d7cec4f19a7e1b13d812e81ff9458d849(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionRequestRumQueryGroupBy]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__41f04e80a751bcdf9dd3b193c9fd3f0b744d995b43df726cf1caec23ec02bfce(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5642af0eb5bbbee384f9ad02beac309f34072cf9762c8069d58eb020c261f2c4(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__07210c0d3b2b6001ab94012e733da904722a8fbc4045fa218e9ae5a53e35359d(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8f3472765585136e3281178632fd5f12bdd1a1bbad37d5a6f80d8001b209b9e1(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryValueDefinitionRequestRumQueryGroupBy]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cc51cfe33fd866b587a6540d85d55a078ae895347a2ebada3df46cccc3e8559b(
    *,
    aggregation: builtins.str,
    order: builtins.str,
    facet: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__974c54782208a7495a1cd48d4c4614c7da680f1dd3c1b095a690e4b2da45721f(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e3e3e4c3fadf90643e33337c31e6db5c780abe1b03435669dda5fe4b22af600e(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__09785c1fcc2cfa778d0a34543d3a5545f7b83f41f9b20e2437af00aeee7d9559(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9a1ed1f9f8b9bab160b72fd4d5952766e3df00acbc1e10dbda6d7d82b70d5616(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b8856cd8ef330d3f5d2b1e07baa35d7b866ad127642f3f8cb0515f87e711054e(
    value: typing.Optional[PowerpackWidgetQueryValueDefinitionRequestRumQueryGroupBySortQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__545679c8a91a63346e1f5804aca3fcd8325234617a183320e8faded413862609(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f131465cf167124ca0c133289a4f177483952612fceaadcae9f77badfcf74b0b(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6871a370f33117787dbda4eb05e91405f0b3352c12cc3ae18da1d4a3d0cd4c88(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__72106daeadb7e3249e9b21de9c48cbd7e57a9998eb643f94077a9af5c4b00a7d(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__146ec8b91af6be8179b33272dc1ad1c0b2d39efadbb5a4c627c009eaa99c74f3(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8000c3f90fcd39ca69bcbddb2b7bf155b0b0c8d9f6104b92d32c885b0cab43c3(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__38701e00a4b6ed9cd990605bb9a5fa2dc362172047e48a5715fe444f0304a5be(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionRequestRumQueryMultiCompute]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6f7e6f414f8b85137428446283e066d7679f917e34ff29016ce92e07762f1b9e(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9d97bbb05a28b28f08248d3443d300a597be0bc21b271278288da6081a23579e(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2771da955efc56f966fd1556aab7803796d0c508a3fc4b68d42697d8e06cdb98(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__efa9ba626689c9cd702655afee12d11d499edbee6ac8faf3e2abdd39ecfc709f(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a52e185ff0f4204a7e6ae8939bbcff28169371b2a63171f269f501831f699713(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryValueDefinitionRequestRumQueryMultiCompute]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__aa44c59cee0d757d4124a1118fa68d599c5a184293be876644b5f311771b3061(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ea68325b6a1b4b266ad7ee3a12a6228d992d42a3b444f46787ab28e0edf66051(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryValueDefinitionRequestRumQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dad2cfacd5bd14362a606318985e504d5018c3ac48871e7d59be771e547e72fb(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryValueDefinitionRequestRumQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__594f322ec92b34e5c99b5f08eb685b263ccb42abbe874cbbf43bd84e585d6017(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f47ddab18c6b3180ea5d5628afb92603d829173ec2006db18ab44fa7a9664f17(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4c0813d7568c758982c0577444df0bcf777582532400cce26e330500b746ebb3(
    value: typing.Optional[PowerpackWidgetQueryValueDefinitionRequestRumQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b2d0e9236761f8712b6d4e1ee03b2774af0c5a4cfeffe87eefbe00025cdfb450(
    *,
    index: builtins.str,
    compute_query: typing.Optional[typing.Union[PowerpackWidgetQueryValueDefinitionRequestSecurityQueryComputeQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryValueDefinitionRequestSecurityQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
    multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryValueDefinitionRequestSecurityQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]]] = None,
    search_query: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__34253fb2198fae930eecea4c83e15984e514e534fe574abb429f94a6d4789dad(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7538f667f134aebc56dc788a15175285dd756f414c17a81e5eadb0c1ccbd7efb(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__67caf903fa7cd0eccb4a88d18893d66bbabd6b9196ff36e0c2808e8ba7141f9d(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__02aa9c11240953fbc1558a66376a8423ea6212b42e2181a12d26b35a01495db1(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__308379c2be08cf384c9194c27227ea2073509b11cd8e32a17b0b102e9f1381a8(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__31c475dddd7b80f62653490b2846f654d7a14d4b021595ea45eb6fbea06647ff(
    value: typing.Optional[PowerpackWidgetQueryValueDefinitionRequestSecurityQueryComputeQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__88174f669e16c140f59517cf9ef6248f96e5ff15203827f79d2ea70fa20a4df6(
    *,
    facet: typing.Optional[builtins.str] = None,
    limit: typing.Optional[jsii.Number] = None,
    sort_query: typing.Optional[typing.Union[PowerpackWidgetQueryValueDefinitionRequestSecurityQueryGroupBySortQuery, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b4f88af8c40e5c05e31d7dda99c21764b157ff723b176398c04e4dc1b6911317(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b2b6a170b6cc34720907f41f84598a3ef5c9bc96afce6d986adeaa52f40f2184(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f3092dde51cce3359bf6bf185774accb91f561d2a331007d05bf61666106b91e(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f8d002e29398ebdcaf2e07536e179050218bb94298e148aee6996322cfd376a1(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__74ec8fbd06810dad9deebef00b5464439d7323d2dc15cefd9349a09af651e812(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b473556bfba5929bbd4263e5ea066b68f168f642d83a6405b118603da915da49(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionRequestSecurityQueryGroupBy]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__426d29516ceb51f3740171bc17e77b1ac389c25e6f1a39eb2e05802c2a585c47(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c661a11e3a831635426dd92e83fccdf9683802473c2acab06681b67ed7ad6642(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3bd1a728b11ce3d130789b487408c3eb32822fae53a1cc729ea497eeb9beeef5(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4d793a119b51986fe36a1c33b79f34448bd8230ae9a8840ebb20f93b41f27c6d(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryValueDefinitionRequestSecurityQueryGroupBy]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f27fd8da6e7dcdf099c858b74ad9c5dc4244419a9d9018d2ce75563c11308fe8(
    *,
    aggregation: builtins.str,
    order: builtins.str,
    facet: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__99920275b613216b49f95c940e0508bec5eadecec93714528db1b3d174ce7b3f(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5a36678d2a144e3a04b7daec203ac61b09470c963adf5819f68c3cc84fcc00cd(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ebe73c7b024c0f04abce1dc8e33c8c1e33b05cc0dcf4cf482b9686faa972c650(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c25ca72636fddc071b3748e989c99cb2acd00abeef9074fd040aa6ad61c2ce88(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8b0a48b76fe907abc17decbb84ac3bb98bffdfa2dbdd8bf395e72540e3936bde(
    value: typing.Optional[PowerpackWidgetQueryValueDefinitionRequestSecurityQueryGroupBySortQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8668a910d4d62a71d16cd4e3d696c39cd3333a40fe4f8081e8837753e0a8e1bb(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__58a9b0dee9ba85a4c4b73c79b1de6e038359bf1f583e8b59c6e8bce8db583451(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__37e688d1a844ea73caeb3c4e0c5d5152edbd5d6e02c150876762e9c88bfde407(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fa0b92281d8b55b35835bafd1851ff291faa7cd07ad0b5d76bfccad92fc5fe14(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1a2e1e187520ececfe9b015f195414c46de071b29a1108cb4eed2be23e00b51b(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2396afa5f93fcf767abfb2d542450f1026d5d389a4cdb1661402e63ada0acc4f(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__99aff0597e2948fc8543abb4949ec09aeda1606a02994820fefd847b592c1916(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetQueryValueDefinitionRequestSecurityQueryMultiCompute]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6980835a4f0c89e629c757aacb3182fb8cc6a471d7d8f92f88127d02e91b8d11(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ee7ea4264f49ad4ff6037203d0b6d747539c115d64d98bd657c720faf2df99f2(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ca61c59ae7d42649af520e3c2ac9b72e588d9e6defc7e5bac450345485339639(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3b62bef07f7e3746e6e43d09f77b48c9dc5b3d78a818dcba1fa6be8c9a69a0f6(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__20b35d9468077f96722388ba46e3b2dfa185ea571f314309480b1aaf2a8c0f16(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetQueryValueDefinitionRequestSecurityQueryMultiCompute]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ebee6fe858dc874c486e725a122aa6cc68d071e73628f26d677caa2f4d3f4921(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__372fa5a65810eebd9b8b465f65bbb798a0cf2a7b7b18f96fadf8905c009890c9(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryValueDefinitionRequestSecurityQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a7f160171783e74cc215dfbb2f5bd428f9d2ed92d251c4a233cb86a711d957d8(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetQueryValueDefinitionRequestSecurityQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7889864c3497d793f0eabd61095230433d43d4eb55e28f48cc9711ec198fd861(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4698e48afc82842a9b8f2e547201653dc9b68e534c2db30ba4ceb393500813fa(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__89bef1a552de2227d64fc47bb85341bc60c4b8c51ef260e91e41634f2c7a68f5(
    value: typing.Optional[PowerpackWidgetQueryValueDefinitionRequestSecurityQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ac1b198b91ab539ce18a8f621182c864b9d492e13d4df6a4f26a2d0b9fb2eac5(
    *,
    type: builtins.str,
    yaxis: typing.Optional[typing.Union[PowerpackWidgetQueryValueDefinitionTimeseriesBackgroundYaxis, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9a1baf9c23ca4cad8428d1310d4657e82c85bc0546739c34ae9d38a3b59972a6(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a1a61aa512ae153f10a1ed8f15f8cf317d9ca2d2e88c5265014c9315e4a5737b(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c16aad3eb0f425da8e2c5644430bf90b0f5a57a8f37801e2af0cd3b94b55149c(
    value: typing.Optional[PowerpackWidgetQueryValueDefinitionTimeseriesBackground],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__852972f5c521e090a44acc49f2c72f9a1f9be8c3b853393caa51f1354026bed1(
    *,
    include_zero: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
    label: typing.Optional[builtins.str] = None,
    max: typing.Optional[builtins.str] = None,
    min: typing.Optional[builtins.str] = None,
    scale: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6b055dec7b59ebc42f83ec38b54ef9d14d2e6a14d59e60b1bc749f0ad5513b22(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5a08781fcda5bc0b7bbf719b560ce6931a308e0d3f357dc09a1a54f051eecd9c(
    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__93eb9434e1a85792b301339647014164c3a899f51b254b64c9e1ebd12716c4d3(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2523e4d92dc921607486e3198063cfab7523996430cd709fbc2500fe1bd9b700(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e6051355f65bfff507a8b7277bf88288ac37c8d76a560cf1befd267548adf62b(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dcebe61a1d5456c39b0448e12d3dba6da36dc8af7fcc1dc6a5ef13114b140a54(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__106caa13a0c71fda2182b323aeb91470cf400cc5ee55210545e2d43486e679e6(
    value: typing.Optional[PowerpackWidgetQueryValueDefinitionTimeseriesBackgroundYaxis],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0b2183c46bcf174022f542964cc7b2c27fd3fa610c14faa75f0edae30483d6ff(
    *,
    workflow_id: builtins.str,
    custom_link: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetRunWorkflowDefinitionCustomLink, typing.Dict[builtins.str, typing.Any]]]]] = None,
    input: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetRunWorkflowDefinitionInput, typing.Dict[builtins.str, typing.Any]]]]] = None,
    live_span: typing.Optional[builtins.str] = None,
    title: typing.Optional[builtins.str] = None,
    title_align: typing.Optional[builtins.str] = None,
    title_size: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c14523faa2ae9d753a58060c0311cc07110cf439c61847795b6cf95e8fe4b344(
    *,
    is_hidden: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
    label: typing.Optional[builtins.str] = None,
    link: typing.Optional[builtins.str] = None,
    override_label: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b3324cd84cc7a60d676cac235f75f5ca2b5d415f5d69526105f8478e22713bfe(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2ebe154c0687ec92c8097ea8ca74d8dded2120bf3014f0e5f3f5a1083d0f825d(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1a1a8d0c27259853444f29f41f767e15560006d2ada86870f3c144feaea75242(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6de7923bf414cd270d42e82000ef0db3d63d32beea77cadf478fceaf126276ee(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6a8fab212edf0f70cdc1b3adac26f198cdd2b32ebdaa96ab428aaacbcf0c2f23(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5f154ecb27d71ba20fcbfe170eb619ab13805e5c25b97277023aed9c48642491(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetRunWorkflowDefinitionCustomLink]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f2579bb5d66005c403c93cd629d5ea76d4cf42dd392c4fbc92c30b45aa3c8a8e(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__75a8c8821bfea5eaf578fc552b34b1d72a7a51a7cafce5a49715fd7dd6db0ff8(
    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b76af170e62f2aaa27eed067cdf4eaf2b4f405e44d7c34c9a7c9b37283610e7a(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__abca52d30b001d32ab297782c02f338f9760986a74bf01b3ee38c4cdfc45eec5(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__56774a92383eba548ed72019af4ead8c0772a1379b2e81069ded7324748ae1aa(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bbceb8ad91c0f9dc4ce6442f81f26ea554b1738f62e8dc3627fe446962058396(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetRunWorkflowDefinitionCustomLink]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__42ee91cd974955698dc0abf7eb15032499c2f653812cda80992d6149a5b2e2d3(
    *,
    name: builtins.str,
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__14e3831ed5d51c1b1b364cc71e2a3181c4bcf11de08076f0967a37f862ef523b(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ebd67744559a8789860126a738a658f60ba44da928ff6abb33ef516cdab83df5(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__16891624eb04e56094f3dbf57f772a3f49ab02073c4741a41e8de9ba11ab8319(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9548f6b50edb69c686b190f5cf1114c39dbd98d8c1e87067f64d0ef3bd1729b8(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0f1fc65030e049defaaa223e439910ee924b583f65a8217c4e46677a530fcfd1(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fc5cd306fc0631dcffc2878afbef50093b973ce65dc684647e474d2f8cc1a319(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetRunWorkflowDefinitionInput]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__de532a03cfe8bbe80278b5849031b33a500b425c05a46e67d89f23671eacb5e9(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a6fb9b55cd202b5562b72d04c314d9000091814ba63115036debd8457514f92b(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5ef93059596f21429e3b3d57d66e6d007d29093406b574055deab4a6cc3e46d2(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7f677dd2d33726c5de799b5236105367ea8a079e95d0fb0f243605e2f36ffc1e(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetRunWorkflowDefinitionInput]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c60b912b9fe6f85e1bd9c2f83853c42c2700387efb28d8ba2c05ebcea447410a(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__014454659bb506c2a482cdbfeb629912be6907780d37694bace1c8bd9256a8aa(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetRunWorkflowDefinitionCustomLink, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e7df5d1f2b754a4e173504aed0265b30e6cfc0fa96eca9aaa9e2f89c22782def(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetRunWorkflowDefinitionInput, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cda7c32b898d8b14b38545dca20d6c3f7eef46b00158b73d7bb7708125b49de8(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__73546b845c7c16bdab6713dacc2a6e0309f7a37b9bcbbb9f51d28d38129cd109(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fd3218cc0a021791b6bd50323fdef193bf4da661e7976d5c6cf37a7358a4e1fa(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f121e37fa3106c172991a02400b5134c8ba03bbeb768ecff60bb96ce8010e313(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e8b9770932916e2b0bcf91e9473e5ad80bf486c53384da3783e7a9b34dfdb58e(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6000f737817b4c908c0f88fbc45ba0d5c797f1e7a4ed3c0c8799619d36f9bc7f(
    value: typing.Optional[PowerpackWidgetRunWorkflowDefinition],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d10709bfa15bb2e27015dd5dd582d1b74862a9f4a789d7349965d37fdf3f1e66(
    *,
    color_by_groups: typing.Optional[typing.Sequence[builtins.str]] = None,
    custom_link: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetScatterplotDefinitionCustomLink, typing.Dict[builtins.str, typing.Any]]]]] = None,
    live_span: typing.Optional[builtins.str] = None,
    request: typing.Optional[typing.Union[PowerpackWidgetScatterplotDefinitionRequest, typing.Dict[builtins.str, typing.Any]]] = None,
    title: typing.Optional[builtins.str] = None,
    title_align: typing.Optional[builtins.str] = None,
    title_size: typing.Optional[builtins.str] = None,
    xaxis: typing.Optional[typing.Union[PowerpackWidgetScatterplotDefinitionXaxis, typing.Dict[builtins.str, typing.Any]]] = None,
    yaxis: typing.Optional[typing.Union[PowerpackWidgetScatterplotDefinitionYaxis, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__84af1d7fd896478dbf0b36051bad0d112aff33563650b04f746523e2a32ebd05(
    *,
    is_hidden: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
    label: typing.Optional[builtins.str] = None,
    link: typing.Optional[builtins.str] = None,
    override_label: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8418c12d81e2ad8dd254765c293ff50c93e2abad0bfbbe8f6d492fdc0cd68b4d(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8ddce7337c79d011c488366f10de5155f43ae0f267c557955cddce332913de6b(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5be37c69a8fb5f07cf497d5d3b3730f86ffa42bc85bcdbf4e137fdea20449b29(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d00d85c941af48cffc32dca800808189cc34b611070190dacfbf2aedd6f2a15b(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__84c85c331bc2cdbfc4566314160d0c92fcd78f871e5b72c054376af2f3be5a2c(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__215e6276070abef97595e66ea798e0729e3926d058c6c991bfe0f9f1ecc7533f(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionCustomLink]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bfa43a7e31db9615cbc4030ca7a822842c426f7d6ca356afad842e08ede829cb(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5d7045cabedf7fc4af3fcc3bb0c91f8976345a6192b8f4b595b30358fd4a6b19(
    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__04bb9805c1d8d8e7add9481bc0e7c0857149e80c74b1fbff25f79cdedae19c7c(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dd28f1e27f32351621e6e71789652ebbcd73c10082dbf7cfd2eaadcab9e06379(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7875940ab5022aa32f6c8a4743c77c0c73fe57726dc3d9cd8edf2b1b39138157(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9b79d855faad8904895c4775c3ee3cea72a94b36508d3632c307c74381ba752c(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetScatterplotDefinitionCustomLink]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__968b207547b2369ef4499c4129b05fc24fd859eea848ee1d1328f882d0fd3a15(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5f563893315b24fd1f7c21c7db409971fcc5cb7c66869b3245033cf6921cf7b9(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetScatterplotDefinitionCustomLink, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5ce260b7bdbe7057535626839bfe60d7cd4b13e00b16bb2d8cf2d1142979be84(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__daa1e81a7d8e7e6cf2494bd4ad38ef0b5fb7643615cf1c6b222e8e918cdf65b3(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5e3b4bfd398a2cbd80900856bf140df975a8063525dbedc0e63a4fb75511266c(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1197190948e41eed4abfe1ab79515a7ea77d21140ad318899a7cd6a073ae0417(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f278d6689bd8aadcc6abc191094dd4735a7bb951bff7b4683453545e87da4b30(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7ce195bdeff5c86c78c00debcf6cdfa13dd9ed7e50b60d5432246d8419fd8548(
    value: typing.Optional[PowerpackWidgetScatterplotDefinition],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__057f8c8bc1cbcd5d113f1076f35e6dc9ca3446ea94dcf16869ece5bcb91d5969(
    *,
    scatterplot_table: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetScatterplotDefinitionRequestScatterplotTable, typing.Dict[builtins.str, typing.Any]]]]] = None,
    x: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetScatterplotDefinitionRequestX, typing.Dict[builtins.str, typing.Any]]]]] = None,
    y: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetScatterplotDefinitionRequestY, typing.Dict[builtins.str, typing.Any]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c329698088f12915cbdee68467f85fc5d59fa46047dfcf9eb9fde55e78924995(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__628e691c46f289a0adb7e9be538bbae14c08e0b9237bdbfe470533d661089a33(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetScatterplotDefinitionRequestScatterplotTable, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__460e6b4f5433d15b22ff503c6e64a9dc5a82445b6da4d8d7c75e9bdbaf594f97(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetScatterplotDefinitionRequestX, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f9008d37060b22d0cab5c6c309ca6760ecfb075fc2277d0dfc5fb9b4ef613a93(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetScatterplotDefinitionRequestY, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bb023c50594df625dee6ee876dae952f149c20c8bd06ec559e12faa340697311(
    value: typing.Optional[PowerpackWidgetScatterplotDefinitionRequest],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8cd1c75f805da40e078db02810f38122cf221f034f7141a843cbe2437e319b6a(
    *,
    formula: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetScatterplotDefinitionRequestScatterplotTableFormula, typing.Dict[builtins.str, typing.Any]]]]] = None,
    query: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQuery, typing.Dict[builtins.str, typing.Any]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b5f96303bdee6ae64e8a6959e9f4d933a8c30d27b124333543f865ad9e17f2d0(
    *,
    dimension: builtins.str,
    formula_expression: builtins.str,
    alias: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__531377c71d303ea15803fc0a10d0ba5a1064f1150bf457c07b7e0d220a8136e6(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f432a5ed4970afa8ff50408bf529addb8e421bc2a894256f92a27a1c051020f5(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5f702194a7b9d4d648024940f7fc4c85c9531ff7459c05cf6f707d1e873ff241(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ed26edc1af84ddb4e1ec73929cdeda8669c847a57e4a2e91832f38812cee6586(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b70195b0c28292123f404a906d5662a7ef9cb0195c1324339aa29a9f611d032c(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__665abcdd6c40cc73cf465b67bba9b291445c8d919d0b8e764677303612c85a4e(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestScatterplotTableFormula]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9e4a1d48730aba2d6c4504a1e024c9889ba20dea4f5113164868eff3e87d8573(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__385baeb7163fdb577c33ac4dc7a70499b3fd061c56d190ad72ae3e5961634580(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9e352f85d686fae27a580a97c0df7a9efe7cb90061fdc50c8705829d26a73619(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a2cff983cedf8cc111ceeb58e4031fe5bc82702666104804f9f2587a7f2c6fc3(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__477738b3cdc74a55daf41245eeb738120fdc7db1a899c3f7ef8e46debf990436(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetScatterplotDefinitionRequestScatterplotTableFormula]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__aa143f93020e40e008b28dad3ecd44efed17d7713261ed7d6cee5807f2d23e96(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e5d60c8fe8b97a2e5553a4cd85e8776a94149f708b29fe4b9a19d05491bbd93d(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6e48bd220be7e52c67dd69d4729d5e6d481246a83a796205d9b922fb01060cde(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6d3a3800433ce66b57cff95da7724682e693fe0a45605e0780051f02c614f513(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9763e9a7ba5ef7aa2bd6d103aca95a3909f9d870e55374d57f18601bd21fcdf2(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__942d907cb7b66214cb5d3e91ec530fe77cd42ec3f5572848b40ebc40c00b5e9a(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestScatterplotTable]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bdd870d354a8b790198fc5d435c3840d8d968957daf70748ce0f1a9811e8729e(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b8bd2ec6a9d5f035e6ffccbd0e74c05403291935b554ec6a2b8f3b7dbcbcde55(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetScatterplotDefinitionRequestScatterplotTableFormula, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fe1e68179e4be18ed6a4c52ab4c0b38f1d088998ef8f1a81cb89a1cbba4f10b2(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQuery, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e0e7c432f2bd03e8e1366c8871e1a2ce628ddcece51b0eb7945a323ea532a889(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetScatterplotDefinitionRequestScatterplotTable]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2e694451ee73e1f6150093d10263a1883ba6521527062c39c4c6f3e31cf2749e(
    *,
    apm_dependency_stats_query: typing.Optional[typing.Union[PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryApmDependencyStatsQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    apm_resource_stats_query: typing.Optional[typing.Union[PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryApmResourceStatsQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    cloud_cost_query: typing.Optional[typing.Union[PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryCloudCostQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    event_query: typing.Optional[typing.Union[PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    metric_query: typing.Optional[typing.Union[PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryMetricQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    process_query: typing.Optional[typing.Union[PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryProcessQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    slo_query: typing.Optional[typing.Union[PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQuerySloQuery, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cf113f4730868b12458e02706ef914c06cfbe2e677683a5678b40ffa57b6beb9(
    *,
    data_source: builtins.str,
    env: builtins.str,
    name: builtins.str,
    operation_name: builtins.str,
    resource_name: builtins.str,
    service: builtins.str,
    stat: builtins.str,
    cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
    is_upstream: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
    primary_tag_name: typing.Optional[builtins.str] = None,
    primary_tag_value: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4bac5d2c4e4054bf817bb0072bb595a1900ea95dea84c7e5966165d35a4d922d(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__51b34c1937bd33e97ed44442e5542e871705f719b3a2d83d7bfcfc37d9384ebf(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__12f6f0338d31d29e748b36593760334c916e547ef9058cd1873479ddf4427138(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4da22da386bad2884f3b8b6bf2d85565cc0353820a09b66e19482abb2064e6b3(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8ce0e554f151e87187a11f27bff350868357e598a95b0546eddf3f3108dcafc0(
    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__093a6964e810e710536b2da4d7408e90432fee2fd21d2ddbf7d03981ae8d74c4(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f56140eab51822bdc0897d6456f2fca9a4240f2d238a625c5248f2976faddfa6(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7b89ffe0f91ead35cdab02230791a88f4b1157091d36256920d66594dc9b77e9(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6bb2c4c186e480717172aa4cbc2a115b82ed3460da90dd01ad670c79d4fa52f3(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5fbdea236e6d46a775122c4928e29448858243193d7d625585d92c886aac6751(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__84265b70e9db05d2f568dd1f4bd87649a023270213bf886b53d3c2d6da262965(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6a608dbd4d59406c706036a74f6123973eceef60681c8cdd44e846f2d94f7916(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9d5a6efed4ac688fe156abfae36c8186782c116cafc2b47672d765aaa07c26f0(
    value: typing.Optional[PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryApmDependencyStatsQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c2ee3e6cc80e8c82c9eb508c4ce4b16351ba597efef48393ea960c709a8daed5(
    *,
    data_source: builtins.str,
    env: builtins.str,
    name: builtins.str,
    service: builtins.str,
    stat: builtins.str,
    cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
    group_by: typing.Optional[typing.Sequence[builtins.str]] = None,
    operation_name: typing.Optional[builtins.str] = None,
    primary_tag_name: typing.Optional[builtins.str] = None,
    primary_tag_value: typing.Optional[builtins.str] = None,
    resource_name: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a4f4f4b57995a670469811233f12c4bff874c2398551b8e56c8524341f0049db(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__918f4d5cb32eb6a6e5fa0d0c9ebfea05de79ddc1f6a0477aa289d1a4513cee7b(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2837f1a61142bc63c6d810f5bc6a996ec28e1ef5962ded84966c05abb50ecb09(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__42c23ad3f86cae9fce3c416a09507253d7e16cf678c701b7381946b6bd0607a5(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5f108722ff7835f2079f6b88e3e302489316e6d8aad6a1c2b38635fc3dfcfe94(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5b6bd7fb4c4936c077085fb2cb38117c80505dabf6dec0fb2f80cf58fd0236cb(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__52155c80905bc6087fea1e76c390a46567e22970d93f7e4c9c4464c4618714fe(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7fc09d73d420a7c3e785a396ba08615ec289f1ee63efe7854f007697a5e75a47(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6149fd817f84cf668afbacc73a2b91f6673d971b439e738f124c3f580b497349(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8d8ae8603641d57031426c5ea9fd97a5fd0e3c3206836bff68867a104b2d4ad9(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ae55d67f6d0e7d18162135c50e405e81c0f6e61ac03f45ec29360c5a50f63ae2(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e36977653df495a6674a62fa930e1d9d80c6a3a73152e6254bd79ad8da5dd688(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5bc03de1db0ef5ef9a3ff47ea2d32a960a4f2cbcfde60ec1f4307b0bea11a914(
    value: typing.Optional[PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryApmResourceStatsQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__783eeed3cdb04ac238804cba42f93e01d1a5d50364785b6929507ea1ef3af3b7(
    *,
    data_source: builtins.str,
    name: builtins.str,
    query: builtins.str,
    aggregator: typing.Optional[builtins.str] = None,
    cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b87bc5a937f989fb604f584d2a514cd1a0e94da1375af5ba23576841c5b56275(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ca4d78e2e7dcf40b874b2820ec67d315e1fe8a93f2bddbcffa1693503b28a6de(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8bf1dd44f68ac5c16faa8737ab92e77b33cc5f4a674215120f02cfd5840050a3(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__03c4ad34d034abb1c1b31484292db144673dd3e06c14905cc6cc056f2d093e41(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7b4f50b8d449ef1e44cd7a20d8859fe8fdf5fd99ef381686183803e82a364e55(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f2deb15e1299c0657e6e0383bf1ff878040906662602fa729f0c7003a60ab0ce(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0c5156d6a8698448958ca5fbf0691b9df90d35a732e0481427be15a64e35e06d(
    value: typing.Optional[PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryCloudCostQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__44c65c685f014b0dd9944555e2180e9a699ebe687396104df5b8be45972ae41e(
    *,
    compute: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQueryCompute, typing.Dict[builtins.str, typing.Any]]]],
    data_source: builtins.str,
    name: builtins.str,
    cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
    group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
    indexes: typing.Optional[typing.Sequence[builtins.str]] = None,
    search: typing.Optional[typing.Union[PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQuerySearch, typing.Dict[builtins.str, typing.Any]]] = None,
    storage: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__146a1f4463beb3172e4b3a4473b4611a613e8d669549573806315165e6b5abf5(
    *,
    aggregation: builtins.str,
    interval: typing.Optional[jsii.Number] = None,
    metric: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ffd141e4cb4e8124d8bc9e6178ef60ea9248489bb5eb29a583ece2505a3e040a(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5e9388319e8b6b00ee0c542abbf4bab7c41bde6e7d895aac322fb263b8b9c75f(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__04d13cfee0cb778be66c4f0aa376ef7d5994d6cc932fe4e8745616eb6b923d57(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__918dda8e52c13ca3129ebb50eb0700ab49ea857a9d49e213313800d78f326ab7(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d8f1d9d0b0e7befaf76992f2808b4fd7c35b0a606f1c8c9833ff6f08d3408c0c(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4f9295f4ae7842792d7179809cc44ed8824eedf5c7b8f5d6392e5736c7244654(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQueryCompute]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__184d80cd5b4e72cd86d4a4dbaaa2560dde28926aa227637519b54d5e1d2b2e06(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b6a2ff0c294a6e71b6166081db1c60c4df1f2b727eee86f122de122947df5733(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__08a61c6cc879aaa7f50fc14fa486e02f343ea6f8c691d39e796a653ac72ac347(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f63b48afdb972e1a67368f582f9873ee2fb7c437bc9a666c36611726d351bbd6(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__776c1ecd54001a63955205a5baaee4e579e21ae5fabba892bd21edf5bf12de8b(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQueryCompute]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c8a0740fe4dd93d44daee94b54e1e5746aff66ddae3840225cecf5767f98ac93(
    *,
    facet: builtins.str,
    limit: typing.Optional[jsii.Number] = None,
    sort: typing.Optional[typing.Union[PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQueryGroupBySort, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ba668dad112e83b366d90c692585aadf5d4bbfcef3ed63fd2dcd27f77be6e5f2(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2b74d10c5142d19cd736ed9a0c563e594b02b87730fbd3d1a3c84993c745f4bc(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c876c67a3e1d309f1264f3b34f0f46fb16d56eadd68edf856aaf6a4e1db180b3(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9e57629e9803138ee2504650c34ce6fb1f6190124b26805d5ee1e1c9eb1caaed(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__db30cf3278a15c9e8e5d94f7c53259d3ea16dab8debbd364d3e8a8450472f854(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__93b56d97b21ddb2d41e0aaaaf75c71ed7a39281d0f9219d6c292acdb6c0a747a(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQueryGroupBy]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__848ac0f9f68d2de4b9360882cb8c5850088b79ec3802064b773ff208a8fb91ed(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__02210ef287bcb70efb0be067a6f816f641cb91135a0e67b0dc74bdc3ffedbd03(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ed85c985e4f615832c010e13b023f7c5b93d94145b542ab13b4deaa17d04a32c(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c431275bdd17f254638c20e585a6d68d1b72fb491ac2efd6bac3c82ae19853f5(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQueryGroupBy]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2f4ba271bd12c230e07e59a303c4a43534af928022385705bdc60831ac64d2dc(
    *,
    aggregation: builtins.str,
    metric: typing.Optional[builtins.str] = None,
    order: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4f8eed02a8c4bc79de0653b74f6a2057aadcab29beafe71296bb217bc51a0574(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__125673fa346cd88b2dde2d5d6f7de0ec4a5f36a93905ae7fb89010b402f729dc(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__17528f5c58190490d23ab9a4e3cf583e2b2987924c5a1cd6795fdc742b1d933e(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__48e77286c34a378f4bfb7b7c849389000041b4b756f9de268f5445c8d2ba1248(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9531b830afcfee490588274edc69c62911245d4ba222448cc28fae18d29fc353(
    value: typing.Optional[PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQueryGroupBySort],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7df8e457ac20acb5dfbcc35b2b2f96c7ab6d641bba9a67d67dca197d7a3aa278(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5a431b4009e2f0f388598198dc339e04ea126e570ed3e80522bd49e3fa1b962b(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQueryCompute, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__604f2bc3957ae86358c7b6384a337437426ab94023d10a386243a2eae734baac(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4985862c72b9b0f00a131bb9c141feb3040d91216e048e03aabf4f868ca7b2b7(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4d70016994255e2fe812ca5a81dd7b50b593d0957524caa683cf77689340390f(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fd70e4a6fb36f5399974f8e9808949b8f4a2ce30b7be13efeefd32d06d8374f2(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ca3610f29019b72e160bc00142b595a9dea7920862926c560b1f4251ccee619a(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f1a90d8b3e06cc1b2a8928a38a9d3dde23d4b13f7bb28bdb0e1d04059d47f507(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c07d00a257dac45333530089a9992c271f771ee850fe53dde06b088f34b7a5a1(
    value: typing.Optional[PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__73f8f865b05d7a55d6c792ec95f0ecceb1d5f8f3b1b8817858f3898bc745ae26(
    *,
    query: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d72cc844f0c1d4e0e0a167f7a1412de1480fc2c697ceaaaee09c2d487c6a04ca(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5c2bff2a32dfd68cc87ca9f6998c4bf421c384b44868a6c16d4cad1ab6feb868(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4440503bdfc10acfa1c7ad8fb120a895d0f5b7e481846e2fc06d8ab3901c39b4(
    value: typing.Optional[PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryEventQuerySearch],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__abfb2ff2234f38c827f5fa9a65f7e8caef9aefaa66dc3af97dee09e0027853c9(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e2b009a35c4bcb1741992e04cd4e17eb251d1b1da1a961be6a1eced2b6836897(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__46472bf420b8a74939f88a145e295c1f1581496ab0d7703ed9b0447c1cc8fe8b(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__187a4dc9cfc44b0bbd31fb12acf754b40090b7d4aa01861c010f33940c865504(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__db70a2fa7b099c3782c304cc51017a756c55dcf33bb96ebd8ec473a8052fa7b9(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__33a53d9e0645ab38ec8a73214fae1e0094464e39f905da924d091413c59598ba(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQuery]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f3d4650483b8798b6bfc4959aef53a5c5686cee12e0c6b679a38a76b6a0331a8(
    *,
    name: builtins.str,
    query: builtins.str,
    aggregator: typing.Optional[builtins.str] = None,
    cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
    data_source: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0790b2cc53254f5db4955ec30851b8239ab9a15f29af96bf6b15801398e0e2b3(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7a9fb005467ad30eb9724011e7b1fce0ad63bb5a9a5e1606911f3711bfee08ef(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7383c3b092e3bfe5de7c7d2184e60992438860f637ae7bea288116eae58f2123(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6e559c26bb7b3b79023461d457aa13ead3d8bbf5dcf254491f45abfc6a71ee85(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c64a0a54a9f4c37689a4fa3b7b9effadc74372185ef4a7e746d7db029b5f95e9(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7182274fd4705df52af754b44a860b9475188ce04ec5fdc418bc3315e0049f61(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ad24ec609b004e931b30bb2e28dfc6c342e5b16c5e97f7b89e0782ae12e35059(
    value: typing.Optional[PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryMetricQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__207fecbf81003d543a119cbac42fa205b0d67cb60b1931e5684e1c5d070ea4ca(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__25b4605017feba5c172a268ba824398981cdf41faedff368b0993b28609f802c(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQuery]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__348cbf82c6637be8ce295feda6d8817f8228d0cca7c5d309e5ec920449dad04e(
    *,
    data_source: builtins.str,
    metric: builtins.str,
    name: builtins.str,
    aggregator: typing.Optional[builtins.str] = None,
    cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
    is_normalized_cpu: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
    limit: typing.Optional[jsii.Number] = None,
    sort: typing.Optional[builtins.str] = None,
    tag_filters: typing.Optional[typing.Sequence[builtins.str]] = None,
    text_filter: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__180617b100d1563310fb4cb2bad6cc587202365691ba72ff46e17e14fc8b1457(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b0ac73f466946d83010d9b1760b7436814d371b87b1424df904c21725071c3fe(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7f02012f75e2b857651a177bda9521db736c359a6df3699720e6d5dc528ce6f4(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a28e8d33136afba67680761c0b413459e4b42740a1bcfb901cbd11d18abaca9c(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8121fb044e9eafc7fd53526bd5e64db250ac2c8c6a2e11ced8fc20c7ee025476(
    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__165fb1edac003b50641bf960013c4ddc0c39202015530705d4a2592e7df61593(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__87f13942610367b66c7201dc40d3d1f02b3e727eeefa17b057db96561d388b43(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0ef78f867ebf71374a4164eab683de7f45524f3c6f07811c4fbbfc4f95e8650d(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__09b06304943f7171cdcbce4d740364ce28254e22356e483579fd4c15185c9a81(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cb195023e7163378f92cc7171d9b683d1f8f2f9cb5ca3254bf6b80b62976ce6e(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3a183559c573eaa4f62d9bca02470399d9baaec68e3fb39a9b5dbbc604d378ab(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c48664479e75e082f4f462f4c8df629392bd27f9a1d4a258ff7535c9f4cbc4b3(
    value: typing.Optional[PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQueryProcessQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4581556953626c04f9450b047a5cdc969bab4c183f684d2bee6067392bdb32cc(
    *,
    data_source: builtins.str,
    measure: builtins.str,
    slo_id: builtins.str,
    additional_query_filters: typing.Optional[builtins.str] = None,
    cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
    group_mode: typing.Optional[builtins.str] = None,
    name: typing.Optional[builtins.str] = None,
    slo_query_type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f2c60c0f480fbcdb249fcb075d2dfb1a272a4bd176d4fbbdc773565bfae918dc(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__331fc04bcbb5a27cc2457a1d2b404fb42866e7a6e208c65d908a56e025dddfd6(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__eb515c418ad272d679aba17a05e6ce285508f0ed57a52b7713abfa00657f7be3(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bd1b7b0511010a8d26b38d1a0d16860d2440b8e0d6f7e7c46808db8b41c0a562(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6d0594e297e595d70ea02f022384efc315a44f85ed3473801195efcff67b3a29(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__05c1bb89fb9104e651d938815b5b5d0ca1a1c998420382e5797f0c907a82656d(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4e10dce7627ae5fe26f3e51632b4cbbe7b7d022de54f59824eeff7fff904931d(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f2fdcb2acf63c59d0c9d8bf603ea5d0fdc2e9cad7c20232144aebbb3c756161e(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__05e5824a3e244986171850d364cfd02c85df314641ccea808dc2f881832b3012(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__089370a286f4f637ea07b9b35150bb473a446257cdba1dc5599638c6ddfb5381(
    value: typing.Optional[PowerpackWidgetScatterplotDefinitionRequestScatterplotTableQuerySloQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7e0026617111ba406fe0484f34211612e46103ced61907e95c709298843b4641(
    *,
    aggregator: typing.Optional[builtins.str] = None,
    apm_query: typing.Optional[typing.Union[PowerpackWidgetScatterplotDefinitionRequestXApmQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    log_query: typing.Optional[typing.Union[PowerpackWidgetScatterplotDefinitionRequestXLogQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    process_query: typing.Optional[typing.Union[PowerpackWidgetScatterplotDefinitionRequestXProcessQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    q: typing.Optional[builtins.str] = None,
    rum_query: typing.Optional[typing.Union[PowerpackWidgetScatterplotDefinitionRequestXRumQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    security_query: typing.Optional[typing.Union[PowerpackWidgetScatterplotDefinitionRequestXSecurityQuery, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e093dfd656d3639ff456eaba7eca213e1e977156d5004120cbdd52e4d9ca94ba(
    *,
    index: builtins.str,
    compute_query: typing.Optional[typing.Union[PowerpackWidgetScatterplotDefinitionRequestXApmQueryComputeQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetScatterplotDefinitionRequestXApmQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
    multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetScatterplotDefinitionRequestXApmQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]]] = None,
    search_query: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c6315a2175485c7128ff3e62f6462bfa8555faf125e251d8604af77398a4908a(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__370dc8dd1bf5ef9262466bc86101dd3ce47c24c75177b5b4c7a2cfa1663f2b25(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a9044ae54371ce42547fe2708b4444bd9b99818e605d59da9a217f824d969278(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8ac5564e6e6139e9e11c35889033dfdfbeeb68e2adc992b1e948f50b2f6ea251(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__376d0ee91878bf249da419bb6dbcd4e5cfaf43120980903379b104cea6b0569f(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__83859613377302bcace865c56ada4337f9220b90b7bf44b991e4fc40bced6a13(
    value: typing.Optional[PowerpackWidgetScatterplotDefinitionRequestXApmQueryComputeQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8f4f7a83fc0f66a45cf506589dff0ae1b93224246b1549c5929b371fdbd4cead(
    *,
    facet: typing.Optional[builtins.str] = None,
    limit: typing.Optional[jsii.Number] = None,
    sort_query: typing.Optional[typing.Union[PowerpackWidgetScatterplotDefinitionRequestXApmQueryGroupBySortQuery, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a6bd78633e6375d7c7e125c10112baf5392c9d92c3fdc2fc71f48462eaad5b80(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__05b05e18ef165718f6357f602b72eff49e007ae0c1f704408c5b304d48fb271b(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__03f9ccc1d009f89ca2b1aa4fdd72d9e1a7b855297bf6a5e4e7213a69f2b1b889(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__28a33fdc915b6328ca66fba60bdb0799fce098d56d67a15e309c5ca683312a4c(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6c8f2abdf2e809378852ff72a6686ebd30fff9a81ef4a00cfecb1b6473e80373(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4585d09ac4fd7d212cb18bf0091d635e85e34eb22b8717a0dfe5b55f95300d3f(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestXApmQueryGroupBy]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d29f5480112a4157ea8146d415a17a6073e94bab84c799ab46e5a19ec31f11e3(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1c38dd15d750c034092cc1e0f4f4dfdce1a0ceaf350f6d8930e07a2ad78eebb0(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9a87673ea1e8f66d7c676c391012d48dc0e064d9f2065fc63af2959204b973ef(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9a1f8098cac09a3659878f7954299e5b1a39e451aca38291b81999eca3b89f88(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetScatterplotDefinitionRequestXApmQueryGroupBy]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__da63f8163334257652f9810804f5cf54099fa95e6bfa13308ecba829fcdeb2dd(
    *,
    aggregation: builtins.str,
    order: builtins.str,
    facet: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0d89292ad26c7594cbde18e92910b0216af7143fc1c4cf884526a93945d7354f(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__612ad08f682c4fb059f62d5770f679f632c8a633200a6a9de5e193536046a9d7(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1b544cc8f4ff544eb10c618e19a5df696a9566d14f5999babe74bee61f2e2284(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__660c710fc775d6ef5f4f96e8f4a06ec6721f7c60c0e7bfb7e972e48437282512(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c101186c384153de8eb9c11c2ed43e6394711ab6c3d42a144c41f0aded8e40f4(
    value: typing.Optional[PowerpackWidgetScatterplotDefinitionRequestXApmQueryGroupBySortQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__04afeb89f8ac947e6875c4dca5ee93322175251e79257042f450defc1426a3dc(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c3435a976e4e886529a93c08f0d008659b5d02dec18a758aba8b93770b06a0be(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d1644a0dc8e4ebc6863fb863b48108ce7b657494e166d39b1c2a5f71de5476cd(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__04b248b93baa805ec27df11c9a5c29d2c836cfb9399fbfe4e9e9490f7bf212f0(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3afb1fae4936a54163511558200676a3eb747ce4c005f7f512d99e9ba7e92e9a(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ad6f5573fd95cae149886d2d72de3905016d720d29d34e6dfbdb16194a9dcb15(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ba356e4a1ff90d18fba75520dcb12be0b66c698f57329cf7114d6b4649a57929(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestXApmQueryMultiCompute]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e74c325a9b8b18df14f060423b501e42bc46d634f4ea297cb080f78dc37f8840(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e0a54567957220da1675d331f905f4f9be4592944bbf921ef61fd56920a3c4cf(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__91bc44f23eee5c67fb175fde65a2113d0465d8b8e335d39d0d000f8dee99af74(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f8475a0c6a9c678d612ff62a4f6f10e5530cdea78ebfd866c3a7bf961e0b30f8(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__14a36ccb6d9c347a5017db9fed8f1f699aa0ac9996dff9d959a08d3d61a38311(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetScatterplotDefinitionRequestXApmQueryMultiCompute]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fce73f259d65a5f1688e1e0aa5d0f0df922915777ccbaf31ed7aa1d9113a5c62(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0c595fed64cd79c85290ab9c5ac4bae57b341783ab00a0374f2c360fbc2a9807(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetScatterplotDefinitionRequestXApmQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7a47e516c1ed180574f55ca1ccbb336ecf686c8af194b25e63f26cd55c84dc14(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetScatterplotDefinitionRequestXApmQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__02ee0f53a10fcef28f6ca986cb1428c05f6852dc7c48fa55f9a68a2eccf50f4a(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d4172e35207a8392b34f003b71b88d61f622987ddfc1d1029d94f4b3de7a7c78(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__68accea1fb031c29cf1b890cb1065c17beaec157d799f332a0a4e378de106cf4(
    value: typing.Optional[PowerpackWidgetScatterplotDefinitionRequestXApmQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f4bc6f7e84077432a81bdf310c6411a1737be0e08170d357e7c59fd63e41799d(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7e642466d7fbf51824bedb903de01bf8e78e2e945f8743ee00a967eba9c0b009(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a6289ef577ca730b1639249e755414852b1a6b86e9a038870edbcc3c9e4a1a27(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dd8bfd8288e1a481b6dd48f678806d39c809bde09fc79aa0ba62386f7a888fdd(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__45ae8226878b06fefc958229b668cb97113c07c9126b1240a3ae041229cd29d4(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9bbf6db58be9201dc7d0f38a90fa27d2d85d7d4567105a482d525d7d9797d577(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestX]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__955f7bd4989c91c38e727468a83f5b7d910383a214dc962013e49fd9f7817569(
    *,
    index: builtins.str,
    compute_query: typing.Optional[typing.Union[PowerpackWidgetScatterplotDefinitionRequestXLogQueryComputeQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetScatterplotDefinitionRequestXLogQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
    multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetScatterplotDefinitionRequestXLogQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]]] = None,
    search_query: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__94a7d234290c0153887454e85cf1ae37834ec415a92f2c3d3eb65f669ac83ac0(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b58b123fc0c9476b66fccadce7262cea34c2f876fdefba9942afe34f8c665c8d(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f8b24168ba85294c611a53f1d7167d9d51645a6b7dfcf0e424bc1de1a27fc5ec(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c6551d7f7aba1ce177a2d1d35361249b03979271b83737aa6b355cc08697984e(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6d660c1ddddfd7b85133fab71be1a4999e73f027b3a35b63ffad074344e6bd45(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__065538b56b873fea237ed4380068a5337fd29f090fe9bbcab5140d38327aca73(
    value: typing.Optional[PowerpackWidgetScatterplotDefinitionRequestXLogQueryComputeQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9834f51021e0fb64a780a713902aeb849128778f7ef4b3493f911a0e7633cd9f(
    *,
    facet: typing.Optional[builtins.str] = None,
    limit: typing.Optional[jsii.Number] = None,
    sort_query: typing.Optional[typing.Union[PowerpackWidgetScatterplotDefinitionRequestXLogQueryGroupBySortQuery, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f9bc6b91142005599466e30b9374b32720994d9f71c9ea6789abd0ae2ea854b5(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__987fb5e8ddf6facbe320502aef5e4aba86d4937444cce463a739d1e90c9f2daa(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__afc4135663e000726ec39b902ed858604f69170ab78ed820bae7a9c85043fa16(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a748e1f6a6d162e4dda55b4c12ffa43ad85a96dd60b5710f9b0a3c67af52a477(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0c29346fd6630a8b136e399a32ef32bd0bc0458ef6b9f9f73b0c7b778eb523e4(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3e6689c61dd363cc55e01bc8389763c3874a4c7990310900e44e86d5af3e51ae(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestXLogQueryGroupBy]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f5eb516ca855c83793316e56c19982e2c04d08e683226dffa327709f73e628db(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d59b31456d0028a3ee8c92919629ad1edd4cdba474b6554199db082aa634e1fc(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f918d057e2957e8681ca2e5bdad35a5f2af6915ed5b7f40c64bc89fc88ac10af(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3492ddaf5ac297e50bd90c241ac203904e34fa6aa20ab9a697f33558628bab5b(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetScatterplotDefinitionRequestXLogQueryGroupBy]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f5c8eb04749d4b9cc730e01ef1afaf42a4a5516a0152009a5240cb4eda99c54a(
    *,
    aggregation: builtins.str,
    order: builtins.str,
    facet: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__333acb41b3cc89a0c0a4a66c741e271c1427873c3c2a3142dffd321d86d86dc2(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e93e05005941bdfaa2b327d0f21f3742f44fcba53d07741b8f8009da7f0601ef(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__16e25f2b7d52dde7b47ff8ab751d9ad35f78e3ff35d73eb5d91167b06a32fb2b(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cdac60026845277abf741ff3865c7f077f03c55fd0c286ecb7d38daf65744189(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__de932eca8618fa7516cb8bb2d51221492389c40e490ee74013a2e19161cf31c4(
    value: typing.Optional[PowerpackWidgetScatterplotDefinitionRequestXLogQueryGroupBySortQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__effc80b7c1e252ea54e9dc914508ac372fa7061c8d4417a77f173426a73e7c1c(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__64c4720e27e1e5aff76d196644d153c8cd2bc6dba41871ff074b9ee67fc69bde(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__eac7f5c169695d0319262e4d2b9a9affa295431dd8db1c5128a8707384979ad5(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7834e34e8709b65adc0a82def17a3c549ac12ac055186e894f0fc9dd4bf6e261(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ca1e488fec13c9501fde4f590fd46cf5a4654ff7b07239fc35c177d1713aee4b(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4e38eb73b77717afc4a80f48868a8c4f2c4a2189390400056f328a03672ec769(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__57ff46ffb33f70475b6534961160f2836af42708cdfc9b00daa309cacb0fc312(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestXLogQueryMultiCompute]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4763ed2e257d7ae7ee7bbee0299cb489c5493e4a5db9a5cfd760e9fd8cbd23d1(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b141675be0f7baca075ea8fa099c62854c66be38667d9d1fb46d8fd035561a13(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__868ae48a9ba13ddeba817d00b77b66de94a5cf422e7d326004411b036a70f5da(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7ec763f65b5501710d014e67310e1bebd7ca41533e589596cc4700af0bbf0ad2(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c246f788c3ba0ea31c95c2d10be86f819995548766820ddd2011f29639e98794(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetScatterplotDefinitionRequestXLogQueryMultiCompute]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f456087b966a2cfbd52e5c3171c55bfbe84dd1951053ae04258e9354945c1876(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c152e2aedc5c1998cb954f122ed20da3bb7fea2997459e9f2db6dfaa8800a4de(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetScatterplotDefinitionRequestXLogQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7fa4c49f62203c028ead32e1de5a8c731006c3b5937c34b1ccc61a2218f5413f(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetScatterplotDefinitionRequestXLogQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4e3913c5d4ef433c64b42ac1fe2fea7b36c40105c56b83c3ab2f4d66f48d53a8(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6bbc0bfc46e885dd39c3ec2a09efddf71ef6ce92b4ae30ee20d63dd64a39a965(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9aff86424250622a6c00d7f23663ba888c1c0fdf2461b508760d49d3aa6a2bde(
    value: typing.Optional[PowerpackWidgetScatterplotDefinitionRequestXLogQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2c4afb7cd2758001f646c72e5bbe7513bc3c365878287dd4a273d6e1127534c9(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d012565a55bc6e49d80c7ddc1e8d7df63f0c4ab2481a30b234681f4545694e10(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0ffc3cff6c34f16387eb91f6eb705e47ae02f4c7a92d177cecb7706456b9d657(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cafba75580e86f145623c5a5189bfefe9f019814a3b87bf6a90a32fe6fb72cac(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetScatterplotDefinitionRequestX]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d05332d7dd508f69ec63d51aca257ef9561381c272342ed36ff324439f59ff6c(
    *,
    metric: builtins.str,
    filter_by: typing.Optional[typing.Sequence[builtins.str]] = None,
    limit: typing.Optional[jsii.Number] = None,
    search_by: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4ff8e01577c456839edb3e5d2a614cecd18f38c82d69465a9e661a68d8c36a2d(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6c6c67a483e0be37a52c7f7f05c97046ee7c6191608f4ccfdcb3853a461bd6d3(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__75f0569e2230ae0e49386e6bc2ae93b592d541f1bc499ecc657935292eb88274(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8076a4197c3e696478e143f233097c2ed41ae46a853a954b769dadb7b71654a1(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3469d3e6ba1f928fddd6bd35f9ea57a01a3f9c85fd0f0593df590807465fc7dc(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__861a9e1e76fac3456ae1ff6d0a5fd44f7fed910c21c086dd85755ce677144346(
    value: typing.Optional[PowerpackWidgetScatterplotDefinitionRequestXProcessQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9c5b4cac3ccf723c1e29c2f873b23fc261750264d9e150b3aca25821652de147(
    *,
    index: builtins.str,
    compute_query: typing.Optional[typing.Union[PowerpackWidgetScatterplotDefinitionRequestXRumQueryComputeQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetScatterplotDefinitionRequestXRumQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
    multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetScatterplotDefinitionRequestXRumQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]]] = None,
    search_query: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bf720e6fa052642d19d0d9484bcedf089756eed861d7f84776fc0e203aea31ac(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__12cc8c2255f272850b95dca2e063626d4c5ca7de8b74d646bdaf7543934fb116(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__077c5f52ec01b3860ba5d321d7e5167d9b6bcf0d1d8f449cc7e6428eaaead914(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e704f2a158018a8a4a55460b1b0838dfe801c8bf34a7e3ad121c28e23ea0f720(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__da941c417216424dcb70bb986b9821591670c6eaa1e764dfd373d78a20d9424c(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fd3c51c0f32e6841db6d64364420103e3af88152d0f2aacf917efa03e75b06ca(
    value: typing.Optional[PowerpackWidgetScatterplotDefinitionRequestXRumQueryComputeQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__95b59e8e711220f40186b7543a29410801d16fec8fb55b9307bc79a17b98af75(
    *,
    facet: typing.Optional[builtins.str] = None,
    limit: typing.Optional[jsii.Number] = None,
    sort_query: typing.Optional[typing.Union[PowerpackWidgetScatterplotDefinitionRequestXRumQueryGroupBySortQuery, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f27cb23f51b55da7362c551480247ea68779cc66b1888c2f4d2731020993d9ab(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4ca4ae4e549a1f1897ce28326f8ecdf3d8b87740f7fcf6dfe50cf25644a2c967(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6a40a35e6225132f89a3f1832669550be17959da0e8cb7ba069af44fae6a2895(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0b758a8b5d667559da647fd34b335cb349d11f7fc302901a04f2e53197aa70ab(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__73bbe5187a853b13467f21a343006b3c2a83bacbabfc84062543ae2cca9d0362(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a755316f7a70efa2a8c2f89b6b804a03855b7ebc8ced3d4e3f53987d2803bff4(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestXRumQueryGroupBy]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5e72d0296a001b173fa195adbc18ed68ff8785525e72688933230265e5807635(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__baf8d881cec0d234aaef6eb544e1e19bcda4b16384b051b6f37c57a97614f8ff(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bc93091604a9ad9a20c33caa40f192ea3a1ad152041eba1e15c6cde284f5d00c(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fdb51f9e4d0539559af24e3fb42ef95f99d2d36c87de7b90bd20949bcbce12b7(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetScatterplotDefinitionRequestXRumQueryGroupBy]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4b81c929809d09dbdadf4f01d1457b5d2fb12c8925b0b77ef2f09853add5d577(
    *,
    aggregation: builtins.str,
    order: builtins.str,
    facet: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__300b2270685c9a7012412dc3ebe55237817d48c50172edf36a41173abdb0358e(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b645fb6994ac48d0a14307836a6b58080e90183e1ca7074386d319c7206299b2(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__eed9074d2ffcd9bbc4174f2c7969b0bf04c1124a9b81caeb6ff15475810d639c(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__200d0a6ad80a461c7b474761e67abf2d72bffabf8ca35629a3051956f02c76c3(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__05c69d07df94a46813fa5eea9bec62dc1444807434723fecb1ebf25f98c7cce0(
    value: typing.Optional[PowerpackWidgetScatterplotDefinitionRequestXRumQueryGroupBySortQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dfa058ef9d8af8c0c5350658f321bec48e449c6223f7fe4f7d4fca2db8a64c52(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b8caad5dc407e563c621106760fd97659f60246ba1e81032b492636a8816d2f0(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4c5f92981d27da9aef63319404eeb1d92f2a5285c0a1b9609b9c922e570bbc40(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9aae94d1a486b0d7877d2197af6aa8ec667d9b9b366bea08b037566a55556288(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5cdf1aba30c4ad8fdbc8cab9091086b8395d5fa0827a61f09b266cf036767c7b(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d85d77753e7610f8822cdd0fb9df8a3561bd6de175331ad3f4b2db42aad1119b(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__690906b5b2f3804f9612b431f76374f62e814668b8257736f8f549c4786dc926(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestXRumQueryMultiCompute]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__510fe7c94ab24717fde73b0bca40fa6afb8bd595262fddf99d43d74081927505(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2e4dba221d9f977d2e5836e7d9cffbd0e5aabc37488aa2a0eefeb79e229036ec(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fa2d322b613cc6e458b7f7353eac858ce450490d3ca218371106fb0d08bfb3e9(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__226582084245b222e0a6e283148912820814513ffde0341b36151b39b4e2f072(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b052d974b7b5ce2cab27241d9ec5d79cf3303307409a3aa710ed059a790a0bf3(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetScatterplotDefinitionRequestXRumQueryMultiCompute]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__eb59d01de6523f9f604a6777303776b68b8d4bfe0bb80669407cf3465230caf7(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ab98d87efab611d03129841b79d24fc4f4a79551905bab9edaaac93c1bd3263f(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetScatterplotDefinitionRequestXRumQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5ab9f4513be7b622699edc5af18d89f5b0d25bc6757176bf7af7996565303c84(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetScatterplotDefinitionRequestXRumQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cedb3eb8e0c2343ef5dc6c7e05e2d87a25a3a50add267212b80e2cc17c9eee08(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__84322facb3d350b043e4ed0966709a5f63d114baa7b82606370d595308862ed9(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6b178d6a2143b142ee45f6ad71429cc5db4c3f49ae39514b3807f8d3cdb21c65(
    value: typing.Optional[PowerpackWidgetScatterplotDefinitionRequestXRumQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__91091bc9f4397b1a53e71ce2c76eab1860e9f878e3c76ef9cd98e8fb778a44f1(
    *,
    index: builtins.str,
    compute_query: typing.Optional[typing.Union[PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryComputeQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
    multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]]] = None,
    search_query: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__025a2f17cee234ad031cc98aa2e0877bfc7ddadbcab992caf94455eecd0af4f2(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3b3437e1116c9ac721f63bfa0c2b39645b6bfbeaebd149af366a6f9b8f7f2d91(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__375471845eda7b6dc3fe073c722eec79e0e41c3b7637dd8d97605ca78fa314dd(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__59b6dc0215b9c5a08acef94298e0739426ccf3c7570df1e93b527235c3eb0783(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__590236a4a9ebbb62b8275bd10520671bb2ae4d42e43e7b1fab2016992da4fc1a(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6efc871223f1b04fb2111d01ca01202e6cef12078c105c7eddfd15b3ebf407d6(
    value: typing.Optional[PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryComputeQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__09a9547c081cdd7a8b28f725778df2a0c4c3d5460e25fbd139bceb9357baec5a(
    *,
    facet: typing.Optional[builtins.str] = None,
    limit: typing.Optional[jsii.Number] = None,
    sort_query: typing.Optional[typing.Union[PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryGroupBySortQuery, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9f69e23e2f9de9630a59606c2e97711ccb114a028688f626ec35d9c414f7e241(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0a8285ad8a577f7b69b8609d5cac1c52bb8eddc228607dac245c3b031fca1022(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__02d427bb70925da21b6ba4d6614eebc31605895f9d05dc7042b6838f519bf128(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__781d1b2352dca5c9a943b2647b2988b1a79679e782ebf62885af3b56481e7ac4(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2f0c037a4f1916a5ee1796ff663fb466ecc2adc3458645e1a16a74d65682ea1f(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2f0198ae8726e69f8a09167c3f39b05cb1b0e5bf241694f21f84a969435b4b98(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryGroupBy]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ffdfa53abdc773b59b00b88758b9882ae0ce3b6fddfe2c430f2bedd96191263e(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bf2325e26f2a3520b13d1c09774d93788b7c4c9587f05940a476d20ebf60fd12(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5dea565b12a6d75e86bedf53f967a3a2ee4decaecbb08a9d8661859760e0b1b6(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c5fe415ae46505cfc29489e6bb3fbea4156430c12f5a3e8c6e9693b97fc506c9(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryGroupBy]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bdf6a69b4bd82c6986fdd2bd78228f3855dd5bed7be79fec73bab9bd48283d5c(
    *,
    aggregation: builtins.str,
    order: builtins.str,
    facet: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d55b8da24c9e0ed1bd3c7173683089bc1b259829e5c4fba30643559ed9b5ef34(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7c7a79f06e9cecd405101623b08e99bddbde44082a6d0b2db0553b8afa0d343f(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f9b67c3b65d99b6dfbe8aad12fad8db41b0c8cc3a413834f3c16afa3ec62c0ed(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8bb48398548c1c27c4e5b9c0883e04cc1aad185b91e5c3293bef7084e881971d(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2df12d4e338914c1e55529b476b6ad2c0d58d6150c6205b12dc182ab210fad01(
    value: typing.Optional[PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryGroupBySortQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__821e386af215194583186ab04693bea79df050bdf06be608a776cb687440fc1d(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0998135452527ef60ab87df72b58b0e533dc5b17eefd350d93ccb7698b035edb(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__46a83e7071c6d9972cd32f75faa39310b13c6470a38f2ed0b542194df5360ebe(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5b9a848dce5987daa79a2e1aab31347462771f50856ea54be067ae2af1d9e714(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__67d4996a46b3d0fb526c4e0898e43653dd3a9bea4dfe051b28376259fb3891e2(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1bbbd57b4d879a85cf5f02153e473c032b10201ac849243295355eaa32e67409(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9e3d9aa677f264e083052ef05d77cbd8646c79da71a3300e4aea0cbf8456d634(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryMultiCompute]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c7faf0673bb5af6994850f259d3a3871e78624aeb2ce5600e2badfc80da30b14(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4e7f87b3bbbfeb9195eab449282cab0c61ca3bb176ad75cb39ac5ae080df7863(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__20d8ef1926023e58598b3e141da9a4332c8ee899986bb5a34baa62c6030312f9(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9baf217fe1b16565f5673704833d166d0f815f2c5d4113d6b3cabe847770bb4a(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d3b5aba9305f643b92759f4393e827d6ed81acf9612e1f7cc13a6ff7f544261a(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryMultiCompute]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__18158c9b24353a2c8f3a166e34bc0bab4533de890623e638a4585aba94962a67(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__025593d1135da0eebd1e641ed74945337187cc3352e182d6c57c24fb9efd9d32(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__78e8d6b8d1a9eaf9ec48dc65edd57d2f6fd2a68690bb0706bae1bfc54eed54ef(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetScatterplotDefinitionRequestXSecurityQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2dac5c2057392b695fe85990c44309f36e229653fff1f62cb298050414fba183(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f0b97ba4f77479b02a5a1e011e5b2182394b1927a9e61f214ec1cda4c43fe410(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__372ccc6ba8dab8991af85b7402216bc7e4963695a857b1d4ee364d1687f63c7d(
    value: typing.Optional[PowerpackWidgetScatterplotDefinitionRequestXSecurityQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b362edbc8fe4379e7a3ce40debe91859d0efdb67a63510df77fdd79501bbc9b6(
    *,
    aggregator: typing.Optional[builtins.str] = None,
    apm_query: typing.Optional[typing.Union[PowerpackWidgetScatterplotDefinitionRequestYApmQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    log_query: typing.Optional[typing.Union[PowerpackWidgetScatterplotDefinitionRequestYLogQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    process_query: typing.Optional[typing.Union[PowerpackWidgetScatterplotDefinitionRequestYProcessQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    q: typing.Optional[builtins.str] = None,
    rum_query: typing.Optional[typing.Union[PowerpackWidgetScatterplotDefinitionRequestYRumQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    security_query: typing.Optional[typing.Union[PowerpackWidgetScatterplotDefinitionRequestYSecurityQuery, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0ec2a853f7aeb7e8258c7a3bccd7dffac001abba99bf84471c0d8a109ac7e211(
    *,
    index: builtins.str,
    compute_query: typing.Optional[typing.Union[PowerpackWidgetScatterplotDefinitionRequestYApmQueryComputeQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetScatterplotDefinitionRequestYApmQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
    multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetScatterplotDefinitionRequestYApmQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]]] = None,
    search_query: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__033d0dfee9f10cff205e0e24bf7790422c9d42b34d64a65a05d946125a67d1a4(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6f2ec4b6f998b9f4755e8cdcedd13597cad00a7199733ef6111550e2df91003b(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8be55b70dd969cc958a3b9b2a6c008a6e2044d7cece70635d8cf9eb73b724c2c(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a410db9cc69c5dadd26c5f8d57239baedefa66ad39c4bba8195981906e8a1f72(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2dec68eb7e97d3201d2817e4ff6e1f40a679b9a41370450f7fee60e6b6a075cc(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b5b8c705f5ce63b9d3e54213a68c47498b7e01168e540bbbe38b99821503cd67(
    value: typing.Optional[PowerpackWidgetScatterplotDefinitionRequestYApmQueryComputeQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__77eb67e9aa1e866d9b29b6e2204856e735784c1ba2efd3693f4629944b5380c9(
    *,
    facet: typing.Optional[builtins.str] = None,
    limit: typing.Optional[jsii.Number] = None,
    sort_query: typing.Optional[typing.Union[PowerpackWidgetScatterplotDefinitionRequestYApmQueryGroupBySortQuery, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ca0beb12ccf1a3a466629055ae3e0d46a3091e2d6b80aa0df13015ea28eb259f(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8f99bc062236e601d39697ad13153a8e775ee16daad9e574153e47f36856913f(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ca95157341b44235bf3eeea6c08d092e843ea750d1931f1a2c9eb94e225e942c(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__687c38de26346436a82b33d6bcecf3fda3fdb3a9f5fcc848f4f8cdb38769af51(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__41587fd098630e4d9aba71febacdcd7d8fdf00d61db660e7efa2b4396ae8b4a4(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1bdc58a8dc631ad35f2da64757264b536c8194c774d17a91aa851e3fb40a34f1(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestYApmQueryGroupBy]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fa87fa89c29dd7b698fd081cc2620a6f1c54d4c370076bd9af056216f0f339b5(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__43ded7b400f6a58325b0d8e1bdcb1e1eee5c277989858114a9020e89351716d5(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2c79bd8956ed9f53ad037eba771bc2dc1bc124c0bc1ab02b477152ae5a77e45e(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ce129ab3aacc992dcb3a7675eb0f6513a749290768d32cf75bd0c73041ac93bd(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetScatterplotDefinitionRequestYApmQueryGroupBy]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8b1801dcf26ada3500001d6b4bef8cea1f871413c09e1008ddcbc93bff25dcf8(
    *,
    aggregation: builtins.str,
    order: builtins.str,
    facet: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ee148e0e10574e07947c3f0529fb6e646ffc4036c04c45f6d6e986622732fda1(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__612d7d70d70034de686249bed9dff5cf976064b094716d355ac4c9e943b788ed(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9a433f5dd1b39ca21d174503eec1920aa75c25facb0cd12260957a2b4d6acbf0(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b5b7e7d23eb25cfc5caf9293bf125e8e32f915baa937ffb1f66edfe7d612599e(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__467bfb49533cd5970c077329258a6a32364af84c9b737da8fd27072c94a0441b(
    value: typing.Optional[PowerpackWidgetScatterplotDefinitionRequestYApmQueryGroupBySortQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__90f3a5c85011ffc2fcb7f907419092be45bdf92490e6effcbb16549c8a25853d(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ad2c0a9b6cd2e7b979171fb8d513e884fe92e33e161e4a1366e74d8b838e3c00(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7bf3599c5e543444fa119a43bc5c7b72a3995bc0cf9d0e8d9b293168b4c354f1(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__09b15d6058415b150d9a560927ee00b670344925f4af47e75afedf2eec7a21e2(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__19b2fa1a60f023e1265b8566896e71266503ef53a4a5667bc710b7a090d037c5(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4c4ad6787732b18c28a9bf408fe668d051daaadc736814a2fbc1956859ec8476(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f80d9dd328e1a4dad4989bc1fbefb275b5c4230aad82dd86630bae4b3e71f965(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestYApmQueryMultiCompute]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a73865827b01b6fb7a18b45f771dcdf510996962e2461ca1cf30c829624f4541(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a05b35c89fcb6d2519947da63c545cdcef655a7e3674208233b546f410b16a1e(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f4a514772af37a24d39b5538048fdc35937583fcb45affba85022212644a32c7(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5c90dbe514bed8da3b4382a8528438b8e5720e59e1e1960bf4c3d6f5d2f831b2(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3f60495d27aba2d405e660ba2eabe3f0e4e4af9508665bccbf3118e25839ef55(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetScatterplotDefinitionRequestYApmQueryMultiCompute]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9c83e32152bbf047dba3ce0d14cf26bc46c05ec696f0e58d9220ca40b30f3789(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ff1c14b75b300b4561167132b9842069e27df9dae68a25f016a3aba7f1503c78(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetScatterplotDefinitionRequestYApmQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4cf6c32f648d8e7c4393b5658decd37bb795a596c53bddda69335ad4813313bc(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetScatterplotDefinitionRequestYApmQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d4260e962b507596c705fe9dd2a21efadc1704146b7bed947f3dd05cc813f964(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d14e6e3c5ee2eb49a549b19623655cda6baa663ba9f901b98495662bef75d0e7(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ab6d3a2419879f094ba66e08bf1e7d2164adf18a5f70d895056bf0c8751b2a23(
    value: typing.Optional[PowerpackWidgetScatterplotDefinitionRequestYApmQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__52966dd89c55bd60d19c088b21950979154be68084b2e37a6f5fe57c4f1b04ef(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d2f76a7e387c5d7d6ffe2fe8c5f248b276f387cf30064526e7a17266fcd448fd(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3940067cc1fa1bdccb4b23144a5023a22740f1dce5a23a39d72c26fe7a3cc045(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__34e2bd374dcdad1d352805df9338bdc6a3d9ddc932dade7dfe476b48d4450922(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9acb6bb676d15c14db33e3be6f43dcdcfaf413d72c035c230143efe98825afae(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e6519021c9dd12cc93987553ab27c6e10b2cf55aca41d0102ac6ec5e477a3f98(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestY]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dc5105d0150ca1b5b50f8f916b6feda3cb2c61174879ffc67608e15417f8b977(
    *,
    index: builtins.str,
    compute_query: typing.Optional[typing.Union[PowerpackWidgetScatterplotDefinitionRequestYLogQueryComputeQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetScatterplotDefinitionRequestYLogQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
    multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetScatterplotDefinitionRequestYLogQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]]] = None,
    search_query: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2c252309c614fe418c63f8a41314ea43f94087842d956c43a106763bf8473e0c(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3b2a8ec1f338e7477d819bed71dd37b1ce27f9eea468cdee40f51bc6f7d03d23(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fa54523959ca93c338eed09248211477192c6003eccb6552c274d552a4b7ebb5(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9a49ce8b4ccd221aeb856efa0ba07c8da27b8dd6db1751d36e74e06c835eaa42(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8106453654f200b99384fe79efcd94a3a6fa973bf0aeed25a637518caa20e8d4(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cd80519b86702bf53b990407246601dfb4c3722f304bed46cedbf3da1b99f147(
    value: typing.Optional[PowerpackWidgetScatterplotDefinitionRequestYLogQueryComputeQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__813fd5dd477c3ca7661528957caa8afbc0c2393fd0a99f712a5b2c182c5f318f(
    *,
    facet: typing.Optional[builtins.str] = None,
    limit: typing.Optional[jsii.Number] = None,
    sort_query: typing.Optional[typing.Union[PowerpackWidgetScatterplotDefinitionRequestYLogQueryGroupBySortQuery, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b267bece16c6778b4ddac98b893fd30f2a1c5c08195ffb49d117a58542035c59(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__00932c167c682ac4408ced0d64a8c86448db28f5b7d215c988c45b37f59fc383(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__32615237207ee8ffd06911cb9d863585996c0b14058bd2c4f467814e42e2f4ce(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a4462b9458d463c1983a7829358806f0ddd17137c1f087102f98c81ef4d5b182(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b660638909e67eb3b8f36063b221fb124eb1d1dc099f72031ea565220d625003(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b9eb3bc37f003aa3389022cd9920020aca30d1927d3010ef2c3aa4877926f34d(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestYLogQueryGroupBy]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cd33543ff6e7013e7b60d71908f75e66adef914a7019959df2c9a9dfae6c210c(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fa9aec60be1f0df51fab88edc92e9199a9374bed233fad85255a061fa9c3aa53(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b7bde759e222475f7381163e40f5aa3e28c2bfc7d5d5570dd870e403470414b7(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__51870017e48b5824cda1b633f3b5b4eb6536b95a3d4fab4ef577b360a98ec863(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetScatterplotDefinitionRequestYLogQueryGroupBy]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b409d7dadc9d199e1f07bea4f92da449d263a8f59738cee208faa2373f35c757(
    *,
    aggregation: builtins.str,
    order: builtins.str,
    facet: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__447ba52b7fffd192aa44fddddc8eadf79750297cdfccd92ec85739a491db817e(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5993890480612443383cfc311a372c284760ff9581f9b88d4687c03a6b79fb37(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__08e37a33f7659d82bb9c505ac66be2694dfb1103dc41a42c76a4836c4a4e2d56(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__be07fe43c5de43f247a360afc5368ddac93622977ec96d86e93f1552c1fb6dd1(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2ef50a9b09290cdcf36950c0ce14088c615bc44efcad28471a24debebc7d35b7(
    value: typing.Optional[PowerpackWidgetScatterplotDefinitionRequestYLogQueryGroupBySortQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8ae7840fafbd51e074018f699fffb5559bc26fcf70314760770781af32fb1ffe(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7332b36fb45d2d6bf91fca1319095b8f5d7083c93e0a7392766f9f29b12d082f(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4c4a9fff990d2038ae1db17eaa88496f64490c1285c4f491b0b4d226c6d0affa(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__02985933af2aaaff1814652742ef3c1bba221ba929636526e7c0a31ef0139a41(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__562fdea7d2d2553f77a3c883a5243698724cb7da6259cd3e27ef21dde77f1029(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8408e90250b7f1a1eb12a8dc0762f7b98a4150d57dc7e0cc6c775a63c4590415(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__01892d6fa630fc4b2cba1f28a12fc512226b4a7c35745e0d17d1308be920aa87(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestYLogQueryMultiCompute]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1cd65499f1326a5f68b542ed9fbd6bffa2887689da6fee68cf662bbf6e1aa680(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0a5729a658baefc392c11fd35d951bd40c5c71d620d9ad25f60f50f5d3d34831(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3ca4a636364a50b3c21a8cbc95c711089e7697dadb095594b70e62021d7d3df8(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b6db98a593354aa2cc9fca9034ca51051c04265d650ae6a8ba7cdf2eebc68367(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ad9efb04f341a9f69322c6b5624781734b309ce77bc47d1a9aad0de130e6258f(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetScatterplotDefinitionRequestYLogQueryMultiCompute]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__56010203c64266ee4250ffc928cea3e70620a419f4e2985f565cafcb8ce67eeb(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3d582e12f93a6f59e48de169cedfd3f68846a4f3cd84d76a686362044b8a6783(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetScatterplotDefinitionRequestYLogQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__eee5dbacb13fb7fd377651bdc67a7add1a6c1cb9e8afe70bb9bc597dd5c83c85(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetScatterplotDefinitionRequestYLogQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__58bdc0a760dd7c28f140d45ab40699dfa32888e3dcf81138329ab6dbac58494f(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7a66636ece4f70c248e8c1f0fab1a14a62ecd2dc8fb4c236a9ddc20175390b99(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c79a4a21db09afd653625b6eb0c47da341c9bd2f595421aa87a9d7ccbd4da5b3(
    value: typing.Optional[PowerpackWidgetScatterplotDefinitionRequestYLogQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5349cab4096b0d7a9ee1d102ce1bc953e7be2ef7c7402b5e00332c3c5874d39a(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c9e714137b4be3dec34e6b9f9a049d49bbc748edda4f53f0a41a2b9e27ae09e6(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8c08b12e39a8d84610a5ed46c35ffe71e698fbf465021e95df437f9b74e04cf4(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1686ffbf2dbb189031ba695033a125a497827b995d98d4d794b43a01a184c045(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetScatterplotDefinitionRequestY]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2179a7bf62e351428edf3c6e8e174a9365888a8e4357bb7b3571489ca78d19bc(
    *,
    metric: builtins.str,
    filter_by: typing.Optional[typing.Sequence[builtins.str]] = None,
    limit: typing.Optional[jsii.Number] = None,
    search_by: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d046a6ba5f8529881fcc96a030c76a9c475c3252f9e571b8224b3b30a4d0f498(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__58ccf274936f93746dd2f4c568b2e410d040b4278778c6f9c6582298cf527515(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cb7ef290c2735a13510c6db2acddef13eddd78ac8f9fa691f3e2e38c09f92661(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__83978aaf78b3f67f5cc44ac977b54d972f22ab9d2851cdd92bb2146d8888e032(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6e468882f34c50df35d0b3cd847e315dfba9ef9c1376b2077af9743b2e207bfe(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e3ea9f313980e4d3fd9574173d13c537eaa29fabf70da73cf45c0040357fdfdc(
    value: typing.Optional[PowerpackWidgetScatterplotDefinitionRequestYProcessQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ce481fd84da0188a8cd4242610ac365ae24bfdc029efd2c625f0f9b2076189a0(
    *,
    index: builtins.str,
    compute_query: typing.Optional[typing.Union[PowerpackWidgetScatterplotDefinitionRequestYRumQueryComputeQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetScatterplotDefinitionRequestYRumQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
    multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetScatterplotDefinitionRequestYRumQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]]] = None,
    search_query: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9e6493319cbe31578918f0fcc8c18a9ac47809d38abdf29640a4fd0c001b0591(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9d1b015c30332a6710e84b97c77fd6407aa0d6e813d32780b2a3e8e67ada21a3(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__659a1e38b948d46939d6afed9770da8ccadc0cfd863b4322a270d0cb923fb726(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8880f7e2f632ea3f3c0b52ad7806d377b6a46b9ef2d85b5a0986f93513934f42(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__81ad0d20d538f764faae68e94c268181d6f23ab8776274064b462bef0edd5b00(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c9e2316b99de0d091c444f657ec128add6defe5fb3a4db784ff5ee731b3f0aa4(
    value: typing.Optional[PowerpackWidgetScatterplotDefinitionRequestYRumQueryComputeQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__508ecece20d519d55338b2d1771bd7c2abd0136ef351c3cbd6f735c4aca6247c(
    *,
    facet: typing.Optional[builtins.str] = None,
    limit: typing.Optional[jsii.Number] = None,
    sort_query: typing.Optional[typing.Union[PowerpackWidgetScatterplotDefinitionRequestYRumQueryGroupBySortQuery, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__91dd0a93580945c4450829e42c496a38fe5119b6bf4449974b66dc774011c4e8(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__733cd322ad68c3fb6c0fea9c12826f3b709f6005e24833e5be0dee872028c0ec(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bb1257a078fbc89fe38c1e7641151f013507dbdeb0099d0f8cf5827d1776e3d7(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a83b6dfef1dfef68da428a4aad5c3ba045ddf9e5b2216f1c2c1049daab0e4db4(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cf39ea8c2e2732e04ab264e9d7a0df20d0c1adb58fb4b2481fe3b3c548b7ae4b(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cc0f609cb462eb9001021ad7393c534705220a1394b57346915be08b62f106c9(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestYRumQueryGroupBy]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d8490de67f289282ac4a1be6806ccb8f9551d40cd480a038f382e2ba78add1d4(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__76c4901714a2c8c771dc9365e22f776558176afc3f59acfaec829c1175268b5f(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f28b7312db534dc9a8c80d5961ea4d4575cf9fe8440f877ffe069e01512de347(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3361951520452c3537a5c51f7cf337faccaae6990d39c0125be55655b13da4c8(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetScatterplotDefinitionRequestYRumQueryGroupBy]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8122df6432929a518eb0b4a6cfed50a73af65a2ae40a5d5f9fa1fc4530948df1(
    *,
    aggregation: builtins.str,
    order: builtins.str,
    facet: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__588d76a4f87ecb65191f8381e98bcb2ecdba24b9390d240a0ad5cab423974a64(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__04938b7714a957c49f19b36415baf9576d8406a2d618fe32ce081e385792c2fc(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0d90919a437851e99aebe0eb6caca2b62cd13251fb4188aed1f96b4cd2331568(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2cf8267f3fa1ce0a4536b0e7aae817581dc3e5f65194054db639ccd09837a7ae(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c072e0b6960670a4a388486185ad0947b43bf6eb614f0adc6ddcb26e9faa18cb(
    value: typing.Optional[PowerpackWidgetScatterplotDefinitionRequestYRumQueryGroupBySortQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9026d94378566021b575cd1e2d7b1609658a046e592bd4a8e8dee6b1df3e1eb0(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__48768f9649bc1d84d95e1cfcbd5098904f0f4438b636e87155f54e8e267fea1a(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a2546fc55d082e9fbf7e95c312fd409b2ae6a1826f516bd8e62b5b12b5bc88bb(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__57bd2c66ebc85f4d6f8e102d2dfcc258878daac210cc9fe8dbed4f17b93d9494(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ea356f0ceb7002e97caa877258aeb02a900d09f92b9bfa3f5721ed1a3df2322d(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b41a00322914b5e5ccf4540c0a239e21020fc916807500bc18503bddb9688bf0(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__819eee6ec07bd26d22e02bb8ebf1ef51cfe885220e842f92098ff62fcfd2cc99(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestYRumQueryMultiCompute]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__63193ce4a22f48a014ad195885aaefbe5ecc3673e0c8a6f8cb23b6beea1e69fe(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bb2acbe6ec8fcee390e98964d2bec6787833ed0143301c69210088b341ad585c(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b93e62d98f9c1b434687b4cb728f6d951b5cc64a0748784e481b0dc2a0fe9c33(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c096bf23bddd259d889c3080e2b3e86c6e4dfe72c133d355b98a8249f60716bd(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e01c4470fa41252d0666e432d83f80ba4e2772f2e43df30517ebdaff2a1ca335(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetScatterplotDefinitionRequestYRumQueryMultiCompute]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c9e992b6b1a697953bbe621ec3f843bacf56ea5703972a8a03f3e69f075941a8(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6edbd6a83c8cefa1efc8f531cd18c74635661ca84ec3ebfda4d60ec3e0d6b87e(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetScatterplotDefinitionRequestYRumQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__85eea9cb5eebe8e95bf6e9bb55430523dcb960b8a9d20a68dda7c1998aac7474(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetScatterplotDefinitionRequestYRumQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e818add657bbc9deb969adbbf360819aa45e7592b2a3723e968d1e5fbe56d867(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__85a13ee72d04953d61710ef6c2311ddbcdc48d6e760925acaf9f88416550677b(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c5c7526a808da31e5994d620b33ef5299f60ef80272c87d56d14164264807af9(
    value: typing.Optional[PowerpackWidgetScatterplotDefinitionRequestYRumQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__82bbc2d6c38206443aca8794f6dc6c9a74de714cfbb3d08ea53c1bc5578bb4a7(
    *,
    index: builtins.str,
    compute_query: typing.Optional[typing.Union[PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryComputeQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
    multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]]] = None,
    search_query: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5e4fca4283099974d5a6ce144a4f98d8f4ddbe87c3262c438c4740c5105f1776(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f73f4908cd19290de6b01f8245f12e3c087ee770757855c26680a2f58001b5f3(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3d9c4a0e7a48b7eeeb01820b28109cf181332f2dc033e7783e0001c69272f450(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dc4d9fca2ef7a44f9e16dd02dc5b7d90ca7e1a9d85385449da1b71d80bc6c76a(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0ded48ca92290704c650d8ea8f4a127c3fc457c1aa9d82081651b1434ea6b56e(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__119fbf4fb0075aebefbb5e6967597b103af8e059568f0c8c4df6a095992cde13(
    value: typing.Optional[PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryComputeQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__35935568f894dbad386a874d147f4ac8ec1cc89d056308beb8544431850b4949(
    *,
    facet: typing.Optional[builtins.str] = None,
    limit: typing.Optional[jsii.Number] = None,
    sort_query: typing.Optional[typing.Union[PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryGroupBySortQuery, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f9fd47e78d025f245a90774a9f2d013994063b845b4e8ffd250af40829a8d0fb(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b1cbf5500a0da26af82900530be353274c82456bee6271e1bf499ab2c93d6bf1(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__aa131d69d6b606b72d3a96601f20e89646cabd2a2d580040dab2bcbb7a34bbec(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fe49efff42ca2945cd6d95744e932bc7a0692044c8e8c798ec2fbe8473307d54(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9b5b003acf626cfc4424b20795cd3968d7c2c244c32dc884c7a8aa3ea2fda65f(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a518c3075d25e2a03f11f01e5b7891bc901d1361cd6d2d558e133a6c4a243f75(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryGroupBy]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__520a5d5e694f988648006f48717f12118c8ffb0607eb87a6a28512c6a2be0fe3(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c1a72dfa5c707ffeceeca06349fc2957a7e0e8c79b04d924b75c536f2eb3708f(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1b53a9d4b86827c850bdc3b917adf9609f7ea4ba20702bbcec56002331d575d9(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1a83e28e6aba1c7d4a41e51e751f1d94904037b2fdbcccc5f60731f2e0343ea5(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryGroupBy]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9cdfc86b4ead4a754acb2f9702844a2a3773293dc9d3d7e725698a0bca52a1c2(
    *,
    aggregation: builtins.str,
    order: builtins.str,
    facet: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cdb518eee4b27d166a6a7524a9fa64f96367a0f34c6191780c1607af3fe7f00b(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__528c8122b44a53aec33b0cd2680cf7fa3b34b968527a0ca656807a09517b27b0(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__170febe0243f4484011fcd2077e2f1363c168c2dfac178bd67f12e5db19e62b4(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ee01b249c90d6707918eea845f2d62d24d652c30b51c65464a5c3c413dcb8f29(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0d11370c5354db46683022386cc7c337224078925078742ce3ab6cf1603ee58d(
    value: typing.Optional[PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryGroupBySortQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__69373306edc8fce579857eac9621cdf40858ed365e7fe5743e9b0dcbb66292c6(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9e3916bce7b980226bd94defce79959b17b2a9cb501359314c9e7a6f0ab6d9dc(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bc331f3f1321083d6a2797efa62a457c2547ac262096a5452fa1d18ff97506b2(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__16be26cfac9754156cf8315adf778304bd5fdfae43e8cecb2e637074b2af1430(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f7696c0946cd6e3a6187652e4627a0b3bc03b5759fea16f364a8dc62a02a167f(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__01351692bb40e0e73e76b1a6e99821cdaab1de30e5f6059bc449a393ac54a1dd(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e2fcaaf5ddaf45508028fed28ac44fcec5cf8b974870e7152122cdf292323b00(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryMultiCompute]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cabf30e5ec33f049e3efa2390152c3d4d8227e85a47cd536413a0c6728ec5186(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__14373c374afa6e7f6c2b839e8c505d3d7d49dd09ebaf23e709b202ba708a5a26(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fa0f2a99b994cc5a294193e325a58f2b5ccb5532f74ab9d8c32a8c23ad28acaa(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9f6ed788f1d87fc4096dc4eb04f7c87534c3add6f8189dab2cb1acf760f83293(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c2fb500f4edcdecf89a42c02b484f41b00331ae356defb1b061a43cf3f143469(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryMultiCompute]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e6850aaf091628eda53b8440c29a7a71afaa439f926e4390507fefedc44f4a35(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__22cae836453ab6ab995aff12a4ed45d8ca58972d201c1426659d2d166ea9bcce(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bdc6c85e603f18c4903b501f0e52662cc2e145a1028d679f5a941e562ecc68a5(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetScatterplotDefinitionRequestYSecurityQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9c834f72abb1dd6a96eadc23ca507c9c9d755719f826fb5055d12df7d54a9739(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cdfa1375bf80a70771358e0de53b2ebc8d7c3f53a2a3dc8e5562cdbd39299cc1(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9799583a3969837861ddae0c87b7bf47d71b42e09bd071653102e01c78dcff1d(
    value: typing.Optional[PowerpackWidgetScatterplotDefinitionRequestYSecurityQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fe4471c1e7f29df32a3945bb4d36d95d35b6265f9d234fd930612d52e8901e4b(
    *,
    include_zero: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
    label: typing.Optional[builtins.str] = None,
    max: typing.Optional[builtins.str] = None,
    min: typing.Optional[builtins.str] = None,
    scale: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d8a77fada173a299e1bd040c009128f82f63a37963495a16f41500f0170cc6ea(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__342a41c37978acb8a03058c0fa083f44d0e00a4bc433956ffa99358249a7bf49(
    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c065018298a619b000b192fa24c9c441bca5ee46064743d63ea4d3a6468af2b7(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__67bf875d153d7028cb5f57f40d5de5443e57facabfb19a81a809dfc55c299939(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ab870528563c39330a88585d7a564ad0a128f6411176670e8aaafc33773bb62f(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dccb67617e7cac16d7bd88003111b29e59c67a19e951cc1285693aab88e155f4(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__254e741fa076796e97037387e8447c16c5f3e3b8a96981812e5c933c218ed43b(
    value: typing.Optional[PowerpackWidgetScatterplotDefinitionXaxis],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1dac0b1a98078a8963b3adecf0671e52ddf6d9625a130216154962f23c749420(
    *,
    include_zero: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
    label: typing.Optional[builtins.str] = None,
    max: typing.Optional[builtins.str] = None,
    min: typing.Optional[builtins.str] = None,
    scale: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__490e597a5cbd271853dea4c6c3df927def392b6e516700e0eec4c7be6caad85b(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__118718bb4c78f02f2427bb126ba605b207f36f7932ae17f55c1ea9676a172f99(
    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2fd9a8201952bf91c2589930245fb0cd65a2965222caa5e607f359e36f518507(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dabe28b478a0126a82b819f22a057977b7f5295df37e73ee9b7e6477a9f26f4e(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__99848a2fee0ff626487345e09b351ebe8451f1d235c69ae47e2473fd841cc501(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c7e1dba7fb33e3348f4be8b26f7a8a575e104c85da2fe9233a8cf8b96851472a(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d78f10d381642a18d2f471e627b055f28cc5ff83405e895906b431587693dabe(
    value: typing.Optional[PowerpackWidgetScatterplotDefinitionYaxis],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__feea9b78cf9cb4110c6c0da11dbc00ca2f293e089d185ddd670fe126d3096400(
    *,
    slo_id: builtins.str,
    time_windows: typing.Sequence[builtins.str],
    view_mode: builtins.str,
    view_type: builtins.str,
    additional_query_filters: typing.Optional[builtins.str] = None,
    global_time_target: typing.Optional[builtins.str] = None,
    show_error_budget: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
    title: typing.Optional[builtins.str] = None,
    title_align: typing.Optional[builtins.str] = None,
    title_size: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e3e0b9eb45c832831436314eaf91a3dac0966a57cb573f890239767a7714be9b(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__428aee7f92556a3dca09ae71d76633a87e7c1451fd66217e403b0f602999c646(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__705b9be5064777482e856a8dd5e62db3b820df8bfbf55935f2e47ddc6054973d(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__10e0d2d815ea6b71645960c0bb53817e0cdc67eb30311a00cb1edd9fca1e7e4a(
    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__21a61c174ba098798a9f4be7e1dc5afabda5f2a7aef1f2bbd841209e8699c3bf(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__38ba764fd2495be21e14938ada7862dd0a1203163357cf416bcc5cb75b0e070c(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__30c3741c4530afce3433c67a1733340b6cc8be25596a673aea946633468d196a(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2f7b454156aeaa1007cbe7bc8796108a568cef3b8de0b1f9c79b88faf838905f(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3514a380d80dbe89ce493ab17589a2865dc646300c731ba8434b707e875f5557(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a459b4df00c72bb3b22a403b7339cc8c25e669915b5bebfbca6e84e1d3f3a88d(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2fadf9488665b8dd3c5bb5d26eb5f5b1cb3a18ecf77acdfd7c3ac0231e06b7c0(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e51edd2518ee4dcd0e0ef214e886b30d7f2a64e3667c85fa54cdb26eeaaef325(
    value: typing.Optional[PowerpackWidgetServiceLevelObjectiveDefinition],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__075b143164fe2f8ef7a1aef3e096d6d892726d512afb6d8daf512bd764003a11(
    *,
    filters: typing.Sequence[builtins.str],
    service: builtins.str,
    custom_link: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetServicemapDefinitionCustomLink, typing.Dict[builtins.str, typing.Any]]]]] = None,
    title: typing.Optional[builtins.str] = None,
    title_align: typing.Optional[builtins.str] = None,
    title_size: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7022f50b8b93445f2580066eb16de0f285eaf390b98086e90275a2a953862b03(
    *,
    is_hidden: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
    label: typing.Optional[builtins.str] = None,
    link: typing.Optional[builtins.str] = None,
    override_label: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a4f533ec410d3dc721084fa8fded47047641902f4cacbd11d73e42e5a302774b(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__42e0b122e0900dbdc982ce79f61e3a17e19cddfdc17c04bd1a9f07b27ca63cad(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1384159e1b5c26981d2288a93e5fdb191e489a76c8f3591e826f53678d0e1d43(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4a29954ffcb6892e016597cf5928c209f1919fb3248b99fb669ab78175999468(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8b84d4d142464e059676dd1ad8cb2eac31e8335b4caab449a0a69afa37755116(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2698d6333c22c087d98a5f9ca6d03e1f4ec7913cb7dc94dade88d866bd9b5415(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetServicemapDefinitionCustomLink]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6409a13af1f3a8e13233cfb7cd2ff77ff2ae0e1d4194b45acc350f9a5f1ec701(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d33c95421e8e6e799ced40a9471db0e2796bf69e1c12aea0aeb01594e8c0f40b(
    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9c01ab462d4e18b66e129a8fd08c9911f5fbbb69d6b4e4cbe1c768797369255b(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__03c89b97dc9b6cabfae132978226a404dbc78eb715be0efaea03f02d66c1d40d(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9ab854789f796b685cf8d61bde74befe1185651632e0da46fe182b31f1f965e7(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e0c0de7b6d4a01fbf9d1450bd25598a80d652e0d09c51c90bbdb9d4fcb28959d(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetServicemapDefinitionCustomLink]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__654d5dd425e56e980b1153435561e20f2a3fa45acc55d8f73ba29040e73be43e(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__954514cc0d1d6cd16fd94a8e8f0e464e297a34547cc05a042b5accaad657b102(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetServicemapDefinitionCustomLink, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4477ddc3309aa6fde553ab6d532e81afb45b4cacc1f14644b59c2649497b15fb(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0b7c430d3bd34a4b55e1de16563852417c40eb08a8467f017e04a307053b2f8c(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e50bf2aef9d932595c143f1d9cd6cde05fb5a72918717ec2f72cd8c422a6838b(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0c6bd5172ab4083d01df4738faa1ba6713bc63a6deedec4f2b4cb47bad90be60(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3b4b6f7f723c378b661f949786d1139b9ee446402a8af59b0c2ddce53fbff51e(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__65e915321c1ad8d0015873cd287e08b5741192f82d192074ed6ae56d9ce39942(
    value: typing.Optional[PowerpackWidgetServicemapDefinition],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4ad6d4aa7e87858913530061a320d8c4597ddc4f59ca0283289803d28e8706b0(
    *,
    request: typing.Union[PowerpackWidgetSloListDefinitionRequest, typing.Dict[builtins.str, typing.Any]],
    title: typing.Optional[builtins.str] = None,
    title_align: typing.Optional[builtins.str] = None,
    title_size: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c2f852b1aa8fad1dfc340c29833c0ec8650545b013ddc2e04f6f23e837794dd6(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__89c19dce651449f771a4273e7f38de3bd69bfdd7fa08f50f1d485de7bfc2943b(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d669ceefe987b5659ec0f9722cee6ba9a3c4e5b2cbbce3b6df0f17b90314f844(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ef1ffdf68e40f46ef2c85e95ca580ed4e6af1e3de08117aa6bf3f2beae02aac8(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1d382b7b2b2dbcdc65e3dadb9a605c2f21ad76eed0c61ade46a606da278c0f76(
    value: typing.Optional[PowerpackWidgetSloListDefinition],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8891b1c792a8f6740a399ed86ae1f7cd99ee6b8056071309f162dc6bb6e434a0(
    *,
    query: typing.Union[PowerpackWidgetSloListDefinitionRequestQuery, typing.Dict[builtins.str, typing.Any]],
    request_type: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f1468e188a39e7938c562bb5c579f98a44dd48eade55cfac307e1ad67498facf(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__132b16c1e23198a5d63ede30bd319b6b1801e9ac780c0ca297604de037f0506a(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fd01bd3c5a1302c1d606a208feb4e2776b9176a0bc4fb32d57254afdb0dbf373(
    value: typing.Optional[PowerpackWidgetSloListDefinitionRequest],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__96b05562519cb993b0e520be9e943ad666ed132aed45b0afaad29d873fc2af57(
    *,
    query_string: builtins.str,
    limit: typing.Optional[jsii.Number] = None,
    sort: typing.Optional[typing.Union[PowerpackWidgetSloListDefinitionRequestQuerySort, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__694b4606cb246a04b9d9ed1097c44197a182c00491f25fd291ebb772ff7b1ce6(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__520b542aecd40063ce3d38a0424a39858b415190d2193288f0a072880b8b339e(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c179e279d677dcfce5559532032ab845722c442b77d7fec10e0d447d587bf19e(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1cf5a7333de3ff886efd16393d5cec5ab3d56ac98c8723401039a5360dc91004(
    value: typing.Optional[PowerpackWidgetSloListDefinitionRequestQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__58fd60ceb1a0675117a2f7cff3eebb7857a9ca7c67e819eb3d48d8d06955f501(
    *,
    column: builtins.str,
    order: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b8ecf70ba5973312c55e910c80441dac18c2d38fa3eadf004187d04cc0afed97(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__98bba7c7b9242ba65290b29cc6651a350fe1ae0f145f991f37758f4e8e1de5cf(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__62f1ce3986dadbe0696e1b1df5076c25953e9ee3050be372a68c31f05f8f5ab8(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a1b3d5a85f9c2ee17068c70cabb6d97a445a4bf528489a7a87a019559a5f21ae(
    value: typing.Optional[PowerpackWidgetSloListDefinitionRequestQuerySort],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0958c8551643bbd19235d6a777918af400d7a30ff57cb18eff21b24445d88179(
    *,
    custom_link: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetSunburstDefinitionCustomLink, typing.Dict[builtins.str, typing.Any]]]]] = None,
    hide_total: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
    legend_inline: typing.Optional[typing.Union[PowerpackWidgetSunburstDefinitionLegendInline, typing.Dict[builtins.str, typing.Any]]] = None,
    legend_table: typing.Optional[typing.Union[PowerpackWidgetSunburstDefinitionLegendTable, typing.Dict[builtins.str, typing.Any]]] = None,
    live_span: typing.Optional[builtins.str] = None,
    request: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetSunburstDefinitionRequest, typing.Dict[builtins.str, typing.Any]]]]] = None,
    title: typing.Optional[builtins.str] = None,
    title_align: typing.Optional[builtins.str] = None,
    title_size: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__94c91f8aa14990a005e63523799bf75ec23386dd1098701e20cd83bf4d0e03bd(
    *,
    is_hidden: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
    label: typing.Optional[builtins.str] = None,
    link: typing.Optional[builtins.str] = None,
    override_label: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6c75654f4309b293e022e6b528ccbfe1cd63828e6019b3e1e6a857de6fad4e42(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ab15b3506f7f146b6c2fa2f3419ba19cb9ab2872825bcc72b7e8d8f544c8dc2c(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__78343ba251729ee2b1d7a988b6b829f38b34e0ca19bf07e8571e3389d09a34e4(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c87fd3f750d4be3746f2f5b37885b66b5410e38eb577ab35b77f335a56034445(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a9cf6d418282433404858e0d90104ecb12151818439c7f338d2a7eb56fd57aa7(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__28697c0b5adb963a99379fbc8788df83c6cb7502b935e5729d3fba42f1ab2c39(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionCustomLink]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d73c83ca7c8f6acb6f6ec7d36376208a142763eed490ac51d041a6a58a1fe570(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__38895a862d2b1061e495ca61d7511b6ef74d64a3b1819e6d7728f498b2946fe0(
    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__794d6cdc7768f077e5db5a9f4f0d456f4f4ebbc10339621373c8757e58318f72(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6dfc9a64bd443b7cbe9458b6a3eaa956cb800d94366eaa4acb69c99afd91681a(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__76713a227f48faf8278599eede42cc3c4e4b2ae9be923f40048fea84427d5a00(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a7bf366732a43775cebdcf1221bdb037e7d9180f58771cb02bfbf383ddd7df64(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetSunburstDefinitionCustomLink]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0c4bd910fc991e671466791fb1612d1fbb85b7c27893382605068c0a883f13b1(
    *,
    type: builtins.str,
    hide_percent: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
    hide_value: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c834992542725a244c7a990a77360133ee60833026fad92865c1f38715762a86(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8bd3690edfde6d2b625062e301e3e6d70759dd7388750afecf3641eccc226f9d(
    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8fe1f6df917da0913fe52d598a935a112d7b708107c62b83da98d9825a466bb9(
    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__023437540af754f195ed3d14661856ed62a31dd77e458088c3fadd2d40847b84(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bfc0c8d22cd6fac5dbe4ba8413a2a19e8aafa33562f3a954bf17089586046d43(
    value: typing.Optional[PowerpackWidgetSunburstDefinitionLegendInline],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__97146e165b7348fe5ff14c201b4c3b0601c3d16d6efed94f9c5bb445a4a324d0(
    *,
    type: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__353dc719a17d6468605981f44164375d9d5d67d229806b7c45222522b60759a5(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7a1c6c4a50968ea06438a310f23b07e066745db45adc514666f07f6cacc312a3(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1210213cfb3835a0397249a1d6b1cfda077a96c6d806ac2ff4d7f837331044e0(
    value: typing.Optional[PowerpackWidgetSunburstDefinitionLegendTable],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__169d0ca45bc32edad5c8ba141e7d35b0dfc64f2e4e734cf8fb6cc88b708661c6(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__28d4d6688a62c9c6e28b3a9ba96d246e7a43ccdcc34930b4a1614983ff906ed3(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetSunburstDefinitionCustomLink, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__897f5fd636be1f996318d40b88d1e57aac605235712806a1f9f916759b611850(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetSunburstDefinitionRequest, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8be8ff4e1b4a15b9b5fdb96735539192d4d54e2cb49692cae14832c30dcffee0(
    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3be81ab0e6b8b241b6bc2acdfd7cd43ae6a098dcc33aceba8590d8df8e50fb64(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a88eca10709b40f3cfdf1a5e4f84d5952240dd6922b47da6a7f309ae0db82fc9(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ae22019ac43b72ee5b68f7e0e356aa26d6d3649ec15525bf19c297eb0a809f94(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a3567eab573d68af3bdadee95d86f40975ded12ac2b6238cbcb923dc7c2de24b(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__25c8b2fc5a7058441e40c0f8dd9892a9092100c4d4967dee920238b605babad8(
    value: typing.Optional[PowerpackWidgetSunburstDefinition],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e0995dc9e66889ebb98ced81f2f65bd6a274cafce41caa998358e9c3bd5a4861(
    *,
    apm_query: typing.Optional[typing.Union[PowerpackWidgetSunburstDefinitionRequestApmQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    audit_query: typing.Optional[typing.Union[PowerpackWidgetSunburstDefinitionRequestAuditQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    formula: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetSunburstDefinitionRequestFormula, typing.Dict[builtins.str, typing.Any]]]]] = None,
    log_query: typing.Optional[typing.Union[PowerpackWidgetSunburstDefinitionRequestLogQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    network_query: typing.Optional[typing.Union[PowerpackWidgetSunburstDefinitionRequestNetworkQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    process_query: typing.Optional[typing.Union[PowerpackWidgetSunburstDefinitionRequestProcessQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    q: typing.Optional[builtins.str] = None,
    query: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetSunburstDefinitionRequestQuery, typing.Dict[builtins.str, typing.Any]]]]] = None,
    rum_query: typing.Optional[typing.Union[PowerpackWidgetSunburstDefinitionRequestRumQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    security_query: typing.Optional[typing.Union[PowerpackWidgetSunburstDefinitionRequestSecurityQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    style: typing.Optional[typing.Union[PowerpackWidgetSunburstDefinitionRequestStyle, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8a7a7c31d226ccb28e0503cc6a94fdd2500edf7f7a873582fecefeda5a455220(
    *,
    index: builtins.str,
    compute_query: typing.Optional[typing.Union[PowerpackWidgetSunburstDefinitionRequestApmQueryComputeQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetSunburstDefinitionRequestApmQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
    multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetSunburstDefinitionRequestApmQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]]] = None,
    search_query: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3af82652904acec2e556f14659527eca04f6c8ccd5472e971dbecaebbbe378ed(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7b9bd8f283049137b4b8f35e92dbc42a4e5d6873bd3116c79c481859e09083be(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1253c058e75a5078bdf9d43734b50f95337c895cf7501a9359acbe31ea6a1e92(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__eb5d0f578836ef7546f54bf600e0fb96a44a6a95ae279ddb5d91558faddb6e09(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ac87c55e12fd88f422455ff974e7c9845f9f0e59918d9e4e15ccd0cba95bf3b9(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7dda0323481c03b51b43725cc066e34e5c861916000c394ffe6eb41a0b7a5b43(
    value: typing.Optional[PowerpackWidgetSunburstDefinitionRequestApmQueryComputeQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f25d100fb5c5e9c5417c949546c7e3dbed2e5321efeef70c20f625cb72bd6ac7(
    *,
    facet: typing.Optional[builtins.str] = None,
    limit: typing.Optional[jsii.Number] = None,
    sort_query: typing.Optional[typing.Union[PowerpackWidgetSunburstDefinitionRequestApmQueryGroupBySortQuery, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__baf75af7d06aa1eed1f8edb800029f4fc2e3d1b52abf14943d1f23c31ae7e056(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__537d0ed1c60e3063868afc6a642c685596ac75cf2d8c829625da29135e99b72d(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e882adacbbbc5f5b9a4957a282056314d95930db745e66ed5ca288b95bdc0e59(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8b9970554a5fbc4dc431f339408d1df1c216972eda16df8df17777e52970bbf7(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a34d24f96fdea38371a8dcf68e3f3e247855617b4bc62b2273b562d011f69180(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6416759d8fdc029236fe418f295ad90e815f4cba88d11f656f61866d69142d9c(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequestApmQueryGroupBy]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2439d617c83fdec8726245450ecf7e0463d09dc7e805d5fa41b1d0b4c33dd154(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__014df03dfb91647cc6fc03bd703e8d734ad870beb7d8df21508498c6c9d250fb(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0b228cea44e1c1ec686110af559711970dbfd3a8676370a17e00f1fbf312f814(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__15e3bf3b35c47b92879aa53390ba0eefdd019f9141f5a5e6fde0f304eb0e8094(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetSunburstDefinitionRequestApmQueryGroupBy]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__079a0229759ac4eba10fd9e649e7dbfc6ae5782d4bbef6b3ded659996d0ca806(
    *,
    aggregation: builtins.str,
    order: builtins.str,
    facet: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a794240ce44682936a2d6e86c99a5a9c1d9edb66e6503787f22f907f7be6c219(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__50e441eceee159deac6845b90ab9f0d13de2ed7414b8bc92d51a8547689a30cc(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f7edcccb19f3c35161686b6fe28192699a59da2b3a738424989aabd7c405b156(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b78586c624a010ec4fd5f9530bcd5993133635c0438f0a57706cbf3e53d0b4ce(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ce44cef874b5ab123471d8f9799e5a1b26ffa5aa2984eae06a6519d2388bd38e(
    value: typing.Optional[PowerpackWidgetSunburstDefinitionRequestApmQueryGroupBySortQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dbc1b83f062e90528bc9ecf2e2af9f291c26b5976e7b0670a87ac196660ee816(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__df9ca306df622ecb8d184df540ae83ee631100d918f390c6110a9168e385475e(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4ded005353127fbae441cb72353ac48693edd14c2f95af7c72014ac637e0b26a(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c7e0b596654a5523f5d26beecaf90d4ebc26aa140be644c1da157ea920e08c5a(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__525f527f31581b5d64a1238544b732c16d54a8cf26fe2ec2f304f27cfe449c22(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b5dc26ded03b6da063de979eb72f47cf01575a45287c78bccc5e4b67cd425e98(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__06520043b54533a1984eaee1ecfe2a01d78c86222636d7dca72de9f059322aea(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequestApmQueryMultiCompute]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c5af327799355ffe8dfc61d43c85d67425430fa8dbd09806afb19ccc4d896d42(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cb1f8855d356f826137783b802ae589152fa43267bd49f1e44e2c5cde2593be6(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__54aaa1cedec7e4d200017a3a4febb8687fbdc458c2ff5e58f89de837b522f56c(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cf779b622a1e2aff82633ac3d6640009df85b86c08846209726cca51d2161617(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dde0f7527b953989027c5dc917604147fa346357afe64c4993887f73b914f712(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetSunburstDefinitionRequestApmQueryMultiCompute]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6887314d0ab9c4d80dd31a987b66268b85a84dcae0a4a7180aea71e0068c10d1(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c6ee691088dd6001bb296b2be75f04bc108e289ef3ca63124ca932404f5f99c1(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetSunburstDefinitionRequestApmQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b9e85ac810c5276ba13f69156705b24f8561e29a5048b489502eb6ec6dc25e9b(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetSunburstDefinitionRequestApmQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__43507b14f40d83ab3218c69b637ac167a0ba1b7d37206417914f37432b1f5b72(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3e840ced79f48ac6ed9a68580119f1877bd9830065d8e3ba03fe2c5835d062a0(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__83419e80597c2e03e65e2d03c8650599d4368136a5193bdd98da8d07cfa6a5bf(
    value: typing.Optional[PowerpackWidgetSunburstDefinitionRequestApmQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cac3328ad983c004f52a9e94b3120165ec4729e9c423c0f23cbddfc3a88acd11(
    *,
    index: builtins.str,
    compute_query: typing.Optional[typing.Union[PowerpackWidgetSunburstDefinitionRequestAuditQueryComputeQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetSunburstDefinitionRequestAuditQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
    multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetSunburstDefinitionRequestAuditQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]]] = None,
    search_query: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__802ebd40be3bd5f61e2f7bc2461101b82470d317bb1da78d9952c1c0d52fe129(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d386c820b0beeadb7b962b82fcb6ff4923080a623b1856d80d280ff70f4fbb03(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f1af238b3eefcb1734f9e253869106f987e9692c6d0b5b3f1b3ea3a2989d2492(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5a701e5865efe94cbf74b27b6d5c467ffa836d7d060a43c304d24287a859da02(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1da0b6af0f087d1b75500ad48fbba0b9f1f957aeb534095d3d5596c13759a433(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__72df6a6dd902dac41ddc6209302939efdbd6c6d7ac5656da4323e3a1ee9473f8(
    value: typing.Optional[PowerpackWidgetSunburstDefinitionRequestAuditQueryComputeQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f5dce7d563fd18431e9d8d33e50de0713bc666ec240f8bcc80f5a87e68c6fb29(
    *,
    facet: typing.Optional[builtins.str] = None,
    limit: typing.Optional[jsii.Number] = None,
    sort_query: typing.Optional[typing.Union[PowerpackWidgetSunburstDefinitionRequestAuditQueryGroupBySortQuery, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__574ca919b602d20db238a73ecf1218b4dde83f1cf4857e1d7d335e7db0980d8b(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__03586746a22f8758406ca54d9e9e35c0268b646c3d622e8ebbf9636a10a38285(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__62a47df4f9dc30e5ea65a413e4c421df07acb1497c2572ba8ec18a40648522c5(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0c303addd6525640ded4554f2fe7aab0c3d28ab8d5cd13138f8afd39a7a51efb(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__15fc886dec5eb632c7ea836e7232740b63c13324304ed2175812cd755bf07d5d(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__64a4ee7c73c61db7bc8555542742fb30c8ad156758f5c0162e266b776e9df8f8(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequestAuditQueryGroupBy]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__73c2c5a342cb08b8459a013e0eb05bdb3632c6a26118c47d9294f5025cd6ae68(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__94b7b77dafbd589442bb7db785b6e8d66be25096272f788a5f1e1abe9d0718cf(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__51c1a7c88c6875473cd59ac7162b127c37fc6c3125f187bf45021e3db12d6bd6(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__eb5ff62f4b257e18a70117c92923d7717ca4d06e84b17e41829eca42a0a16f9f(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetSunburstDefinitionRequestAuditQueryGroupBy]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__de6a32f27b289f6e4b9a8ba4eebf3611a1e5972aced1531e1fc7f88cc2e885b3(
    *,
    aggregation: builtins.str,
    order: builtins.str,
    facet: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e4e3ee536522bb8f583865156a7fb2d46967f0a9993a679c17a8044417513c45(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a603a5d0efc5bfa7c0360981b328bf34d82ea22055d44de3af977d3866151d87(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__af0cf869b5c65aa6f90bc3d87354dc3071b7a15d5a0997d5b533e0e5bf393fd8(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9b54496087aa1d172f32bb9c5106e903d13d7550e2cfbef5e86400660d3e772f(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2d11068e44323539c41d7c579349f48f9776c899bab085bca61a3a7f5b0104c8(
    value: typing.Optional[PowerpackWidgetSunburstDefinitionRequestAuditQueryGroupBySortQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__aaecbf86bee0953858f5e59c3027fc6d8a6f43f7aa960927ed7a0ae227338320(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__11c63b610f38e0a1d03781bbfc9e81b6a717d1ba4ebd7cd82efe3793b52e8d41(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c46de066897049882f9ff1ee211f9ab3ae0becd8735f0796c6ff4e44cb0f9e67(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__697319a017d81d1c98ae2a46bccefe4dd8e89588bf1658b1aa9521f98ce421bd(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f72314cac09dcc1f69a2d070dfed8149149730a506b0fd3069ff741f734b6a01(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__045c134459048efe7ad2324bb971f001acdac240ac0e5bd196366d1595d5f349(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7d658d3c91c6005d32b4c7eac3da82b371aa45fe21a52fd63d3f9f1fb47fffb3(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequestAuditQueryMultiCompute]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__804639cae287b684964f27d4430833631fd7695b1189daf98a13f658adb50f77(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d1e343482d71ef61f2c5ad79743d2c2efbde3dcb164f3bb33aab480e88ebf870(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f715ce3f4b5a9489ae8298b3c4b27087439f05740891332b9061315cee823b7b(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a6ef8506d1c177e726c6aef7f87515174afeef0986e6705615285bfd29b7019f(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__854e62c1b724d84a7ab8bb10fe38cd8e8b97268b69cb530054c1c92e0d665ac0(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetSunburstDefinitionRequestAuditQueryMultiCompute]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f1546f9bf16cce7fb70f99ce24fbb8598d3b6297ca8f4754d076945226b557e0(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4b2acb213f69056b6abcf1338035a0256d82904ae854f8ac99673a2b30b37320(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetSunburstDefinitionRequestAuditQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ada9e39829917ca5add5204cff5b4f670e9c515d0b479b9a311255d6da811794(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetSunburstDefinitionRequestAuditQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__92271f3f6f47900260b15ab58849b52c2487f902c17d9946028b524bfc4760ec(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7f9ac15e06e6e0cd541e19bd6ec395956781fc5a1e32833d0aee76550997763b(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d3de1db196020a00176e63f341567adf49bfd7fa7dedfb148e990f1e342e9f44(
    value: typing.Optional[PowerpackWidgetSunburstDefinitionRequestAuditQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b7a297ff7c2a03bf5a982965cfab4ddd98f5f1d071dae850bfa3ccbe7998744d(
    *,
    formula_expression: builtins.str,
    alias: typing.Optional[builtins.str] = None,
    cell_display_mode: typing.Optional[builtins.str] = None,
    conditional_formats: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetSunburstDefinitionRequestFormulaConditionalFormats, typing.Dict[builtins.str, typing.Any]]]]] = None,
    limit: typing.Optional[typing.Union[PowerpackWidgetSunburstDefinitionRequestFormulaLimit, typing.Dict[builtins.str, typing.Any]]] = None,
    number_format: typing.Optional[typing.Union[PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormat, typing.Dict[builtins.str, typing.Any]]] = None,
    style: typing.Optional[typing.Union[PowerpackWidgetSunburstDefinitionRequestFormulaStyle, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__446d3d863bc4abecd26fa250ffd9815da1f7fe18a22ca3f43d062751624ac389(
    *,
    comparator: builtins.str,
    palette: builtins.str,
    value: jsii.Number,
    custom_bg_color: typing.Optional[builtins.str] = None,
    custom_fg_color: typing.Optional[builtins.str] = None,
    hide_value: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
    image_url: typing.Optional[builtins.str] = None,
    metric: typing.Optional[builtins.str] = None,
    timeframe: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6e94e22ffeea988274924a5d0eaac3085405cb7b5be663cb22f5e84d02126768(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f5d8046521ac25212eec7fb35d93ae24f297292ace697f3021506c5a61770f62(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__498682372220216b3ea54ebae76432841501b4ee3fa9d31fbe14ec82ff68b77e(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9f9fdbce16fe3ff44fc1a6eaecf211182c8ed35d83b6f1ade87557b1c4139c81(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5b9e1f95aa67142a4f0fd91f9c965ba4a146acea8bc09e04678cdd7423bc3fd8(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2003d10ef1abf6b68fa157718e599f090534e2e523331eeddac90e6271a9445f(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequestFormulaConditionalFormats]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1e2462c3d383913593de51a6cc0d7c9fd22a0449557e388c0c1180a8ff3f1ab3(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__db7283b43d1032d1610f4993a8ec8fc997599cbb062f58234e528fb6b288a04d(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8c2caa2d90b2d2f3927782c47c40bf8dfbfb2f16cd91ed86411bd0ea0a961af1(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5c7ce0cd68745760f9ff3b9d3f44b8f0a182275f7958638f833a19fa3d65d34e(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2d07b0bf7ce1ece087d98cfcffb97165e94a67fae5bc5f45b97bce9edaa71d25(
    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__92a2c7b18c6990085140fee3f13a677a11a9856f7c3f20e6d2de8a130b038295(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7f35e029be30e14f8a543b653c485cf7b2be0af1c894bc22eb7fa859c913b9ca(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__93d57937201626b4f5c30082d3323cc3054c437b42b78eee1b509acfa858f5a2(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c30762956a66e77f8ee3381c4a8b6d34129f306494a2d75df91b1f154644c981(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__97c697efa0959108fc88766276e45b964bd8393f11eca626d042056b3d4dea29(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__04e99faf2a1ca5eb3c41f30389d8b2d46281d56f970dd3dd92178fb982d00bce(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetSunburstDefinitionRequestFormulaConditionalFormats]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__80e8d615008f0b4761057fbf9394d96ec1319d726f791e862c251bd969f57694(
    *,
    count: typing.Optional[jsii.Number] = None,
    order: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__20349244e549901ffbca9453a177516f6c7e372471a2a60de598bd95e8a4e394(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7338f04550c7e816dac951d488ac7b40dec98ca232b1db860779be5cfc7e5821(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9222643ca909def373e8860b92265ada6edfd1bd1a40b8ad4d3f30f118e9a939(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__43eea59c153c9ef8a4443b29d02838d1355db728c193a592f823e3d83ba70280(
    value: typing.Optional[PowerpackWidgetSunburstDefinitionRequestFormulaLimit],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ad8e72520d28e9e1f439c2c48b6c4b593f6415ebb991af0498465f75a9ec1d75(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dc38e23866564cce735cdb0bbcb4cb7197f707527ec4596e5e158503e73ac562(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__becd4d697d1139392f32753c196d13fbd6343c7b521d5fb48829de256732036a(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7a61590c8817749106d5d30965744f768715c6a09fd3b70d86f56407b8302ffd(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__56ab0ef27568b05bc1a8a3f1a33ef13c348c778f345435e1370a90c775623193(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c9d1146c9fa0d501998c9a38c8204267ce142b55c7ff8b0ab7888cf4ce8847c8(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequestFormula]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e50eb6e78b71a6df83c42f81a5683da98e95385b2671cbe90f036d4757f7a0f4(
    *,
    unit: typing.Union[PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormatUnit, typing.Dict[builtins.str, typing.Any]],
    unit_scale: typing.Optional[typing.Union[PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormatUnitScale, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5bd074118429c0b018a31927905e8d16a945ce70e6665ede42678d4e52c0749a(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b6b43baf6e2fc0b805528c6cb962fb0103f20ce497074cdbc8e39484ddf07ce0(
    value: typing.Optional[PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormat],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bc3cba64425bc4a6361e1e5de92166d2daffa8734f7d30720cb528d548ecc99a(
    *,
    canonical: typing.Optional[typing.Union[PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormatUnitCanonical, typing.Dict[builtins.str, typing.Any]]] = None,
    custom: typing.Optional[typing.Union[PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormatUnitCustom, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1ef08f883264805463f061b6a89cb15138ed1e551cdc1d20a7885fd0bc4be4e8(
    *,
    unit_name: builtins.str,
    per_unit_name: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5c343bc84776d5c205b416bc1ff076056ea6c751aca50df9bafbbabdd9a2bfae(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__60f749a16eefcc0963a0557a946f8a9809caa0a14be6fca0391109a16fc23906(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1e0a16b8f6448a528d93ff0e59bbaf143d154fefbcc5cad6b1041c2be0562f66(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5fbe52f7d9945baa845bee4c5863f179f8ae6f3149cd9b247ec0d0d15873f3cc(
    value: typing.Optional[PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormatUnitCanonical],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__707fe16e529e6835d93913b0ca44bbf2eefa47a9ef5f7617649f984973cf1bfc(
    *,
    label: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__666f879bfae940b9ab97868624dcc9379b1ad59e7a10be9af07e967ff83e5a93(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__241f97cd8a75c026809eea44c978d3aebfffb4b24ed401a604c44c04e1768d35(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__51fe7f2c3e6b3e01a037c9088b6650441c7088f82e924a4b004c9bf9c8811fbf(
    value: typing.Optional[PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormatUnitCustom],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__85738f95508f972c61c138298f377a53bf6a4c1e528e83f86fe3ea34bdc91ce6(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1d37114e56e1c58603cc4c1915d11eddae5bf8f3b834b8420ad443ff6a2ec24e(
    value: typing.Optional[PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormatUnit],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__09f6fe0595180d81bdd643b67bc28286c4ef05dc8f39ebb71e18ea5bed228a26(
    *,
    unit_name: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2fb4407ffa8f3be2a298a0e800ef40e7d0c46dbcc56ba0dcde6644b9dadfb542(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__363edc60f4ec2136b37b5cf268d4a109a3d4b32853c5a751394eea2b5ac5a5ec(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__db854819fb7a48319abc70ac012862eeacb0b4fd74734f618235a8658bf5afee(
    value: typing.Optional[PowerpackWidgetSunburstDefinitionRequestFormulaNumberFormatUnitScale],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__68269d9327569a124607c9bd18e2ff8dba454470e500e9397b5b9a6ce6b65c2b(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f9e5c176982937fc21c6f173234a95ef533cdb757178ea2647b1c10e5f2e644e(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetSunburstDefinitionRequestFormulaConditionalFormats, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cb334c2a9599c62f4079fcd62c24864edd01199ff7f9e211ea444fcc3f9ed305(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7f6a420c68892ec1a5c78e3a4e8e747a80e046352cff52d89e0da49d4d70ddfb(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__901ac238bf8c3b6820cbb9d1f079b82432c604849d4265d21ecbee78b8ff0c33(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ece6ffbe8a62c48c325caaddbb0ef112317cd76821cb68451aaf2be6962ce01f(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetSunburstDefinitionRequestFormula]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ab3154a4563d073370f0e6f315cdd6ae0169b554a73b16dd4ef86b6e16700cd9(
    *,
    palette: typing.Optional[builtins.str] = None,
    palette_index: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0ea2c1ff0fe8161211894e6697a22dfe084eb159e1eb987013ea2b329d2371b8(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6d6fa23383095e9e0ddd2541e08db5b8850b45c707c56c9c64be0b5422d5bf92(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b083d8106e275a4f4c26671f005c42b8c2647628e5a943d7d9b46961097988ee(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1bd24e3fe6db95d61503179bc339ab0f90a896878ff6739c9804017d05a20e57(
    value: typing.Optional[PowerpackWidgetSunburstDefinitionRequestFormulaStyle],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e29b9593b7a148844ca4dc06b269f927aff17104616d05cd5e71cff4a71af22b(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5337cca460a5e9ad84fc0b5539551ceff3b476900464a3d6d257b8ce713be13d(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__382335d0b190bd07f406536199176a78651ffa422d4fd2e70a99f6e7f5aa4f9e(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__abf4d797830afd44d55a9e3ad3cef56aeef5e9eebee45fa0f975911435aa2d1f(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f4e1af7624cea8632a60c9bb9d41f8befc6cc905d5a1253669a0c1baa151211a(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b003e064bf075f556e23c638a9386d8f7ce0ab70485674c4246dac7eb0309232(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequest]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dfde00dabdde12714dd9b6bfd242ed36699e510813cd9c3a1589a797fbabb7a6(
    *,
    index: builtins.str,
    compute_query: typing.Optional[typing.Union[PowerpackWidgetSunburstDefinitionRequestLogQueryComputeQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetSunburstDefinitionRequestLogQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
    multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetSunburstDefinitionRequestLogQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]]] = None,
    search_query: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__96208bb84b1265da750adc4035ad3f73d31dc965cd7c74bbe40119453672b02f(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__92a1ed4cc2a849e84caae0654accbe776f8f57f78589405f17ba1ac9da6d16a0(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__307a0841505791a879a99bb05f59dd8d99d58a101a40dedfc0f3733460b4a341(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0209729865d1f2d12d52bfa1361e4029b87b7ef114382b33192e91ea5c194739(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2035b7fd0a68577b24ac29159432ee530c61c00d889f37183ea94b763464a415(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d6f2dd54448d8ec221654445369b37d4d5bebbb65375048a435819a51cd0c804(
    value: typing.Optional[PowerpackWidgetSunburstDefinitionRequestLogQueryComputeQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__48a741ac667f1ad0340fff3728cddda8cd017de851939d2b32f9028fe87b549a(
    *,
    facet: typing.Optional[builtins.str] = None,
    limit: typing.Optional[jsii.Number] = None,
    sort_query: typing.Optional[typing.Union[PowerpackWidgetSunburstDefinitionRequestLogQueryGroupBySortQuery, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e24efb78183ba18858e80ed2fc6fd255ea06044136139e2f65dcf066dc6d8f52(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2f6fad132cbe940b10535112732914bc2a552d2c4dd9cba95d18258ef7268ec0(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__35d8688129c0ae2416aaae4fd7b6d8eee3a2acff2bc83de573441cf53588deec(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__128a4d1ee2a39aa5972e89830bcfc6e56cf44be677bd6927ed88125d0ea0aae2(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fef8beceb360bb45681a41652f8ab1d6a81d94508452828c039cfa0542cbbce0(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bcee36606933244ffd5881f2353883fa707eb204b75544a970607647e44c1d9c(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequestLogQueryGroupBy]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4f1f4691d0a10edda5d2c17a462a55fea143c1d5407328c7b060c27bf47c7df7(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__70864a083203183e67f5badd07e16613d52629bf4cd3c3c0145027dea7de91ed(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a4cfd1b19f977ba60dd015c429a5e4c90ae0756e122cbdf747f905479eef5510(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ac51a8d31c807ff078c398ac3e9e2acbdaf7874e8e7b35f360cc60ae11b8b84d(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetSunburstDefinitionRequestLogQueryGroupBy]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f966ba2e808218e719d32e44147d49e40f9003364b085194ba5ac395ee685b32(
    *,
    aggregation: builtins.str,
    order: builtins.str,
    facet: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c2096ee4bc21b10d4303bd73cea567b748055f26bf24f9cdaf3fd3ab0067e1d2(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4caa089bb4776a8bffdcd6a795a34f70f91fc28b0671f3a80f6698103d425b19(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a08574b77206f7da5126f06d84af732df258f2c9bea1e2fcf9b340c9016669dd(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0949474e6359c96186a0c242a771bdc719b0603ded3c5186c1346a08d37e308d(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f9d497a7a059d5649455e87238afd1d9a32734f7d6bf396a65c1cfe997fcec68(
    value: typing.Optional[PowerpackWidgetSunburstDefinitionRequestLogQueryGroupBySortQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4f939fafc0865d5bac37e8d5b6cbf4982953485a70aa1353a90e57defd6662e1(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__09ab0733ad7c7902223adab907b8b10754098ddc8b565cd43d2b05556cda7dba(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d48cc5321218b5082274bb8558af3cb460a6cd4a86f7b86938a7319104908ed5(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__91552b01c857085cbcadbff2b4e67c5ab2652357f5fc76763645bb0be8422fca(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d8d747ef59ae2e2b7592fc9410f202d5278da9c7a1f499c0046690ec826b5f77(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d7ea6f68fcade609d5e03a7639c4168bd4126629b7cb00374454b8048b13f10d(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ecee38fc00ce1b397cab4eee047a540432885c29f54c60a5f7700ff6347c737d(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequestLogQueryMultiCompute]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9d3bfa5d8c26df8b7a694dbd27323e492b1561ed4e49cfe87887332df5c30718(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__384ccd23a46a53e429173259e0d2bc754f88abe20162e6c2fa4027141dad43e2(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3273fe1a27762f7b82d039dd4e56dfccc7eae5c7a4c47273f78e50abc3429acf(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__83b7654f71b4dca140f6d2cd39a88eeb99d171316b6414552bffa1690a29b8ce(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__237b0d4d7eeea38f153d8b8fccb86adbd9b90095002f79ed2f62ab459de1ede4(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetSunburstDefinitionRequestLogQueryMultiCompute]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6ee3b947a5786685351be1cfac79251f99b0056141b48ebdc5194af8d9c90560(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2a2361e1d9c4db8747f64509a127ab5f8d2a083e9409436a884864ee22116890(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetSunburstDefinitionRequestLogQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e7b86a90d1c6f6ca852ce67e4a24e8609838f2438f2d52de4bc2b189507efc9c(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetSunburstDefinitionRequestLogQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__24604abe049b7f7604f17546f339202cfb6473903b50445749cdc51bd81c18fb(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__84dd25a34ca7316d709be8266a8f72a98fd63b15ba650aa5cf1b532b2062d580(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__07ad1c6409e8a29043417137128b22cf54227387f14e96eda7c27bb20d29aefb(
    value: typing.Optional[PowerpackWidgetSunburstDefinitionRequestLogQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4efa3c8a351745bb2cb0a6feb64c5c506caebb55c15c171dd5ef2a7b922c9258(
    *,
    index: builtins.str,
    compute_query: typing.Optional[typing.Union[PowerpackWidgetSunburstDefinitionRequestNetworkQueryComputeQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetSunburstDefinitionRequestNetworkQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
    multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetSunburstDefinitionRequestNetworkQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]]] = None,
    search_query: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0e3edf8e9a094116581cc8dc49048315fca6c2b3c7cb4162e1cc4c32e9d19658(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e0ea56aa0d8c6595d546c3cdda34afd099cf1e23ed9f41cb5d99da9f1a495a58(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__823297cb25886d8f77d19491e0bd02c7ed04687a4db85130e4050658c3a3483e(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e1cef5e46a7ce960c5c7b46b029395a9e5452605826c5adcd4db99fbe0da322d(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__878cab84be97251ed931b05a3ebddf0a8ab0f91db71fd41e266554e1aed3cf74(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__de8f72d7635a9d8e524eab44eb311a3e74d5daf3d1ecf2368cd3516543263c43(
    value: typing.Optional[PowerpackWidgetSunburstDefinitionRequestNetworkQueryComputeQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9edbdf4c38a3c3ee79bf51bce232398a03c8ab6d77491341ffebd3823ec0a527(
    *,
    facet: typing.Optional[builtins.str] = None,
    limit: typing.Optional[jsii.Number] = None,
    sort_query: typing.Optional[typing.Union[PowerpackWidgetSunburstDefinitionRequestNetworkQueryGroupBySortQuery, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__912135f9e24cb1bdd196c3732f02e551dee9512dd541aca2edeb554082cafa41(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4b9072c9bb61eebcbc94c71ae42f3fdf0a0cd7955c5e8482dd2d064f15e3a097(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d5380d7aaee9cf0450992deb85dd683cde781d9ad3f7d0896ad67bc6b598f366(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4047108167369a61144ec16bc2511699329304f9c1d2905465da83cfaa3e665d(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3ecf6e811909246550784a7461a41c241ccc2c260aa9b51a982001c159663769(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ac43a95c3aa4ce936c3c4d2e0d3c79ad27534f4dc47094bf5cc7aab2570f776d(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequestNetworkQueryGroupBy]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a9f8e09e1f687f9235daa7addaea6cb2eefe71dd90a27af476531c2d76a23b56(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7772db6b6a24e1c0bbab04663c689c6d2a2500e631779a47a47abab208012ca1(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__414bafeeebab94009fe846b24cccd576b48ab2288ddcd10cbf785c8eef2d0758(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1d62663443f3a52f79c7313af22fdd3104f3b8e6916436744f9f7e2fb3004afa(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetSunburstDefinitionRequestNetworkQueryGroupBy]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3d741cc464aae5ca9636a5c5f51d24143b3e4fb0ab41550b9477d832504ddfbc(
    *,
    aggregation: builtins.str,
    order: builtins.str,
    facet: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b20524c7cea80a5c00b8c6129ec83c835d748d2381444a19d8fcee5798272de3(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c9d131433d584fec47a75a941e0761e913600856ea7d0c891ed0f8883aecd92f(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c9e0876155f1c5aed967d35698f02492af3f6832abb2d49d8a7d017dad99204f(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__21061d44c150636bb5dbc4367d1973b6210a980a787a3a222899147f460a6ccc(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0d2a4045919014fbbb6a29fca154c26d8d131acfc0cfb9e5e4f3be6a3c5325c6(
    value: typing.Optional[PowerpackWidgetSunburstDefinitionRequestNetworkQueryGroupBySortQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__abe8bb23e2ad6671f4c7ac460aec63e3db863080f18759ee452b0c4739a34cfc(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cda090c4863e925f60f7b05c2d62c99e9271ae031d48a5a55f2e6012ba2aa8da(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4c018ec47cbcd617382b045944cb3632fff5bda39306397baf7584c99322a85c(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__74ef625d2af96c33375445126120d0008f623e7a17ea741e7a5ae769df4d74c6(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f8268874d76b895eb19aba7b88496623ae44db2a6f1a8f6774610cb9f48f061a(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__de9f52963e757e0dccd3b762faf0aa9220c908b1babccf3275fcce28acce7f6b(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__64269e295dfabfa8987c148174619597a1d7a2a549754ba4adfe5e1c0c298ba4(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequestNetworkQueryMultiCompute]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__45bcc5c088e3d12f6e5745916a292f12e0b1794b9a8249e31b429079e73510ed(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8e9d6fcf2228492a8554b7cc233efacc666262368b440f9fb5a352259f75d5f6(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__762f53a573c1af60c00c6f721412c24c962056ca7b1ce97e877695e476630dd8(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1fd432e41dcda5e3602a54f0823499f399ff5a0c54ded183bb7a82e8f0a634a7(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c84f4531bc2cb1aa26189c1722176fbcccf9bfeb99a908318ff90b6eb6e61ff3(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetSunburstDefinitionRequestNetworkQueryMultiCompute]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3f2ca55bce2abadc6007e99477957b44df445466a3f24c3de30a3b7083050b27(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8853a3b8da97d1922660ad79804346ed61d3c68263fa64aaca8a61f29ac5eac2(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetSunburstDefinitionRequestNetworkQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8662bdc3c2f5f29eb089122e9b67127eb53eeaddb0ca68f38efaee9f769a8906(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetSunburstDefinitionRequestNetworkQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e8d2bb7bf3110938111f53167b052db2f65971c732139d3ff11ce0c952693ddf(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__26130c7e86bef07e41ccd49a58b82225cfb4122646851ee9ab62f89daf160bf6(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3f00da3be295f76474f378868a74c4d7289d94e341e698968a89ce2ad11a0a99(
    value: typing.Optional[PowerpackWidgetSunburstDefinitionRequestNetworkQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5aaecdd16746d53aacd41ff81b836ac0b3e70dc2e9e186263e4de79f1fc4c9ba(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7b85cd8cb23888591a60a7d2f94bfcd78d0cbcfd0828a16dd6930e97a80d6127(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetSunburstDefinitionRequestFormula, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9a75dd292395a20a5165cf0a12c59f3c7f6cd0af785e61dfa28fae2ad43a2d36(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetSunburstDefinitionRequestQuery, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bbf01ce7422f8524c1ac4065050a1fb85fec33ba2faa057f2a1dbd5cc2e8b19d(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2866035cdb6debcbf3580cd67b27314cae487a47213bcec5e0c5420105129465(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetSunburstDefinitionRequest]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3049126131f9cc914e6abc51a07deb817daa3bdbfde03a91057c0abf91e93808(
    *,
    metric: builtins.str,
    filter_by: typing.Optional[typing.Sequence[builtins.str]] = None,
    limit: typing.Optional[jsii.Number] = None,
    search_by: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3dfb2342ee171068a57987c050e3898a56903c66744b324e1a9290ef282ebbc6(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9234139a9118123cadb293d6d42a8324f161f7e9e4e8530d41c466bb65b71b27(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__866122b60bb803dcee699a6efb01392e8b1ec74e64852a68c61f286e46d877d8(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__65cf96fabc6593beb1ac676f7fcbc87aa6dd596f6a650170d702a713208a446f(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d0b90555c189fd97d0a32fab1d4cecb257cdde083c938c811aa6bea35170ac71(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__eac856bf8b1abba663c0bff4e61e294649ebef0911c57babb983e38105bec067(
    value: typing.Optional[PowerpackWidgetSunburstDefinitionRequestProcessQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1d29aba37fd281bc31c0af62f38c43efb4c06a4e828095cc84329d12e4dd8eea(
    *,
    apm_dependency_stats_query: typing.Optional[typing.Union[PowerpackWidgetSunburstDefinitionRequestQueryApmDependencyStatsQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    apm_resource_stats_query: typing.Optional[typing.Union[PowerpackWidgetSunburstDefinitionRequestQueryApmResourceStatsQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    cloud_cost_query: typing.Optional[typing.Union[PowerpackWidgetSunburstDefinitionRequestQueryCloudCostQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    event_query: typing.Optional[typing.Union[PowerpackWidgetSunburstDefinitionRequestQueryEventQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    metric_query: typing.Optional[typing.Union[PowerpackWidgetSunburstDefinitionRequestQueryMetricQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    process_query: typing.Optional[typing.Union[PowerpackWidgetSunburstDefinitionRequestQueryProcessQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    slo_query: typing.Optional[typing.Union[PowerpackWidgetSunburstDefinitionRequestQuerySloQuery, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cb5a1a5fcf3e88a44555344f4ec0734e2a3f7d68028620b409b5bd79cd03c307(
    *,
    data_source: builtins.str,
    env: builtins.str,
    name: builtins.str,
    operation_name: builtins.str,
    resource_name: builtins.str,
    service: builtins.str,
    stat: builtins.str,
    cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
    is_upstream: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
    primary_tag_name: typing.Optional[builtins.str] = None,
    primary_tag_value: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4605f1492e3d76f983a6bf70a3a1439797f815a6894db58a4a4d060ab1e3c53f(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8c9fe6a9baad8fd6eb052789cfa6b51bda6624166c6892870b8586f423ed260b(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0478b0656184566ac14645379b01a7731fc874f014f5bc03866214995923e9a5(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__025b7900c2d58e96912c15007f00736dc926a49b26e00142e5f1f383d84e7520(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7230e3b1979c84eee87351072130fe2a7afa0c9b5db0d1af0661e55a4e17e6e8(
    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a4f01f46b6d62af14a283a9c123689e08e6f8b8d3ea44bfd6124fb015660ba99(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6d6ac9e369941adf59ce10e40bb23d89d3f66599506989ff3b7c4cb5c0ddfbe9(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f09cd6db12bfc23921bf86ca772287eda9e08cbfae46eb3855089a3dda042930(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6127dfa478b348fa46870a1efa4164b4628fdf1ba3ac0b4a1a1091260ebdaf47(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4972f467057c85274890da58b8c949e2648c53136de19a7548ac587a1696f085(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e712e560bf7c96920dfc4865260d0e3220f3f3142510e4913ca396879827c616(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ff54d60893a07681a5436bf6f6af0cc5999c6420bbbd7b4905d965166680bcad(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__72a0ad8dbdaf6613f062ea4f787492474aebaafd3b59a847b8fb964ddbe1b8a8(
    value: typing.Optional[PowerpackWidgetSunburstDefinitionRequestQueryApmDependencyStatsQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__718d5358613b1d893fc109f1a83f979ac7e0668c0bc792f82995b4105d5536d2(
    *,
    data_source: builtins.str,
    env: builtins.str,
    name: builtins.str,
    service: builtins.str,
    stat: builtins.str,
    cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
    group_by: typing.Optional[typing.Sequence[builtins.str]] = None,
    operation_name: typing.Optional[builtins.str] = None,
    primary_tag_name: typing.Optional[builtins.str] = None,
    primary_tag_value: typing.Optional[builtins.str] = None,
    resource_name: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a851bc0426448245814dadf03bf716fa6d2341eb22367b9ed89b27a1c63fe5b8(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2f64de41a4432ca0fba627304f3dff347ecf652cb4a8a026eca1abcd718b66a0(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f09d12d93a41da8fbde23e26196f303f56a6394b59e0c55ca5b50f5ae9d5c5d2(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9d9371559a8ab951fe6094e43fcaa7aea142be86ba9d30705e25794a85d9438f(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e81f70ca7e366b78690e396c7ffea51f3aa5d8aa19883a60009a44aa18abd5a7(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5a327d8c80ab7fc09fee7e42ad5ead9e041a3a90483eaa8f7ac69cabcc91995b(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8ca93d1831ddc0092500a23cf85d30097f2b901c1b2e7e8e613d9623b88740ca(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__690d4dc486c0ccf5e602100bf6a998c713a4f366cd4c50e0c052ac7191a2d38e(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__87dadc09ffe5bcc31bc4f0068c13d945adf0768ea969a952ffebcee1aa33c388(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7cea2ec36c044590a395f170382fd4702a9a5811991b3bda87a014e42066f3a0(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__492966dc9c64be0fcb56f8299bd5c18c9d2fe38009a3a40133c1aedddfedb914(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__30267ce0d1f8583f18033df555de25fa1aa693fc05be222ca16f84cc34713903(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__03ff876fbc46afa23f297d07da21d7f2bcf6dd3907eddb43fa66111a3ce95682(
    value: typing.Optional[PowerpackWidgetSunburstDefinitionRequestQueryApmResourceStatsQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c3a135839de4f328ae8109a4de9a21e4d00a4113cc8ef661e86ad9bcf6f358dd(
    *,
    data_source: builtins.str,
    name: builtins.str,
    query: builtins.str,
    aggregator: typing.Optional[builtins.str] = None,
    cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bb4aed7f9bbc6836de5d824c471aece36da87ddb36409046d0a7f96ac1a9bc6b(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__38a5a7cfa1ea221373488cbf97feaddfa4aaa33e458f76a332a0d288391d20b5(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8f2bdb52515394561d4df72a043c6bec1a053d5e30e1102e3acfce368b7d10e0(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9e96dea6c95abe837807cde9a823abdb761b96d236e08934a943d2fa5b3fb6e3(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a77a47ee0f97c2e463c0ebd5ad374763e2019977062c4e45e055a543be64ea5d(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__57cc75e7e40ccebb6963aff98c885c2686aa64b06a5a6a2a0d64f1522e65bea7(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c64ed26d65a9935c06241de717db8d8b714d275211634b1942cd70be74abaf6b(
    value: typing.Optional[PowerpackWidgetSunburstDefinitionRequestQueryCloudCostQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__08c6c73402d23ab821a246ff11c920a19339ef686731abae55d6082254b8bdcf(
    *,
    compute: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetSunburstDefinitionRequestQueryEventQueryCompute, typing.Dict[builtins.str, typing.Any]]]],
    data_source: builtins.str,
    name: builtins.str,
    cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
    group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetSunburstDefinitionRequestQueryEventQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
    indexes: typing.Optional[typing.Sequence[builtins.str]] = None,
    search: typing.Optional[typing.Union[PowerpackWidgetSunburstDefinitionRequestQueryEventQuerySearch, typing.Dict[builtins.str, typing.Any]]] = None,
    storage: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__11e119990accc4c6d0c22048cafb7ce4cdcb78ed1e9360ce01b1448f25ad8211(
    *,
    aggregation: builtins.str,
    interval: typing.Optional[jsii.Number] = None,
    metric: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6b94cfb445dc9ff1deb183702adea4108ff391ec616728e7c0eb994d77825b8f(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__836d0a4cc4e23e718e1370b66eb1972ed70464d71334f774a831c8deafdd305f(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__932483abde8b2c9e3f5867e8d19405f22bd26a05daef6761569ff8f1bb6dde93(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__50c7b6d46f61ffe3b7ebbf487fd6cd3daaf3cb71dc84a0da1834fb21be6f5e39(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e42b51294f285671d6edf9817abc8b84be7993e3f523a7a33f12abfa5475ae97(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e081a7de5f577d9cf9a3ca1f755d2de8cbc5ecb94e618a4ad8edbc4cc0d23d48(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequestQueryEventQueryCompute]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__05944d86d9aae4b5a1afa1327a810b4b7bf58bfcf33d878becb813c75daf6c64(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__adbdc3c715eeb264c086ff7c94dcd86c38d7338356af956133717b718ebdeb0b(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a6cde24d232959c0c24214315f32af995aab81cecaca5c23fd8817b9061459d7(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9b18ca6b2d71e3e65107ba31e8e8cf850836f50bb1848adae8e05861fca2577d(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c430c2b2d8c07127ec13ecbc810df52bf00c0a28b2e15195d137a25aa04bdeec(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetSunburstDefinitionRequestQueryEventQueryCompute]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1a48dbdb53a22ee96af221ec0c973649937aef67ee5520f32664c81a23e30f88(
    *,
    facet: builtins.str,
    limit: typing.Optional[jsii.Number] = None,
    sort: typing.Optional[typing.Union[PowerpackWidgetSunburstDefinitionRequestQueryEventQueryGroupBySort, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c9225f31dfe24a9e4bc594adfa801da80e67785bfc71e9017150a3e5ee8eb9fe(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a8c589d54757e73f6a870ab69d26286c8e4bcda7e0d567d963d37e0b91dffdfa(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4e313192aa15ffe234565fb67a0a3222f414d7a4067ef26848517dbfc3b0694e(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6bd41c499f8363c1b0330aea6de1112ff79dd554b550002cd2850cf01f62fba4(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5ee00e0f4fc16550913ebaca75d4485d5a1886f82b4111a8c789942491ead3ac(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7de276ab3e782fd62719ec7fbbaaaafe569cd025cc96872b728bed456a1f27e0(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequestQueryEventQueryGroupBy]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8f27d315abc07c51678b22a5e1a7d6b38cc451efbc411e420a45ebc40c60b767(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4354bf813bfba7b8f8c400e37b0b9bd43666661d95ed232d1bcf8dde862403cf(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__774b1b353753efaf66fce237c0899c011488645128c25ebc033bbbc50f688311(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__66c5cfb3c9cf67c2d1bf0a26bbd16ea3cc381b8c68512c6e4eb7cb2964758847(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetSunburstDefinitionRequestQueryEventQueryGroupBy]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b65ff12b2e1d777fc5a874e2e47affe1a00c2684019de739a1a8895d4fd36143(
    *,
    aggregation: builtins.str,
    metric: typing.Optional[builtins.str] = None,
    order: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a401b25afc8a7361d0cadf0d002b2c4db55d2636fadcbb6335085529b7721de8(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4ecf941b997bba27e32bbbadbf19bed89dfa86d902a0b541592bb7b0e1467225(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f4bd16661843e7747c86eb84b13a6d3aec9606700b38dd20a5889f861ba83d8b(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__efed57c6d52d7731d457d902cf1844dfc6c150b9ffd8800dd7fa1890a116f47f(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0ad32fda348e8b4a6ea81da0208f8510aa31450eceddd20c70bd26e63a8795cb(
    value: typing.Optional[PowerpackWidgetSunburstDefinitionRequestQueryEventQueryGroupBySort],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f2c696534c0f3512d87bb13259fb1f0fe424cfdb12e7302dfc85c57feb73c7e5(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e5b7424b706da62137a623086e4995b83463e168e46b6ded330c0859522563ff(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetSunburstDefinitionRequestQueryEventQueryCompute, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3bad93e091674257ad67f4d349b8d5f78c3d57471474169cef4f68950feeee43(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetSunburstDefinitionRequestQueryEventQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8961cc4f1c798c7342813b6a5a3107588933f55c3aca2f0aada1fd0150253473(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ab966700bd32d6f3c228ac93a402ef7c54c10b04741770fa8fb758cb1a2d67a2(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6b95d02718f3c487d4d2a47c1cd67a42e065db494b3d845d6ee5202c5b778aea(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ae6f793488f7eb4844b4c60907e62b0a5f1982b3daa79cde69a84e1f573af176(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5cedab61a1daaea0668becdcea8d313466cc74f82b2d107141fe328265963646(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7356cb86df03ae918af8fa9f5b281fa4ef108af10a5b2b3cf9d3846f868e3ea7(
    value: typing.Optional[PowerpackWidgetSunburstDefinitionRequestQueryEventQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2c83d094817dac37cba130d6cd7501b69b0b8e16493aadea2666963cc1610796(
    *,
    query: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8ef6d2645145e81febc8a8005e42e20f27aaee9b6bf399324017fc353e57fa00(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__39a427f7fe2778e2879f02242dab7237f7e423d4d92a83e37fd80e745ffc5f0a(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a8a33300d756c53fc357022925ef133c59fed450d6f76dbc61c07c89b4e5fd47(
    value: typing.Optional[PowerpackWidgetSunburstDefinitionRequestQueryEventQuerySearch],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__50bf811863a8f2b509901e7eb15d861ddcf9cfeab82e426eaefa5b1d59ecae2e(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__54979cf5c811e2f56fcd03d949f117a8764967ab24c7c3725dda90ef29a66dab(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c2fedae5dab36089d2a7e95ae8a6385967709ebe94a702aa031c39f087660987(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3d563ce78c9855ce12629f620a2ac4a7aa49b046c0047d1e77ff9e4c37b1462a(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3c8d4b51d5da1355a4901e7d01fdd714d97e747cce5dea917e3b45f2d28fa017(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8bc0e08da3928af9ea3aeed8ae4d1675e8d944fe192c236a156d989e25e2015b(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequestQuery]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1b90fa9f5e8273c148184b013e7687f504b6123b1bf5934f20fb25e13d8a28a7(
    *,
    name: builtins.str,
    query: builtins.str,
    aggregator: typing.Optional[builtins.str] = None,
    cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
    data_source: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__532f66992f397f073c0fd2caae3ff74efa0b093179607a5beb5d893a9056784b(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__041011815057b99cfc32995e1f46d673e749190a5d77a07e9ab1e135faac96d0(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__75bcdab0defa3d76cc2c40b23c0e3e5ba27e3854e5fd7df2523f813f46c10886(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__24d67cbbe7574184a617b9e12fe7a1b919326beb0ae8c4f8950d2549296dc107(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__81eab4b277abaf0e2a95a516529187816a515d72210c756d86b884b0305dd836(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c4c135be7d2c5bf9fad97f5a67599eeca909e9dded93afda03e9798c98a353af(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8b3c9e9939634b9913394d3362902c0dae40a893d169280a21b3ef5c92d0922e(
    value: typing.Optional[PowerpackWidgetSunburstDefinitionRequestQueryMetricQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7ad645bb7b5ec593de291baf0221707b7307bc2c672c5bb561cdfc346af14df3(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fe01f39fe3e084503daeba320906b5ab40b9d58204b5271e99873ee444621705(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetSunburstDefinitionRequestQuery]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__76abacb3eb67fd12364fbb5d5a82c140c864bc2487bfe0ba24c127b00529257a(
    *,
    data_source: builtins.str,
    metric: builtins.str,
    name: builtins.str,
    aggregator: typing.Optional[builtins.str] = None,
    cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
    is_normalized_cpu: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
    limit: typing.Optional[jsii.Number] = None,
    sort: typing.Optional[builtins.str] = None,
    tag_filters: typing.Optional[typing.Sequence[builtins.str]] = None,
    text_filter: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7f41c955a6510db40f2baac1de99c21709666e6ee36a37e954b1b8883352b869(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__35c39831f41b993a83a74986ca989ca8991e463971971bc13f929a346507614d(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4f518407e4b848d8b69fe9295ddbbc81e5af82ac93b5e0506a0a20c153638eae(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ca219c3ec31a558ee28aa056862ab5cf08eee76a347663355ce229dee99067e8(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8496219aebc8c109bfdef9db97c38d0a08e31b951f1782f2808ebc2cdc40eaee(
    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__08c5d60cdd25e34c91893f5cd0bec44f9087acf8b6268e94edcd2ad97a1fd3c8(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e86c1ba89dd156585042b7608a813ed6a23a98fe9adfe40a2e33e51cee26f6b0(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__323c21449ef8d3b08f9d9315b10d0f366b68a535a20d9f6165134d59415a152f(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d4df6bbdae683cd340ad95a0eaf67a24fae7a174ee9caa344b26b96d4b3c9442(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__756262986b65a35c3d95a9bd8b431ac87e752e8765b21c88e0390587a17dcfda(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4781eab37fe2adebcead06b312d8339136584f9faf43129676b38bfc9c7637c3(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7c922acc779735e24bc10d06a365fc2387d499951233065c330accde829458d3(
    value: typing.Optional[PowerpackWidgetSunburstDefinitionRequestQueryProcessQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b4f7fc708f6b356f1810f2c4440611ac8c60f7a0357e97520a6e2d9713997a8c(
    *,
    data_source: builtins.str,
    measure: builtins.str,
    slo_id: builtins.str,
    additional_query_filters: typing.Optional[builtins.str] = None,
    cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
    group_mode: typing.Optional[builtins.str] = None,
    name: typing.Optional[builtins.str] = None,
    slo_query_type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__19d452287f22692201dc34a2438d547f5c759b7dd4eb13c5e51d932731185354(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ab4a0930a559b2f90b61075eaefc008bdef09463cd57242ba27b95ffc5a2944d(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__43253afc1c8fce39150b9e6cc2c9e914e24e426168d7618bc72b807decc57968(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f2ca53637a1224eba15b133d28ea40532736af7d0fc7210d54e337f0cffb25f8(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bdefd88fc1d84244afb4a8cd4c12cf61b482a2dc57528231ee716a54577b45cf(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b8fadc724459d9f5763ff03d1dd027d51ac96cd7df235733e60fc20334e1c31e(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__179a5150e3ebd72cfa808c9ce020ad95ad07e9b1293e8c201329f39ccbb74db2(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7b93c122865946bc459cbc9be2b006ab56ff00c696d076d0bbe67f79f1a94c53(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a6cd6a90d50b37439b4ae60ca56e3aa60e0e11bb51d4e2b43c6f084416626473(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__359aed28db95a37cedc0fbe9d882c4cf8b722de82826a6a1c103848d32a5b8e5(
    value: typing.Optional[PowerpackWidgetSunburstDefinitionRequestQuerySloQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2bed6ad97309f413a71cf589e657f3f3cedc0ac8408a702db33bd20de5c174f9(
    *,
    index: builtins.str,
    compute_query: typing.Optional[typing.Union[PowerpackWidgetSunburstDefinitionRequestRumQueryComputeQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetSunburstDefinitionRequestRumQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
    multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetSunburstDefinitionRequestRumQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]]] = None,
    search_query: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__07cdea11356ffec7cfd4730002582217201c01656ee169a68cba7af812bf6bb3(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__69791ee536eb167ccf35026b0e461e9944aacd0cd12e8b7f116d2497a61e53ad(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__aa214227b50d784bc5be40be3bde9c93f1742ff4477c607cee1505e0168d7216(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c54468a42bde2ce30ffc5428c2d3da8814e7fc6573406d3d2eeb6cba9c801d53(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5ce4231f38876de26fed28dd4df93688886489becaa8dc958e00a860393674d3(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b9a24a99c8d4012c278a55247745ad97c033f872781f41889044ab38996789b9(
    value: typing.Optional[PowerpackWidgetSunburstDefinitionRequestRumQueryComputeQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a93ba6668d7b4a15c232c15db79654736256131b68cc63b4ae9a97e4fa389b64(
    *,
    facet: typing.Optional[builtins.str] = None,
    limit: typing.Optional[jsii.Number] = None,
    sort_query: typing.Optional[typing.Union[PowerpackWidgetSunburstDefinitionRequestRumQueryGroupBySortQuery, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5cf63e4e598d97ea3d47587278071f91e7de5698072f3c9442ba58e090b9e33b(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__47fee7435b4e980e0008dd34b830f14f2995be886a7d92d6746a67697ff01426(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7ef5c54341ae8bd0eb86d385155d074a962d550a0c8dd00043a81a49248291f7(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__627be6df0f006d101c24773104cd22f2d9b417922b21d2d06e19c2a16b221e5b(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8a183de43c06dbd7caaf2fad7709798e766d727736eb9b2f7f948b809e22dbfc(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__12133f4c2782473c00e19e4028d73ee0167c2092ca268288898326fc46b961d1(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequestRumQueryGroupBy]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b13f76411c2e665f4b99cbb1dc6f8edbc317e76d1349fc8c977acd8ac38f3a6a(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__564f1651b6c649056d30988eb5d613064081aad9b254200fd08d83792b23b62b(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f11681a8b3757af3ebb046292fc046c0dc3394b62a631896494bd4087b9ce3b9(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c1a47a51f9e340e3da8e587a4dbd3aba668afd5cc37eb9ecef6afeec736bd245(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetSunburstDefinitionRequestRumQueryGroupBy]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ca026c5842e713b7863a0f4dca4c69ca60554327c1337316ad34982ec9e854d3(
    *,
    aggregation: builtins.str,
    order: builtins.str,
    facet: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a3cc6cb7b22f73ba3321b2963c172df9f9d0e54e8d1cd3869a24e3caa40f3722(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a460df5e95422707ca3e4bad0e8f80e1a6af3315beb09ec00fcff99dba269dc2(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f9ff0d8cef0bd672e31397f0a02158a0685c9bf823cadfc020745ea0c93aa54c(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4f45ad4a42a732c2b4c0cbc46bf759390cfeadebea1852882bbc5271ee1cff29(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d29637d05401349d3000332b099faac88625bc2865d775da8775fb84ff93bc9a(
    value: typing.Optional[PowerpackWidgetSunburstDefinitionRequestRumQueryGroupBySortQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2ae3290fe1bc97a95da50e2a9dbff0ec0d538e3bbfd5191df4ce347fd5148ef5(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7414aebc9679ad7e01e209bf44c1827ded1979776b9969d7c42857f510d8f441(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__12bf8b2c97245a3aeadc0739217afb1827d3c86a5788b28774f44d246cb6575c(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d115337d22f8b1d28aad69eff12ee8f72c61a114e4302b593159d616b5198e1c(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ce069b75fcba2e9a0f9c4ea5bb6c83195eee88844035e4f5daf3cb313523e79b(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a2d65af1ec059369a7f038c98fb539239787464289910e748fd99bcf6da1c20e(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__10596dcfc5ac174d316de43296730ef389a211c258f1a678f1d155cf84dffe65(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequestRumQueryMultiCompute]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c521dd7b9bbe3ed4f60bbb7747c3212b75d3f78732656bcf6e12133c77864bda(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__637d1697fb5bf533cf76c85fc14c6bef6208559c6f4133fd9b18e8b4583604bc(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b3443a471f50b9d42a77001bdd2c7b126656ddce2d277c47764129728d9c2478(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__da08516cfe50db6ae69031cd8606e367f294bfc9d0f05f4036f73b31d429ab73(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__58107392fd67d51112321fda370907b7761e7f8d501d5b15ad61f39b10815e3e(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetSunburstDefinitionRequestRumQueryMultiCompute]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d57e02afa66db56e7b60ea072aa1e88cdde8039924450b401b6673b80661f98c(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__110140832e178572bfa5ffe8035424a7418061da85249b63b4dfe5303fcc07fa(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetSunburstDefinitionRequestRumQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d31cef6482bf5ee8e356c354b071b2c7e3daa7047b442dd6867eb9ea6aa1f7a5(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetSunburstDefinitionRequestRumQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f89fb947cad135eb923bea0063e9421233a4d3bedeccbdb83d9e645ce6afa028(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d6e692b0a70f9981d2cc6a040543a86602b85b0c472669c452e25c536764f992(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bd4c2ca915e1dea3407001741a75169d93d25260fdf4503bc08c306355bf8e03(
    value: typing.Optional[PowerpackWidgetSunburstDefinitionRequestRumQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ffd81982d2aa490b362256783c48e043fd5b00a041c52fe3dfa8074733166fb5(
    *,
    index: builtins.str,
    compute_query: typing.Optional[typing.Union[PowerpackWidgetSunburstDefinitionRequestSecurityQueryComputeQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetSunburstDefinitionRequestSecurityQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
    multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetSunburstDefinitionRequestSecurityQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]]] = None,
    search_query: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f829e655f12402e301c9d0dddf3501563c9432e45e02c07ace1ecd98fec09a99(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2a3fb5407b92f6f85b1662f96f1a7e868cb5e4a0670fe575dc77e18f26170188(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3640aeba7aebfcb27043b6674f85a85619a31f4c6e8fc222438cc74179badbc3(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0ef6a8c355359bc3d454bed9203bf8a7b0a9fc418c237ca8bc78336681a10561(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b9d57a8174c7619bce1f8c3b64ed0b820865a959523c7f788a70684e60ed7be1(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4417220ef7a56baa520099a215b6286a1b6524c6b70c0b6d05f02e4192228186(
    value: typing.Optional[PowerpackWidgetSunburstDefinitionRequestSecurityQueryComputeQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0947002a008e1ecdf6f95b402c98cb4f73c571ec20f0bc7564f89023ebfc42df(
    *,
    facet: typing.Optional[builtins.str] = None,
    limit: typing.Optional[jsii.Number] = None,
    sort_query: typing.Optional[typing.Union[PowerpackWidgetSunburstDefinitionRequestSecurityQueryGroupBySortQuery, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__26a480d445b74d3778c895b1b42ec80a4ffe5e0ef9c85a98c63bb401ffa9d2ac(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c40081a4252056b7aa4de163f980efbf9e80c62ca2ac3dfbf392fb38fca62cab(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6d6cb535b42e176071c27b94477ef469802069d875a3204b337119fbc838a0fb(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__da25223bdf3c5e8207722b151b756d158f2413ba89f397b7936ab8dd11a36b1f(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__237399e9842904be98ebf2685f6aefbaf41934f7322b0cc592734f257c9c4a8f(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7573cc72f6ccffcffabd26a63fe246521175b2dc91fad4a642cdfb7e6f7f846b(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequestSecurityQueryGroupBy]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__39ef8f60242f39ad2a78bedb9df821c3ea103f44cff7cbdae453ed10ccb6ae72(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__08776dde3b3f567390244fba2a3068a65c08da6c066c52cc534ddce6f38419cd(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a65ebae2e234ff7e0c29ae6ae7570cc98c71773eed1c335042d0077ffc5159b1(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c409d2a1d50947b082f76061f2922a2866aa3d05ce75bc27b5af4c8fcee05edf(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetSunburstDefinitionRequestSecurityQueryGroupBy]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__449f2c55e78cf11ee573febbf5f45b14c0af6ee5f34b5416414f40f8bf1b52a8(
    *,
    aggregation: builtins.str,
    order: builtins.str,
    facet: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e12df5206d6bbad41f45fd1891679fe29e460f6d9d5f5beab6f7fec77d78675e(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__532c189f96a7baea778ab741f9977c8b463c9c75e2222937c99908fcc35e5fe2(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0b5029b9f0157df88a966284274d672744b2df32481acc8956127c7f0e80490d(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__eafcbffe2543cd7ccc7d296dddf3ef07f859a27926910e6a4891fd62a3c8a952(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5e069a43a4f2eefc9052cad5be88b8e40408b4d4c14c735873c2a36d277a331f(
    value: typing.Optional[PowerpackWidgetSunburstDefinitionRequestSecurityQueryGroupBySortQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fcc2b80b334202141d8523d7ce75e6765ff7d04dca165ed44d2a9d628ab90cb2(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1907d8e3a0cf4560e6e0311d1de449b01b44fc3260828cbefa96a64b920e3490(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fa1c495926b817f61ac125a41ce253600df26e4cfcb0170e94f1ec8214303979(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__611b58923fbedb688c5553c547b5210dd32f90ee0f971158a2c6b950d0717df2(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2cb9142c697977bb093fec9d87e70d6321ffa33405b5a817130e1239f2ed2dce(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dfb8757e37bdc8f57ff54d5004c3d9e8a24f52f87260d3b71c0bfb6e7a97fc34(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4dbe0a0aa65d18625466a8b14dc27b70ad4c62efe043b77d27986c18e45b8dd7(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetSunburstDefinitionRequestSecurityQueryMultiCompute]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d22522135ccde47a1aacc138266f43956053552d9075c2f76ce4848678c4d2d9(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e15077de356a0fef7640b9b6a731516563cb431b11127d484ba5555db919ec0f(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1cdfe32e145a464eee419b428b0c46d89ad23d9fdd17a4c46b153df6004a4f1e(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9b63b6e766295f60f16a10ea43275082f4db6dd2738559ddf554d2df5fcee3d5(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7bedbefc9528b6b642bdba9cbf0ebf1d16eaf457425f41aa27ba23fe3fd21155(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetSunburstDefinitionRequestSecurityQueryMultiCompute]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2810f259159240142e2714126847776ee0243810b78330bdc1b394fbd67814e6(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b9fcc65242eff67574af1a05c816719559eb8cdc1a4c077ede34c05e23308d4f(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetSunburstDefinitionRequestSecurityQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__78939730c250c3852cde0eb4131ab35f1bec3745e1a6ba127989202e258261ce(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetSunburstDefinitionRequestSecurityQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2e31fbfbc4cdd2c875dbe45df2d14080aaf8521dac9561e1a15b69324c332996(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__39e7173bdc00be608e605078a6ea6d46917659ba683ce5e1f749f97c81bfd19c(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3d5103a27fb33cc25a69f0be7e85553f92938f09dc1ccde67ad059b2f7774299(
    value: typing.Optional[PowerpackWidgetSunburstDefinitionRequestSecurityQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0c0229909a64d616505a57efc0bada262e87c4955b5ed1b8aa2a5548baf0d07e(
    *,
    palette: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__58304e0f234eed552c3813182d9993ca64556b78c6e4cd89222a73bde79df1b7(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9cc6136cc27b8432561f48293b8f6e86663484345cad3dd93c973c41b02b5ce5(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8cce65acab2409a3d7f3c2d1bc84023bcc87e80659f9861ff66d4ef8e20dd6b1(
    value: typing.Optional[PowerpackWidgetSunburstDefinitionRequestStyle],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__212514e36da37dd5ecfd44742511b30072b67cf97daf6aa5f4704eb2cc08de4f(
    *,
    custom_link: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetTimeseriesDefinitionCustomLink, typing.Dict[builtins.str, typing.Any]]]]] = None,
    event: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetTimeseriesDefinitionEvent, typing.Dict[builtins.str, typing.Any]]]]] = None,
    legend_columns: typing.Optional[typing.Sequence[builtins.str]] = None,
    legend_layout: typing.Optional[builtins.str] = None,
    legend_size: typing.Optional[builtins.str] = None,
    live_span: typing.Optional[builtins.str] = None,
    marker: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetTimeseriesDefinitionMarker, typing.Dict[builtins.str, typing.Any]]]]] = None,
    request: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetTimeseriesDefinitionRequest, typing.Dict[builtins.str, typing.Any]]]]] = None,
    right_yaxis: typing.Optional[typing.Union[PowerpackWidgetTimeseriesDefinitionRightYaxis, typing.Dict[builtins.str, typing.Any]]] = None,
    show_legend: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
    title: typing.Optional[builtins.str] = None,
    title_align: typing.Optional[builtins.str] = None,
    title_size: typing.Optional[builtins.str] = None,
    yaxis: typing.Optional[typing.Union[PowerpackWidgetTimeseriesDefinitionYaxis, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6b564c9105c6a17e6291bcb70f7d08d02504041ff31bf950a580adae348cd538(
    *,
    is_hidden: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
    label: typing.Optional[builtins.str] = None,
    link: typing.Optional[builtins.str] = None,
    override_label: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a7e7a2366ff6d4e032d6935590188626bb5bb5550627aee153ae6d5b86acb438(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1cf15fa75703bf0767fd03b71238d1d09e94680b894544f0a6a983d1b790d836(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7d8d0def77a7e3d67305767e47563b32b1152f8ece1683f7b84b8307c3ca7caa(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__854f87675e4a28243c486a2ec21045ab77d4c3dc9ff0d098c4311549d889fdf5(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__51044f09c7489ffd8239b5d7ba4c146cd7890327f5c99d8ada96a765d2891c42(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ea3bbc3369c545486603eba93970535d2fac3b6b435328be7ee69e1d5da2f8ec(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionCustomLink]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6a7836909ff5326e8527bb06bd5d956e90254db09b13ade964666d278d191f56(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0ec0f9436c4867353d076657c5c2d9baf0ec74c83268c7a9d6b64752d3fbce7f(
    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4d5f3610166fdae73a8a852e58b5bf94efa49d547567b79b946f8470d33ae3ec(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8a26d96b2aefe37d826d9be374b56ebce7d5e7be7d59711a934e0b88441d7bf6(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ec2874e08572ba2c40d5eb10a6d80782e9040729838b25a48d0bc367008826ca(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cece3b00dd4487e03a14c82dea66898b6435271dfbd727b67815c9e165d36c39(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTimeseriesDefinitionCustomLink]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6a8094a04d46466ad8729111ffebbe226a3c81839eb19c281f5dc38b6f9af38f(
    *,
    q: builtins.str,
    tags_execution: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__87f14fae1756227628b30c6943f3334b00f00af11c744dc9e65f59443fe8631f(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__335aef13525479145c1353e06312e84b1464620927569c10038a260ceb2a2ccd(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__97d81a01d8ed0d109ebb6d9e25cb95638b52d8b824e676a0fca56bd23ee7448c(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9d8723e03704bb47e4612749a8f5463b25f2b6267fe2ca8540c6c62f3b715f12(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__95ef9a084c39228f4bf6088933a5dfd684a56101c38d6122335aca2bcfba1373(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__35e3b9ff4c480d845fb61f1d87b4c6d9a949050cb6f6be993dbf78ba9bb4129e(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionEvent]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5ec9633110bb9f20a4823842d2884196a6acbd281bbbd6968c4c550d4bb9b7f9(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__900f1fb5fb2311a72eb9b572f14dde8deab455061e928b10c4b18af6dc3180a4(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4e38434825f2565854a147ce45d6b98d4e0455817d24c8c26bcb3bef7549975f(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__51572665df03881946cfaafa3a3c01b53def6c2a582b818ba368b33e350ae02b(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTimeseriesDefinitionEvent]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__31b127ea58c69015a84fb5e86dd636976aab4feb4fcc333d3b201d0b64931154(
    *,
    value: builtins.str,
    display_type: typing.Optional[builtins.str] = None,
    label: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__35e6ee182e61ff197c4cdf7ae1ff218b5e91374140f25ce132f724571b6759e2(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__578575fcf43d862dea7937201638b43b72c7794d882412359537e4289996300b(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6880b1603f1eb4ea56d8f3df0b25bcc244b29e13438ff925cf56ff02fd1087a2(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ef5a5fbce663ccd8f8e5185df6ca63cb9f7149aa37c641ee0739b1a4a046c5f9(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__72f7c6417b8ad24ecdd825cad509251302e7e430aff112625dc1e754f3a838b9(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__119d482c5225e700945e63d8eb885e89ded2bd0703677afdc32462009fced8d7(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionMarker]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3001633cad02dc36d21cff9441a6d762e346719c9bdf77318e3315831b5081ea(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b194f6a2c69f9d96a400ea05e5f0d23e4ba40dc8e9732fc762e1d291c8f06488(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3c3bfd4f7b285041739c40e442f090fcb80d6fab3cf8ae3fcb776f36d27fd6e9(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__690fd691a54ba1784f67a9d8e5b5bf7b85cd1a9d1873e25fe3881993e5c39114(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1f08b223d22c2c2d10d75db47138b6afb2cb669185ae6d631c7571ecf5baaaf2(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTimeseriesDefinitionMarker]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__85c31423bb14cb599bbec230ea24809cc78ce88a25b8d698c407b4dd9dc2f947(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e33e04993cd66e09f022c362ac48397bfd1dc6a58e674d02117ca62d869b7dda(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetTimeseriesDefinitionCustomLink, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d617740f80b1bd1ebc7722856c8e5bebb83de725ce91f91a7c9a9e5d0a9a13aa(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetTimeseriesDefinitionEvent, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__205defc0b613a3e4ef9bf3a97d8f241393454bb3c9e24e19ee35e7b34b0dce31(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetTimeseriesDefinitionMarker, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__601616dc08df6f7e8a029186dc35e13f86e035be62303adff74e04ee92acdf62(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetTimeseriesDefinitionRequest, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6d5dcc2900bb4b931714ce7339cdf3db9b228b03bbb7cc26e6ca16b922284712(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ff721530ea7816b88485ea925566c2d23da7c272b1aa366b03c1f72ad95d608c(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3aeb0b28c1bb2357be6584e1fd9b9c5ae6f7934e3a24a41deb75fe7157bc8f14(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d47fcfc4947b705da6dcb7a8b1f8c8a3b2a8f2627456144b2321c0d155c7a987(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__43f3466f30e67ea19232489349879bbb8aa4e045b7df30cead7068b703e48675(
    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__44f5847c8e9a51a47d26f83b451ec8e1fcc74d11d95fa9a2078d91bc0360aa49(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__855994fc3798c957fd5eb11ce5c2ec598c0b10d380d894cd2099d1a15d16f7b7(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__41601bbac7784acdfede7501e2f97bcad40d4186d7424f1441700e8216cb2cf9(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ce192962cab670d708600950369031ca2965e5dd0b56145c27f6b2be4efa8587(
    value: typing.Optional[PowerpackWidgetTimeseriesDefinition],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__77f4eb4971ebe03ae017bbc1cad2031bb7680c65a68e4d0aa6780c9f1c086b28(
    *,
    apm_query: typing.Optional[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestApmQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    audit_query: typing.Optional[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestAuditQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    display_type: typing.Optional[builtins.str] = None,
    formula: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestFormula, typing.Dict[builtins.str, typing.Any]]]]] = None,
    log_query: typing.Optional[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestLogQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    metadata: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestMetadata, typing.Dict[builtins.str, typing.Any]]]]] = None,
    network_query: typing.Optional[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestNetworkQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    on_right_yaxis: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
    process_query: typing.Optional[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestProcessQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    q: typing.Optional[builtins.str] = None,
    query: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestQuery, typing.Dict[builtins.str, typing.Any]]]]] = None,
    rum_query: typing.Optional[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestRumQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    security_query: typing.Optional[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestSecurityQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    style: typing.Optional[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestStyle, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b073382e6be165caac1893023f48820fad1540e7cc8ff0a0256834dd76d7432c(
    *,
    index: builtins.str,
    compute_query: typing.Optional[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestApmQueryComputeQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestApmQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
    multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestApmQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]]] = None,
    search_query: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4383e706bc455b38b134715870424f4c754f8f8f1ed5e137d6406501fa4972ed(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__74f594ba6003d3ea7dea2f335352b1b4392dd61b7f1e72bebd187904fbc5e5fa(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__765aed441fe6684fd28fb926d85ae24beb3cff389da2ebcec499022270eea436(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__86c8799e44f1ea341003fadb56faa74cee217e5c5ffc1608ba3b0a220b82c89d(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__12149c3b68b7ab3551801fc5449f1b927d7d0684b61d9a9c6a7f2a5ff792b5f5(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__00d92cbb3f3d537604ce696cf871fed02054b2da748f7e94905222f6732d5c95(
    value: typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestApmQueryComputeQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0340811879c1cc7e9ebd68fc1b42114f9e9d33412d01114a77df9368bd8ca357(
    *,
    facet: typing.Optional[builtins.str] = None,
    limit: typing.Optional[jsii.Number] = None,
    sort_query: typing.Optional[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestApmQueryGroupBySortQuery, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8fdf33cfdac341648918234731dbcc47c2412d79ce2420689f87f578a7f2b292(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a360d822d82c1bb89a74ca734aa469de3dfe63929a84ec3b4b1dc28535d91c6e(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__94fe1eff36f58d57440ee5c17c2b310a55d35c7a1412d8e357f6fe520e18e618(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__066731e2da8e31cc10306780dbce3633305e05d4cccc3019019485e24d4cedd1(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e7ec5789339105ae4ad8194146d175435666d963d834026603c1aa4b0ee68df5(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__360f4a82da2097261a455d0dc0892467400b12d2ae4ef4e8da8c909e5a16021f(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestApmQueryGroupBy]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__20001c2f33aeb3ca5bb9ead8dc834746ce23c5e478b72e872149bd4e2ea291da(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ab20959a61a6513cbd65f2e15e5d738b0c405fe04dc0900ed41ab0c4857d6bb2(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__affdea3970429d1f8f3b37e955c5a4c72aca302357fd45572e3e46a2c84ee4b2(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__54f18579dac28a9133d0afbc5f46b86d59669c2b40c26b0db88b486277acf9e1(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTimeseriesDefinitionRequestApmQueryGroupBy]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__65ad10a33293fb2e50b4d7ade12df4b25cfb8795686e6e0dd34ae022c17bd33b(
    *,
    aggregation: builtins.str,
    order: builtins.str,
    facet: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f698c69c048424688865afc2df0a54fb75343da66053d200b8ad6e16a31c3bac(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__00df37f0e3e89a70ba3e6a4a1985617a01a9e54a5158b0eb38a991a7d6395859(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e76a2dd44bb094911282b3d60d638b67137028ec25c4d05460907e6ecf401c4f(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__068d11661f813c714f92aed258a00fdb2ff445f8740f0bac17236d41408c8a74(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2d333ffa90b4ae771106709b0b5db40a19ce035521baa7c10ec67892edbcc112(
    value: typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestApmQueryGroupBySortQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0ecf83d2607a55f1f360f56a40b2671d9c26762343cafead6ee49429dee10f98(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f7755376e6a71b39789e569a30fdedbe6399140b52e0cd9e106d22d728d26f97(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1fa147d7a9272052493e65a6e8c851e38e6f382115c101cbeac00ef7b59f74d7(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0d283abb9745a7bb04c71d45796187f5778ab93517c01cd4cea5ccd236759063(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__221de27f7f3be7d06a5002a987414196062c39072d679654590a2313b37873a7(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fe3a2c5cf659ce32251c86f782b7098e5f9bf2d98e08a8ae37336465611c5e88(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e90c5d6629f9a6536dafd1daf50a075c13bef225be14f733435133965cbbb05c(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestApmQueryMultiCompute]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__32168bfd10cf6c6f127d1b0e7d90efaa7225a9c1d4fae2b0d29a249c5aad3cfb(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5f4898f6ebbd5053258cb9157e5ad87f56049fdd5069075fe5762418fcec762b(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f99e85d7ad8f1e654fd329c48e5aae93d8b9623a15df2dc57b77fa5b1f6aa5e5(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b7f21587cf819def326ca18169a32bbb8e0b70a655bad1779debdeb101cc4f81(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fa0a7944307d3272ba016bde6f7dc63e167e80d372d9ba027e5b24d15cabab8e(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTimeseriesDefinitionRequestApmQueryMultiCompute]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__30c3b3ee96462680955956596eb45d495634de405aa92bd59e64b1f851bc151d(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__caa9e1d9dd7576f4c7c67900698d75a1aaa3dde09cdcd5a82908958f12772711(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestApmQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__06b954d90c7e80136156bdccbcf1c4a65643e47b21b6a2d81a845abe90d20ea8(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestApmQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3a2c45d210e0f854e2f7b46bfc761055f85fa4ce9f2fa3b73ba98191c2cae3ac(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__daf1f2af896bfa5cb6576b5fa1b471fa30fa8e0bd76273a82b6bdb1c52e00ff9(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__df3a1acc8303de429654b6db8597ca0bf27f7744a91cb58a124e0a67c005ccee(
    value: typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestApmQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e9d30e3f45dd3bc02092efba03e260f51bd31ba3cc0a1156d011bda70fe711b2(
    *,
    index: builtins.str,
    compute_query: typing.Optional[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestAuditQueryComputeQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestAuditQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
    multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestAuditQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]]] = None,
    search_query: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__93e4a5295e2f17331097c879c013e67210ef946c2e4a1077be8344abd2e5a900(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__999563dd2c8f64502d07b3df0e0a778d81cea4a119ae5f308ce2c27c45568c9f(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3ee0524cf8974ba0511a7ba4d28947266d62d098a5caf6fb29e85fe3b2268214(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c44a6b6999d44cc82be5eacd9bfb3fa9354c8ca943b8813ce5e3bf977c787165(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b77a37640034765cc4f8744c0e1ea90cee897d80720626f7c20fabe2cac29d10(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a924b8c632c06b61b9e18542750fbdb22e7a36505a7b25ee44af54a2cb3720c9(
    value: typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestAuditQueryComputeQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b077e358fbb395143384f4c7398348862cb1e2d22e8cdb36133a30f08b53f36a(
    *,
    facet: typing.Optional[builtins.str] = None,
    limit: typing.Optional[jsii.Number] = None,
    sort_query: typing.Optional[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestAuditQueryGroupBySortQuery, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d5bf7c674a4855c323b17c5bb4abb5e7489a232211526e4d3bcc0b140ae6185a(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8f2f625eb3343bfc380379fa2b6777685249e5f6f316eb19f42f7770d828fdd2(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bc9bd1e1bcc0d1d51d97dbffcdc85191d3eff9b97d16a3af7e19891f915b765e(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d2380ffc29d5cd9a3d096acf1b3a8baa68197b2292bc7c55ffc1f92587e64aa1(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d9a837cf91f79397348d37bcafbea8b0546f8e9e4d8d6d1df3daa522d86cadd0(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2cf9b90db9be344151530194bfe68938436f84303d5e5a715265ceeb3a5c37d5(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestAuditQueryGroupBy]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5e99c37798e46944d63d624f1c034f9fadaa831a5b2fe57a00870ddc72ae3bc7(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__149a882a66760b0c9712e5aa3a488d53c4197e759915a5649c5f0e6533c2768c(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f7d51cad01305caffeed1850865d73ac88725a2a7d9d1aa4063fb2db740469b4(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__306d20cd30f3b49c15f8923912ebda076772ad5d09e48d5e2fe38f3f0d0f5936(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTimeseriesDefinitionRequestAuditQueryGroupBy]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7f6399711209552518a87b6f442c326abc51dfbee86c854a3084b80347766961(
    *,
    aggregation: builtins.str,
    order: builtins.str,
    facet: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9778b8d5718f7eeea40ea0941a09119e44176a0c9c788bf495f00651124a599e(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3afc82f79b77e06e09f18e3d13c347b4065034790c7c505983d2631a50d75019(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bca53703edc925ad7f6b556e355a6893efd1a23a37c7e804afd90b1348fd2f0e(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b60d5b3d9dce9df9ded5a15704028d989eb7b2d2aadf1c6c797300c3725632e5(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1a3366f18c02fd25b711a24166f17436f863bdadb455803104f3621fd065f82f(
    value: typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestAuditQueryGroupBySortQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__285b1354bf51b64d0ecbfdefc3f78a1a35bd62d51e94a01ca5258afa0afb870b(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e545d99d6112f0aa113867e3572d6ed7f01ba06c8e741db744a65e4e2f22d691(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c403c0cf103da2f267581ce1486c4dc46839d6ce4cdf56be016c98261b4a3920(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5a2f4c0391a2b277087c9557a8cba5cedc308eab89f22c18e13b32033f37c7ab(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f169bede196f32682c181e546702589cad8409c26062d5f806ed5d951f7d475c(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5f8d35254ad1e642ef35bad8b01093b5774177ae4ca10a86aadcba160693684e(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f9674f74a8ca2839c462f7459355957ae8251a2ebedab88aac749f8f01e9e6d5(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestAuditQueryMultiCompute]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__608504259e6893d4455e16ac7adf076e846d6e093df2f31da8a4ba448c7f28dc(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fabbba5c95ae1d3db58a87e78c2c888ab292d66fb042631487582975dfd4f7eb(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a1a3763e6a2ede6bacf5d6b3927f47655166ba8778a14293eb95d7372f630f1e(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__071fd641abaa73851e71351c227fff66eeae268331e8fbb17651e5fb5015584b(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__83f7310446cf961656b24a7ffbf3c3d780df7a6009a6e773a4d25fa2f0203869(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTimeseriesDefinitionRequestAuditQueryMultiCompute]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__be30173ac3765b8586a0408a31d8a4a0def2e472033d0e017a89ffe6a25753e5(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e700268480e6fd3f33c5d2c19248de9e85f2b6729ded0f171525add054b9c34c(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestAuditQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__250c0620c13cd41d72c3eb88649e742e8bd79516222b94ebd2346dc398c64ff7(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestAuditQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f07fe74eb188401027353ae7088496e77533e7f65a9c080deb6230d8353fddf7(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0867b53aeb6e3e15b74d45558275c25fb587f6513274644553406347979dc4ef(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b13c8ff115ad787e8ac6eee1f4792acda61f465dc452870af3064b15f5ce37cf(
    value: typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestAuditQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7653cda5be9a13171b7817712fe1c7eb967116d96b16048843e43b85ba0dd330(
    *,
    formula_expression: builtins.str,
    alias: typing.Optional[builtins.str] = None,
    cell_display_mode: typing.Optional[builtins.str] = None,
    conditional_formats: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestFormulaConditionalFormats, typing.Dict[builtins.str, typing.Any]]]]] = None,
    limit: typing.Optional[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestFormulaLimit, typing.Dict[builtins.str, typing.Any]]] = None,
    number_format: typing.Optional[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormat, typing.Dict[builtins.str, typing.Any]]] = None,
    style: typing.Optional[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestFormulaStyle, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5eab865caec75a7853f691aec2f7e7a878f597b17de83a5a8f8d9697a9d32514(
    *,
    comparator: builtins.str,
    palette: builtins.str,
    value: jsii.Number,
    custom_bg_color: typing.Optional[builtins.str] = None,
    custom_fg_color: typing.Optional[builtins.str] = None,
    hide_value: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
    image_url: typing.Optional[builtins.str] = None,
    metric: typing.Optional[builtins.str] = None,
    timeframe: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__165dc3a8a6a4d98327056c96ba7988efa772ad98837a6bf8e0a6173ed8a183ef(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__461a6c4ec632bca97bc69b31723d55133cc07b48d899ece76e7a691465807f6d(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8e0bf43e2cdd44229b1370879396e3f8fed9efdc1d98038ed81a330548312437(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__152c39b1a67f33b6c6d85c710f29029c88f77b1d059111708bb583a5d84b83ec(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cdf366b05cbc7ebeaedfc32187e773563781bc95735403d5b07046fa75303044(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3cc55763ae4f8fe78006aafd6e4f2e004afbc6e589d68f5cce0ffb0bb25d70c7(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestFormulaConditionalFormats]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6e62b1c700fb8cdf39b583802fda2ad5b8f0a96f899effc229b92260ce1b589a(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__181751f7ea2c81900a9c17cf960a2a7cba0b2f8292155f0500e0761d4dcf15f5(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4d9f1e1c12f857331c96370bf9fae1ff6b31835b1ec7e81a9f2e577c60b2f681(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__071b06217061c0d9732fcd23a9df3bc6d1f78ae20fef3aa26422b51e5eda576f(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__02275be4494d180d30ec663151cec5f710d7995c0dffbfb9c2775f09760b8545(
    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6d684a52dd03576043cb102df30717ea22d09ff3a7eac57b1caf261597eafad0(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__231b0cc20aa0da5056d508592e6d9451c05e71193623f70736422b004422327c(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3699cd874cc978f62cd65c4d0acd94af5be7ac0003a61848ba104f29e602047d(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__714449cb82fb127b021fb798a2dd7a3f123f24d16f28cf637f4954b57968164e(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dce813db640a54537a2fbbe13baa00dba082905204e770e27280c63190b72425(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cecb7c0c4f215ac1b502bdded8d3a084643890ae4c5a969cb240144762599f01(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTimeseriesDefinitionRequestFormulaConditionalFormats]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a374d8ae0af9c7622eacdb4cdb254ca79204674262782a617e31df0aedfddc55(
    *,
    count: typing.Optional[jsii.Number] = None,
    order: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8b72c514031539c4bb7ab41808d7f584e102e432eac529015f9448ed2c790da5(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a579bb9f698df6f49bb9fbfca2ae8da515cef51d18a1b9c0adb1c0c22231436a(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7c38957a81d25628a5fd2c060984cc5391459bddce41c8986ca53c89aecb5f98(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4991fe820fdfaea4f9a7ebe7034cf7d1bee36fa2b49b5aae3f50d60422f7efab(
    value: typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestFormulaLimit],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__800f3fadc24dc187a0d07aa1b7ad07362f003e3d5d91c2511c583820a549a955(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__75ff498066645588b3dec789ce9b9cb78380e8bef4a685ba9a79c850fa75224b(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__612ac1eabdee6d8250562351ed2f6bd16e0a9449759f6f12958fb86c10de57f8(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__aedee0c7622ee74a3e516cbd3b5eb8b8d9c0794ef3fcb4846bb92e9f49c0c221(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d1ffd0563f54a7d38ee591531763093bfb3ed221348ec8c6d0d301dc12dc35e2(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__abad77d5db70b92399f4e6c686639e99ad238063f9e6f58f0385ad6e4b07e3a1(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestFormula]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9b2d759908b7509d1ca4a6b2ec508331f4d3233290232d5527d85463b826c04d(
    *,
    unit: typing.Union[PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormatUnit, typing.Dict[builtins.str, typing.Any]],
    unit_scale: typing.Optional[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormatUnitScale, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__67fdabdd896cb9bfcd95eb4be2a87cbb77e2c4b15770ab386f80abc36fe52d04(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__827f97ea9bcb800a3bc72ac89078772d0510bc9ef93e55b6075196f03c1dc5a8(
    value: typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormat],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__78939b797104febd123ecf87b6fb4a86b8697178839ad11deec04ba4b4f0b2bc(
    *,
    canonical: typing.Optional[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormatUnitCanonical, typing.Dict[builtins.str, typing.Any]]] = None,
    custom: typing.Optional[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormatUnitCustom, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7395ebb2d8809fc79fed955db8281dc12f636d010da67ebb4707a4e56fb9a242(
    *,
    unit_name: builtins.str,
    per_unit_name: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c20fb3af26613994bb8c64f8bc74ba0aac1ac91a44fb4f1f8276620c1a86b2e7(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e2bdba4bfe270df8f585043cdf896cb1e52c839854077ff78080cea6d2b92d8b(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3fd79bb90e8bcfb20dfeb0d5bb0fba8b84a36353a60bf98c7b698d98147b92c5(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f714aeb58a7fc6d5e03e398dff8f6359ae50878b40305429758ac576e0c29665(
    value: typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormatUnitCanonical],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7f4847784cef9439900c6d0b8ebc61ced40d670bc8a29111e14a9ab7ce31eac1(
    *,
    label: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__18ce09e5913b2fbb9911d64d630566eca06dd34c1cec0b24662eb7f1b7dbd4ba(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__25f7cb38dd6246952773b36a097fe4e96fb035b750c1a3d30321e40b86af5dd8(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0a9dd2d4a7171f2cf0d0075498ee26bed1bfc775ddf20ae06c533704db6f5521(
    value: typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormatUnitCustom],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d56686067885d2b12b89ab8cfb1a8b665dfc3975df81905e21df2219875a2195(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fe29a5b791ba95e818aee088f62904bc2718acc5d49b7fbb4c3e05e908ab3590(
    value: typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormatUnit],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__164cd7a2de9d1ec1528de4abce63782966bc21ebcc13c0057bdbdf35219953fc(
    *,
    unit_name: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f33ae3b1706ce24a4c1aa30360fa92845eca0a6bab6dc15571381522d23fe366(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a69d44810052848d3497db2fe346add8f2d474492ecdf019c093333f010bf00c(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8952ffe81745070df91a63ee8d2241388768e65e665c1a00fc3d09623346a970(
    value: typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestFormulaNumberFormatUnitScale],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c3b0579f480944a66086eccc76909846877d511aa16be269517c4ef85df95c99(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__28644ff11d38c38720723624d8bf77e0b1400b374a949a2da8e35f962159afca(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestFormulaConditionalFormats, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4af3eda8fd07911ec64742a6c3cffea7cc6c40c52c1086b508bcf02de625082e(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4600ada5dafb4e4af7a1b5b8a6059ddd388ac719737c401c8ae3767d9aa6d621(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5e833ef04f22d0bda6312bddee077d8c28d03cc2de3df0e7df6a05707d9f3a11(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8edd30d2c74039ae9933df48b74f4fd954ea6c52d101a45068be87c18543150b(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTimeseriesDefinitionRequestFormula]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d278537f23c8e3e6652afda82388717a851b7c699717a2d74e2c504be5623963(
    *,
    palette: typing.Optional[builtins.str] = None,
    palette_index: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3a5db7610eeacd3f6c43cef472f30e8d4fc5daad67a7d141577462baf9f50ea4(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7c96967c737d5b1fc80a83746e935f4b008b595fa4969b9c128b29927ba1943a(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9f6e2437c8769feaabe753d53918ef8489d6d826b105861a5fa9d017f8b76fe0(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ee143716940aba631bf7910dda8abf852860d2bf87c5b7d7d738aa494d6a185b(
    value: typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestFormulaStyle],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c0841d1629196d8320f732195d19276eef79c8f59b678ee8725e4c1db3055ca0(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7bf866c39444071562ed877769c60f1f18a61341a350c15c4b607da1fc2c5b01(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__539a7d51a6edb7d1d1db17f90ed6a7f5607b2d1157d3f8795781c35e44bed784(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f57aecaa5a4963e81fb6ba17d587dd5eeeec872f5093bc8d9c119127df7236c7(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__adada9827ada4c574303b7f586a423177e7510920f26ad504c1fc723ae9c3bfa(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b2a2225e86bc3d13439fdea6e62c7e374983306ffa6edf38f716b694ee04da0f(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequest]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__52133ab88def608ad3c64b5dad8cf49548fb036aeddecb94b044ea9bda6c11bd(
    *,
    index: builtins.str,
    compute_query: typing.Optional[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestLogQueryComputeQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestLogQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
    multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestLogQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]]] = None,
    search_query: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a1bb754573c745cbb9393876834dd6663eb13dab086ace00ba7582de01890bcd(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8ae387b63b7e0fb717763d93c850c92c6a720fdab4a9e6e2af4bda458a92191f(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__07bb1b53a409c6df082f7f3e29a6674c6f8b9a2f7dfb264ba2bb08373c9acc5d(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4d0429e9208904efe758f3927806381fbb8eb61ccfa3e3bf265129a076cc36e3(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1a08aef1b7ff0d9ddf70f28dd5e2a4b9a8928bff7fb74073e8a31befebd3b2a7(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e85fac70c9892c7022d52a11d39f957642b93fca885895135cf0bdc2c4167f57(
    value: typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestLogQueryComputeQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__19291b1bd68994b8f061bef8c7a245e601f111c641e3afdfda47b76d5adc8fe3(
    *,
    facet: typing.Optional[builtins.str] = None,
    limit: typing.Optional[jsii.Number] = None,
    sort_query: typing.Optional[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestLogQueryGroupBySortQuery, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__df2c4b753e935242ddd3dc03ef527f02fcb3df76a2d19eae269ab10a57cbd193(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b7b11f5b8b1bd205331fc06d505eb1e9aca02347e3439d3a809829aff2f064a5(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b8e379ca1f1440e35fd2265e8ceb183c238df223a7525506a256d9d74dea1d52(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c04b6c97a1bad91bbc534afac17f7487e5dd97b23facaf922e2643f88a7fc8e5(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a8a7da04cb7355b32175e04b96a1bdf6d8c4ef73d88e6d7ab3f23a8644a03832(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__101e84a4dbd17d7f5d7bc85dee0787959c97c226f48e5948ef723dbe341d4d50(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestLogQueryGroupBy]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1c193cb7bdafb96affb806ed03749c74d7736c6bbdeabf53522da3244e29cbc9(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__db6fecad84344a6cb4cbd06ddf8179e3b41db75854fe2b1f61eccc3201de40e1(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dd654df66eac694be073c53cce2dd9265273741d9638d465aabe912b9b9a9500(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8e8c67ce36da2da4f1a5abfd30499cf75618a7cde000a4d22a048a32ac58cbd5(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTimeseriesDefinitionRequestLogQueryGroupBy]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__049ab23e5f05d26efe6673a1fe0d7253d6b2a7e1e6edefb4d2deca22bb777c6c(
    *,
    aggregation: builtins.str,
    order: builtins.str,
    facet: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__603e9192ea3006134d9f38f6bd5c89faefd9bce2ffcc892c7c294b31c7a83489(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b39a86462cfc391360e9b8595ac80770e9fa6e7742de06681017cd10c3ea89e4(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fe89a9cb95b8d74d43a83cdfa0091341d508468655eaa7bb524fd11e6c4def4a(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__de83d41efcd1c3fc6f714a01909cb0a8101dcdf232cc858639389cd0f2debfb3(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f4d502ab30c21c2c2b1040bab9344de2495f4da9fed3643f3112856767eeb577(
    value: typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestLogQueryGroupBySortQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2890cd2f696b7a0166ae0944e9b5d04d00ef3a71d806b67bfdaa89806a323c56(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__747fcbe482a2489cf814ae135da139dd24a1495d7e87c8c32de215988e309cbb(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__73d48cf282ce80f5d0ecda6f51d3c28d86d4cf80f388a24b7cb8fecd220ac40f(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__90befe1e939f6ca58184ceee40ea0573c1769df4dee5d1aabfe6be17acdd1158(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__49066df1029edb337c0851dbc25734fe066be10f2abee167d67350c7dd799f72(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a99f309a770050671c18fd3e7fa3c2b15fd78080d43d0a6f118b86cbb2732155(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c1ee9cd606c493bde41598b498d32a55ace5b07fdf027a9886bd864fcadc2263(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestLogQueryMultiCompute]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f1e5cdcefc090df55d883e36423da5564500c99b2a07fb2a361478878a43f17a(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ba16fa141ff0a1b1d533478ccda83138dfaebc1edcb919fb98b5e777d0250bb5(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__11f5aee0a7e110829fb75229ba22ac71473ea7a42dafe718585b91feca907945(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bacd97c9c3b81da6ab5b63458c80a07310c0c5f8caa38076bd28ab6b05fb46c2(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__39da9fc5cb291f3cbb842b3abfff3b8a311d1aca8d82c1376dff65e3e9af0081(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTimeseriesDefinitionRequestLogQueryMultiCompute]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__72a1ba865fef546a46012484ef715711a4c3d96850947d9e5f0a5045f3f53043(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__457daacedf9cd210ba43f5af1a5117c96072e330f51c5a2c5f0c6ff086c1f9e5(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestLogQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__869637830c16fba707551dacdc2626df5fa8e765034f562d9e4b27deb1be6d54(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestLogQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__be3a4fad8543b694e126c915bb2984bc1fe1e338f8a9c07bfacfe8f59bd6162b(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__21eb6664de1fdd69e362a6f22949cbf96af862a87c2048e219c7ff6b621013e2(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c794d29acfffb2a170dc403ff71c0bdd0be96f9c5476760f3a5da71e32e216a7(
    value: typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestLogQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f46795b9a56f01dd5f329d9253eb3a23adfce0e5effe2a13fa44a627901d81c1(
    *,
    expression: builtins.str,
    alias_name: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2641e4a131366bd1392b35e5502cc2215f9b0e32c368aae5ed647cc16ab35943(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__51280bd890dc53245cd7fceb3098fc9a3690665936e9ee1f568a2404487928b5(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__97da60ee31d5182fb934cb6b28e2d77bd6793360939c1313d0eaf044b3e59cb5(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__234eb2a67a4954ce0be7964856e04920f7c1a71faccb21fb45080389d4855821(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0a346c9da70b67e9a997f1df3351a8dacc72220a69802f55382be4d4ce90efd4(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f5afe327e8399c68d4c6b27672bca8d4e9ee72a7d9e84a7a09bdee86dac374c3(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestMetadata]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9b3a78ab8eedc2b7adf458c6a7b983b7f5a280850e30caa67861cadf0d808b23(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__281b3296570050948f28015b7c7c016a0a1a1f9b05dc6263c373e09c5f658717(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4ea63df48e04c2e468efb65ebc877c6da6ad869114dbd86df2d95929cb3e8807(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a2064f9f3e17e82c03f0bfceb6b58aa0e5de0745b5a1186ae45695b25e4dc2a5(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTimeseriesDefinitionRequestMetadata]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__db315b47af8a7a1f85105ed2df45c7fc4e475c85591d830222ff11bb9f449c29(
    *,
    index: builtins.str,
    compute_query: typing.Optional[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryComputeQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
    multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]]] = None,
    search_query: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7ffb1c9531eb1194b96c4b6a8e122cade1b6378e9e6ff902565cf1a52964f709(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4f197a6596234dad31469198f17ad549caea8340b9d0f29849541b37ba0a9be7(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2d1cb9d5ad0b59561de95ed628e0af5e517f8a19fa8eac27aff7a799a17d3a42(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d7cd3d999ed49cb7adce5f80bb0229182e89f33fd67544dd29cd838e44771d97(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__62de95fc9c49faa42ba5ad207dd9fef5d856b37b3f70702393e49e4446c22fc6(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__27dfb301e46c4530bc340eb12725f32e024f135686994499fe902b13c1ad777a(
    value: typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryComputeQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d31db44e62968f10ea0849bbc7097f091380c2b8ae055159213d53f7f6a7ada3(
    *,
    facet: typing.Optional[builtins.str] = None,
    limit: typing.Optional[jsii.Number] = None,
    sort_query: typing.Optional[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryGroupBySortQuery, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__49cba8caf6b38a10b2c4e6749f72b7c18fc34b479343001563464fa35a9b457c(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d1a7c822ed4b23728cf73a725748acdd228e9f665e8416741a9630f826df0df7(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__99b6250c6d552459fb3893ccc53fbb8542297ef7b10e1a3153c7dd10a6d5c931(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f3a028f55f6f2af46ae19b4aab4ac1966ac875acfcd25760854ba669c8a16c05(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4f8f512a5ae62066953a5fe80ed7609845e9285c8dda71ad39cdf04f9189cf71(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a8abf72eaa119dbcc291e355d74f021560aceeaed3002675e629d04b9324d61b(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryGroupBy]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ac79bfe5a19011e3197d1435347f00ab8a5a02c548fc9ef9585829379ff90e58(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__323b60a6e0b2a603b8ccb490c9d2c1438167f49e5e65fa9b56b8fa70e82299d4(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8f8ebb9672077e6dea12fafbe836b5ed2f48328fa7a926a8409adef686b2bafb(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e361fed3baa191cda028bf058dd11b472606ef2f2c7dc975c568e82764c7105a(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryGroupBy]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__643744eac577dfc1e9699ae4332d1ccc2b24d74c9cf4f6ae8385790d4d038700(
    *,
    aggregation: builtins.str,
    order: builtins.str,
    facet: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e57c3fc762e91ee67aed84ff018a445399e0e24c8c5884a29a0b83a4f637867d(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d9cb4b9207c86c239d1f77332b3bf0e7d1044505a9435a109b1275b7f809e086(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__95339482c5f2c2d8abb0c26eec7cba91e31567d0d0e18f0fa24c1f843bc1b805(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9ef0a64db8679ef78852be1536735ab1bac488b51643513efc405e74fa529be5(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9d963e1b691aacac1677204cbbd1e6e97dc3197a30d45b1ec3535b6f9bd686eb(
    value: typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryGroupBySortQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a3b6d131cc370df6551ba9e2632d1673cbbf6143f22f461913213a1329e2ea4c(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a772196a659697b2a280477d1a3c9534607e2096fa4b8a08154b4adf9cf9f6ec(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1a41d8d61418cc0157d0b711c7eed476cccc96fcf1ebc6f1ff1797c173127eab(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e008bfc89c02260efbced9f59ac824a90dc2dee3ab77f43376c1ae8bc1a45854(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7c8328d72299d58a81945d9c2e60221fbbaa5b50c201ec979b3f31aa7c2a6fd4(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__098baed21d0f6837fdff4efa8c5ddcb4a5b9d682721066eb91a998cbba324597(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__df2c6e489320390b5092e7d4db1fde3dc6634dcf917799da43b03818372b31ae(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryMultiCompute]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__72dca084ff31e3dc4d4e30c07f5d4f0ce8192639cb85ed4ad50a5e9d1db4f0e7(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5de19c0b1a61054e737f74edfa73a26f073d2cdc66333951898127c8798f1bf0(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1f2fd29b4e7aaedaf1729963e355f023e187d1a20571f0c66a89f606c097a478(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__855938f082c5b9eb8ea0bf2585f7549a73368d8c11295d6912758332ded5e272(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__28221648204b7aa448b3bd30e275a023c0adebc028e0dbe9953f0840b6f2b6a1(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryMultiCompute]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__62bfac1c98383d1d1662dc880e9b5ea90a811415e822964c132ec51d3a6827b0(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d734df955c13c560cef863f99cc83324b03359d16156918316318dde225b016f(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__39294d1c0448c4ff7a919dd475279aa9f9f421b54329213052707cf259690c44(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestNetworkQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c6f8e5b25f9034eff7beb3447d93a35fffc01d946917e5863187ce9f9a3d43a1(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__62fc2dc618b7d7ca43a6511801c7112a134b1b0d805597fdc85b815fb0718b23(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c4f332607909f639bfd9bcdf793827913f7eecbec661a97b4f6dc55c6eb963d9(
    value: typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestNetworkQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7ba780e4937e6fec5274a49bbcedb533686897bb1fc00f4381402090fe6f7a1c(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6f78d1aa4c79a19752309a2b53f84462d303da0ed99dd048af759b73a5bd2acf(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestFormula, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5b5f0bb7d8ffdbf8784e3cee813d575f6098b8ba8febe947e8ed2005f14218c4(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestMetadata, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f206091f9693165ce966ee5340f207592e5b804246dba9c35491fab0ad9f7a5d(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestQuery, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__33b36199dbe83047bf7556ecd336eb7169c19aca3f5b1c4d01eeb6cdaf8f0a08(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c0d1e1259b648c7b5c3450c202c381cb6ac8952e4b22eeafd5a01d82e28e14bb(
    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1c6f85de59c76da0e8bdbe0c37c5f256008d79b34bd833d04578c6aa51b52ae7(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__53dc7ec96ccf71d1137afc953e1d134f509cc0ac3138c2630489b4cf92105967(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTimeseriesDefinitionRequest]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2f199fc7a58dcafd5bf6edb7f0cb3a80f7cfc16ff7d50b0db5d48850aaaefe74(
    *,
    metric: builtins.str,
    filter_by: typing.Optional[typing.Sequence[builtins.str]] = None,
    limit: typing.Optional[jsii.Number] = None,
    search_by: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0719ca38e6cca84a6c661e632a0739dbc4c42b77e46f60f50e4d97dac2f28932(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ff726fba186e60133e648e52e5cfa38e284be64b5a7a16e1c01e105474979088(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__57c763b2bd87ed8246725907c1911cc7f1a3d75a6c4f21a6983f0e7541fd625c(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__05656f026dbfdbef64ab8d0f6a71f3ae8af1976e74e503eabec6ff9c34717006(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__10805b90d89178bc1e1a5853658e6a6e47da117847b6b1a8631fb3c8b3c41b61(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b6cdb06df284de6b28bf2876b1d1a9877b120340465b2d4139624efc158b12b6(
    value: typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestProcessQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__583205c621acfee22b30891d3dd7903789381c55d5440ce772dad06776e08bd0(
    *,
    apm_dependency_stats_query: typing.Optional[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestQueryApmDependencyStatsQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    apm_resource_stats_query: typing.Optional[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestQueryApmResourceStatsQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    cloud_cost_query: typing.Optional[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestQueryCloudCostQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    event_query: typing.Optional[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestQueryEventQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    metric_query: typing.Optional[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestQueryMetricQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    process_query: typing.Optional[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestQueryProcessQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    slo_query: typing.Optional[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestQuerySloQuery, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__328a3d7bfb2c37b6652b7aca13648d7eaafc7f39e6a3d9606cb9a4540b847238(
    *,
    data_source: builtins.str,
    env: builtins.str,
    name: builtins.str,
    operation_name: builtins.str,
    resource_name: builtins.str,
    service: builtins.str,
    stat: builtins.str,
    cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
    is_upstream: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
    primary_tag_name: typing.Optional[builtins.str] = None,
    primary_tag_value: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5365260b71983ad6fa95545e915a8bb3d3353d6c5402d1eebe45126761d0d673(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__919bdd0eff6d5ae3cb1da541e9e8cae9b392848b43d67414dd4a8ff3b5541f2f(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a20e32b855fe2ef717912e176e4803a100e58d55c6a0f745f9763309cdb4fa6b(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__274e04c8d6bc61fa836910c31f718221ceab2b393c675c2d19eb21570aaf4f34(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9ba78c06461313989650a24718bf261b511bd31b713e85572d685fcbefbdb5a6(
    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ad80098a82deb65c004f3e7dcf71988509f217d6ef5e9f57cc318e349601555b(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__474aefd9578cdc4f4716147aa5269aa6b24296841229f1b2500abf642301b0f3(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3d825ba27e8b3dd5820605eaf0fad3cac251de7c2f5452c6eadc547ac14e2464(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e1130609e8509369473c5ce8c35fe79e0784dce74baa382ca4d247d31ec0d59a(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__642b74ee10536c54e1c414324ccdf4bd892de811e03be1e275667fe953205e17(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c6362095944a813b8a722f51058647e46dadef3eb661772c04d7306c902d3acb(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__aaa7cbbe5b9f35df3926a2e976f0c582a4ff9b6fcd2fbb8eeb6d06c352f4b8aa(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__048347471d676fd26c055cb1c6ec0d7b2109df2fbe062ec65b0b1fb05f96f627(
    value: typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestQueryApmDependencyStatsQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2d33e958a7bf0ccf01f6ab0c926e10acb53eada3a8f0c83021e3494bf2c03e73(
    *,
    data_source: builtins.str,
    env: builtins.str,
    name: builtins.str,
    service: builtins.str,
    stat: builtins.str,
    cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
    group_by: typing.Optional[typing.Sequence[builtins.str]] = None,
    operation_name: typing.Optional[builtins.str] = None,
    primary_tag_name: typing.Optional[builtins.str] = None,
    primary_tag_value: typing.Optional[builtins.str] = None,
    resource_name: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3b8de35f5a13921cd2cc8532e3f3a7dfff44cf96d27112e8b657ea19df39a931(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__92eee58b9805f3b27987c0e7a1dad4ff020849fca6464b620d0d4debf2ba0e9f(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b48683e9cbc6b168710f5e61be1dce490d9027104f903229c1132145eb7f42f5(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5daa231bdce169c86b6dd364496cfeac2536893b7901aa86b743dfa0faf8583c(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__baf29dbb44258fd53d3439d5021d2a24d281853203741892cd96e213002263af(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__73d89b1ed63f552c94e67d13bea04b2199ef26b0310361ce2c8abca338198fc3(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__be15fc95ff106424f4bc79379826d3a9015b3ba65ff26a58a85c5246bfa86626(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__019f2bc837f06d394eedecef6f01cf48a56fff7e30a90a8a45b44c9e736f0f61(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__843973aac82dd2b4406746a59a28a2671b00e2f2ac7c0b1e8bcf0454f144ae93(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dfa24ac15636c7214b0ba36ed7a929924d2d8838a606908bd71c7b7416588769(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9dd61484e67703684d672a2c8124a563b008a1b4970b8a3b365692470e876fb2(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b95662f2de113762eedfabd49b3f8a5f2a2dba2d392ddc6f2f68b6541faa54a7(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__13e49b8cf88abab62bbabab8f422b00323c6c0a9987cf0d91e96db0c11c1af89(
    value: typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestQueryApmResourceStatsQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__681ff90e27784fa2203a0eeaea5305500124c2a9a7100f9b9b215a2945275093(
    *,
    data_source: builtins.str,
    name: builtins.str,
    query: builtins.str,
    aggregator: typing.Optional[builtins.str] = None,
    cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dc330f1a4dd0ca374192159bdc4f8525c41ab3221a0b983fb672ab14d6b3a035(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8b28b82aec2b70dc9e59ec01c9cd59cfcff46969d55b5b8264b03f0c6e67e386(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__04996a78facfe801f03c19d230f4d1d09cb894eec3baa515b04ed9cde2723f2c(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3ea9b945a09e834f733fe35110c739e4733c645ebe31d82477f37041345df34e(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__546828245b8ae901cf63cee278f7e2223ace8440916fc6af9d00bac1179a7460(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e1316497666ddd0fdf923c105f92467b42b6b91728ff747ce670254839795554(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2d0aa26fda6952dccc16ff33a843c0f1ddc9c86823f5487ba3fc3f938300625b(
    value: typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestQueryCloudCostQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c92b31a6a48ff3d260c3be4c1c53134116184741ca7879088b2500af27bbb6e3(
    *,
    compute: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestQueryEventQueryCompute, typing.Dict[builtins.str, typing.Any]]]],
    data_source: builtins.str,
    name: builtins.str,
    cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
    group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestQueryEventQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
    indexes: typing.Optional[typing.Sequence[builtins.str]] = None,
    search: typing.Optional[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestQueryEventQuerySearch, typing.Dict[builtins.str, typing.Any]]] = None,
    storage: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5ecac23c84813a928e32a31d00197dc81e8ba2030b934a7b25426c25cef814a4(
    *,
    aggregation: builtins.str,
    interval: typing.Optional[jsii.Number] = None,
    metric: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__178435041c9b8b339db20423c01318dbfcbdc1fb08b9d575d7a0ec42f6127a01(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e9ce5c5e1861b0ade25532adadff5bd12e60a9f2439db2cd2f1d68af314b113f(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__31e29c29afd2f328c36b03ed95a101fdff6c660dbac28ae1d3ba4281e8c59728(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0337f2423d2ed88e98b88368cb5ab700de814f1049179165ae4668f57ff3fcbf(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__472ef9a99bf2c878ecf79f8fc8e4ff681d6ee49559c095bf1f9cf6b573c54691(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__17a01746802b84e49d652cc01de8aeb5f466eefa2a88167d42530c5d583fa0d8(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestQueryEventQueryCompute]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3f6c2b8867fbcd45c976e2ee39099bfa805fdd7059302b2ff52413c43ebfcf27(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7759f3b69d78c68e6f16c884b31a4a45c7c7aaa00a155a805feebe48c9217f17(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4e3128fb613e9b9573b0e2ed348d7446fc7bbf8a14ae5a86abc74f003d50474a(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__229a1b3348647369e0cad775bd4e55f3c792cb316207e181d18986f75e87c144(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a8f9a2be69435b2467c495265235f0d43e415fc98efdd94bfa2a7550f8567b03(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTimeseriesDefinitionRequestQueryEventQueryCompute]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__53bcff6219a876712c6fa0e050ac8530deb447b1a107753bef74a2e915dc2c4f(
    *,
    facet: builtins.str,
    limit: typing.Optional[jsii.Number] = None,
    sort: typing.Optional[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestQueryEventQueryGroupBySort, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e705b8407879ed1de5006fa7a690fbc19470c1bc341d44574aa02372952a27d2(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c48fa8aa0548b9853a484848a85b31f4207aeb0f024213fbe6c5d7297991983d(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1b8e96b1463b654d655475b5425970b006ed2fd39025198ae7357790798eea02(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3c2a3ad54a0c42fd2dc1124e937c14e4c27f16601ae0ba2149c35af47d77dab4(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ecc86e453bb874d449bc5d4105cd313608c71845656c407fcb0d5ba2f9891570(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0510cd2017a3c0f3ca6b05277794e37d628c6248377f0db38b746eb7aa15936f(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestQueryEventQueryGroupBy]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b862be40da8d672ade963c84ccb2f8e233f0c61975cdff8f8c1d31faa28b4669(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__75b48f302c19e3ac3e356369a7f5062691e23c8362c3d1fc8230f1dd7b039560(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__867b59771ad4bbb7ead3a9a1165fbd060275e867436e9abbe812f1688a41d86c(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__17d8739cc79e166e8e6f2030804fb62dc14dd820f7a999f534fe56480d297734(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTimeseriesDefinitionRequestQueryEventQueryGroupBy]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__33a73f1f5874021947d96f98775cc2653195c932668adae727853c30acb911fa(
    *,
    aggregation: builtins.str,
    metric: typing.Optional[builtins.str] = None,
    order: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2e4cfb3243386281fb2981850591e6ab0e9ff7f483ede4ebce566698e32de6b3(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__734e0cb8da99e0658c5948e1cd54667401612413ca90a04289f7af19d9399ea2(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e7b6f48aff788c738c0fbc09c2d1418ee75659246e2c9e845d05ceac95ed8a77(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__77f4f339d6993a57cde7975c9ce69ae50fbcf4fca385b87ccb5cba92c51b5a9e(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e353256b9778cdb4517cbb7295d480cee92a156d7bc4fd1c3e18b432a41ae984(
    value: typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestQueryEventQueryGroupBySort],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__192d41c5d89193788e8a1ba32125256de1a3fd750ef87dfe868029b21f19166a(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9443f5fdaa40277d07cfbea2ed80946e17bd80e196fb752d7727331cbaccb11c(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestQueryEventQueryCompute, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8d971beab43826ba3ecc9d012f83ba2bbb1a111296e02dc089825ed5b616ed69(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestQueryEventQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7b9580396bf793d81c657cb13cdd6df10971a2305fd1b2b604787d0f4c561992(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__99a0d0aeb99a91f3c4e0606b456a26f007fb3c45cb6d25f33d56b668f8f1c2c4(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4e66be085b32aa619bccec810fbd4353e356679c942c038e11c571eda3018de2(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__012aae014d52fe005a14555227c5a993235c51a279fb85b1afb502ccf6436ca2(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d81b90b9d0f14a656d06b5ef6651f4c76fd853b3f2b8019d27bf9a25ff7691fd(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2bb1f4ba3de83eb63ab73958f2f7d29fc7c230a88797816aa57267466dfcbaee(
    value: typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestQueryEventQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__637d3a9385fd07e0f18e27a8652cc23387c8894af24b5454e8ebb75b35afd546(
    *,
    query: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__31689aa02810c33b2d838b600d5da847cc9f609ebcc9caf1147d5175017bd242(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d13d41d5fba1a0a6c037413338fc63a6faec394b04009fb584057891e0d91ef5(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e87c1b828655bef331bdc3cca35af8f55669fa28186e76fb571ae277573ecb0e(
    value: typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestQueryEventQuerySearch],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__48e681a6f23118a936ce24c8fdb3a9b5d92f0cd1655cf2668a294220110d4882(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4ad5ee2bad233d38f137a69be735dbb8edfccae81176e5178bacf92a04af5906(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4e3ac3f600f959729cdbc3d4e5c20e0d6d406438027dcf42f968ffc423b9ee89(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f3b941372362bf31c67ea7dcd972caa802b03b609961f3fa46a27c37b6bc110e(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2760b29f497d5a5934777fb57206c0c40d026a369186e2a07bd819cf37d566ac(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__edc5d83d29457b6a5029b10495696488b40aeb11d2ce09aa3a7dab4776475a48(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestQuery]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6e60b87bf51bcddab8e1588f37b1c027c847ae1e4f9bc77222ba057dde3a226d(
    *,
    name: builtins.str,
    query: builtins.str,
    aggregator: typing.Optional[builtins.str] = None,
    cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
    data_source: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5a151e5bcfd0b155069a50e25d4e05c654b2de6cb5baad8c39b7a2c6c3df47c7(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__28ed05184e7839982839491cd8ee60def7804cd4096fb229f911380f62d2d17b(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__40581dc5b677f06fea0716bdb20973f85dabccdbb3fa499302587847baca593c(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__aa7d4c03792ef4bf83b048f2c6bf99c1bd28205bf9f6c930b1957147e048510e(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f98fa6c27a043890faa341473dee0d9adfdf6b23944b21cc36f787ecedd1ed5b(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d6ed8a583a4b715c675b4ebdc6d543aaddd8edfb3853afd8af207011a508f6bd(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0dedbf294ca8782e872cac5dc27c87713e6d5b0a7b1ee2e8c7e3ffc639a8430a(
    value: typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestQueryMetricQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cb06bcc5f0b9697a419b250f081879661ac724faa6d1cf60e894d3c1f52b4e3d(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b4287e2c8d863c37a9e155059cfe8066f331d31d06e25e14b10662cd14fc4b6e(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTimeseriesDefinitionRequestQuery]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__81e7b2f18cfca3b2b4b7099dfade01164cb24d83c07dcc031554ac0473116f03(
    *,
    data_source: builtins.str,
    metric: builtins.str,
    name: builtins.str,
    aggregator: typing.Optional[builtins.str] = None,
    cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
    is_normalized_cpu: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
    limit: typing.Optional[jsii.Number] = None,
    sort: typing.Optional[builtins.str] = None,
    tag_filters: typing.Optional[typing.Sequence[builtins.str]] = None,
    text_filter: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c4f4855457d92e6dd26f8bb48e5cbe97ed940c1a81f7dd94a72079b548d80bb9(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6baf37ff28b6da811f748b3faecc23ddcfe4905c12cabde2d89d378c7e496f09(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a5376d462b4bb6e5fac5707e434a0dd171c41e639a3b876e4523bd4de76bc864(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d488d905f5c9a83fee89a43c00cb86f23371ff2a6a5011b4accaa8477290dc9b(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fc73bc028602ba759b7a0621b38df6bb5827a6ee3aecde213b8c252c72ebc588(
    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__590283de44f876f3d1da4a4b0900e47fcdd3ec248603aad7024149c0f6740d35(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__198094afa367739b44a8572c395edc27473995a1e9028afc961fe9d039eeb201(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ce5e160ca5b365526362dea254ae6b2114ef913611b3c23e911095f91665b8c0(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d8227e7864fbf6ef1f4c5f4654624bec019aa210436af94c097ab72cb8b048b0(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__49e48723e34826df7d0929f61721408934a2e7b50ddf073555827cceb64f34a3(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3df9b2288a21dad8be1a1b19df892f1fb80e2ebbaa876ceae2f541fef4fb755f(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__464ab4c096da91bc9e7a0706db51619724178c2a81a251ee61f303d0168e81e2(
    value: typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestQueryProcessQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0934f6ffe25b840adf939a73e2d35c72a8f05f6848a399870f95d354fcb448af(
    *,
    data_source: builtins.str,
    measure: builtins.str,
    slo_id: builtins.str,
    additional_query_filters: typing.Optional[builtins.str] = None,
    cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
    group_mode: typing.Optional[builtins.str] = None,
    name: typing.Optional[builtins.str] = None,
    slo_query_type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a784df6068f129ebf344a9d77a0e249b3d032df8490ba05c852a07e07ab65f9a(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__154d8a30e659497d27752fffaf41a11221a555d8fc506b0bd96a54cc81f65c4d(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a615b3d55836c9b276d012359ab7f2df8e3f41b39b2c0125eef47e4e8de1654a(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__46707c2a54d11734e5e96900693aeb6f789f15cb184742e7bfa00db4dd13f656(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__abb6ff80cce937f330f37fe17b29645037acffabfadb0b3c7027f934fe551f41(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d01c5f668b20b8a59d3ce827d1fd20f37ad920463047e9aa324ab0e75dca8b8a(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c5c5a0fe660bf4a950c63b3f22d0ddf5ad60dbdaf8e613484c73fe4afd14b182(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__599f728df1408b7ec93cf1081ea1a5de896b7c0fe49b7d3c0020e51986ba72c7(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6ccee986d75fa7dbcb88bddcb0347083585990546d01e63ccc3937854f9954bb(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__85e8d71a2ee8ce093697fed566829fae0f88836b39549a3392ea07e04fe64689(
    value: typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestQuerySloQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f1e15116a3cb82b24b14499170141e244eb31ba673f158465628e4f03e550449(
    *,
    index: builtins.str,
    compute_query: typing.Optional[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestRumQueryComputeQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestRumQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
    multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestRumQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]]] = None,
    search_query: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5159233f31a116458e80de064da0919438f35ad97871e6165c96d765f132c3e5(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__61fcd795ab17d36242ebfd99e16fad0893f1b4b638f84c9aee6c5f96824daac9(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__08314ffddc963804428935f950300517c80a64f3a9ab40b757c193ceb007a8a5(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__451b8f5da91a7decb5f59b6c2c5702627f62461ab5c62bb6c9082317e87dc560(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6bd5fe35a71b6ae770f61ab60e754bbbfa86a9c0ba2bd76da3796a2ec3a32606(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__814b4eeb49a8c455cda94697fa4eabb58315e10a512ecf324672202f2a6d990d(
    value: typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestRumQueryComputeQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e34ff591efc20a78af4274fed2ab61291890524a62b442987c2a9cd50f92af29(
    *,
    facet: typing.Optional[builtins.str] = None,
    limit: typing.Optional[jsii.Number] = None,
    sort_query: typing.Optional[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestRumQueryGroupBySortQuery, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d8297ca65b53b28f7b72f786e508006dd763e9f443b71f1883cc647495d9fa98(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0763c93e85211ca9a3d56def2083b2d2021bce0e0e5bf652bba5c5928244e55d(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__470adb864a19c61da83999303a30bfb5926de8d9df581a021d8e4b9f57757270(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__12a1af8da6b169e5a323bb105130ad345625ed7e19d944116491a492db41a68c(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__232c39f8b880eb448c5b909abc279f7400fa31e1efac0b0d28e5d8df22310db7(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8754c6930865aa8f2edcc7f79720cb635e12b5140fc8a297803bb65e39907e64(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestRumQueryGroupBy]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2757d2b4dd81d6f5b17b11c77a8f8a4b0bc471de8c92151208854786322b9feb(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__18a0e6233cefd3ce60e794838f099d3edee1bdff6e271b63b1774769a0ef6fc6(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a3fdeb8807fef621c101eed154adbb23a3f195a8887d988220b6e6725b62d55c(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__078f4ab9deaf6f02d875fb7c431ea3ff8f9a7d9fb3b8c9c15dfc240a9b650244(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTimeseriesDefinitionRequestRumQueryGroupBy]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6f91a3eb615adc714214abb092ceb49c8f8cfc48e389d262cf562d248e233b7c(
    *,
    aggregation: builtins.str,
    order: builtins.str,
    facet: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a7e0732765beee1fde28b3abf73203458d73c45ca0521be1c2c5f7cd9d9469e3(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d1a342585f9eea8c7dd2dd19dce367aea66ddfc280f1a0c1cc6219cbfb1b871c(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__636046dc62141e3b3156db6743282146f0b1e237b5d025be1319b258f990de50(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e9c1e5a65530341b720fb12b637f9e223ffb758477a5e031d473a2fe30bb927b(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8e0c1b12d3678154a97629da35ce502a0b80b79cea3c00dd4adee2170c16f2d2(
    value: typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestRumQueryGroupBySortQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6840209a9a03d8e2b4bcaa837c9d2fa032b054a6a01234e2462d35aa94c3bf42(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3f2cc970143d6a4df15fcf2b1d86bcea6ff0757eb45149de6ffd889b4c55399e(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0cfe91c6991b0c5b101e1477836af7cb1609943f5c4393f97485ae17d4d1a32b(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ec856ec028b535160bc67396b1454acb8b2d0ce78f970bbdb7be28dfa7c71f02(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__49f628aeb54879d17bf1c84be3d1c95d8f5227ac7d984755b5d172ae800e1f9d(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7184ca1f1cb83a43996ae7a95dc01817a7e7cea605fd34dd779f6c2dfc3abaf6(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f55be7707a5e844b94bb353593672627470624ff826013acee57ba6a58c6800c(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestRumQueryMultiCompute]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__891cd580f195f052f9e54387c4f58c505b6284f6063f6e77f8b6a2713bfc664b(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__74b0cb3189e65d45afc49f4d85e09e551768b7750122e8e225f8e1bb5dadae68(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9de78d0628a64854de7a9d18da8d1b590680763f0f27fe154efffa8792385ac0(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4a1454e90e59128456185b21bad9ad50b7e88def46299d98d881d44ec8da9602(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3fe00ee7edc4ad94fde7ce6070b7010a0b3516a818c2e88ab1563c9eb20ebdc6(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTimeseriesDefinitionRequestRumQueryMultiCompute]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a93fe5e65f2addfb614b7ca76d03c37214f83b5cdacad776d302d129584f8205(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5406879d06ad6eea3ebbeacd06a5e1b7ab38fee63da89a4e6ebf4617b0e469da(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestRumQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__03de81b229400417bddf80614c2f073807788b9954ad81e9faea239dccc6a002(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestRumQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0884e3e2b1d55d4301f5ada8e994c31dbe2b27a87dfba29d050585e5708b7295(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__94757794c40c30e41b4fa6f4d1a12e822fb4c48bd87d5f15218e720ac10bd947(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fba140d80226034b00735cff19645e2aeab0a17d5b5c2bdc0005466bf85cdad6(
    value: typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestRumQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__27c1430b5d8a764a2f059dcdf3e1bb6b19fda04e2e7f906882b1d20300f9d497(
    *,
    index: builtins.str,
    compute_query: typing.Optional[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryComputeQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
    multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]]] = None,
    search_query: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6a0a5ea30ca04827a40ac7e8460cd0bbc343f831ebd8b725ceb0cb17fc4caedc(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4b9ad0001b170eb16f4ec59c663f8e783713760e6727ab63a619eff29fd3b298(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9d2a4b45083acd25305282ffa03ce0521391006ef17114b19f597a0b021d6d51(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ef95d77a714fc549bd47a365103e4f203e5e8d9e678a54b4df813d499d4180c7(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__84d57f78b0eae46c1d156ed40ec41d23a75e5cbc0ce62d2182e633c9c3d80216(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__07b204a10df552da4bcd827011771818fbaa9d561ce7a8dec7bf357ae9650a1e(
    value: typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryComputeQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6882877ddaee08d412066d2eb09f4bf75830e763fa5a9ef9d849b1323ae56819(
    *,
    facet: typing.Optional[builtins.str] = None,
    limit: typing.Optional[jsii.Number] = None,
    sort_query: typing.Optional[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryGroupBySortQuery, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__45e6eb27bbc5a02024a9a5654efe3c3adc607889e098d1fbefc87e3b318f8c8d(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d3497a23ae0205302b4484db6121015e271b905db2e948178defcc5f2179d840(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bcc41abc094c6db627a5229858c3c6a547c4fe5e63039b5e86b0a3a3854a474b(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c70225b5f105ee7be79c182b4a21ddf2aa2233ed7c6dda5aba004a5d98733733(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0292cf5cf0834cbc2f7c2ce08c8d55de47e93e2d523310e23ca8dd4c0edc410c(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8f5c950f1b7595ac62c3c871c7a187114f1af6f9a38373e5243216a08e84afa2(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryGroupBy]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__35c88829239ebb576fb92741015dac1011d2159ae00bd5763278fe85e16882f5(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d2a23902a2d33fbc5205d5e322ff2a57a21c9f52fb4e8c975eef75317266f536(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9ab1896c423e0d8b5639890d15154db3932a976832d495c20de777c2734e74cf(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e75bb1742b5853189ae61c7d8cf04a42653805a05e1274fd9a4daca4c3435ac6(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryGroupBy]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d646495971f534cfc76b6cc1c188bee0e13f8172452f90659944dffaec4963a5(
    *,
    aggregation: builtins.str,
    order: builtins.str,
    facet: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__750105fbd729aa45404e44e7a792a86ace2588905241b18c1234030ed2d14874(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ece3835b914dabaaa5f0a29ec51bc3c841f84dca93f76a5cb6144329c696ecaa(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__79159daf8f3bd9b5ef59f2371fb49402ee1821b0d66bad39c782720c0ab0ec03(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b968264dcaab00e4fea3ac9b78d6f2324024f08a0f3e8a0bb638c53ada266f82(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ddbef4fd052eae4480cf4e5aa7a56157307a29bee902083f30ad759bb4f1d39f(
    value: typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryGroupBySortQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__68aae0b7d6601b5ae5b0c375bc5d3966306834227744445cce4930dec90c34bb(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4a5c3614ac35e0ecd2c4f061a003dcd3ec27cc3bbc9b3fee5135b1ef44ccb7db(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7e5912908ac52126bcfcc8edac679258551c581328daceb45560c5bc4a7b0053(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3efd7febe8e8e13e186c23d5783d2f8c941ccc6df8f13d166a6ded32b3e63915(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7b1db46610026d3775dbb9b09904169c84cd3a5a9254f155610ac36c32d4870a(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__77655720cffad68c9579296b908a127aeeedcd2a2206dcddfd4442608676abb0(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0e3297b9e12f0b5800be90b2963634b262a93b0792b25efb6f334499b6c9f811(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryMultiCompute]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0e35bd963ebdc263c556c520dd9b6ee7c19dc94de1f006f43b4a4db67bdb7367(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3653fa0c849dea3bfe087873bf90f91ba616b57ee1fc492d2321973207cdd447(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4d4362bdc04666fa21c4bcbeb80e21815fdd203986c57be330e925f32fe07463(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9c2f2ae714913055c35ca00eff6115ee207e1b08c62d6b38878aa5eff413869d(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c5dc9bae12da9e1b1002b3e77d323df82c09933e3c5d8aa305f610c29433fae8(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryMultiCompute]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__eec395da72699341a2264076be1ee1b91970f018fad00f7c4c79c8eb9b1e013e(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__67b5d38c98af967bf1ea28faddd5803f9d72c747d7815a765fe34f7d27c5afbc(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c540e3ad6b2f154dbbf03855816c59931c2bda05312e7f89aba136b5361d27d3(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetTimeseriesDefinitionRequestSecurityQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d785d31a50b5460af7f3e22251983be1afccb2993664e59899620764ae882d92(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__27cca65559cd35fe4e6c93385b0597b96d94d85f58d39d4d325ca111e5704524(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b0e0a7e2c69d620752314158b453ac70b0fac0cc5257d9cdfcf3c95ebd88aaa9(
    value: typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestSecurityQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6ce096ec99d6c79a15def6291f39b91a09a5b41d17b11aabc73106289cce399b(
    *,
    line_type: typing.Optional[builtins.str] = None,
    line_width: typing.Optional[builtins.str] = None,
    palette: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__00a4b50b327c8a2d509bc7c1dba475a38ac7ac881007f4ecd6698c64701e81d2(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3a1960ee252b8bdef9792e8cae6962e1390ef808f5e24cf1d8cb4bd8da5056e0(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c870c53094cb9adc45612047065cf97ef39150c866df8e96f1ed4655bb892a14(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__08551710162070b3c451707524572a538b327aad2c37fbe0e2d99eda8833a447(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__98705214e737e69fba886310b001127556f723b9cdd2d2a21f6793735db1a7bc(
    value: typing.Optional[PowerpackWidgetTimeseriesDefinitionRequestStyle],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fd96fe88c9462541ee1f7c6d967f8d845239ea12c3718a535cfded2d2f6be369(
    *,
    include_zero: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
    label: typing.Optional[builtins.str] = None,
    max: typing.Optional[builtins.str] = None,
    min: typing.Optional[builtins.str] = None,
    scale: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2dbd24605231e1f6fd1f6dd82453ad447ed2f0654b92ec729abfc8360d925a35(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f6c8ac0cc704d444d9b6451620d21147fc4cb8da38e9343d03d7c642139b40f9(
    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f3a1585718fb01c43aebf0ea0cbbeb7738593d29ff78a5e2257c2d87c9dc845a(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f2f7a123f3de4d89fdacba189955b479c386ba4c49cde4a3c39050243535ed59(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__52eca119ba3978722e6701b87732ed223f4b08831cacd7b54282f4e1d5a65028(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1ea4f16db7a0363b6e619c3f4daeabb07c9d9e5bb316d41cc813a64d1f0409c5(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__10bae89661deecdc47bf84a52ada8a10ad17d1a262408a0390c0a50808bf403e(
    value: typing.Optional[PowerpackWidgetTimeseriesDefinitionRightYaxis],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5eeb726533b557d5558a4051e3b2de7166fcf9be98c755e89a8c552a881a0469(
    *,
    include_zero: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
    label: typing.Optional[builtins.str] = None,
    max: typing.Optional[builtins.str] = None,
    min: typing.Optional[builtins.str] = None,
    scale: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__538b97b26702cbd46c3e90bb4272ab8bd94ac773e3fba8e30ab40c5543ac22e2(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9b12fce1d2e892ec63e4aa35749c5a329d308a2128ae016ae05491b6dbc04dfc(
    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__31fe5da41cadbcaf3312ef60a7a2d32337489b2897c3e94cf8acce7825709da7(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6bbf8130570a94be8d91c9b7b5ba81e436fb5f6942199223a321227c54d35c91(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__76eab25b92cc7270ac7ffb5303992f972f677bab99d33399d1c7b8330e9ddf06(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1e6822dc738c93de8270167a2ec99f1c7c839fd651e41d6110b87190a4529ce8(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__94cdb41f9ddd49634428a0e474b09515b72ab53d339b9f33f664629983d63682(
    value: typing.Optional[PowerpackWidgetTimeseriesDefinitionYaxis],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__273bd147ea86d43b762b2a52adf9493f460c0e1a0cd4a667ed7dae08cfc0ae1e(
    *,
    custom_link: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetToplistDefinitionCustomLink, typing.Dict[builtins.str, typing.Any]]]]] = None,
    live_span: typing.Optional[builtins.str] = None,
    request: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetToplistDefinitionRequest, typing.Dict[builtins.str, typing.Any]]]]] = None,
    style: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetToplistDefinitionStyle, typing.Dict[builtins.str, typing.Any]]]]] = None,
    title: typing.Optional[builtins.str] = None,
    title_align: typing.Optional[builtins.str] = None,
    title_size: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8afbd59e21f8935007ab0e09784668693df69eadc9661d7ce6b1d8703bbabad8(
    *,
    is_hidden: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
    label: typing.Optional[builtins.str] = None,
    link: typing.Optional[builtins.str] = None,
    override_label: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__902d0f1937e891531ee6d297e4e22635a79a3030b0f969dfd62610a84527e5f1(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c6cd8711b1a8e17190271907f091776c9c8407d4cbfbeebfc7e2171dd9276704(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__704e425b2c5ec0a3eafdd9ae920c86434620d734980f7c9a61a2162981d39f7d(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3cdf901a04b17cd83b2bc8d9ca2a68b74a7fe8b72eed8cf0e6967098f31f866d(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c3d2f1608f54a28cd9d902de6cdd529cfb4b9a207b4767f7a0abc4ba0324f7e0(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8fecf2bf20203ab2078c22b19fd0cdd0f04a385762683099f52931a36f814ec1(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionCustomLink]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__64381967f34e6f97b3cc5f721cbc4bf54dbd90df1c91ba48e7bbf1b3b83dcfd3(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3c6748a9ecc89bc64ebdd4d138b15b44b0b91eaa7089b30a5c86a4173b215080(
    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8d886ef2c2f38389cafebf222d2584739d5b13b4ef2c9dca558cbb598897307d(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fa2b0c38d591c3c04cac53c078e98e8f564d83ab0f0b6b9b4abbd22fe468d1cd(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__89fdc94fe2d2382b14cbcd09ebe9c0f69cfd1788d611f185de30ea982bc7f18e(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__55c89023292d93fadb1a95892d36f0dc528f5199cd937306202540684e1d64df(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetToplistDefinitionCustomLink]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__575bd7fac7028d563604a485461be9df40afd8220b2b599771f8b1c856c95f14(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8e34ae117cf07a86e4cc41b29cc751ce58f0d55d94bc0673b3605ded03afda21(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetToplistDefinitionCustomLink, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d0d36f81edfcf1011eaffb9d1ac7b1b6eb26456d8d403138bc8ba09168cab99f(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetToplistDefinitionRequest, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__93c904858910ceb7dbd2e3b7abcf99eac98ee60ab0c3ef8a8cbd39b55b6dc159(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetToplistDefinitionStyle, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__638288c5400a11e4e5765a2f0c0615a02e85f06981c7b03b1076777bbcbc348b(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__674f80df69a3f6dd149836c1d690bcc7985ea104c9015b12a390978e7f0accdc(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5268e72ccefea69b48aa919fd348b975a961689ff75cbe2b449cc474fe653b67(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d8bc7aaad86b1f62f550d9e612c7ba63a4ac825b5438dfa8789b6aedd1c423f6(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a9caf1036965a5a9cbe25cd5878e117f2e0d22aee7c03f22d56f8295dc293e5b(
    value: typing.Optional[PowerpackWidgetToplistDefinition],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8de4987406758dfe634f94b0e960f3ab7455949b7c625a28b436331443eb8727(
    *,
    apm_query: typing.Optional[typing.Union[PowerpackWidgetToplistDefinitionRequestApmQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    audit_query: typing.Optional[typing.Union[PowerpackWidgetToplistDefinitionRequestAuditQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    conditional_formats: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetToplistDefinitionRequestConditionalFormats, typing.Dict[builtins.str, typing.Any]]]]] = None,
    formula: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetToplistDefinitionRequestFormula, typing.Dict[builtins.str, typing.Any]]]]] = None,
    log_query: typing.Optional[typing.Union[PowerpackWidgetToplistDefinitionRequestLogQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    process_query: typing.Optional[typing.Union[PowerpackWidgetToplistDefinitionRequestProcessQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    q: typing.Optional[builtins.str] = None,
    query: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetToplistDefinitionRequestQuery, typing.Dict[builtins.str, typing.Any]]]]] = None,
    rum_query: typing.Optional[typing.Union[PowerpackWidgetToplistDefinitionRequestRumQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    security_query: typing.Optional[typing.Union[PowerpackWidgetToplistDefinitionRequestSecurityQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    style: typing.Optional[typing.Union[PowerpackWidgetToplistDefinitionRequestStyle, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__abea32f6f9f5f733f4c128a916b6e5c684bc43a067c80be1cf28d17313adff48(
    *,
    index: builtins.str,
    compute_query: typing.Optional[typing.Union[PowerpackWidgetToplistDefinitionRequestApmQueryComputeQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetToplistDefinitionRequestApmQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
    multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetToplistDefinitionRequestApmQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]]] = None,
    search_query: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3c0fe869b9b2c6d3dc7ffe17a5a15ec4a669eed7e113a9b4c9a86e15fb699d44(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c39168abc00482dda8a85502c3b211301eef5b99b18f8256245621aecfcb70bb(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b676c14b04d8b30c0cb3ca77fec94ee1a7f93e3185f2095ded0b99e1237b02e4(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d2a67de416b3dffa586e4255b4846bdf7e582f4d621e6f78022e32c0c8dfb81c(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__664260ac0dc4b3c97e1aa048b33827b5cbbe8cc8f71e7e727bcb226cd8a70dd7(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f8b921093d9bd04f9c1f641e37504ef1c01bc2484f7cd51f6994e63facf3cee3(
    value: typing.Optional[PowerpackWidgetToplistDefinitionRequestApmQueryComputeQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9538082d8cd96a1c478bfd7c3105fc3ac12f228fe694c93fef2cb65307f36735(
    *,
    facet: typing.Optional[builtins.str] = None,
    limit: typing.Optional[jsii.Number] = None,
    sort_query: typing.Optional[typing.Union[PowerpackWidgetToplistDefinitionRequestApmQueryGroupBySortQuery, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__670ad668ab9dac9a4598c8b442df87a4825c38e46155f64d158968452384ac9e(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a3cedb7c734774dacaec064dcb53eb5d5098b4c140434d806402652f3bc57c34(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b756b892100fabfbf1880be7220df2cf9ec1fd7c984ce1ec85fbd329f3f427f4(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__44063b6dd926851d9f4eb8d89b1ec78251699ba2b943a2c9e4b7ab9c8c945d24(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__36b237107b5531dfc3adef39a5474d53f0eb3ad646decf82d42399bd3fcf4d87(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7cc3bf3e8ee3743493c5a67cd3e2136357be6d6bbe8c955932199f99e62d14a4(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionRequestApmQueryGroupBy]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__46e6feb7bc59c110bdbe566ac800e6da31fadff770e75dccebd03bef313fdbd0(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f57c6f50419e2fc404a685b9fbf74703cfbad21b3f5782b817d50c7f9bb31f7a(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__de61fdbd1a2a5a7b9e06e1f84a79523209a3f317978f4935ca1f530652a6a4fa(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4575646c49fb4e45a9c57fe406dc17c68cab0d431dc9205495adf5fe0ef10ebb(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetToplistDefinitionRequestApmQueryGroupBy]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__98764c99392d6a4e93160d43763b2ba2604dce7a0fc335828e31c82ebe6fe3a9(
    *,
    aggregation: builtins.str,
    order: builtins.str,
    facet: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__42369d2f8ac93f903310742a7fe5301922623b1b78da78f6ef92bfb07ef2d163(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b1ce06f5a23ebc1f341c999a5198f539cc7f617551317ae6f2dafcb8e2a0efe4(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__58d322b64fc1916d3f36ebdd85a6433969a044f5bb79a24031e6e428d1c6c99a(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3a6730328e0a1d6c72b8d1c18bf086ab54510626fad20fd04bd091b2f31043b3(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b10fd1c874da0d3f8ac0aa4bd8e97e825068bba8402a21c01b1b9ffbfc83dcbc(
    value: typing.Optional[PowerpackWidgetToplistDefinitionRequestApmQueryGroupBySortQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__60a8f660969fe9fdeefe58a5af9d0ca813f8bede6933558190c702e3c0fb87ca(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bcad328749223d0f5ca49f63720e6bc94ebc7a9bdbd617ff4069edbe60d85c69(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__715e09219284e501bc2b6b54de482bf6d741bca6fe6958ee36df66337008eddf(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7b37e9a88f75057874fff3434ddff07ed934bb11e8faf7b3f3f6e01c43e91a36(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6744fabd4bd4c0da2228b7a788fa6bbbf301d95b10442e7befe4b43520aef5e4(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4c92eae412dd65de740beb4ed9500b3de550c0014ce6826b1b6bb8c77dea098d(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__86373bb339714bad13f3a1e2fd7160dd4361fe68c73764bb9bd9158f670d9cd1(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionRequestApmQueryMultiCompute]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7c45f28ac40fde9b03de7675865cad3354dbd72e22ced44e9418ea7fe0528571(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__af499ada3e1e6857be3d2edda43ea54673eed4e1ef82dca8f2d5fbcb594a63af(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ec57da219c493fea1cd4bdcdf5899018e4a285670b6118d942a8f656a55bb0b8(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__330b2b4218110108fb293553e028b1d788e44606b44f58b2a1b0377ec8c99ae3(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__144156fcfd06186eec35b476cfbbbcfd41505f338e86b49a1c29a108e3bdc75a(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetToplistDefinitionRequestApmQueryMultiCompute]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0d59d067e020dfb39c577c7c9c24eb0d09ef91498abdba0d9e731c93b7d5b444(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e9cf4e2c7688e314ef63e0fbf44f1cbf8e974b899f8f6f77518e22f6e708efc6(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetToplistDefinitionRequestApmQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__39687643aa6416d6bf19256834b7159161d2f8d42f8ef8f5a5d79656b6d9deca(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetToplistDefinitionRequestApmQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a916bfadcbafcf891c18be5e23d200857a3ddd944d7977b31b944df1583b5a97(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__39031ad4df09d0d20d161959ea3be1822bbe893cb7ad76e8d3a3ee27da0da57e(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6dd78afda10262729bfd87aef10bfdba932061c3ce1152d5829a3367e5540913(
    value: typing.Optional[PowerpackWidgetToplistDefinitionRequestApmQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__30051c635d73db349728be2853171402169501fda50757aab7dc09f65c16b8f1(
    *,
    index: builtins.str,
    compute_query: typing.Optional[typing.Union[PowerpackWidgetToplistDefinitionRequestAuditQueryComputeQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetToplistDefinitionRequestAuditQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
    multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetToplistDefinitionRequestAuditQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]]] = None,
    search_query: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c1f666e0de0f03a2745d838a615d59974a0fc7576b6690a6c5f5ea1953d6a297(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__eaf09fa868b3249288b9d391ecfdaf56f694999f4409e49a9bf6543c0657bd81(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6ec40ed777a8bd8101344a22f574d06db2e9bdaba80debc6ac175ce6d7c3aa50(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c47cec5768e829745510f5b5328ebf61244183c271563ea87df7cc18c1acdf8d(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1877a173d033a3584d2e8b2f85f7e9ccb5504fa72644a11f14f30da5f9a874b5(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__266773298add8e307ba043d6608c7b633237191c82f6228a6358a7ed9cca0a21(
    value: typing.Optional[PowerpackWidgetToplistDefinitionRequestAuditQueryComputeQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b39dadb07f190cf8259bf634bd5dcb3af3f102c29ffcd4da56f18bbe87735ad1(
    *,
    facet: typing.Optional[builtins.str] = None,
    limit: typing.Optional[jsii.Number] = None,
    sort_query: typing.Optional[typing.Union[PowerpackWidgetToplistDefinitionRequestAuditQueryGroupBySortQuery, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d2463e9472a9291c00ea66f72d4421c5b5e367c5e4dddf7949e5638b2e2caa2d(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__40dfbd32a819fcf5e72cc36b00bf595838e4b6ac0d26219ac660be157ac4dcfc(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f749c4c50f51cad0e43b30d84c06ab93b91d92e56d0a50cf6b6442f80ef16737(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__523c27a01d5d09c238adbdd011c60924d59d84f7c774e30082cceea80a763d03(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a182b4c7dad431a61dd32cc4bd1e6cc91c6785be5012fd523f5b0fff51e01f69(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1fd899de6838299577e022380c3564cb6dce86e5cdf1fb4484301f290e8f4372(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionRequestAuditQueryGroupBy]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__49a655f5c48a8c1de0ea246749cb7229f3eeb9251a8eccdeb0e90a9ea598d198(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__50972ca10d24b7b144adfcf0c34be9f80b65598169859edda1b4acc433b48b15(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__563e9d8a9705e5cad3d28019c49c3a1f4465af70d5bafa2f4ef3e5047c5b3325(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__46fce561927f1418b3d334eba9d0f0eee6ed4f5232124fc073688aa6bef0c2df(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetToplistDefinitionRequestAuditQueryGroupBy]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__47f2e6b872935184ce861e6a374c16be1e99acea8fe2a4e369e35ee31a5df799(
    *,
    aggregation: builtins.str,
    order: builtins.str,
    facet: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d8ff1c73ed432430608adfc06fb781ed1914fb5409103918d33253cb9d33bc9e(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__50209e072b89b8a7268bbc5eee0a8fbae92b6f4b8703d1fb75ed8840cb743835(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2a2a60c5b3d58027252eab74cb762a4fdafbe2dccc713c9569b116ad1ba0e07c(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bf8e5ed3408de4e0d5d519d6ef3a4d12c3ee221988bc2c4134775661645857c6(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c2abdeb39787ec63ae966564135226546ce1e38fbd66960d033b79ff44dd12db(
    value: typing.Optional[PowerpackWidgetToplistDefinitionRequestAuditQueryGroupBySortQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f5616b604eca7eb8f2261176de274085131ea10530e17c7455d268b9cc419a0c(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b2080e3006fb03e6cc394cdace73ae56356221980f7312c27482a1a63e7210be(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__11cbbe6418a77de8b1a4306df04f83d07787f794cb9c6fb8b73fc24734a0a1c0(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d705f6e9c2455085133c21377e786dd9b876ca42f1377522bf69c9e672c679f5(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4ee072321eaec90e6b1c6825904bcc8e8eb25fac2fb08f4c421cc11923180618(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a31d7171fe856d52193149fa2fb51b9ad30f085a087396be4e9c9979bc4e3dd4(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5101b1a268d6b3e676bae58f6ad8895f38c5bf1a8a500427534a5734285305f7(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionRequestAuditQueryMultiCompute]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0f679118d380e87263f46297d9356fcef1ebc931432f227adb44c90d0776f01f(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2b39606a028d9ea2f0046c6351b49b14b5aca6f60c3eaf3fe7f6dea10c514d55(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f33fbcc0861c3e60e9e9b5e14d48ecb66bcf66532cea48f9c6926e854f188d99(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5edec11cd7304287c3fe090cc33af576eb0c2b04a20e717726337e0d03de9ce1(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7a6d3e2dee4b7e7961b5b7827e116fbb56c2e22ff4137b571cb6faab8e690caf(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetToplistDefinitionRequestAuditQueryMultiCompute]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4bde00d9dcd13a310c4e21f509289cd74c633bb063d060cfa686e63bb7b506fa(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__60f97e0bc0c1209cb5735a9dee36e07d737ee5636c9dc1bf42848660e0eababb(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetToplistDefinitionRequestAuditQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cb0a5b4ca6a6b387be4e65628742377e883ee90d64a7dc4f3ea80c2a7d2bf1f3(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetToplistDefinitionRequestAuditQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a7acdb35f3563335d37a3c949763ec433a2357217eae01d2c00d27f176a3977e(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ca5d17aa3613920fe2760b42925016223567211a1a636ebf277f1ee844a00e1e(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__03934125455896d00a5d9f8202ef7a7a3581c45539f47dee2d21b16c70eb611f(
    value: typing.Optional[PowerpackWidgetToplistDefinitionRequestAuditQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a00991e2237b600aab4b829f6a7b60439afc720a079950c481bd6537bb818873(
    *,
    comparator: builtins.str,
    palette: builtins.str,
    value: jsii.Number,
    custom_bg_color: typing.Optional[builtins.str] = None,
    custom_fg_color: typing.Optional[builtins.str] = None,
    hide_value: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
    image_url: typing.Optional[builtins.str] = None,
    metric: typing.Optional[builtins.str] = None,
    timeframe: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__024d38c1518b2b5053d7606a94b97447dbfd44f1517af093cc56d943bcbcdbfc(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__231b9fc146ff8a3ff39b0bf7eda3a88efe146fffe65b766273b9f4d3e3993d23(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__77f6b2a2b7452873feecd1d36e56ac5c77f1fa2c3ebe6d694062545aaf2f8c66(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__26303747dc0b85af6e52074de4cf36435d755ced4071511498e43e46d087f35b(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0954190d783996aaeef81f0885c767eafba26b5468bb045af9060ec0cf2644b3(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b2716c430498293cb5b96f3c3417ed4d7b55a49be7fea8652388170cc52fa0bc(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionRequestConditionalFormats]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f90f2f49c57d10bac53ef1af4407555650498e678ea6cc4db07dd83e47bd0374(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cf3d1225ca986e2ee5bf83beb1eb8f619ab4ed9c21ccc407ffe4f25fb7d263ec(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__656c886115b81e633bfe1a9dfdd49f1c6b9fa10bc802e030433d96440d3b3361(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__717e546261fab62be9eb5d676cd51533673937f85b84e154bf7bf49b3505a6b1(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2bc6ff59e5aca329ef8b6bdb35a185401342581ba048715cca61b08593e82fa1(
    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__286372c6fd58ae1d798e4d1ddab511a2674f1966298340cebfa70a8be382e6a7(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5d867839b70c58c2850b0aadbfcfcfbdf7d8dedfee3684357f859ae4db68ec83(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0a48f82f612c6db144ab5854cb9aa6015cb205b9ee985d5bdc5b9b006d6d6f61(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__88338f555e276ff27136d3628cfff7a2e31e92293a5d5d70b5b0ea2b909788ef(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__824a1dee6291996e0c5c7a5cea24b427e677f6c12ccd3afa522abde4793bc58a(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1563c24614567c2ff86c84b3b5f6c66f7bd64e1f12a042e790d2a829d83bac6c(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetToplistDefinitionRequestConditionalFormats]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ab8faf831d902ff99a897170d16c0c81b7987c4e73515ea317dfece03bd081ce(
    *,
    formula_expression: builtins.str,
    alias: typing.Optional[builtins.str] = None,
    cell_display_mode: typing.Optional[builtins.str] = None,
    conditional_formats: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetToplistDefinitionRequestFormulaConditionalFormats, typing.Dict[builtins.str, typing.Any]]]]] = None,
    limit: typing.Optional[typing.Union[PowerpackWidgetToplistDefinitionRequestFormulaLimit, typing.Dict[builtins.str, typing.Any]]] = None,
    number_format: typing.Optional[typing.Union[PowerpackWidgetToplistDefinitionRequestFormulaNumberFormat, typing.Dict[builtins.str, typing.Any]]] = None,
    style: typing.Optional[typing.Union[PowerpackWidgetToplistDefinitionRequestFormulaStyle, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5fb3c2a29de2e42b92d1f733a634d3b2952f618f6c67fba3c15b0394cfd82726(
    *,
    comparator: builtins.str,
    palette: builtins.str,
    value: jsii.Number,
    custom_bg_color: typing.Optional[builtins.str] = None,
    custom_fg_color: typing.Optional[builtins.str] = None,
    hide_value: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
    image_url: typing.Optional[builtins.str] = None,
    metric: typing.Optional[builtins.str] = None,
    timeframe: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__150f1efcbf83c9824f50fc6fec2c938bedb5c4bd06b09004b9cf6a3e051738ed(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__62a4a5c75567fbfa31b9f91ad81e4c6ca0e4bac97318a3dd4ca452b188b28726(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9d24a2f43998632b399495a576234c45561b8d0491646f0ced34d5bb98428c5e(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d14501fccec55696afd0be1fb26945ed0a62900db2d73d181722c46fd339c82c(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4bae84282a7b6bfe2f251db6432c3e1622e1223bc750254946de160fa7305d73(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__59d0523e091d8a4b41cde0e3a979216ca36d2abddd3d6489fd9ffc0c3b24d04b(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionRequestFormulaConditionalFormats]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7839489accca3fbfad62e8f7b06ca06008e60e55f0b249a3cfe060fc0b861b1c(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a1d1d78c7887822947541818c9990c53b1cdcd8776e65e8faf355d29b9dbab00(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5d8c22aac1b7cf08428890f652a1fdfb8b416ae6f462f9f336cea6a4d0b13fd1(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__595198521fb0c4ea13b5bad83366bc96c138f61cae686f88f1ef75459de651d2(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__30bbb98310d7ed9680dc16a71470d687020623950af41210afb60c11defd8228(
    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3535088cff0c164560d4bd2ee9e5b5efecd742c40606ee7f21e9d289ef43d362(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c28be8da688912edf3655ab7616e861996faa597fbe550c4aad4a1e8eba37120(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__82cb4fd909e4e0b0550a8abc8b900b9bbb1eed01c9d5474893227c11a2b758a3(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2bd783a2ad2bc70d0154f1898afb0d9d67b311fe6f40cf52e98230e6423d2480(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__584346352ef0795dee07cba4f68e4856af6dd8ee782057035eac139e8dc994a0(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__36df04080af632892151dc83fdb2355abeb90ed08281b54c12a4293f0c1f9a34(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetToplistDefinitionRequestFormulaConditionalFormats]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ddb341cf55d7c8bc48bb4eb58428af58d4bd4f871ac967305b9989fc7a9aaa45(
    *,
    count: typing.Optional[jsii.Number] = None,
    order: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__58285ba7a1ac9070526c9c82432b34de83a65b59d12a2797bf12176ad5d8b7dc(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dcc2d317b450e616b835e5b4b7fc34f69d2498194790ae735ccb772efae70e9f(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__22a9dc888673695133bd7a7187a9e7ff061a8ab810b0027af9bbe50f70e590f1(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9617a29c3ca136106ab70654881bb1355f608ae6c0851003ed054d9fd184a1dc(
    value: typing.Optional[PowerpackWidgetToplistDefinitionRequestFormulaLimit],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__70aa8472e2e4fc5de7aa5e662f51daf7b1ebd0b59c9a90d96cdfae2132c81e9c(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5b569d56cd62de662ce60c6ec32dc26af5f98fbf1ca6ed94327313612a1d0024(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a815fbf790cbba8f4e9cbab2d724244b8fbdfd422b32a6c08376fc44b52cb8a3(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0dd11a3ae98591d1300fb4c0c0c38c2ff767cda4413a1fd88178c13fd50612e5(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__23d0bdfda9b8a13e50f7fb0c390b2ae4d12cb730d076f4a2900d1420ee66d89c(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d08c9daad145c2577d7501c92bfadce3ecaebbbee821bed0d2bba0484edebd87(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionRequestFormula]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d49c894892511dcc2453fa13c37422e068aa3777b2d617376155ba1a39e5f0fd(
    *,
    unit: typing.Union[PowerpackWidgetToplistDefinitionRequestFormulaNumberFormatUnit, typing.Dict[builtins.str, typing.Any]],
    unit_scale: typing.Optional[typing.Union[PowerpackWidgetToplistDefinitionRequestFormulaNumberFormatUnitScale, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0c3529b65a512410807491db5aa2183093c4305122367cce948c8f7cf06237c1(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__459a48aa3034125fc28ec694522b938d4226aa0a7f6638275437836e3a7d533a(
    value: typing.Optional[PowerpackWidgetToplistDefinitionRequestFormulaNumberFormat],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f3a56e5c7bcce903b792a02743ebc8412067c7eaf4a340904cd0fcfc0d2fda1b(
    *,
    canonical: typing.Optional[typing.Union[PowerpackWidgetToplistDefinitionRequestFormulaNumberFormatUnitCanonical, typing.Dict[builtins.str, typing.Any]]] = None,
    custom: typing.Optional[typing.Union[PowerpackWidgetToplistDefinitionRequestFormulaNumberFormatUnitCustom, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c6227566ade3f941bdc839ee6426056171fb79b71c1b8e15065be125c650e9d6(
    *,
    unit_name: builtins.str,
    per_unit_name: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e5c0240d5585d3e95994795539888fab80b18831ee9078bf6e13f7395f70e4f1(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3f9c9932d3e47521b9551d4dbcc24b5adf817efde4d799c948f50e1dc34f435f(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__747ef03e9ac3455b0f5841c26c902c2d7bc5325737d5287b4e1c9c136c4c56ec(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8aaa53c73210a578495c15f40468b4af8b4c11f98077fe3b65262fd553d2ebd0(
    value: typing.Optional[PowerpackWidgetToplistDefinitionRequestFormulaNumberFormatUnitCanonical],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__740b91a2457176221ace6cbe0cc96db2853b136907f687b6747af65133fcfb13(
    *,
    label: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__79067191e2cf70a07da60c305e232b7d3277c64c015bf5b25329734c70b53625(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__058e7e78437de06976e69269026b7ca7eb79aa3757bce99c52dc87c1d95b4232(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__530d2234bf654b4cd1e3dd6d3d242f678472ae31ef61d5e2f27a5ffa74514a1e(
    value: typing.Optional[PowerpackWidgetToplistDefinitionRequestFormulaNumberFormatUnitCustom],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__35c1ef4411e140100bcd8dce9dcf186256bb954e879c9c9554394c50ad4aa281(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__625081123978f102cee30316cb9c022be11d262318e2e632bcf6f3d97e92b92a(
    value: typing.Optional[PowerpackWidgetToplistDefinitionRequestFormulaNumberFormatUnit],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d2f55ccf4747797f149260ad16a2e990fdd41f4c6a96ac121f6eabba062864c7(
    *,
    unit_name: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c2d76d8b81aa345be4c355fbba151deb140005a0d76c3fcd1d5ffa56e06bf826(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0157a8a24b903cc3a3ed0a7bb2dfdbb21dafacf9008af5646b2acc353781501d(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c71e21c32469f784533da43342ba7977a76a9d5fa1521073da720568da62cdbb(
    value: typing.Optional[PowerpackWidgetToplistDefinitionRequestFormulaNumberFormatUnitScale],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9c89630624bd3d223c76357ba31c6cfd8899f322d85a8a603368ee56e327ce70(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__11954d8af87091e385603da62327cb0a3d83f6d172554acd15741207d14dfed4(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetToplistDefinitionRequestFormulaConditionalFormats, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7327e7ec34dfe7bade7e135cd19b0e85f7e0874863af0e70581ae4afdc2d38b6(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c3c4f50336c629f653884ed32161f72eba342a69a511ac1b8aa3850a10df85a4(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5b1b76030de5490963505900fabb624c930a0ebecfcab7facb12dec605f76a7c(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__aaea3ef8fa68a5029efb01218d679d9b01dba81b1d57b0f8f02bbfcee5fd9195(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetToplistDefinitionRequestFormula]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__152157c8315e4b96c35c8f1548751585d5df3806139f6e7d6c78b953de3596aa(
    *,
    palette: typing.Optional[builtins.str] = None,
    palette_index: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8543fcb66e811a27fdc40a0c048edcb8f2de4b3cefddcd25010491750482da44(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ebf7d0af02dbda533250ff75d58145cae1e76dc1465c602627c503163ae5163d(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__24f2dc39f4ef042076995649f0032010451e5634b5e0b0f9b6ec6a1f7c6725dd(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a8efd83386e9f362d879f549cf57c7da2047b17586fce6eac115c05bb9762d0d(
    value: typing.Optional[PowerpackWidgetToplistDefinitionRequestFormulaStyle],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a47ce83f6f3291309e6267ce52dfe1f53f2c16b96671c6ec03209a20ca62197d(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f1552b70b3d786ffb70f929a623052115ecc7c8451307fc7779ec81675e3464b(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__df8652ce6a5b57d5ca96bba4cc579adce310e40f513daa0186643be3cbd9673e(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__419b50d941fcda8d43c105e17c4a7ac0469123ae8cc65698467ecf7654a4ba6c(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0543df50dc0be94e18ab4c89ddcd33bde8e61cef6489461aa1a4380151063859(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__acae551226b8a1876a03e8ea90dc82d41734b6a094b3113a707f81b4ed060633(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionRequest]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7fe037ac53949ba38e8e3a962da809c1232dbfbccdbd91c931a9479f88e7935a(
    *,
    index: builtins.str,
    compute_query: typing.Optional[typing.Union[PowerpackWidgetToplistDefinitionRequestLogQueryComputeQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetToplistDefinitionRequestLogQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
    multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetToplistDefinitionRequestLogQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]]] = None,
    search_query: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__081dfe787a08ba73e31ba72ee64663f6fd98a966b5a7315f581b1ac91d909477(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4bfa57384b22a5c98f948322d75605a26b29c678c7072a89ff824dec014eb4fe(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1dab749f700a3493c2d2c712b426627a315a7496b625b50dd43363dfbdd7161d(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b008850f52768898b7f4d73a80eb0d830265c3beb11af5b7a0db3b3dff9beaf1(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9f00dcd9d2e7aacf031321f32c6de70e4c79d8374625e51a947069b9cf2f6161(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0fd30208f7101bc0c2e78a07657b5f6cbb927bf38a7f62f8b2a0a958fadab313(
    value: typing.Optional[PowerpackWidgetToplistDefinitionRequestLogQueryComputeQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__781917eb26832b06b6597372c6be4397fb1a81d5ee828a21ce64885cd05f07da(
    *,
    facet: typing.Optional[builtins.str] = None,
    limit: typing.Optional[jsii.Number] = None,
    sort_query: typing.Optional[typing.Union[PowerpackWidgetToplistDefinitionRequestLogQueryGroupBySortQuery, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0bc3ee9c5a79bce6e84b6299f7886137d610f387acd5ca28cec287710d8beb7f(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b33b3fc784fa5aad8a84663d703439db55ffe099e494364626f67c370108ff6c(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e927a0dbf92ad2005d0597cebe4dc7b9ca1da2586195ab514d80ed0465999a5c(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__37360bae6ec35176acbeb99bb7c8ac3d89f9a1eb437f4c470c3ae246992e8c0c(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f3ec13f009c9394da96446610a123dafaec25661f8d01a9ea247c2935de089f0(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__904ad8e8e5cb08c69af8c99ff25c88b73ec31fd5c67e873c66eb50f2521afe49(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionRequestLogQueryGroupBy]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__376431c05cfbc4cadcece17025ac0cfb3e4c3ae1c518de32e6ae1b8bc2e5d708(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e86d057c475e8d80f17cd2019994da65aecb2bbe3b5dc48e3a9aae2e3e20d433(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__beed61b26c02f8d86607e6ada66328ec783cdfcc96ad87e2b18fd6db866c75e5(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__abd9a40eac811ac29a4cc55783aa602cf14e28fe8187309016a84f41c624bb99(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetToplistDefinitionRequestLogQueryGroupBy]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__03ec76be4e9b059f7107828587155b7cf7f043c94484251eccbbe04449af8133(
    *,
    aggregation: builtins.str,
    order: builtins.str,
    facet: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8f0437bc49623398b56fa0a17aa814bc881c2ab1a001560e8ed5af472f1e0a91(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__deb74ec36d92235afdeffa7e8ad78dd063e29cff4a77b0e7f690c2879f7461ae(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__81c2fcb5bca98022959dc62742efd594eb7bfe6a865abcfd07096f1a1c29a2df(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0f01f2c958b5619b31e01e936427956a7d35df11b65f1014fad150590d93b8df(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1f3918eef3c451ec0dc347858f26718d2d140a3bc0a0221cf8561fd0e81e6fce(
    value: typing.Optional[PowerpackWidgetToplistDefinitionRequestLogQueryGroupBySortQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c5405e91a7a3e1883405cefc064654b21723cc9bd41884bda8c4de997a6872e9(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8853f38300068155076a1ead21e582e47bd2c5e731d8ddb21b707c40408db9ec(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__65f99c63f12fe51bfb58c576aa65dc93f08a657b7a76ce3f82948480c8c6670f(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f862c3283c196f4e84496a93cca1d9b4f98ea470c403e39743d56234f05eb0d5(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5d7dc86a286b71f52cc28c38270f815a901d3f5736fe5fbdd5001f7c11ea46b7(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4311b1ba8ecf27a3fe8997a7759d8297365610c5ed73d8fd854c6be302c7e573(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a2da02486cb54247d1dadfdb5cc353b3383d59424991fcafe1f634017925291f(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionRequestLogQueryMultiCompute]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bec3de74794c2a49d837c2b48713feb7ac126bc54b5b31ddcf6dfff9a2ce9786(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__362b52b9bcde17c68516db4f2bdbf0f5665058134b6a8e20f4b6121d584556ff(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dc9bcbf9b635ab7ce34bfe8fb4e9412b82476d411b30ae1862fb039e097c69e5(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bbcf1387ba51948fef5a65c7f06334abfe04ca03b8880dd35c3c9d4e9f4dec54(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__22e488b3b59133a6f57c696ec6c9dff0f183b38857ea37fc6354c82931f42023(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetToplistDefinitionRequestLogQueryMultiCompute]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cc56d549307486e7374dc6d77625068da3a2f984764dfa6311750652e22fa875(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9998fe9e4d7df8d5e5ff133d2caa9d59511ede74ef3f6e3cb3d3e8161a12f4b6(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetToplistDefinitionRequestLogQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1a86e0d5e33c1dc9d51dcc3c881771946b90da525db2a2045b1240fb98450c68(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetToplistDefinitionRequestLogQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9d32829b217133712e25cd22c1bcb45c335a7ccb9c1ce748a89cebf7f1c6d66f(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7789ead85a404399ccfe8d71a510383a3a34a657565e01b54a0d87d078d31992(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3b7b0c048eee21736ff9872dce51757dd2550c7f1b3c8346482670779d860196(
    value: typing.Optional[PowerpackWidgetToplistDefinitionRequestLogQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9675cedc2bc954c10a4a4dd34a467a03b23a46f7155b1a111a7f6cb5c686d2d4(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a949b3db9f0bae035254e066fdba715836f472458ac2c9f2a0aa4cb97e0ffc80(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetToplistDefinitionRequestConditionalFormats, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5a03fe749bc446d510479f1139afd06e407b4cc75a6ae933f040d21476d5b753(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetToplistDefinitionRequestFormula, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3b297f39fa813164420597841d80cfbc303c18618b0ed6858c0e434b2b628915(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetToplistDefinitionRequestQuery, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e484219091ea288eb9c6268f33d32792f0a19f1d51899edaf7d3153a1d5cc2f7(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ab9d53d14ba2f49cda814627e0f0b6094993516f0b7e82ac603261d40a5e1ef6(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetToplistDefinitionRequest]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__17a05563f9f477a751ffc1590d7d7376539a0d29469da209ed0fbe7a012aca00(
    *,
    metric: builtins.str,
    filter_by: typing.Optional[typing.Sequence[builtins.str]] = None,
    limit: typing.Optional[jsii.Number] = None,
    search_by: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__58bfe64058fc53926e62cb9f43cda4d3d45562d023a484a040dc70453df9b0c7(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__34b9426dd012610a254e1954c093f2a01a6da5eb23b7d4c7c66b5cced7b85fb3(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1bdec8265886e8c3d1e9797ac816f12c975585433d6e6ae7ca7e650c37c85981(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9888c899095736f89582021822236a1c32d1f73311d5912937b7d776a74d1794(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5593562249fbc100b7f529d01cd8c96a80244a660d5dad161c89e5dcb40b2f0a(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__46510097989e770134e00d4e72a9526474a59e3151ed204317e5bb93b402be43(
    value: typing.Optional[PowerpackWidgetToplistDefinitionRequestProcessQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__320cbad83e992eeb6fa3499f55527f356405a0c6cd4bc7d59ce5a9c098b7ca82(
    *,
    apm_dependency_stats_query: typing.Optional[typing.Union[PowerpackWidgetToplistDefinitionRequestQueryApmDependencyStatsQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    apm_resource_stats_query: typing.Optional[typing.Union[PowerpackWidgetToplistDefinitionRequestQueryApmResourceStatsQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    cloud_cost_query: typing.Optional[typing.Union[PowerpackWidgetToplistDefinitionRequestQueryCloudCostQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    event_query: typing.Optional[typing.Union[PowerpackWidgetToplistDefinitionRequestQueryEventQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    metric_query: typing.Optional[typing.Union[PowerpackWidgetToplistDefinitionRequestQueryMetricQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    process_query: typing.Optional[typing.Union[PowerpackWidgetToplistDefinitionRequestQueryProcessQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    slo_query: typing.Optional[typing.Union[PowerpackWidgetToplistDefinitionRequestQuerySloQuery, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__414ebe1176aa3aeb3682c63081ef4b0a01d6767600483e2c4780099511249aca(
    *,
    data_source: builtins.str,
    env: builtins.str,
    name: builtins.str,
    operation_name: builtins.str,
    resource_name: builtins.str,
    service: builtins.str,
    stat: builtins.str,
    cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
    is_upstream: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
    primary_tag_name: typing.Optional[builtins.str] = None,
    primary_tag_value: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8f7dee4edae558cab294af63497e46a5b20dc2ff0493864ba376beda2a126065(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d7c974d4b86125736653a922381bdb557a41af3779321b2b28506c45326d290f(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__433bea0de90ee0bbd214646f7e91b651e60df7f39ae9f8ace599806c8cc2294f(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a77dbb1f71b36e3fd549d5ba29a068172a7ab513e3ed3fdd3f9b76896975714c(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f020db6de3ffe3d16398046e0eb2d5986c8a0f96508c942259a0091bcf54c9ac(
    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__93e3894da697c5310d748f44d01f7a6bcf5aea0e49abe85c1541c6ce1282c306(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dc622c95cf139181a532d37c58c82d093402a981342bcedb4c877d7789bc5ae8(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a5119a8479ae66f5584f5dae62f284d6faedb377d9a9df2d01584126f1087a7c(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__547751bfa605c29a22bc04cb9aacd649d0941c2eef683f52d0b9c2f2b91c6506(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__38d0f450462005799c74af9ab70f133dec6edcd8bb13a9c1cce0b6fbcbf75f75(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cc86ddeccddfea6d7bb10d3ff7260589f5b652c76762cdf92fcefbe7f1d00886(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5795ed0bf3083bbd61cc8ed88b6db295f611d6bf1662fe6b0366c7395aa60cd5(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4556ed166a1742af4eed02b3ebefb79c89b19953c55681100f8c2388c8689af4(
    value: typing.Optional[PowerpackWidgetToplistDefinitionRequestQueryApmDependencyStatsQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f90623029866ad94029541722ffb08ba387b23f5890d1103d31467275893b863(
    *,
    data_source: builtins.str,
    env: builtins.str,
    name: builtins.str,
    service: builtins.str,
    stat: builtins.str,
    cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
    group_by: typing.Optional[typing.Sequence[builtins.str]] = None,
    operation_name: typing.Optional[builtins.str] = None,
    primary_tag_name: typing.Optional[builtins.str] = None,
    primary_tag_value: typing.Optional[builtins.str] = None,
    resource_name: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__db532bced3dfa0b89ba8ac562640d2e9ce719f865839e8f888db1709f887e631(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9a1a9e222ff38209e164f10e7d5fa75f46de5ea8c5058d444808ccaaeccb394d(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6718f2851843b25841d87ed2984f891cf9c83826b1e15dc541b77d51c3da1f85(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ae60377f883dd3ffffe2ccefcd6fdb4b25ce651e980c3ed71f44fb5fcc990ccf(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0f8d2c4e20a17ba17413b3ae66ae0b18ba4bf4e3efa0883cd181d4cd5ad7a63a(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1887c13b5ac11811a2ba8bfe8dcdfc160364672b83a03b418724f2c17b2f2fda(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d040434a07885d3b53388420d2b56cbdfd32bca981a09ceba2f8a5de0d50967f(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__db0016d63063323ea3397939a3521c859d1fb2c72dd69a4ddd149737c48b3547(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__365b8d08d2242ec5aca004befb4e6303819002113b429fce1a1a15c3cbb48634(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__22bee4af9dc01ccc25de96f5a04744cee75128f11e145668adad3c632863a4ee(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__61e833eb2736afd88dfd44672de32d8d4e7d65dffb70abf6c29114298ac60dde(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b6099d2d87fb419486ce647474eaa78de2d894b263097e97f737ac14bb396c89(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b2488bf6941b53cc551c4911b1a49e626a43f65cc79c76106ac7427973fd843e(
    value: typing.Optional[PowerpackWidgetToplistDefinitionRequestQueryApmResourceStatsQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7319ed1da4d2f3378934e56734a0b46f4bbf9b1f0d4d99e5689a0990d2ed193d(
    *,
    data_source: builtins.str,
    name: builtins.str,
    query: builtins.str,
    aggregator: typing.Optional[builtins.str] = None,
    cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5fcb92fd717b4dfbecd3ee018ffb1f5ec63c7e67e937888df06b1b8c01a43c03(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__481adbb365332ab9df8e80da0a6779c6c2ad1a5767965fad2b9183882fa8954b(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fa990b3a21bbad540ed2c0df66015ceebc8024ef313638992e42d2cab3c47674(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__679994cfb74fc451db36cb11b8d5228a97b323b7147483922d36bd3e6c3fc1b2(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3328a48f37572026b0e1f638bfb8a9778c021eedb3be4ea6958e87740bddf560(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b31470392642d20096d15edc620fdedfa4be5325f3581787045256e7dbdd8777(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a73b99fc3dc982d4a19a071148d7ecac53adedc545f785566e8114c29a4c44f8(
    value: typing.Optional[PowerpackWidgetToplistDefinitionRequestQueryCloudCostQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a9d0e76f22894780aa8404228202958e8b9f5659950c2bb8af1e967a5b7f2db6(
    *,
    compute: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetToplistDefinitionRequestQueryEventQueryCompute, typing.Dict[builtins.str, typing.Any]]]],
    data_source: builtins.str,
    name: builtins.str,
    cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
    group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetToplistDefinitionRequestQueryEventQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
    indexes: typing.Optional[typing.Sequence[builtins.str]] = None,
    search: typing.Optional[typing.Union[PowerpackWidgetToplistDefinitionRequestQueryEventQuerySearch, typing.Dict[builtins.str, typing.Any]]] = None,
    storage: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5dbb39e91fff862274b4e163c04767925716833d6f92a929b4c7844dd9c9b139(
    *,
    aggregation: builtins.str,
    interval: typing.Optional[jsii.Number] = None,
    metric: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__80945282e5b8410dd3e6668fbeb56eb716f6cd6e23c2e2a104d11d0c2f79dd35(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8dd49959e79b7f41c48d1b5244268fca425a40add713f936b009929d6d737a83(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6e3f6195d7b652de25f547dd4c9cc11e2fc01d9287642ec1af3b9af14da62583(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f294746a90ae41fc1b798ab602a7aa9f4d98f889379c322c7ed6c6b509f260c2(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ff45cfcc02746a7d83511ecd68e81a9f63a02f9b67a14f23b0f224b58eaae03e(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a63de3bc69be5d18f4fadb846b2e28d2f59f87dd79283b3d4ddfa8ef90b65884(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionRequestQueryEventQueryCompute]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a9d0899935aa708ae6a91df67d9a82363b1bae05b9c9d1cf7f937107ec9f6753(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3f0d945711a83ded82f0819b24a3587998bc5bdc6856c65e72ee4ebdedecdb5b(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__80b4b3b001ad097c55133116c65755cb3d395e284329de1f915f34f3993b4df9(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bef5df77b4f3f8bec3edc8d4f5d0200735feceb115e15e278417f9f7e491a58e(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2c264861cb7e58a79391e95f133cf4fc370f5bd0429ca3ffc073561f593111cd(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetToplistDefinitionRequestQueryEventQueryCompute]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f80a0a75476ffc45b63dea358d55309e1bddba08de1fd22a549f16f0ff5bf43b(
    *,
    facet: builtins.str,
    limit: typing.Optional[jsii.Number] = None,
    sort: typing.Optional[typing.Union[PowerpackWidgetToplistDefinitionRequestQueryEventQueryGroupBySort, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__72370ee2b0c1c84f8e71dff1679e2feb9b3672abd4a91f0bad8470bb1dde2cb8(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__252260cc86be06f79acaa7044270966332fd31f89472435700d1f2c2b44df8b7(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c5281d0d5cc6044a691b0cf0d7c909644b511741ad824d6024cbcc9a4f16f1a9(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__14beb4fb0ad2b526c09bd40daeaa372fd72bfa48a9ca09a8a39530d2baaa6ea6(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0609850b8d8a590dc3e1e6104d0e3599ae7575bb431eb539afe1946e8df36753(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__49ef36d36813f4e03dac205ca8438d76d90ca9ea93515683ca0040508bd92aa6(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionRequestQueryEventQueryGroupBy]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e15446165a4409c393fb7173270d046a7d5c4819a5b0d2ea0025490e710bf0cb(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1afe192fb83076d33383529512d9b2f247c88e84b175c22a7ef41855e38beff1(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__52c1627fd6d5c46f3212348387b49a1f09b50e492d230a1c92451e8c48fcad51(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dee63a446c3b58ed84968347100907048aab290a3e680187e115f750a713d323(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetToplistDefinitionRequestQueryEventQueryGroupBy]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__44331b9c23de9e13f1fe4bb88b290971af51b901708f42447faa0cd8ab02a9f9(
    *,
    aggregation: builtins.str,
    metric: typing.Optional[builtins.str] = None,
    order: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__66c81cc95a5e2b8595dd237f0d840094ab9c49abfc35f30c93bf6551cc735723(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4db8010b5d2cb7bfe9a7039214470a5405dd382c650181e9f02979bbdac52c8e(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__443a0f5937aa1d836a6798bb92a4a2b2ce6969f642787528a88bead00c808bd8(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3b77e407ed7f9c28198d0a0a646d92286d641059d4e28d06cea3a4baaa18c9ea(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7ded662da9f6df7980fc3d9e8bf1b678ae0e5f0d8ecedd0b89e5c939d5e8a2fb(
    value: typing.Optional[PowerpackWidgetToplistDefinitionRequestQueryEventQueryGroupBySort],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c8fadb78df46fa6cdd329a5afc0c15cad2b949e0eb998a5fd624e12decec8faf(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e588b1dcd21b1361449b1c9d7980dce3040782a33babd30e31ac5f29c0982fc7(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetToplistDefinitionRequestQueryEventQueryCompute, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__acdd8f6567e7f2d8137cbda0b0a2ac3d9d4c869ba1087883e4948fa0de245cca(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetToplistDefinitionRequestQueryEventQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7e2308fcc873d5d04c3e7e06bb660f12f2cf9d56056b1a1b5b9109971599bf99(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d65dbbe287cc4bd8af895c94dd9b0c8b2acfdb00c70d3cf9dabe7d670237b0aa(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a8703f43de0b5edefc9545867b55e40ffaa4ca9f0c2ca672d0a59ec1cf1e5bf1(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f80f5ec2db597eec7a8a3a16996e8388af43457406a2b618f46aa734ca91d345(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__55c940b8493633b2d0bed53d9314853d427198fc014e18a341515259ca859824(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__908516984920089393cbf16224c4987f017eb61ab38c1a4260ae9cb9ca7a16c1(
    value: typing.Optional[PowerpackWidgetToplistDefinitionRequestQueryEventQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2d0264a7db603e59223125833e9c46206a06c387df12b70576d858d8de3bd33e(
    *,
    query: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9cab9e4781089225b7f0fbb6ad9990e45e3468565e9d2cebc71c7d7c10e0108e(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6fb08573e15e26a88bccf5a49cc6e68a3ff1d1c13d9c780fa15068411e58d7d2(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c39b942ad71df7775de5ac81b0bd4c12ec3e0ff71b94921a97d78016b31a4b53(
    value: typing.Optional[PowerpackWidgetToplistDefinitionRequestQueryEventQuerySearch],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6e63146e32308637f9164a17cfd1569a90c9458c6f660fca9e07d0be21d57253(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__eb3c7b8fc995242f2a8384ca32a658cede017af4939559613095f68d0dba217a(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1198ac6d27e179f400c479c787b62cf17236ae2fd16ec21e08c25752e0a6ad32(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__af4cd700bda9b4e6845d31394f3357d1307b088405b2914c0d1f90ded6434685(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__72a7fa0fac266affb39b3c1344f6437e99c79989debaaac32fb63306f5cb2498(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__869b9ae8e04372e41709a4756910b6ed5f0178ea23b328a054189633927c5125(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionRequestQuery]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1d6a1c0d81be4c463bfe244cd4cc81897490ace4164434ef9dae1797cbc3b358(
    *,
    name: builtins.str,
    query: builtins.str,
    aggregator: typing.Optional[builtins.str] = None,
    cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
    data_source: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9911f9cca6f044b0aa9bc6740baa6f012c5e4766cd4f5d61b1490cd040f471bb(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__136e51d5d2a48bde65351733e41c8849392d874315b9c65bced630c9623998ca(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__53e1c60e38b104c997450ff2fa6e0cfe8767fd2c03143a361986f099a0912cbf(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4f882c86eff6682dad67c6f23e7daec9cc182d6957045f29283efbed87ad2cc0(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f9c0035fc0638646f44b5fb339aea624348dd9f334cdf392164360e5a1ebefee(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8eee8dc3e1bb20c15dc81f2293f633516dd796c7e66fd31b0970e5989d916379(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__59e58bc228c674d21bb9a46ae115dbadae62ba7e1d29d05806bceb6927a5c660(
    value: typing.Optional[PowerpackWidgetToplistDefinitionRequestQueryMetricQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__66a3aa60b4a666c11e40b21289479e32021fd48224165dc06abf6d0d07c3d7fc(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ae947c228148f0281ccf393ea84b47bc1fc549864897e1648e8942885ea8edde(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetToplistDefinitionRequestQuery]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7d5d0e8dd029f24bc0b495f1a67fae8c6129f8f253d8e58cfd0ef57a18e0859d(
    *,
    data_source: builtins.str,
    metric: builtins.str,
    name: builtins.str,
    aggregator: typing.Optional[builtins.str] = None,
    cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
    is_normalized_cpu: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
    limit: typing.Optional[jsii.Number] = None,
    sort: typing.Optional[builtins.str] = None,
    tag_filters: typing.Optional[typing.Sequence[builtins.str]] = None,
    text_filter: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4c07fab5377c1f4dad94ed9a53062263bd208596e431773eb0149acbfbc400aa(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1a35bd7d9cc30f715ec6f158d6fa64f6195f479d20acc9b58ad731a2ab3f7fb6(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d18857d62b767da55ae83a3f5f15a11226a0a611f47d3387433d4d50f1c0cbbd(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f44d36b0a2e8a0cbf2e19b7c0f7ea9511dfc10e7d2998681619217983bbeaeb6(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b6c85e79cfed642d881d79f35755bf738521e721f520aaf7191859ac5c8c1983(
    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__200aa63e083ecf9d50bd55031bb208e6c6273a3df933e2612ce84112698d0a53(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ebbe608fdd3fe529162211177769be066b4f26deb5d700fb9be6a47328ff5fa3(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5d34275df1f968277ce1aa86aea95cd72d73a18e6f2e8f3a02df9428fa8686bc(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d1f4d8e2ac944518ffe7f4cc69e44cf10293a594732ae42469cafee7e1f7f912(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ec9667f3f6772ff66aedcc202dc20ddbacdbf480bf7398e69da61d81828f324d(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7c50f98aa83789499138a122758fbdb06cee28ca439257a23fed6e792b34c21b(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6969d5ac75ef81d5e0e528805c73a88999eb858de365bdabd749222fac9d273c(
    value: typing.Optional[PowerpackWidgetToplistDefinitionRequestQueryProcessQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5e5641d267d0d99f73a8f0a60651962de45d5953191a22235c9c6e25c116db7b(
    *,
    data_source: builtins.str,
    measure: builtins.str,
    slo_id: builtins.str,
    additional_query_filters: typing.Optional[builtins.str] = None,
    cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
    group_mode: typing.Optional[builtins.str] = None,
    name: typing.Optional[builtins.str] = None,
    slo_query_type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3135e8b147bd24e2a098afe8232b8e7d82ba95c877e8181237caf8fd7fcd9b61(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8c533ea5d069659494332b0df2ab5967ed5a32639610c7eef75416f18e7a4e02(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3d0b70321c1976bea6e66e76643e81bfc4c8311c250c45003313956f50909a59(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cbd53ebaa4b8da08b5f9792c956d7113c80df29c5bedbfcf646a6e8d9fc2068e(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9366c8b13c7c57096529839cbd29dfebf143e8b9131293419260193ca5435851(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__47c6a5b31931e4aad10d5b39d47a5fb281a46c6781449f07cab6a9ce27a2c00e(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6e483e8cde6f672451b4fb1d1726be6aa80a84895e37e5e732d7938677e47013(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1c200a7e153cd7d3df3185b99a088f5d81e1500f068db34107a0ca1e86f5a955(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__89dac0f070591bb9ee11919f1eb18dfa689b3622f688011b449a17ab8b26f8de(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dd8b3562a1dc4d9348a6c5fae0ecb22d5ad4763365216b4319221e833787a7ea(
    value: typing.Optional[PowerpackWidgetToplistDefinitionRequestQuerySloQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f07d5c62521a3bb453757ad2cfcf59f210bdd21726fbbeac39411b4e9976814b(
    *,
    index: builtins.str,
    compute_query: typing.Optional[typing.Union[PowerpackWidgetToplistDefinitionRequestRumQueryComputeQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetToplistDefinitionRequestRumQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
    multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetToplistDefinitionRequestRumQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]]] = None,
    search_query: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b1a5d0b3cab212fe7ce2129a75ccefdd3bea3baed4dec8c1183c5df016ce88f3(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__14a401f770f0f93d3bd7cb5ff7c3452ff216e65bea28f1466a02d174d7352e83(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d8b43e7fde65fedce3dd16c2834e0413631cdb8d2648df84398763d3aa6adaed(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a8a7e393120018cc59f555a244c39a1156722eeb15df2e52ca60fb6e492ddc69(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__61dd855316afdde7ef1915ef71ac86a1d4314d83c376e487b1b34b4e36c498c3(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__317edbfc8a1029566870821892e18746e8ca732d990e7cbb29dad2308c84a191(
    value: typing.Optional[PowerpackWidgetToplistDefinitionRequestRumQueryComputeQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c271d4e1aaeea3f51fee579a937d08e6db891d88b2cd9c3dcc78f88e58d966f1(
    *,
    facet: typing.Optional[builtins.str] = None,
    limit: typing.Optional[jsii.Number] = None,
    sort_query: typing.Optional[typing.Union[PowerpackWidgetToplistDefinitionRequestRumQueryGroupBySortQuery, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cd03c36d8e06d77347911c4566222f7708d285cbba3b3f9b69d4fc6c80ffd8e0(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7ff68a475fad9b442a725ef809f881455aec348649f533572ddb23a88d6f4e18(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__93fb4dab34363ad3b5100d4a1a37fd7b2f4d5ff12671672094adfcde4b81c963(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5568b02949b7539c7a7702f566cfaaebe7bfac0cf6854deb2beffe0fbf393ae0(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__124bebd398108f97af8f5a7413225a2557b3921ad0fcf65029a67b17495274ba(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__36d9d5abe53ce1f3765031b508cd84706caa1d36a428c0232835ed40aa8052dc(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionRequestRumQueryGroupBy]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6b849717cd2673c58ebec4802f8d01cd41d6d3c2450ec73254ac330dc663321a(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9ee380871f466cb413256ce90dbe5dc07617e177504f8f617a745d7863038e55(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__318168e01b2d30bc48994b3b4152bb958a7a8ae2953c2c74b174421afefa8cc4(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__22900ae7bc92f40f7f0967e6c74330e7cc0fb9a52645bdbb60d0fc04b8965ed8(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetToplistDefinitionRequestRumQueryGroupBy]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e9160ae6a1a39081c2742c704c0ae30279bef5702aa7c701e811eeb53d947c36(
    *,
    aggregation: builtins.str,
    order: builtins.str,
    facet: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5176218588d423e475ad2665850a5d19b4edef79a6b5e7a4d941b6756584c4d9(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5ebe20e988d2d116eae0daf617b717196702c0fb10dd80e0c8d836038c1c9555(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4f80a8ece8eaecdebcccb332ed1aa13cb024e2c86cab721be6ca5690a730a27a(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dad6fc70b7bc27e62d964d8c3d4c2e720cc2a62dcb202315ce938dec417b92e4(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cd711031bdb69bb497f1b6f367a40aeb778909b8ddd02e918974ac1a714b1979(
    value: typing.Optional[PowerpackWidgetToplistDefinitionRequestRumQueryGroupBySortQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b1108a8be19e29fff379d1252d71ceb68b1a3d4601c08d7f9c118a580d68b8fd(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3c0b2eea3637b0eedb0617d8888598edcac222a212f3cb81b502086b23b8c789(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__442b3c3cc07beb5668c153bfa4adde428c20d1c637ecdb6f5482ffcf8e3d20c9(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__df3b003106c9a6bafa34a4c69a59f53b01728ddb7324dcc14d3b60fec271d0cc(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cf48c18956af271b5f91fd49ab8cdf17996aeb6e7277c78759be7e15d7b0e518(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__78c6bf8a20f92aa57ad3124c1c465af0d61f4a8916ef07ae6e06bdcf717c1aee(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c28133246a54931468d1e016f3f4c74ab32009f3e5250e699e3d3eab7af3f2cd(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionRequestRumQueryMultiCompute]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9823478e56e8c1d5774266e80738e6ef23c8134d0f158f0b37dc451586251324(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b8547f0f82ff872ed50b63991898752c6db3a560cff0442b2979402676015f8e(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6b33b70f8d840279860fcac01993d1514734b62e23d60aca8d0b19a00c6886d7(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e9bdd56d84ac1d37f47d3a13e4908c5ed3c90111433d01655914213e970aae8d(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9b07323c67f287941c1ccc583852c7e8ec1ffa25a9e186302309efee21061636(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetToplistDefinitionRequestRumQueryMultiCompute]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bd0526f8bf3d62c77a888976bca14293b5a4c0d572a16945571c33c9154a6225(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ab0854b6e7b9e0eb8b52d45e1cfa1290280b5d6cb4679a280ccaff36e763173b(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetToplistDefinitionRequestRumQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3544325099098a366ca08d535d7247a90b4a8aa32f3da52eb62a4d82c7a040da(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetToplistDefinitionRequestRumQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b2c73b2150dc127da2d131eca843dee4a216aeaf450db8b8183c5cf272892a8d(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6d0b66a197358ad46ed7d4f5be42f6664301be38a123a227e78184a27d528ea9(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7dd627760e20d0d7785cc3dc01082b366e4d07083ac609d65d8961b1b0b0407d(
    value: typing.Optional[PowerpackWidgetToplistDefinitionRequestRumQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__08d0111e379f8b7425b28c6db6ac1a957ecd243fbdf36c8e3e3312ab619449d1(
    *,
    index: builtins.str,
    compute_query: typing.Optional[typing.Union[PowerpackWidgetToplistDefinitionRequestSecurityQueryComputeQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetToplistDefinitionRequestSecurityQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
    multi_compute: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetToplistDefinitionRequestSecurityQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]]] = None,
    search_query: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a1bf775f9c5dca08f89bd33338499e93218795aa8ab09b78a0011317bacf5330(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1697f1831f74a5abe0a3c6b7276487cb87f1ec2e862ec1e59d08c788e1834acf(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5f0699e3079fa9e024711bf71b12775f62b4869a4dd4ede9e9cf405308fe7cb2(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fa00fa4fff139d68c454c3d07973c065477900ac3c3d5f2d81edc015eba598a5(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__385efc2650d57c0210efce11b214593755f67fdc565be6d56fb56c771e4a381f(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6b4709ce2ade041c075cfdbe3b116c415ea8337ff3b1d9ec3d41f3a882c02973(
    value: typing.Optional[PowerpackWidgetToplistDefinitionRequestSecurityQueryComputeQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b9798c476e9c739268497453641443263569c404d9de587b34bb953da1f88175(
    *,
    facet: typing.Optional[builtins.str] = None,
    limit: typing.Optional[jsii.Number] = None,
    sort_query: typing.Optional[typing.Union[PowerpackWidgetToplistDefinitionRequestSecurityQueryGroupBySortQuery, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__391d568851d2b7463a3b1015eebf495c4b0a5c1df55190e5ab61cd831092406f(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e725df86bae523c013f56190c030c11d7042dc9d764480fba7b1b4a055454684(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__89c3ceaa265a2659c09e7e4030ec40c5c237124a35823e23efe4cea40abad4b5(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__abaf37c8df929604bcee9c9737ae236d857e619f2519508452b133001ef5645d(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__be9cdae9d787ff5656cff2d0105aa5178532e6d1d098575799bcc4986f40d186(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ad204541e4ab4b116dc42877e8249c24117e30ce536b335291fcc2e8aee28d1a(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionRequestSecurityQueryGroupBy]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__87321135a144159e5bbc8c556c260abad7853e89a6e5794e9b90f12a9a26a3f1(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__014ea717a3571df31d578076109c0f51748294e13c620f23a92b475925568574(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e2e7c88fbd30a9bc3cac63ad0d189a4a3288e29b6d0cb9c1a6fed9e14b24b4bb(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d83744ff89f15890a8531229edecb3941abeeb0493a1e95f7e3a4af64ad2e3f1(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetToplistDefinitionRequestSecurityQueryGroupBy]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__434d4ec5105440ce6760be7e683d0790641a179de590c81580d9f98b79ee2886(
    *,
    aggregation: builtins.str,
    order: builtins.str,
    facet: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__397744ab8231d8e819bca1b64228987c24df4160d585eeaccf35466c3d5b8895(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8f5dd8faa893ea62a27d28d53bffdaa518f44af1ff4b327acd20efe4d3e364c5(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cd47cbe4d6b0b8b0163f635e7fd83b1cd97200a18bdcce2c30fe0041e509b55f(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d113c895a66c56a16607e52884deed0d1752064e574753ecfbaa0f5561b7fa3a(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e3b0c3ee5643bde603f7eac0ec3f26e1f156a6b40117438434febe63176ed929(
    value: typing.Optional[PowerpackWidgetToplistDefinitionRequestSecurityQueryGroupBySortQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__66e42c587239b148cde16756acdf1963305aa1170a5588759500d2603ff5ddb4(
    *,
    aggregation: builtins.str,
    facet: typing.Optional[builtins.str] = None,
    interval: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ad92111dd1c531b4f0e7bb933dcedcfa3658d2d7202f22a352819d84e9e8a242(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a7e422e0e679fd9215c3cf64cd2bae3d77721e4dc3a2434d9ad79affec7fffa8(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__842b58117842eeb44c31a88cee02eaf5bd716d5a080e9ad63906fdfee2864511(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__da3d1fbf4f89100ac351f267ec00f4edc1cd3559d748850dd29f54a32e04a656(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e109b325038fcfd85391eb67afc8604a59be6a9a733ed2ee272c529041c672fd(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cb8aa3040a9a83dd5a7549ba29fe35959a89036b9ec4f5e30c06b334d8ddedd0(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionRequestSecurityQueryMultiCompute]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__74830e576fe4e2d870e4eecb467666dc95fe466c9e908649a97780b113c65ceb(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b01e8328473c38b907bbabc1e1aa4887808fc68faba9cf9c57be1378466d0b1a(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ffcd395ca0f8a6e5d27a29c4a54006bcc32f34af0df9867db138ed2dc6ae6a48(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__80c24defd63c23ae2b75bac4dc14bbb428b47d376bdb8e844df601f28ed5df3c(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__33682fa86bb0ce4c148d703f0a378762d356d7d53f766b39a7d0fdb33ee806e1(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetToplistDefinitionRequestSecurityQueryMultiCompute]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ed6afecd198b344301d1b1a9a1dc4d8b0456c3dfb9f20c6a763d5efd46e77ef7(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__09345a207fa80ff27d57b6832bfe666b13039f7839eee6616fc2c24519e6d6ad(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetToplistDefinitionRequestSecurityQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__095865b9375cad2f7e87fefe12aef070dab72ca2d34835a68878a16f4f951404(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetToplistDefinitionRequestSecurityQueryMultiCompute, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dbde6bcaf102689602692cb70d86373c0ee75f2fdbb63845ad82ef2886ce8be3(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a9bb718b17535ebbca00766533bdbeb4165196a54be0ebebfa9656752928bc40(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1934cef43f6a6111987fdddcf37cf8c47b63eb617284191972022943e78ed3aa(
    value: typing.Optional[PowerpackWidgetToplistDefinitionRequestSecurityQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e264778977ad83cd690e04d323532dda9b324a904019991c2f03e27e97cb3801(
    *,
    palette: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0881aa8ce092adb488b08dc8199afd2db7fa7931e2c470adbc8c8133c8f8bd7a(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__42ea96bd0790a7fcc6b293e39b35aab4fa54259327b00f806549f6bc51431a1f(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f44ee46c41b47575c7433c18bc391a6def608436689a29f6c63043b2c0db707c(
    value: typing.Optional[PowerpackWidgetToplistDefinitionRequestStyle],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__29e105282ccc931d67fd981ce421173fb79c08829e63067e982d9a7769717737(
    *,
    display: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetToplistDefinitionStyleDisplay, typing.Dict[builtins.str, typing.Any]]]]] = None,
    palette: typing.Optional[builtins.str] = None,
    scaling: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__26ef2cee1a4b5451dddb0a7ab49326297d8201e97f413362ad0acdec8dd98dda(
    *,
    type: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c50427ddfb097fb923d347f8eb5bcbfc2f15fcf73a75256b75dd2aa2b61c350e(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f7629a8f255a169ffb8a499df0cd1c9ed9d0b31a483dadfbe4fe081be94dca35(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__675f8d1f0178c5cf0d97fa2e49e38a966e5171ced7f3ee085b619a9020970907(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b91b6f896cda8b893624e8c3cf6a5cd20efe74e9cd21d7366cbb838358b72d32(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dea07f074eb851fed2a33f506f0ff876b1507318d8f03b9ee9dcfc40de5c0514(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4a70b92cabc07be3e5017e008024b22ee52bf2a8c6f0f0af5bb7fd8524d85539(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionStyleDisplay]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f0ee9fe3b401f1fbacf9c917e2fbcf44217c240727a24aaa7767bab322516c76(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5831d647275e74842f5fe47285d6e47cb25e41c8aee71de419907a732d731314(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ab6b7fc32b1e93db047785d122f38e917fc0563c945eb0bca5881b595efa7e26(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetToplistDefinitionStyleDisplay]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a30cc5199bab473f84718924056c1e8ad9603219b136e014475807876c184ccb(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d532fb6b2d8c98d427b213efdecf09484dba595ac6d8e42fdfa34c2ff2288f9e(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cc8a2affbf176ca8aeabad2175e2f9033d17525ad6a2d360186e916ac116efec(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__875f17fb3614ed13b56655361f7049325dea356bdc4a6d9b1e4a67c98b50b1b6(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e09117da0ccd35a7a17862804fb201ae0c2a81a017575bbe7c190890eed95084(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__51ecbc040e42fb5b5225a759046885061add59fd3ee4cc22911fa60b43662986(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetToplistDefinitionStyle]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f46fc6a9684fae9e9140e5c09d9013289da3d59f478d2f8fb60fae8f32c9ebb7(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3d58186aebb3f828bfb33ff1a370d15050fd6492222c4c7c5e0a4dc1787fb593(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetToplistDefinitionStyleDisplay, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1584d8e4b25d58c8fe9de5113dccfac3f29bbd063d30aac2c716e1ab4594fabd(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__44abb6ce012f2f765fcf3638581731d7eb65575cb3fb65a848b28d90b2375111(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6670674715d87d33d7c2e3bebc46f14b6523b12d1443dea8a87442934c3e019b(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetToplistDefinitionStyle]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e860e5fb9de3528e02c41a6e2780e5183b953b22838d72aac38d70186bbe8ea9(
    *,
    custom_link: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetTopologyMapDefinitionCustomLink, typing.Dict[builtins.str, typing.Any]]]]] = None,
    request: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetTopologyMapDefinitionRequest, typing.Dict[builtins.str, typing.Any]]]]] = None,
    title: typing.Optional[builtins.str] = None,
    title_align: typing.Optional[builtins.str] = None,
    title_size: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__33c9d75c7b14743607e6415d2dab4d0ec917881a6dfc3de5d1d519eac27d34ab(
    *,
    is_hidden: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
    label: typing.Optional[builtins.str] = None,
    link: typing.Optional[builtins.str] = None,
    override_label: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6cb12d8686c987127c6980ca7902e79098c36f25e058692167633955e84dc25e(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__24005f5ba1d6e70c7b9f6c76ab4a04d2bdbdcae556f42a44afeb893be2168a12(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6af44975114069c2d295c255359192e51f4617113221699f27e974757af9382a(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8ccf8280ae99885b7189f16143b1c98cdea13ff3bffa62118c78cb6969fc094f(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7de45d34d34c93dc744d7474d30db257288ed226f3b9bd2ad36dc2923016bc03(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1cc2ce483ff78d26192bb2803590ba93f9c8da618e9614f39d00b56c61ee4cb4(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTopologyMapDefinitionCustomLink]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__26aa46c4f48895b8795b557d2a42f385373f11d30feeb95dac3292e762746629(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__52dbb980de1286301dc33f289ad7e3964c24d1fad28dca5b6ad7d4c4e77d3c12(
    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__94853d9743e9d55546b1308aaa36e76d3c44107c10aff379cba5b9568ee8eee4(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__df2cfb89f0a3926ae779ec90605b2ad96504d269c8d9cf95cfee5bee478906f6(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5411970df823969f694a91e45c0135cd71230643e832f96c2c81ea1a4dba14c7(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b6112ed6a30384214d1cf5836bc9bf3b90f9e98255351df39e03d36d63457402(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTopologyMapDefinitionCustomLink]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__619128ca9ee7123d9fe78e30b0d6bc7733ba237ba1784832864d68314ea5c885(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a5d247f471002e67e81f1daccf7ee2d92f0433d2391ff140eeaf1a0690cf9064(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetTopologyMapDefinitionCustomLink, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__60e884585b8c958c8db62b27ef9722849244a1a87eb6b62a8c4cd21093f7b32c(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetTopologyMapDefinitionRequest, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3c2cd2a05910239fd52676bee465468e391acca6ae1d032a47f11437635817c6(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__69eca333c66b21d5f1878d2140d29a605174c2ad06a0a6a07ee9e0ef97348709(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__eebb0f43409a8511254a068efb7502ab3474c8361380f967fa111dae20483c68(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__df34aea2f5d9766566f83a3645362e22f9ab0708d5bc7d90f4a6b26d702b0633(
    value: typing.Optional[PowerpackWidgetTopologyMapDefinition],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5855dee78398c4e53af30fbd0b0f85468829107bb051ecff3caa99bae9bc3ef8(
    *,
    query: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetTopologyMapDefinitionRequestQuery, typing.Dict[builtins.str, typing.Any]]]],
    request_type: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5fd097ccbfbca14e8a66f197ad33527086d62962777b73e4cfc3658064879e92(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e8aaacf2f97b57121c2b7d1a3b2e3a49f8fde78a80b3a8ce5eb38bcb9feb82d5(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2db10eb6df9792db824b239190ca32cf130d29b71e3f2815e8648dcff28a963b(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3ef4bbb388bb29d24e82dedb2af724554df97cff0216ba36134d32703239c546(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__afbf81ae306838922ef62827959eb26a2e4f85641260b06b4d95285e7217e214(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__698a5bbe9c22420e6f790b884a900ee21841f499fde0c4c9b667cd4153c8b378(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTopologyMapDefinitionRequest]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fbd3eb1ca399d1eefb60aa4314256b73e052c30dab9fd294fe9e84590075042e(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__609c46f7ec007c5b155e269ce6cd565315b47348b68242e5fda2b3e05f4c9127(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetTopologyMapDefinitionRequestQuery, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d7efd0268e7669014dc75b1515cbb963bad4e0cf1a4fb762796607a1e3d93cd8(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__52bc487a67f497caaa49bb0b7b0ef6889522dd60ca2637434cbc89f9e4f0a100(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTopologyMapDefinitionRequest]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f2dba32a4b96e85b95203becdce6c7c4a67020d31a576f5329d90889f12af672(
    *,
    data_source: builtins.str,
    filters: typing.Sequence[builtins.str],
    service: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__849c43a43c3c5014ba7b974ca8fcab9615cf1cd5928ede24020ef50095ee89d9(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__00889f89d95540374b4c8736c1b08d4d1a16953f48f4f1167fde56008440305b(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ef5a44698ae55b50268b9d8157912277d7b99735fc3c1bee8f1a3b811af8b338(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__354e3293031361bbd27a2afec49c8f39746c89d66b24b6a271e4e078bb04517e(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f125305dded1b643d00aed2df852048d1fa3006a78d582074acf6a10052c496d(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2364ffa7fd62b532bc0f18b5fc5ff3fdc0527ee8a6d351ab05457b9d4e65c9db(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTopologyMapDefinitionRequestQuery]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f6c80c317c046079b2a9cd0ad239938563b9c2083435c2759c5db5cc393a1c55(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5f08e519df10744d77198da54868e1e5d24cc9f313ccd204fa5eb24c2cdbebce(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a36cb6dde30dec3ef63f451680d35e031cd9173f4223770c0e02f15bcb89b5b2(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__281ee51a26d3919786a55c466fab40e5235a9fb54cd6dbeca44a86f10ed4f735(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f943372155bdd700324f899d034c89acc010a14a375acca42246fdea470c9ae6(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTopologyMapDefinitionRequestQuery]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cf690326f94521ae9f304ca69c75d259d831ca09c6422c2e3309e371201b7355(
    *,
    env: builtins.str,
    service: builtins.str,
    span_name: builtins.str,
    display_format: typing.Optional[builtins.str] = None,
    live_span: typing.Optional[builtins.str] = None,
    show_breakdown: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
    show_distribution: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
    show_errors: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
    show_hits: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
    show_latency: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
    show_resource_list: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
    size_format: typing.Optional[builtins.str] = None,
    title: typing.Optional[builtins.str] = None,
    title_align: typing.Optional[builtins.str] = None,
    title_size: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__306a5dea8b3d910bf39ef2b0bd579bd8ec0fa8f8f1a5bb90b65a67341517149a(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8a53e4a944d9f0d5b8d8b9e53452f89afc0f9ad071bfc36124f3b978cd7449bf(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bb7c93e1942d598a394121831c3e6d8cd6577665590cd31d46c2ec835baa45d3(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c2630678513589bafa1696a478a40ca73648994b7bb1a26d8a9a440d7ddf6c19(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__487ea491ee5c2b124a4ab047c7e2d1057d6f4fee707ea8499eb7579920e3a9e3(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e8d64df9c44a14ac92436f869bcb9d813ccd9be721d7e02c13cfffd8a184f03c(
    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7ae7568b6aa4d07caf44e73ebbc4f224c73044252ad02bfdd52423145b7b26b2(
    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3ee6312eca96dc910b2c40f21a3d8a9ee4ba4ff85bf7e9c628c55012d96aa450(
    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f2d31c67d298bbd50feb1050aa76bca99835811fa2e58794b203b7f77ffaa7ad(
    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f5c47fae9f537434aea13c4e5672e7f6397dd156a433d313fa43f903a650dd47(
    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b910f167802c2ce2afebfb599fa2ded06172d701b7ed9f12543ef339fe77828b(
    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__de4129c18fc095df2fcb2e9598dcee52f8a10edf2fce7719b92b702014bb7f45(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__00b97ef4378f129e499d6db4451283977a88a2a73136b893be0afcf22513d40b(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d0df21aa2a99ccedbc46be5cbafdcd6db4867a38e2d6d9d51cc4d9f03afdac33(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__aae726572056674d91a46a569e6f83dd919f3cb293b3a9efe42dd4aa7cb3cebe(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d57e2f10b6fa5a98fa8f3d0db925f45e2e85782c9bda994f66c98a901f93f66b(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e504dd3bd205f708e9e941c9bdf7b91d3d82ccaaab3a08352c3de95f19ad7328(
    value: typing.Optional[PowerpackWidgetTraceServiceDefinition],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__33fc0431fb6d26335040f3bd538f72179f104c8f5d677e697cdf2cd084aad18d(
    *,
    custom_links: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetTreemapDefinitionCustomLinks, typing.Dict[builtins.str, typing.Any]]]]] = None,
    request: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetTreemapDefinitionRequest, typing.Dict[builtins.str, typing.Any]]]]] = None,
    title: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__264cc9c1d769c95bd453f234d033fe1e520ba0d6d6a9dd08286460e5582d4a88(
    *,
    is_hidden: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
    label: typing.Optional[builtins.str] = None,
    link: typing.Optional[builtins.str] = None,
    override_label: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__40903b01bd1d517e8f65088c0a70be28b9b49c323b80c48c37e5e81674fbd1cc(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2bcda43ffa01e383cd97b264e69445ee1e1e07906b0a23c53c071c7c575290be(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__23292dd256b9e5e9d403fe1a68b28c20ac6197767353b223954c9080a6b2d32a(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8f47b212f1c0deb76829b9347470abbedf7e67c6cc86019f730d73e7835000e1(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9932265982d4ec8edfb8d6d67fb7d01ca8366568f28be4e0b268f2b6565aac33(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4e2d660bf29e74919d14a17a44f1418ff7dd8add348fd04b5e33a64e55ac838e(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTreemapDefinitionCustomLinks]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8e480cf68cee705e48fcb30ce30dbf815309d04234b043f944f12fe03c291653(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b38e2026ec94cf37327458863bca760a4e1f713fd3e1f1d2e22b2026389a5885(
    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5f5bbcf7b110d8f67d5c65d7461534aa220ee22eff2311fdba86e5bf2495a12a(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ffd7dfea0c1bb747807367c17d8b783ca4102d8a76e265ae1e1acfd8fc1a5d54(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a6b590af8e83dc9c280a5e507548a4bdb1462d6a185d45a7a0769357bb32f865(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c222a79e56c4b82cd9544f4c3573734de0e374a6d882a359460aa3946f9f7da0(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTreemapDefinitionCustomLinks]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6847043c64c2b7c4cf3dd42bb7d82df39e3de8d37afceee8e782228a056891c5(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3c36e62580fb63b0cad72930c46d13f54366b4aed609d856ee7595ac394134e9(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetTreemapDefinitionCustomLinks, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dc6905f80ad5f075a9a3b2cc11d070f2b7def255d571a3d4978542b699b22722(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetTreemapDefinitionRequest, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b92662787ca612ab106ba4bdf14ebbd7e5113062369660096930d682e8367f77(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__86bcf8aa2f5a0a4338d26bde5d5f9a3bf407923c225b68d6c75680d9aa9d2d2a(
    value: typing.Optional[PowerpackWidgetTreemapDefinition],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0bbb6dc55117f34ee5a8b209a5959b3f068988e7c8095e86ebd2fc32d5a08cf2(
    *,
    formula: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetTreemapDefinitionRequestFormula, typing.Dict[builtins.str, typing.Any]]]]] = None,
    query: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetTreemapDefinitionRequestQuery, typing.Dict[builtins.str, typing.Any]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7e46da89455f1fa58c3b3c4a65095768ddb5c4db995eba33d57b2b0cfd77c486(
    *,
    formula_expression: builtins.str,
    alias: typing.Optional[builtins.str] = None,
    cell_display_mode: typing.Optional[builtins.str] = None,
    conditional_formats: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetTreemapDefinitionRequestFormulaConditionalFormats, typing.Dict[builtins.str, typing.Any]]]]] = None,
    limit: typing.Optional[typing.Union[PowerpackWidgetTreemapDefinitionRequestFormulaLimit, typing.Dict[builtins.str, typing.Any]]] = None,
    number_format: typing.Optional[typing.Union[PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormat, typing.Dict[builtins.str, typing.Any]]] = None,
    style: typing.Optional[typing.Union[PowerpackWidgetTreemapDefinitionRequestFormulaStyle, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d5860f711cb1fe61f91da22de27d62fbbd1de4ac1eb3ff8f4686856ff8f76e70(
    *,
    comparator: builtins.str,
    palette: builtins.str,
    value: jsii.Number,
    custom_bg_color: typing.Optional[builtins.str] = None,
    custom_fg_color: typing.Optional[builtins.str] = None,
    hide_value: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
    image_url: typing.Optional[builtins.str] = None,
    metric: typing.Optional[builtins.str] = None,
    timeframe: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__48d3239974c76b67f15e2b8ae945366d2bda290b845a896f7c3e69efc009670d(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__05404104d4fed14a319c22eefa19a62a7764f7c3cec082cbfec96ba8b14b4f5a(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__184c9787d6c62cf73ecc5412c29593fc74906cb6d56401ee2dee72a501cdfee5(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b520007e1a5daece32831cd8d815d8fb465aed086bc5191f921a3ee8370fb915(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__189587c54911971e222549b6271f657984914310898f22cc3fe654c763b6574e(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__02d404ce5608c41c8b096bd6c56998cb1037a8f8e55216481db6da3f8c2199c4(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTreemapDefinitionRequestFormulaConditionalFormats]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6279b02dcae1f6340dcdb5a1ec19a573b414ac3bb2d295bde238fe90ae29d972(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c26b11e8a07279014a3b373e4294c1bc048fb41033b53be5656e6b7e8df3aca3(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ec8f023ce4b0356ff4ce4e4400ab0cc68972613d62620522e6fabf29d4e0df8a(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0df6e4d8d809651a31da97fb306fbe2dc3ff032ab0cf45c7e45c45a2ad272de5(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ecccec65f1e5ae62f87329b08f30f1970dab2003814a14d1fd7377485ab45567(
    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2ed0ea5a7a56a476feca984e48f17c34840a1191ecf9b9541acc9a358229ed2d(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__aea5e7cab21f879b2917e9789c4eac0a1b1b9ee01e9fb4c21618f40a62ce2bb3(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__344a3c7c88f5b258bee2cfb75dd645a9d52e34bbb5c9c4a321ca425de48edb30(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4e87c4dc6fc8cc463b92ed8c928a5c9b1b4a2c740554d19cd4ccfd0b022ed469(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7e6457b929f8671b52f4513fec1ee3ebb28a5d69708fc8db6e3d41c34014da8c(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__68697ab7c4d3b06e0d28f1cb7f9a334198129e9d2bfc20aa03711a0d9b14f1e0(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTreemapDefinitionRequestFormulaConditionalFormats]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b8e473c5f3e16f91671c85b4e37991a7780e9177d89ded72efecfaa7b43c45b7(
    *,
    count: typing.Optional[jsii.Number] = None,
    order: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6bd7388365d87257c8e4c2f803a02fc3f8eb00af3519dbfcbef6bc87eefca6ca(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__91f827b2841c1d3731ab5c2b1e7972f66c7a25ff62f6625e050119000539127f(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ce5004acf31a3295fbfe8ae4327978a1b0ad8cc2254f712fcea9264da0666835(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b398cd73efb7e636c9ef9c28f8d50f174a89dd9f70047552a0d9b82ca970bbc7(
    value: typing.Optional[PowerpackWidgetTreemapDefinitionRequestFormulaLimit],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7bd595be88187de58c4518028978cdec44e0c67c024b9bc3bcf5a85c72448bef(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__34d9cf1d34242c30af539a7deaedd75e1807f448c1bb3b330dd0b4bb3616e235(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__73efd2009589d6973b49d51febaa519b7be491a740b40a000367b1364db8dd1d(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f774104f6b1b3c157fc640765daa3c3777b49de57375f0d9fc70321e8959ef2c(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__991e99aee5fa93cfe93a2192f97a76422acf91f51bea40fb743b8bf563e9b43b(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0b0bca4cd16cab19fb8596f9078d3f51b609c165b040c24661f8e61281364bab(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTreemapDefinitionRequestFormula]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6bb990ae66cba6dd12389e7265e2e61ed4d167a91f371e55e4f4bd5c7d3ec587(
    *,
    unit: typing.Union[PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormatUnit, typing.Dict[builtins.str, typing.Any]],
    unit_scale: typing.Optional[typing.Union[PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormatUnitScale, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__622910885e6b51ca03caf9838824d06d90e479844956022f0bd698c66babe98e(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0b540f96215539a769bbc08e8e28320600985d70bbc02e3feb394afc47d1bc3e(
    value: typing.Optional[PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormat],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b9a43ebc9032888e21dffa5419533efbe69ca4800e70585b852b0752ba4a8080(
    *,
    canonical: typing.Optional[typing.Union[PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormatUnitCanonical, typing.Dict[builtins.str, typing.Any]]] = None,
    custom: typing.Optional[typing.Union[PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormatUnitCustom, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f39bb6c542373391eb0fffcf555fed7f748179eec4313bd266cc2d908b60e5d9(
    *,
    unit_name: builtins.str,
    per_unit_name: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ce0686662af65887e9d2fbb150252c943ac88c99b3fc2ef0f59910808abc8d51(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fe1d0a0f8d75f4fc6bd4fd004d8f787bb00e5496604c576d7b60864e1f5bc6c1(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3d4fffe36aa289ace1946caef86651f86ec7262114fe2c6952a3f37110af9052(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__241915248ba2d49bb6ace956a74b9d9ee76e3cd307e37811943f408d54c5ae3d(
    value: typing.Optional[PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormatUnitCanonical],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ce2c67dd63d4669e3b0e746127dbe922d2832b0ed0b6187a70c45522cd9f51d3(
    *,
    label: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1d37883d5f919537db2c174b61803cf5b434da3413bafdd71c98787c5d2c48bc(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2d417f3a86c6155333d74ba30847882a72394e187373204039d40894f4c60707(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a025863afc7396fe72deffce7ebc0258614d7fe8ee9a9bd768873cd728978a78(
    value: typing.Optional[PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormatUnitCustom],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__231ef5a4fb937792e48fe5a2a99efff591b94811759bc97ce6962dbab0bda4aa(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__563c114101cb447afde53ffc8076ff9195e9b9144b4bae1138d7b1e4dad50b83(
    value: typing.Optional[PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormatUnit],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__68191ab81134e27a8d0535b066b227bb94f41001ec7edd4e832f2827f7a89cf4(
    *,
    unit_name: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__775c274bd2ae6ad7e4552058ef43f675497712cf7f4e0848d86ee54eeb1458a5(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__76b4366871671ac4b674dee15b8b7f14db6ee0101a3c49b4d8ed304a22b614f0(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f15a6a6f734806d92190e0ac886bcc724b497eb3100f8c40fe55b85500b50f95(
    value: typing.Optional[PowerpackWidgetTreemapDefinitionRequestFormulaNumberFormatUnitScale],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3a1a53cd91cd017c2e1c09fed2df4c94f958f474546f5c17169a418e046f94e5(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__eeee701ecb5e4080f3715ca16d5c3fa2d70f7db8dc254a5baccdb7d77bef1f5e(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetTreemapDefinitionRequestFormulaConditionalFormats, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e2e53ab51776167d77b9d4ea4f7136c5d817663d72f683f925506c7e7fdeaca3(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dfee514ff07c6bdbb526fa4340f5db76ef881b1e1f47de3cbcb25b7ce67ca42d(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f68c163e2b1aa8e20009bc6a6ccdbc3a04b012df442c3f0caa1a31bd276acc3f(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c52367da7e24ed801a1c77eaa274d56041f2c02aa3b097547bd8bd989d71df32(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTreemapDefinitionRequestFormula]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b26671d570734520dbe81190028071466873e1d7496f03296b241a5418f945e3(
    *,
    palette: typing.Optional[builtins.str] = None,
    palette_index: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7e1fbad6c0aca07710db8fa06db21973f6a280e419986025dcb63f81d1f79702(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ab1225d4e7abd135b61978cb00c4917594bbef18ab6e69613c088939d2fe0a06(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ffcddf2353ebcd5c5edb0e40b8d2403447ddfb108a5a97bd3ad640f5e1c1e096(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__28823fc4fbc0b12a2c919d803d25d8f3b8bfc403814a47f55ea917dbbc06ab4a(
    value: typing.Optional[PowerpackWidgetTreemapDefinitionRequestFormulaStyle],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c1736bbadf35d8b28041273f7c4db5f166f2cd4644df58bca42e52948779490b(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__da57d94aa3683ef89e4082f79b50b9bfeb294b700a514aebac0432e6b4d6153a(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__02d6858552ea75d0ec911b704870768244df1b27941b2e0e16336b6fe92422e4(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__004b477147e7889bc8483f3e054d174aef279cc459fda22a5859f816867a6aeb(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bff0ded4022ef27765594884227136da993cf8a124d4b8167e9776306c978e69(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__04358c7f8e6019b419e396ec992316ceb12a5183a1aece9d56a4c1180ba40ffb(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTreemapDefinitionRequest]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c1b702e25f3456d3b264cb08a16a897256420d623675000d6b600b768ffa992d(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b378911043395efb1ab219f3798ea09811eef90c729b6cf80897cf7b20f50ecf(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetTreemapDefinitionRequestFormula, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6cf01c8c117d055a87fe9e97392bb0b59677c64b461e06dfc220b33c202d9ea4(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetTreemapDefinitionRequestQuery, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__48abfa7e8da5361ca611300f792e0300a9685a86254d8814fb48832663514bb8(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTreemapDefinitionRequest]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1625143f46ff499a6ea3fb6e9bbd72bfba1982aa61bd2fd66646a70de29093c0(
    *,
    apm_dependency_stats_query: typing.Optional[typing.Union[PowerpackWidgetTreemapDefinitionRequestQueryApmDependencyStatsQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    apm_resource_stats_query: typing.Optional[typing.Union[PowerpackWidgetTreemapDefinitionRequestQueryApmResourceStatsQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    cloud_cost_query: typing.Optional[typing.Union[PowerpackWidgetTreemapDefinitionRequestQueryCloudCostQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    event_query: typing.Optional[typing.Union[PowerpackWidgetTreemapDefinitionRequestQueryEventQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    metric_query: typing.Optional[typing.Union[PowerpackWidgetTreemapDefinitionRequestQueryMetricQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    process_query: typing.Optional[typing.Union[PowerpackWidgetTreemapDefinitionRequestQueryProcessQuery, typing.Dict[builtins.str, typing.Any]]] = None,
    slo_query: typing.Optional[typing.Union[PowerpackWidgetTreemapDefinitionRequestQuerySloQuery, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c800cac7e30f7457ac4f5217f5dd3a7b2f27c082764aa6f7c8d8b106451922ff(
    *,
    data_source: builtins.str,
    env: builtins.str,
    name: builtins.str,
    operation_name: builtins.str,
    resource_name: builtins.str,
    service: builtins.str,
    stat: builtins.str,
    cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
    is_upstream: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
    primary_tag_name: typing.Optional[builtins.str] = None,
    primary_tag_value: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ba18897f980842aac9f2b658a057a896279c77610d72c5a817183715ff8dcf63(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bd576faf68cc9762fe0f9093a24462469c2d6ed875e174e3cfeec5f4579942fc(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ff80990444c52cc1203c2743507e238c58c699928f3a83b1cd5a47bd9414542c(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0c90c98d2666b3663968bff4ac223a71a3350917551c8328f397afa7b1d1eadf(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7708376f098b2e69fd8e883970200abf4d9b840d767d397e4c853297094098c6(
    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ef76eea7d7558113a89a60ed5fd1acfd5ec2dd3a48644d03191186ccdc10d01f(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d9525126ffe2b1f9d09426e946489d3f42b5f6f9cc3a5ae18c86d7e9c700e96b(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__85370f26b8c3a53710051fa2273138c043f76001b4fc5414e94968929990d509(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__936f469d1a1678b3d53e4f3ab92330b12dc06656059fd92b6d8e81f65ed527f0(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e3ee20b0198a3a1d055c76f2666a97ca6e743284ef80932914e608bb7e339086(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__89f917d0ff69f6885257917352835f0276a8af4d8e35cf55e823ee27421facbc(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__403e04dedbbe58747a3d924397144ad43060a7e98f3684f20d9872b6526b8a6f(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4e3e025f98ac827edcd254d561600e593cbc9fe1c5bb78f6673e1372838781cc(
    value: typing.Optional[PowerpackWidgetTreemapDefinitionRequestQueryApmDependencyStatsQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3015d885491c426561fbbf39de0ea1fd0f5680327f09827ddd71bef0d5f92a9e(
    *,
    data_source: builtins.str,
    env: builtins.str,
    name: builtins.str,
    service: builtins.str,
    stat: builtins.str,
    cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
    group_by: typing.Optional[typing.Sequence[builtins.str]] = None,
    operation_name: typing.Optional[builtins.str] = None,
    primary_tag_name: typing.Optional[builtins.str] = None,
    primary_tag_value: typing.Optional[builtins.str] = None,
    resource_name: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2b56b3e0c9e9ee6e0ad295daf45d74817be230b4eb51e542d8fb5ae618c1135f(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8d72ded041120ab505046300414f805df860663f92d9572a60132c387a424e84(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__082aa33327f0222155e257d8e0d941fa8aac872a6c1f40c869c86795f39361d6(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5659cd32b04ff62b4c20245922f5947d89558e78462d7e76986237ca707d1bac(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8e96283af86058636e51c22b808b27d94ced5a57f682eeb66b815c30d7d580d7(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__059c028fa63d7723fc67a182c1a70e5a046bd99503f9164dd138710bafdeb931(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1962f2881145b01afc466b4753ebfaec463bc9829a907ef26a852a57a0c19ba0(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e072a037ff264be58e08144becf451fee9f97b1114d7f9c0198746a480dbd5a1(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ff4d2c72e890f012c9d3cbd0be3a2dbb08cec9365cb8adf8003da99ff7f12388(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__74cd12111211675b2f6f940e82d2dab5a6f8b330fd01e19ddf5c2a0c81553d02(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6ee5636f0f5164cae677f4812e1c39df4915b2766dc6c080e9db73ab8114d606(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7f8d2dd79a71710de8df6314cf8870edc6089e8e52630c69de5959032a61ce80(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9f68b45a2b8dbbe92a63907618e1a0f09163b2924a22decf9619e600915770ed(
    value: typing.Optional[PowerpackWidgetTreemapDefinitionRequestQueryApmResourceStatsQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fd010fa0a15841a053b1330a22e37e1d898e80ed8ec9e5fc4bdbf3cb028d98ea(
    *,
    data_source: builtins.str,
    name: builtins.str,
    query: builtins.str,
    aggregator: typing.Optional[builtins.str] = None,
    cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d4ae44e651ccdb9a05d7dd18e66fcdc9618df42fb085b8c1e76ba5fb43523a1f(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fd4b97d351e5bd54c773d337f912630429f15f8c342f6e26c0548c5d204c38da(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9a4e201ffd3cb4805b1859fb070ab45ea14d5aa2b02a219b5633f799e089eb2f(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ab08a65e011ac7858c42841faf81ee6283489e5e7fbc9af4d9dd05a765998018(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__66449f8ed2017203152bad037cb64123757476e77ea074ba19c44c6dcc0db732(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e485db173f6cd575f8e5cdbccc58bcdea90e562ec85533ba4c3b384722da72ce(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__89d7188a5630799c2f60721492a679a3b237cbb8eafd75033b8f077b835d015d(
    value: typing.Optional[PowerpackWidgetTreemapDefinitionRequestQueryCloudCostQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__61a1f0a1936aef4cfbdd7562fd507e925cfdcdca6682a643adbbd0fe7716bf6d(
    *,
    compute: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetTreemapDefinitionRequestQueryEventQueryCompute, typing.Dict[builtins.str, typing.Any]]]],
    data_source: builtins.str,
    name: builtins.str,
    cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
    group_by: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetTreemapDefinitionRequestQueryEventQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]]] = None,
    indexes: typing.Optional[typing.Sequence[builtins.str]] = None,
    search: typing.Optional[typing.Union[PowerpackWidgetTreemapDefinitionRequestQueryEventQuerySearch, typing.Dict[builtins.str, typing.Any]]] = None,
    storage: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a61b56cab240a4f1635499a14be7832194b7fffb87a86a0d6bcdfd4410c2ceb2(
    *,
    aggregation: builtins.str,
    interval: typing.Optional[jsii.Number] = None,
    metric: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ed4820ff67bb6d27970f363fea12ce2e9d4531cbcc52d5127658740ed49fb2fc(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7911eceaded75183da59ed9a6ad9f4bf6e0f75417429dd282e3adba90241ed9f(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c459407725942b8261a12c546525505addbaa7ced712b8a63a4f209d02f4286b(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__43953152eb62e4de8dc854378f8df8450fa2c18899991d16de8b16a7bd5d4c26(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9065cfb8f344d7ab16412bcda06af8e22c2e68040d437c2e220e8d88fd31a0a1(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__40b5166dac75d43d5119cd6fb01eec88a86907181419a305a0510363d48231ff(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTreemapDefinitionRequestQueryEventQueryCompute]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f0ba61658f9a147b52ef7b16e8323a8f9dc25e18a847abdff5396d2b5899b678(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d5ae48342939de778fbf208e032b925a00af7422143f9d3a36b863c708bc1f53(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f6b69e50d0d19689796abf279763081c3a5982aaa22331e0cad6cd4e739207a0(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f539300b3f6ac557330dae7baa527d7e1599c5ee23e9c6a8304143f6531ab4ec(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9cf9ae9f6cd64b6b5da48f2b01aac496de1fafa3c6016c15289f6545ed7d8896(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTreemapDefinitionRequestQueryEventQueryCompute]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cff69e4b4482bff65b11c9e3217db250a7fcc5d2d4faed7a83252068ec0abd89(
    *,
    facet: builtins.str,
    limit: typing.Optional[jsii.Number] = None,
    sort: typing.Optional[typing.Union[PowerpackWidgetTreemapDefinitionRequestQueryEventQueryGroupBySort, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6a8df3393112735d55558ea6213cb68c52daa0f7e7a72a9b114852e3f9b9719c(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c0d438cc787c5b0138b0698b7b52cb1810882a56136fb0e59831c2aee448b7d2(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__26641d48e8a9b12efb522d140784969ce13eb8168c203bbd59e2cfe35a42221a(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__76a9085f78e36a76c78323ec8bb1ad586b5138617f65713f1eeb92fed7146369(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__36713c1a2c9e75001743bd4263dc90b4d3b630701330d062f66001f26771cf6f(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__690f407def95700c0482f8de245ecd52a52eb9d52e8f89cce1256d7154e64b80(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTreemapDefinitionRequestQueryEventQueryGroupBy]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5e666727ab86a6987b8fac8e5686f415aad0cdd2cd9b61a246722232fd718b32(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9fea1e374128aadc520fc0d69dd8aec70872f16759981258e590047b5db05d91(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__feb3c46c9cf18a004b95770e0757d7cd0682385e59790b358e0e1b239a174001(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e4f4b65d26831e281ec15d07a8d7c26b26fd7b2574bdd5edb034d7ac1f4c965a(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTreemapDefinitionRequestQueryEventQueryGroupBy]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__56c6edba5fb031ffdefec8d3cf3f736afde2f0681825154aa38a845ef2745e47(
    *,
    aggregation: builtins.str,
    metric: typing.Optional[builtins.str] = None,
    order: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6046211a5cedd1c29e7266a63a490cd464b1f2c885d05301a0e392a8d2fe1df3(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__83145e7dc2665106c8a98b4dcbfcfc01d805ae0478fc5c85e0a29f434d5fd89c(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__456f173ba3b45b9c488f1e2b7810e6f2510c7ddb8e92cc4edd21726ea8627bc6(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__50983f2fc2ced2d63880c2440aeea1995a1389a274cde55d2886793ebc1f93a4(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1a039fd51a9c320ce8150b0abc2cc264a37462dbab7a7a1549b65093ccb74eaa(
    value: typing.Optional[PowerpackWidgetTreemapDefinitionRequestQueryEventQueryGroupBySort],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__44ed98911ef6bb64a8d81a76d5d1143ae337c74227acd811961a0ff5fb956714(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f01c692b74e926cbc41f5916c953775b71855e72c3541a6a2b3150d0b1084dc9(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetTreemapDefinitionRequestQueryEventQueryCompute, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e9506faa9d184eb0837735da72c0ea785bed7539dd042eacc807560f104b585c(
    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[PowerpackWidgetTreemapDefinitionRequestQueryEventQueryGroupBy, typing.Dict[builtins.str, typing.Any]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__aec6d7ff0ac853b271b5f22b11513f2bfc8de5d452bcc72236ea68fe4401529d(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__be3cb6987eec7653ad74455a6c1e9b6e9508aae3e90f3f5d53499e14070f0591(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__82d886ae6ece3e7c5b4d3b25ee20dc884d815e4f813006228ca2c1ab3c441124(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__16487d967aa5f762ca3fad6fb5777f0001b886778f8e75cb0526c71d2742d877(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__19b9120ab19a81252b3b00f4e2121b6f7434baba1e3df6a4e11dbd27aa478505(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fd35f15ca0c84e24012c54dd0aa3d07a5e977533495c20db1884408b2cee4a4e(
    value: typing.Optional[PowerpackWidgetTreemapDefinitionRequestQueryEventQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__043bd768052f329c323ebe0e40a44c8c7eed2ec3a6f27ca038939682ebc0f344(
    *,
    query: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__66f1da64d0e904f944a7b8f2a4a2ce2354deb23b0c45721f5623d1b5c52b7681(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b1300a239cadfbdef0240e7ca943b7161ec9591fd59c7e91b12af9237ae8b71f(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ccb96a1f48a4544855f02a7904cd8e9901ff67763e46a82c53f46c18e712aea0(
    value: typing.Optional[PowerpackWidgetTreemapDefinitionRequestQueryEventQuerySearch],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5600609ed17d65225b12f2cb88a8c93c31db2af84868963341fe70db5d29fee5(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__90dfab764958aeb876fdae8d125aff118c3c48f563415ba4109fefbe17728483(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bd461dad7d39f60c87d473bc687c12d778d3c56f47bcbf9d0aeef9b61e4d308b(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__917e108385b035e958111dd708c09a3596b3265655af5d4285de5b3071aba890(
    value: _cdktf_9a9027ec.IInterpolatingParent,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a53c74b507a028b6c5ef8431a0b25ecb80f939ffb35d9531de78d41f1e1b9060(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e2346e265b89c561eb114e7d0b8f4a6be407123fffcab5880c17807b8349e83d(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[PowerpackWidgetTreemapDefinitionRequestQuery]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b69194ca1c02dd601da36cf23d759a7dde7cf9ac076bb2d394ef10ac8de1ebe6(
    *,
    name: builtins.str,
    query: builtins.str,
    aggregator: typing.Optional[builtins.str] = None,
    cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
    data_source: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__37e354a91f8ae701b24751cdfe0faf45a4cd32121b7306692f0dc8f315803d9f(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d7bf3645fa938752d625e0ebe44a40b48716acbf8745bf0c2e833f619f56b74e(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c8440e2159cfebc4566dbf23df7900e3e1f4e058de1043821971a79c8f92e723(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__62d15bb61c2fd8bfc113c526b14d1247bacc402711d66e0a8ee0440d93a9d6ce(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6327a0411706d741733605da96d742ad4663152ea8bec3e092f0a2766c00dd5d(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cf45ae078402cc234d3aed73286b5d317244c8f13b0d3f2cc6d4616823209d2f(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5c9c446f5f3dfa1060f59baf805ac8d08f519effc717bba0579f74703404de93(
    value: typing.Optional[PowerpackWidgetTreemapDefinitionRequestQueryMetricQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b8c486ea485ff64ba40ddfac6e8af279963653019b1563855ce9dc030cb60690(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__56b155153df00fbb6d7528a96df3525433f550eb263ca3ba1362a9562616463c(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, PowerpackWidgetTreemapDefinitionRequestQuery]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ec9a12794324cddaf1e31651497f3442db51d5c951e8c6c6083c55970de53ac3(
    *,
    data_source: builtins.str,
    metric: builtins.str,
    name: builtins.str,
    aggregator: typing.Optional[builtins.str] = None,
    cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
    is_normalized_cpu: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
    limit: typing.Optional[jsii.Number] = None,
    sort: typing.Optional[builtins.str] = None,
    tag_filters: typing.Optional[typing.Sequence[builtins.str]] = None,
    text_filter: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__997e9dff862a064d0df207593a68cc43d39c5999cb346e6e65d3ecf7a398e451(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1c7fea2604037af8dc53509eeeb573f340ed02d3aafe26e7c5211a3d3fd04f82(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2860483dd5f2aa700abfbcd152ba5121822e3d48b09df10c7b5ce1981c07cdf4(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__26803bdd5671d42be3574f7626f8baa90115960875bc62262c4f1641b54d3084(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dc829c846797c98b40ca7b5e1a06712c49eb23c5b3363e41b27d32d2880bdc8f(
    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6f94929a6def34dd26a28c8c546db2850cee374a295384b3f190e54d999ea29d(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2b9c86f91c1e2242652f297925d7cb76f55310b00fe7485252f802e91b586180(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a692afaedeef3453842f22552b29d2cea8a7b14fe1a6f241deee2e917692f453(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__60780648607583e464b5509df0b73dd50d40513f220cdfd48cf0520ac1d6a385(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__016b5fd0520212a4832487745374ec2f06184a5ea3132bd0cfbe9b04f104a47d(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__32bb0a98caa671105fae61951e1463cb0117218e3901cb2eb6cdd6a15dd29cdb(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0c0d48fb1b523e1e09570834378bbe962cd86c1c8b3a8aa75ee4df9d276c9dbf(
    value: typing.Optional[PowerpackWidgetTreemapDefinitionRequestQueryProcessQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ea4308c7c3381b49675e631884220baee8a3451ac769710e6a898d5d32b5bdc8(
    *,
    data_source: builtins.str,
    measure: builtins.str,
    slo_id: builtins.str,
    additional_query_filters: typing.Optional[builtins.str] = None,
    cross_org_uuids: typing.Optional[typing.Sequence[builtins.str]] = None,
    group_mode: typing.Optional[builtins.str] = None,
    name: typing.Optional[builtins.str] = None,
    slo_query_type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6495b8b73fbb3b90ece65b3ce49b36f414c2a9f4c5dd6f1149ef6bfea25e267b(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6ea5d9160b698554cb6385e9c7536481c3b19335dad1a356209c02c46521e6bd(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0503a3dec02636efbb4fe69f54e35dffec976d06283a92f1ccc430578ee0e09c(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__145ab596ec16985fdb8c33376bb5217e0888a4b29b4ced1690fbf1ef9e7d4132(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a64ae871c1fe72bc0e44e5d17f16d2cad77b34c1fa44cced9a32cd8e6e332873(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f14c962f2eed1d1ae67278d8adc7745e822de62c9d266548f72b2ac29607efa4(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3dd05ad089d67ae3bab3dd2a7a8608b972af0a7e3c34a5d0a718661b01ac5e15(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__648074aa77bbb573a41e2f35b5645f9167ab9a7399681f159a805e6ea987b1f8(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e8540f53f4b7ca955392de749c16a56ac9192180d4cd6c0f6090a12f2747cab1(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6148359312b547a685b5be260ed463469f28e5d2b3df4d8eba7fbc320d41c360(
    value: typing.Optional[PowerpackWidgetTreemapDefinitionRequestQuerySloQuery],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ec5a54099ae59cb92b8568d6a8efc175973a02f46c1a075bb5940caff2fa83f1(
    *,
    height: jsii.Number,
    width: jsii.Number,
    x: jsii.Number,
    y: jsii.Number,
    is_column_break: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d87bbbf3d7d5eebd1c031a6dbabf58b35e0ec70b091c9b05c8cf51a0f8d4bf96(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__06537abd922b9bf902114684d647455e1572a0ef1a611a7642bfbc1e60ffe354(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__037bb97e6726d8ab1144693ccb84d8d99b0b5c4572d3121381b8e6671ec73ea0(
    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dc467eece6d9f9c7c270563c5a30eceebed2197563203439d999ef9602cd0126(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1c49fed4b0dfdad0999f4324e2714e0226d56c1c73f022d5e45cfb44eb06cd3a(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d576cec1ab1734cbd58809b901adc984855a804e0701545c3b7e213260905e04(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b404a1c3944998cde43c69085b82e3224a43fda522e42a59928e1dc858da3113(
    value: typing.Optional[PowerpackWidgetWidgetLayout],
) -> None:
    """Type checking stubs"""
    pass
